""" Cisco_IOS_XR_ifmgr_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ifmgr package configuration.

This module contains definitions
for the following management objects\:
  global\-interface\-configuration\: Global scoped configuration
    for interfaces
  interface\-configurations\: interface configurations

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class InterfaceModeEnum(Enum):
    """
    InterfaceModeEnum

    Interface mode enum

    .. data:: default = 0

    	Default Interface Mode

    .. data:: point_to_point = 1

    	Point-to-Point Interface Mode

    .. data:: multipoint = 2

    	Multipoint Interface Mode

    .. data:: l2_transport = 3

    	L2 Transport Interface Mode

    """

    default = Enum.YLeaf(0, "default")

    point_to_point = Enum.YLeaf(1, "point-to-point")

    multipoint = Enum.YLeaf(2, "multipoint")

    l2_transport = Enum.YLeaf(3, "l2-transport")


class LinkStatusEnum(Enum):
    """
    LinkStatusEnum

    Link status enum

    .. data:: default = 0

    	Display link status messages for physical links

    .. data:: disable = 1

    	Disable link status messages

    .. data:: software_interfaces = 2

    	Display link status messages for all interfaces

    """

    default = Enum.YLeaf(0, "default")

    disable = Enum.YLeaf(1, "disable")

    software_interfaces = Enum.YLeaf(2, "software-interfaces")


class SecondaryAdminStateEnum(Enum):
    """
    SecondaryAdminStateEnum

    Secondary admin state enum

    .. data:: maintenance = 1

    	Maintenance Mode

    """

    maintenance = Enum.YLeaf(1, "maintenance")



class GlobalInterfaceConfiguration(Entity):
    """
    Global scoped configuration for interfaces
    
    .. attribute:: link_status
    
    	Enable or disable link\-status messages
    	**type**\:   :py:class:`LinkStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.LinkStatusEnum>`
    
    	**default value**\: default
    
    

    """

    _prefix = 'ifmgr-cfg'
    _revision = '2015-07-30'

    def __init__(self):
        super(GlobalInterfaceConfiguration, self).__init__()
        self._top_entity = None

        self.yang_name = "global-interface-configuration"
        self.yang_parent_name = "Cisco-IOS-XR-ifmgr-cfg"

        self.link_status = YLeaf(YType.enumeration, "link-status")

    def __setattr__(self, name, value):
        self._check_monkey_patching_error(name, value)
        with _handle_type_error():
            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                    "Please use list append or extend method."
                                    .format(value))
            if isinstance(value, Enum.YLeaf):
                value = value.name
            if name in ("link_status") and name in self.__dict__:
                if isinstance(value, YLeaf):
                    self.__dict__[name].set(value.get())
                elif isinstance(value, YLeafList):
                    super(GlobalInterfaceConfiguration, self).__setattr__(name, value)
                else:
                    self.__dict__[name].set(value)
            else:
                if hasattr(value, "parent") and name != "parent":
                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                        value.parent = self
                    elif value.parent is None and value.yang_name in self._children_yang_names:
                        value.parent = self
                super(GlobalInterfaceConfiguration, self).__setattr__(name, value)

    def has_data(self):
        return self.link_status.is_set

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            self.link_status.yfilter != YFilter.not_set)

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ifmgr-cfg:global-interface-configuration" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()
        if (self.link_status.is_set or self.link_status.yfilter != YFilter.not_set):
            leaf_name_data.append(self.link_status.get_name_leafdata())

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "link-status"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        if(value_path == "link-status"):
            self.link_status = value
            self.link_status.value_namespace = name_space
            self.link_status.value_namespace_prefix = name_space_prefix

    def clone_ptr(self):
        self._top_entity = GlobalInterfaceConfiguration()
        return self._top_entity

class InterfaceConfigurations(Entity):
    """
    interface configurations
    
    .. attribute:: interface_configuration
    
    	The configuration for an interface
    	**type**\: list of    :py:class:`InterfaceConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration>`
    
    

    """

    _prefix = 'ifmgr-cfg'
    _revision = '2015-07-30'

    def __init__(self):
        super(InterfaceConfigurations, self).__init__()
        self._top_entity = None

        self.yang_name = "interface-configurations"
        self.yang_parent_name = "Cisco-IOS-XR-ifmgr-cfg"

        self.interface_configuration = YList(self)

    def __setattr__(self, name, value):
        self._check_monkey_patching_error(name, value)
        with _handle_type_error():
            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                    "Please use list append or extend method."
                                    .format(value))
            if isinstance(value, Enum.YLeaf):
                value = value.name
            if name in () and name in self.__dict__:
                if isinstance(value, YLeaf):
                    self.__dict__[name].set(value.get())
                elif isinstance(value, YLeafList):
                    super(InterfaceConfigurations, self).__setattr__(name, value)
                else:
                    self.__dict__[name].set(value)
            else:
                if hasattr(value, "parent") and name != "parent":
                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                        value.parent = self
                    elif value.parent is None and value.yang_name in self._children_yang_names:
                        value.parent = self
                super(InterfaceConfigurations, self).__setattr__(name, value)


    class InterfaceConfiguration(Entity):
        """
        The configuration for an interface
        
        .. attribute:: active  <key>
        
        	Whether the interface is active or preconfigured
        	**type**\:  str
        
        	**pattern:** (act)\|(pre)
        
        .. attribute:: interface_name  <key>
        
        	The name of the interface
        	**type**\:  str
        
        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
        
        .. attribute:: aaa_table
        
        	AAA configuration
        	**type**\:   :py:class:`AaaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.AaaTable>`
        
        .. attribute:: afs
        
        	Per\-address\-family and topology configuration
        	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Afs>`
        
        .. attribute:: atm
        
        	ATM Configuration
        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm>`
        
        .. attribute:: bandwidth
        
        	The bandwidth of the interface in kbps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: kbit/s
        
        .. attribute:: bfd
        
        	BFD over bundle members configuration
        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd>`
        
        .. attribute:: bundle
        
        	Generic per\-bundle configuration
        	**type**\:   :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle>`
        
        .. attribute:: bundle_member
        
        	Generic per\-member configuration
        	**type**\:   :py:class:`BundleMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.BundleMember>`
        
        .. attribute:: bvi
        
        	BVI attributes
        	**type**\:   :py:class:`Bvi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bvi>`
        
        .. attribute:: carrier_delay
        
        	Set the carrier transition delay on an interface in msecs
        	**type**\:   :py:class:`CarrierDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CarrierDelay>`
        
        .. attribute:: cdp
        
        	Interface specific CDP configuration
        	**type**\:   :py:class:`Cdp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Cdp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIosXrPppMaCfg_Ppp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaCfg_Ppp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_fsm_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIosXrPppMaFsmCfg_Ppp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_ipcp_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIosXrPppMaIpcpCfg_Ppp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIosXrPppMaIpcpiwCfg_Ppp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_lcp_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIosXrPppMaLcpCfg_Ppp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp>`
        
        .. attribute:: client_port
        
        	Mxp optics for client ports
        	**type**\:   :py:class:`ClientPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ClientPort>`
        
        .. attribute:: dagrs
        
        	Direct\-Attached Gateway Redundancy configuration
        	**type**\:   :py:class:`Dagrs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs>`
        
        .. attribute:: dampening
        
        	Whether this interface's state changes are dampened or not
        	**type**\:   :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dampening>`
        
        .. attribute:: description
        
        	The description of this interface
        	**type**\:  str
        
        .. attribute:: dwdm
        
        	DWDM port controller configuration
        	**type**\:   :py:class:`Dwdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm>`
        
        .. attribute:: encapsulation
        
        	The encapsulation on the interface
        	**type**\:   :py:class:`Encapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Encapsulation>`
        
        .. attribute:: es_packet_filter
        
        	ES Packet Filtering configuration for the interface
        	**type**\:   :py:class:`EsPacketFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter>`
        
        .. attribute:: ethernet
        
        	Ether specific interface configuration
        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet>`
        
        .. attribute:: ethernet_bng
        
        	Ethernet Infra BNG specific configuration
        	**type**\:   :py:class:`EthernetBng <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetBng>`
        
        .. attribute:: ethernet_control
        
        	EthernetControl
        	**type**\:   :py:class:`EthernetControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetControl>`
        
        .. attribute:: ethernet_features
        
        	Ethernet Features Configuration
        	**type**\:   :py:class:`EthernetFeatures <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures>`
        
        .. attribute:: ethernet_service
        
        	Ethernet service configuration
        	**type**\:   :py:class:`EthernetService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService>`
        
        .. attribute:: interface_mode_non_physical
        
        	The mode in which an interface is running. The existence of this object causes the creation of the software subinterface
        	**type**\:   :py:class:`InterfaceModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceModeEnum>`
        
        	**default value**\: default
        
        .. attribute:: interface_virtual
        
        	The mode in which an interface is running. The existence of this object causes the creation of the software virtual/subinterface
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: ipv4_network
        
        	Interface IPv4 Network configuration data
        	**type**\:   :py:class:`Ipv4Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network>`
        
        .. attribute:: ipv4_network_forwarding
        
        	Interface IPv4 Network configuration data also used for forwarding
        	**type**\:   :py:class:`Ipv4NetworkForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding>`
        
        .. attribute:: ipv4_packet_filter
        
        	IPv4 Packet Filtering configuration for the interface
        	**type**\:   :py:class:`Ipv4PacketFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter>`
        
        .. attribute:: ipv4arp
        
        	Configure Address Resolution Protocol
        	**type**\:   :py:class:`Ipv4Arp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp>`
        
        .. attribute:: ipv6_neighbor
        
        	IPv6 interface neighbor or neighbor discovery configuration
        	**type**\:   :py:class:`Ipv6Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor>`
        
        .. attribute:: ipv6_network
        
        	Interface IPv6 Network configuration data
        	**type**\:   :py:class:`Ipv6Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network>`
        
        .. attribute:: ipv6_packet_filter
        
        	IPv6 Packet Filtering configuration for the interface
        	**type**\:   :py:class:`Ipv6PacketFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter>`
        
        .. attribute:: l2_transport
        
        	Interface Layer 2 Transport service configuration data
        	**type**\:   :py:class:`L2Transport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport>`
        
        .. attribute:: lacp
        
        	Link Aggregation Control Protocol per\-interface configuration (for bundle or member)
        	**type**\:   :py:class:`Lacp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lacp>`
        
        .. attribute:: laser_squelch
        
        	Configure Laser\-Squelch
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: link_status
        
        	Enable interface and line\-protocol state change alarms
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: lldp
        
        	Disable LLDP TX or RX
        	**type**\:   :py:class:`Lldp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lldp>`
        
        	**presence node**\: True
        
        .. attribute:: mac_accounting
        
        	MAC Accounting Configuration
        	**type**\:   :py:class:`MacAccounting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MacAccounting>`
        
        .. attribute:: mac_addr
        
        	Set the Mac address on an interface
        	**type**\:  str
        
        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
        
        .. attribute:: macsec
        
        	MACSec service for an interface
        	**type**\:   :py:class:`Macsec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec>`
        
        .. attribute:: maintenance_embargo
        
        	configure maintenance embargo flag on the given interface
        	**type**\:  bool
        
        .. attribute:: mlacp
        
        	Multi\-chassis LACP configuration
        	**type**\:   :py:class:`Mlacp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mlacp>`
        
        .. attribute:: mte_tunnel_attributes
        
        	MPLS P2MP tunnel attributes
        	**type**\:   :py:class:`MteTunnelAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes>`
        
        .. attribute:: mtus
        
        	The MTU configuration for the interface
        	**type**\:   :py:class:`Mtus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mtus>`
        
        .. attribute:: net_flow
        
        	Interface netflow configuration
        	**type**\:   :py:class:`NetFlow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow>`
        
        .. attribute:: nv_satellite_access
        
        	nV Satellite Access Link Configuration
        	**type**\:   :py:class:`NvSatelliteAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess>`
        
        .. attribute:: nv_satellite_fabric_link
        
        	nV Satellite Fabric Link Configuration
        	**type**\:   :py:class:`NvSatelliteFabricLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink>`
        
        .. attribute:: nv_satellite_fabric_network
        
        	Complex Network connection to one or more Satellites
        	**type**\:   :py:class:`NvSatelliteFabricNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork>`
        
        .. attribute:: nve
        
        	NVE operational data
        	**type**\:   :py:class:`Nve <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve>`
        
        .. attribute:: optics
        
        	Optics controller configuration
        	**type**\:   :py:class:`Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics>`
        
        .. attribute:: otu
        
        	OTU port controller configuration
        	**type**\:   :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu>`
        
        .. attribute:: pbr
        
        	Interface PBR configuration
        	**type**\:   :py:class:`Pbr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pbr>`
        
        .. attribute:: perf_mon_disable
        
        	Configure Performance Monitoring 
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: performance_management
        
        	Configure pm parameters
        	**type**\:   :py:class:`PerformanceManagement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement>`
        
        .. attribute:: portmode
        
        	Configure through port\-mode
        	**type**\:   :py:class:`Portmode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Portmode>`
        
        .. attribute:: pppoe
        
        	Interface PPPoE configuration data
        	**type**\:   :py:class:`Pppoe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pppoe>`
        
        .. attribute:: pseudowire_ether
        
        	PW\-Ether attributes
        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PseudowireEther>`
        
        .. attribute:: pseudowire_iw
        
        	PW\-IW attributes
        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PseudowireIw>`
        
        .. attribute:: qos
        
        	Interface QOS configuration
        	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos>`
        
        .. attribute:: secondary_admin_state
        
        	The secondary admin state of the interface
        	**type**\:   :py:class:`SecondaryAdminStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.SecondaryAdminStateEnum>`
        
        .. attribute:: service_policies
        
        	Interface control subscriber policy configuration
        	**type**\:   :py:class:`ServicePolicies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ServicePolicies>`
        
        .. attribute:: shutdown
        
        	The existence of this configuration indicates the interface is shut down
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: span_monitor_sessions
        
        	Monitor Session container for this source interface
        	**type**\:   :py:class:`SpanMonitorSessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions>`
        
        .. attribute:: ssrp_session
        
        	SSRP Config
        	**type**\:   :py:class:`SsrpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SsrpSession>`
        
        .. attribute:: statistics
        
        	Per\-interface statistics configuration
        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Statistics>`
        
        .. attribute:: subscriber
        
        	Subscribers on interface
        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber>`
        
        .. attribute:: track_name
        
        	Track Name
        	**type**\:  str
        
        	**length:** 1..32
        
        .. attribute:: transport_profile_tunnel
        
        	MPLS\-TP tunnel attributes
        	**type**\:   :py:class:`TransportProfileTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel>`
        
        .. attribute:: tunnel_ip
        
        	IP over GRE encapsulation
        	**type**\:   :py:class:`TunnelIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp>`
        
        .. attribute:: tunnel_te_attributes
        
        	MPLS tunnel attributes
        	**type**\:   :py:class:`TunnelTeAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes>`
        
        .. attribute:: vlan_sub_configuration
        
        	IEEE 802.1Q VLAN subinterface configuration
        	**type**\:   :py:class:`VlanSubConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration>`
        
        .. attribute:: vlan_trunk_configuration
        
        	IEEE 802.1Q VLAN trunk interface configuration
        	**type**\:   :py:class:`VlanTrunkConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration>`
        
        .. attribute:: vrf
        
        	Assign the interface to a VRF
        	**type**\:  str
        
        	**length:** 1..32
        
        .. attribute:: wanphy
        
        	WANPHY port controller configuration
        	**type**\:   :py:class:`Wanphy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Wanphy>`
        
        

        """

        _prefix = 'ifmgr-cfg'
        _revision = '2015-07-30'

        def __init__(self):
            super(InterfaceConfigurations.InterfaceConfiguration, self).__init__()

            self.yang_name = "interface-configuration"
            self.yang_parent_name = "interface-configurations"

            self.active = YLeaf(YType.str, "active")

            self.interface_name = YLeaf(YType.str, "interface-name")

            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

            self.description = YLeaf(YType.str, "description")

            self.interface_mode_non_physical = YLeaf(YType.enumeration, "interface-mode-non-physical")

            self.interface_virtual = YLeaf(YType.empty, "interface-virtual")

            self.laser_squelch = YLeaf(YType.empty, "Cisco-IOS-XR-drivers-icpe-ethernet-cfg:laser-squelch")

            self.link_status = YLeaf(YType.empty, "link-status")

            self.mac_addr = YLeaf(YType.str, "Cisco-IOS-XR-mdrv-lib-cfg:mac-addr")

            self.maintenance_embargo = YLeaf(YType.boolean, "Cisco-IOS-XR-dwdm-ui-cfg:maintenance-embargo")

            self.perf_mon_disable = YLeaf(YType.empty, "Cisco-IOS-XR-drivers-icpe-ethernet-cfg:perf-mon-disable")

            self.secondary_admin_state = YLeaf(YType.enumeration, "secondary-admin-state")

            self.shutdown = YLeaf(YType.empty, "shutdown")

            self.track_name = YLeaf(YType.str, "Cisco-IOS-XR-manageability-object-tracking-cfg:track-name")

            self.vrf = YLeaf(YType.str, "Cisco-IOS-XR-infra-rsi-cfg:vrf")

            self.aaa_table = InterfaceConfigurations.InterfaceConfiguration.AaaTable()
            self.aaa_table.parent = self
            self._children_name_map["aaa_table"] = "aaa-table"
            self._children_yang_names.add("aaa-table")

            self.afs = InterfaceConfigurations.InterfaceConfiguration.Afs()
            self.afs.parent = self
            self._children_name_map["afs"] = "afs"
            self._children_yang_names.add("afs")

            self.atm = InterfaceConfigurations.InterfaceConfiguration.Atm()
            self.atm.parent = self
            self._children_name_map["atm"] = "atm"
            self._children_yang_names.add("atm")

            self.bfd = InterfaceConfigurations.InterfaceConfiguration.Bfd()
            self.bfd.parent = self
            self._children_name_map["bfd"] = "bfd"
            self._children_yang_names.add("bfd")

            self.bundle = InterfaceConfigurations.InterfaceConfiguration.Bundle()
            self.bundle.parent = self
            self._children_name_map["bundle"] = "bundle"
            self._children_yang_names.add("bundle")

            self.bundle_member = InterfaceConfigurations.InterfaceConfiguration.BundleMember()
            self.bundle_member.parent = self
            self._children_name_map["bundle_member"] = "bundle-member"
            self._children_yang_names.add("bundle-member")

            self.bvi = InterfaceConfigurations.InterfaceConfiguration.Bvi()
            self.bvi.parent = self
            self._children_name_map["bvi"] = "bvi"
            self._children_yang_names.add("bvi")

            self.carrier_delay = InterfaceConfigurations.InterfaceConfiguration.CarrierDelay()
            self.carrier_delay.parent = self
            self._children_name_map["carrier_delay"] = "carrier-delay"
            self._children_yang_names.add("carrier-delay")

            self.cdp = InterfaceConfigurations.InterfaceConfiguration.Cdp()
            self.cdp.parent = self
            self._children_name_map["cdp"] = "cdp"
            self._children_yang_names.add("cdp")

            self.cisco_ios_xr_ppp_ma_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaCfg_Ppp()
            self.cisco_ios_xr_ppp_ma_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp()
            self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_fsm_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp()
            self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_ipcp_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp()
            self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp()
            self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_lcp_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp")

            self.client_port = InterfaceConfigurations.InterfaceConfiguration.ClientPort()
            self.client_port.parent = self
            self._children_name_map["client_port"] = "client-port"
            self._children_yang_names.add("client-port")

            self.dagrs = InterfaceConfigurations.InterfaceConfiguration.Dagrs()
            self.dagrs.parent = self
            self._children_name_map["dagrs"] = "dagrs"
            self._children_yang_names.add("dagrs")

            self.dampening = InterfaceConfigurations.InterfaceConfiguration.Dampening()
            self.dampening.parent = self
            self._children_name_map["dampening"] = "dampening"
            self._children_yang_names.add("dampening")

            self.dwdm = InterfaceConfigurations.InterfaceConfiguration.Dwdm()
            self.dwdm.parent = self
            self._children_name_map["dwdm"] = "dwdm"
            self._children_yang_names.add("dwdm")

            self.encapsulation = InterfaceConfigurations.InterfaceConfiguration.Encapsulation()
            self.encapsulation.parent = self
            self._children_name_map["encapsulation"] = "encapsulation"
            self._children_yang_names.add("encapsulation")

            self.es_packet_filter = InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter()
            self.es_packet_filter.parent = self
            self._children_name_map["es_packet_filter"] = "es-packet-filter"
            self._children_yang_names.add("es-packet-filter")

            self.ethernet = InterfaceConfigurations.InterfaceConfiguration.Ethernet()
            self.ethernet.parent = self
            self._children_name_map["ethernet"] = "ethernet"
            self._children_yang_names.add("ethernet")

            self.ethernet_bng = InterfaceConfigurations.InterfaceConfiguration.EthernetBng()
            self.ethernet_bng.parent = self
            self._children_name_map["ethernet_bng"] = "ethernet-bng"
            self._children_yang_names.add("ethernet-bng")

            self.ethernet_control = InterfaceConfigurations.InterfaceConfiguration.EthernetControl()
            self.ethernet_control.parent = self
            self._children_name_map["ethernet_control"] = "ethernet-control"
            self._children_yang_names.add("ethernet-control")

            self.ethernet_features = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures()
            self.ethernet_features.parent = self
            self._children_name_map["ethernet_features"] = "ethernet-features"
            self._children_yang_names.add("ethernet-features")

            self.ethernet_service = InterfaceConfigurations.InterfaceConfiguration.EthernetService()
            self.ethernet_service.parent = self
            self._children_name_map["ethernet_service"] = "ethernet-service"
            self._children_yang_names.add("ethernet-service")

            self.ipv4_network = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network()
            self.ipv4_network.parent = self
            self._children_name_map["ipv4_network"] = "ipv4-network"
            self._children_yang_names.add("ipv4-network")

            self.ipv4_network_forwarding = InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding()
            self.ipv4_network_forwarding.parent = self
            self._children_name_map["ipv4_network_forwarding"] = "ipv4-network-forwarding"
            self._children_yang_names.add("ipv4-network-forwarding")

            self.ipv4_packet_filter = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter()
            self.ipv4_packet_filter.parent = self
            self._children_name_map["ipv4_packet_filter"] = "ipv4-packet-filter"
            self._children_yang_names.add("ipv4-packet-filter")

            self.ipv4arp = InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp()
            self.ipv4arp.parent = self
            self._children_name_map["ipv4arp"] = "ipv4arp"
            self._children_yang_names.add("ipv4arp")

            self.ipv6_neighbor = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor()
            self.ipv6_neighbor.parent = self
            self._children_name_map["ipv6_neighbor"] = "ipv6-neighbor"
            self._children_yang_names.add("ipv6-neighbor")

            self.ipv6_network = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network()
            self.ipv6_network.parent = self
            self._children_name_map["ipv6_network"] = "ipv6-network"
            self._children_yang_names.add("ipv6-network")

            self.ipv6_packet_filter = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter()
            self.ipv6_packet_filter.parent = self
            self._children_name_map["ipv6_packet_filter"] = "ipv6-packet-filter"
            self._children_yang_names.add("ipv6-packet-filter")

            self.l2_transport = InterfaceConfigurations.InterfaceConfiguration.L2Transport()
            self.l2_transport.parent = self
            self._children_name_map["l2_transport"] = "l2-transport"
            self._children_yang_names.add("l2-transport")

            self.lacp = InterfaceConfigurations.InterfaceConfiguration.Lacp()
            self.lacp.parent = self
            self._children_name_map["lacp"] = "lacp"
            self._children_yang_names.add("lacp")

            self.lldp = None
            self._children_name_map["lldp"] = "lldp"
            self._children_yang_names.add("lldp")

            self.mac_accounting = InterfaceConfigurations.InterfaceConfiguration.MacAccounting()
            self.mac_accounting.parent = self
            self._children_name_map["mac_accounting"] = "mac-accounting"
            self._children_yang_names.add("mac-accounting")

            self.macsec = InterfaceConfigurations.InterfaceConfiguration.Macsec()
            self.macsec.parent = self
            self._children_name_map["macsec"] = "macsec"
            self._children_yang_names.add("macsec")

            self.mlacp = InterfaceConfigurations.InterfaceConfiguration.Mlacp()
            self.mlacp.parent = self
            self._children_name_map["mlacp"] = "mlacp"
            self._children_yang_names.add("mlacp")

            self.mte_tunnel_attributes = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes()
            self.mte_tunnel_attributes.parent = self
            self._children_name_map["mte_tunnel_attributes"] = "mte-tunnel-attributes"
            self._children_yang_names.add("mte-tunnel-attributes")

            self.mtus = InterfaceConfigurations.InterfaceConfiguration.Mtus()
            self.mtus.parent = self
            self._children_name_map["mtus"] = "mtus"
            self._children_yang_names.add("mtus")

            self.net_flow = InterfaceConfigurations.InterfaceConfiguration.NetFlow()
            self.net_flow.parent = self
            self._children_name_map["net_flow"] = "net-flow"
            self._children_yang_names.add("net-flow")

            self.nv_satellite_access = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess()
            self.nv_satellite_access.parent = self
            self._children_name_map["nv_satellite_access"] = "nv-satellite-access"
            self._children_yang_names.add("nv-satellite-access")

            self.nv_satellite_fabric_link = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink()
            self.nv_satellite_fabric_link.parent = self
            self._children_name_map["nv_satellite_fabric_link"] = "nv-satellite-fabric-link"
            self._children_yang_names.add("nv-satellite-fabric-link")

            self.nv_satellite_fabric_network = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork()
            self.nv_satellite_fabric_network.parent = self
            self._children_name_map["nv_satellite_fabric_network"] = "nv-satellite-fabric-network"
            self._children_yang_names.add("nv-satellite-fabric-network")

            self.nve = InterfaceConfigurations.InterfaceConfiguration.Nve()
            self.nve.parent = self
            self._children_name_map["nve"] = "nve"
            self._children_yang_names.add("nve")

            self.optics = InterfaceConfigurations.InterfaceConfiguration.Optics()
            self.optics.parent = self
            self._children_name_map["optics"] = "optics"
            self._children_yang_names.add("optics")

            self.otu = InterfaceConfigurations.InterfaceConfiguration.Otu()
            self.otu.parent = self
            self._children_name_map["otu"] = "otu"
            self._children_yang_names.add("otu")

            self.pbr = InterfaceConfigurations.InterfaceConfiguration.Pbr()
            self.pbr.parent = self
            self._children_name_map["pbr"] = "pbr"
            self._children_yang_names.add("pbr")

            self.performance_management = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement()
            self.performance_management.parent = self
            self._children_name_map["performance_management"] = "performance-management"
            self._children_yang_names.add("performance-management")

            self.portmode = InterfaceConfigurations.InterfaceConfiguration.Portmode()
            self.portmode.parent = self
            self._children_name_map["portmode"] = "portmode"
            self._children_yang_names.add("portmode")

            self.pppoe = InterfaceConfigurations.InterfaceConfiguration.Pppoe()
            self.pppoe.parent = self
            self._children_name_map["pppoe"] = "pppoe"
            self._children_yang_names.add("pppoe")

            self.pseudowire_ether = InterfaceConfigurations.InterfaceConfiguration.PseudowireEther()
            self.pseudowire_ether.parent = self
            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
            self._children_yang_names.add("pseudowire-ether")

            self.pseudowire_iw = InterfaceConfigurations.InterfaceConfiguration.PseudowireIw()
            self.pseudowire_iw.parent = self
            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
            self._children_yang_names.add("pseudowire-iw")

            self.qos = InterfaceConfigurations.InterfaceConfiguration.Qos()
            self.qos.parent = self
            self._children_name_map["qos"] = "qos"
            self._children_yang_names.add("qos")

            self.service_policies = InterfaceConfigurations.InterfaceConfiguration.ServicePolicies()
            self.service_policies.parent = self
            self._children_name_map["service_policies"] = "service-policies"
            self._children_yang_names.add("service-policies")

            self.span_monitor_sessions = InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions()
            self.span_monitor_sessions.parent = self
            self._children_name_map["span_monitor_sessions"] = "span-monitor-sessions"
            self._children_yang_names.add("span-monitor-sessions")

            self.ssrp_session = InterfaceConfigurations.InterfaceConfiguration.SsrpSession()
            self.ssrp_session.parent = self
            self._children_name_map["ssrp_session"] = "ssrp-session"
            self._children_yang_names.add("ssrp-session")

            self.statistics = InterfaceConfigurations.InterfaceConfiguration.Statistics()
            self.statistics.parent = self
            self._children_name_map["statistics"] = "statistics"
            self._children_yang_names.add("statistics")

            self.subscriber = InterfaceConfigurations.InterfaceConfiguration.Subscriber()
            self.subscriber.parent = self
            self._children_name_map["subscriber"] = "subscriber"
            self._children_yang_names.add("subscriber")

            self.transport_profile_tunnel = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel()
            self.transport_profile_tunnel.parent = self
            self._children_name_map["transport_profile_tunnel"] = "transport-profile-tunnel"
            self._children_yang_names.add("transport-profile-tunnel")

            self.tunnel_ip = InterfaceConfigurations.InterfaceConfiguration.TunnelIp()
            self.tunnel_ip.parent = self
            self._children_name_map["tunnel_ip"] = "tunnel-ip"
            self._children_yang_names.add("tunnel-ip")

            self.tunnel_te_attributes = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes()
            self.tunnel_te_attributes.parent = self
            self._children_name_map["tunnel_te_attributes"] = "tunnel-te-attributes"
            self._children_yang_names.add("tunnel-te-attributes")

            self.vlan_sub_configuration = InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration()
            self.vlan_sub_configuration.parent = self
            self._children_name_map["vlan_sub_configuration"] = "vlan-sub-configuration"
            self._children_yang_names.add("vlan-sub-configuration")

            self.vlan_trunk_configuration = InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration()
            self.vlan_trunk_configuration.parent = self
            self._children_name_map["vlan_trunk_configuration"] = "vlan-trunk-configuration"
            self._children_yang_names.add("vlan-trunk-configuration")

            self.wanphy = InterfaceConfigurations.InterfaceConfiguration.Wanphy()
            self.wanphy.parent = self
            self._children_name_map["wanphy"] = "wanphy"
            self._children_yang_names.add("wanphy")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("active",
                            "interface_name",
                            "bandwidth",
                            "description",
                            "interface_mode_non_physical",
                            "interface_virtual",
                            "laser_squelch",
                            "link_status",
                            "mac_addr",
                            "maintenance_embargo",
                            "perf_mon_disable",
                            "secondary_admin_state",
                            "shutdown",
                            "track_name",
                            "vrf") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(InterfaceConfigurations.InterfaceConfiguration, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(InterfaceConfigurations.InterfaceConfiguration, self).__setattr__(name, value)


        class Dampening(Entity):
            """
            Whether this interface's state changes are
            dampened or not
            
            .. attribute:: args
            
            	Dampening Arguments
            	**type**\:   :py:class:`Args <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dampening.Args>`
            
            .. attribute:: half_life
            
            	Decay half life (in minutes)
            	**type**\:  int
            
            	**range:** 1..45
            
            	**units**\: minute
            
            .. attribute:: restart_penalty
            
            	Restart penalty
            	**type**\:  int
            
            	**range:** 0..20000
            
            .. attribute:: reuse_threshold
            
            	Reuse threshold
            	**type**\:  int
            
            	**range:** 1..20000
            
            .. attribute:: suppress_threshold
            
            	Suppress threshold
            	**type**\:  int
            
            	**range:** 1..20000
            
            .. attribute:: suppress_time
            
            	Max suppress time (in minutes)
            	**type**\:  int
            
            	**range:** 1..255
            
            	**units**\: minute
            
            

            """

            _prefix = 'ifmgr-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dampening, self).__init__()

                self.yang_name = "dampening"
                self.yang_parent_name = "interface-configuration"

                self.args = YLeaf(YType.enumeration, "args")

                self.half_life = YLeaf(YType.uint32, "half-life")

                self.restart_penalty = YLeaf(YType.uint32, "restart-penalty")

                self.reuse_threshold = YLeaf(YType.uint32, "reuse-threshold")

                self.suppress_threshold = YLeaf(YType.uint32, "suppress-threshold")

                self.suppress_time = YLeaf(YType.uint32, "suppress-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("args",
                                "half_life",
                                "restart_penalty",
                                "reuse_threshold",
                                "suppress_threshold",
                                "suppress_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dampening, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Dampening, self).__setattr__(name, value)

            class Args(Enum):
                """
                Args

                Dampening Arguments

                .. data:: default_values = 0

                	Default values

                .. data:: specify_half_life = 1

                	Half Life Specified

                .. data:: specify_all = 4

                	All Arguments except Restart Penalty

                	Specified

                .. data:: specify_rp = 5

                	All Arguments Specified

                """

                default_values = Enum.YLeaf(0, "default-values")

                specify_half_life = Enum.YLeaf(1, "specify-half-life")

                specify_all = Enum.YLeaf(4, "specify-all")

                specify_rp = Enum.YLeaf(5, "specify-rp")


            def has_data(self):
                return (
                    self.args.is_set or
                    self.half_life.is_set or
                    self.restart_penalty.is_set or
                    self.reuse_threshold.is_set or
                    self.suppress_threshold.is_set or
                    self.suppress_time.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.args.yfilter != YFilter.not_set or
                    self.half_life.yfilter != YFilter.not_set or
                    self.restart_penalty.yfilter != YFilter.not_set or
                    self.reuse_threshold.yfilter != YFilter.not_set or
                    self.suppress_threshold.yfilter != YFilter.not_set or
                    self.suppress_time.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "dampening" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.args.is_set or self.args.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.args.get_name_leafdata())
                if (self.half_life.is_set or self.half_life.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.half_life.get_name_leafdata())
                if (self.restart_penalty.is_set or self.restart_penalty.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_penalty.get_name_leafdata())
                if (self.reuse_threshold.is_set or self.reuse_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reuse_threshold.get_name_leafdata())
                if (self.suppress_threshold.is_set or self.suppress_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.suppress_threshold.get_name_leafdata())
                if (self.suppress_time.is_set or self.suppress_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.suppress_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "args" or name == "half-life" or name == "restart-penalty" or name == "reuse-threshold" or name == "suppress-threshold" or name == "suppress-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "args"):
                    self.args = value
                    self.args.value_namespace = name_space
                    self.args.value_namespace_prefix = name_space_prefix
                if(value_path == "half-life"):
                    self.half_life = value
                    self.half_life.value_namespace = name_space
                    self.half_life.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-penalty"):
                    self.restart_penalty = value
                    self.restart_penalty.value_namespace = name_space
                    self.restart_penalty.value_namespace_prefix = name_space_prefix
                if(value_path == "reuse-threshold"):
                    self.reuse_threshold = value
                    self.reuse_threshold.value_namespace = name_space
                    self.reuse_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "suppress-threshold"):
                    self.suppress_threshold = value
                    self.suppress_threshold.value_namespace = name_space
                    self.suppress_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "suppress-time"):
                    self.suppress_time = value
                    self.suppress_time.value_namespace = name_space
                    self.suppress_time.value_namespace_prefix = name_space_prefix


        class Mtus(Entity):
            """
            The MTU configuration for the interface
            
            .. attribute:: mtu
            
            	The MTU for the interface
            	**type**\: list of    :py:class:`Mtu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu>`
            
            

            """

            _prefix = 'ifmgr-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Mtus, self).__init__()

                self.yang_name = "mtus"
                self.yang_parent_name = "interface-configuration"

                self.mtu = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Mtus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Mtus, self).__setattr__(name, value)


            class Mtu(Entity):
                """
                The MTU for the interface
                
                .. attribute:: owner  <key>
                
                	The Owner of the interface \- eg. for 'LoopbackX' main interface this is 'loopback'
                	**type**\:  str
                
                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                
                .. attribute:: mtu
                
                	The MTU value
                	**type**\:  int
                
                	**range:** 64..65535
                
                	**mandatory**\: True
                
                

                """

                _prefix = 'ifmgr-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu, self).__init__()

                    self.yang_name = "mtu"
                    self.yang_parent_name = "mtus"

                    self.owner = YLeaf(YType.str, "owner")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("owner",
                                    "mtu") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.owner.is_set or
                        self.mtu.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.owner.yfilter != YFilter.not_set or
                        self.mtu.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mtu" + "[owner='" + self.owner.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.owner.is_set or self.owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.owner.get_name_leafdata())
                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "owner" or name == "mtu"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "owner"):
                        self.owner = value
                        self.owner.value_namespace = name_space
                        self.owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu"):
                        self.mtu = value
                        self.mtu.value_namespace = name_space
                        self.mtu.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mtu:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mtu:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mtus" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mtu"):
                    for c in self.mtu:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mtu.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mtu"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Encapsulation(Entity):
            """
            The encapsulation on the interface
            
            .. attribute:: capsulation_options
            
            	The options for this capsulation, usually '0'
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: encapsulation
            
            	The encapsulation \- e.g. hdlc, ppp
            	**type**\:  str
            
            

            """

            _prefix = 'ifmgr-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Encapsulation, self).__init__()

                self.yang_name = "encapsulation"
                self.yang_parent_name = "interface-configuration"

                self.capsulation_options = YLeaf(YType.int32, "capsulation-options")

                self.encapsulation = YLeaf(YType.str, "encapsulation")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("capsulation_options",
                                "encapsulation") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Encapsulation, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Encapsulation, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.capsulation_options.is_set or
                    self.encapsulation.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.capsulation_options.yfilter != YFilter.not_set or
                    self.encapsulation.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "encapsulation" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.capsulation_options.is_set or self.capsulation_options.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.capsulation_options.get_name_leafdata())
                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "capsulation-options" or name == "encapsulation"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "capsulation-options"):
                    self.capsulation_options = value
                    self.capsulation_options.value_namespace = name_space
                    self.capsulation_options.value_namespace_prefix = name_space_prefix
                if(value_path == "encapsulation"):
                    self.encapsulation = value
                    self.encapsulation.value_namespace = name_space
                    self.encapsulation.value_namespace_prefix = name_space_prefix


        class AaaTable(Entity):
            """
            AAA configuration
            
            .. attribute:: radius
            
            	AAA radius configuration
            	**type**\:   :py:class:`Radius <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius>`
            
            

            """

            _prefix = 'aaa-aaacore-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.AaaTable, self).__init__()

                self.yang_name = "aaa-table"
                self.yang_parent_name = "interface-configuration"

                self.radius = InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius()
                self.radius.parent = self
                self._children_name_map["radius"] = "radius"
                self._children_yang_names.add("radius")


            class Radius(Entity):
                """
                AAA radius configuration
                
                .. attribute:: attribute
                
                	AAA radius attribute
                	**type**\:   :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute>`
                
                

                """

                _prefix = 'aaa-aaacore-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius, self).__init__()

                    self.yang_name = "radius"
                    self.yang_parent_name = "aaa-table"

                    self.attribute = InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute()
                    self.attribute.parent = self
                    self._children_name_map["attribute"] = "attribute"
                    self._children_yang_names.add("attribute")


                class Attribute(Entity):
                    """
                    AAA radius attribute
                    
                    .. attribute:: nas_port_type
                    
                    	AAA nas\-port\-type attribute
                    	**type**\:   :py:class:`NasPortValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_aaa_aaacore_cfg.NasPortValue>`
                    
                    

                    """

                    _prefix = 'aaa-aaacore-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute, self).__init__()

                        self.yang_name = "attribute"
                        self.yang_parent_name = "radius"

                        self.nas_port_type = YLeaf(YType.enumeration, "nas-port-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("nas_port_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute, self).__setattr__(name, value)

                    def has_data(self):
                        return self.nas_port_type.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.nas_port_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "attribute" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.nas_port_type.is_set or self.nas_port_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nas_port_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nas-port-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "nas-port-type"):
                            self.nas_port_type = value
                            self.nas_port_type.value_namespace = name_space
                            self.nas_port_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.attribute is not None and self.attribute.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.attribute is not None and self.attribute.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "radius" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "attribute"):
                        if (self.attribute is None):
                            self.attribute = InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute()
                            self.attribute.parent = self
                            self._children_name_map["attribute"] = "attribute"
                        return self.attribute

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "attribute"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.radius is not None and self.radius.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.radius is not None and self.radius.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-aaa-aaacore-cfg:aaa-table" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "radius"):
                    if (self.radius is None):
                        self.radius = InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius()
                        self.radius.parent = self
                        self._children_name_map["radius"] = "radius"
                    return self.radius

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "radius"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EthernetControl(Entity):
            """
            EthernetControl
            
            .. attribute:: small_frame_padding
            
            	Enable small frame padding on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: transceiver
            
            	Transceiver
            	**type**\:   :py:class:`Transceiver <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver>`
            
            .. attribute:: transport_mode
            
            	Set the transport mode on an interface
            	**type**\:   :py:class:`EtherCtrlTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_asr9k_lc_ethctrl_cfg.EtherCtrlTransportMode>`
            
            

            """

            _prefix = 'asr9k-lc-ethctrl-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl, self).__init__()

                self.yang_name = "ethernet-control"
                self.yang_parent_name = "interface-configuration"

                self.small_frame_padding = YLeaf(YType.empty, "small-frame-padding")

                self.transport_mode = YLeaf(YType.enumeration, "transport-mode")

                self.transceiver = InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver()
                self.transceiver.parent = self
                self._children_name_map["transceiver"] = "transceiver"
                self._children_yang_names.add("transceiver")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("small_frame_padding",
                                "transport_mode") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl, self).__setattr__(name, value)


            class Transceiver(Entity):
                """
                Transceiver
                
                .. attribute:: permit
                
                	Permit
                	**type**\:   :py:class:`Permit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit>`
                
                

                """

                _prefix = 'asr9k-lc-ethctrl-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver, self).__init__()

                    self.yang_name = "transceiver"
                    self.yang_parent_name = "ethernet-control"

                    self.permit = InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._children_yang_names.add("permit")


                class Permit(Entity):
                    """
                    Permit
                    
                    .. attribute:: pid
                    
                    	Permit pluggable PID (Product ID) all
                    	**type**\:   :py:class:`PermitPluggablePid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_asr9k_lc_ethctrl_cfg.PermitPluggablePid>`
                    
                    .. attribute:: type
                    
                    	Permit pluggable type all
                    	**type**\:   :py:class:`PermitPluggable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_asr9k_lc_ethctrl_cfg.PermitPluggable>`
                    
                    

                    """

                    _prefix = 'asr9k-lc-ethctrl-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "transceiver"

                        self.pid = YLeaf(YType.enumeration, "pid")

                        self.type = YLeaf(YType.enumeration, "type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("pid",
                                        "type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.pid.is_set or
                            self.type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.pid.yfilter != YFilter.not_set or
                            self.type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "permit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.pid.is_set or self.pid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pid.get_name_leafdata())
                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "pid" or name == "type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "pid"):
                            self.pid = value
                            self.pid.value_namespace = name_space
                            self.pid.value_namespace_prefix = name_space_prefix
                        if(value_path == "type"):
                            self.type = value
                            self.type.value_namespace = name_space
                            self.type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.permit is not None and self.permit.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.permit is not None and self.permit.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "transceiver" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "permit"):
                        if (self.permit is None):
                            self.permit = InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit()
                            self.permit.parent = self
                            self._children_name_map["permit"] = "permit"
                        return self.permit

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "permit"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.small_frame_padding.is_set or
                    self.transport_mode.is_set or
                    (self.transceiver is not None and self.transceiver.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.small_frame_padding.yfilter != YFilter.not_set or
                    self.transport_mode.yfilter != YFilter.not_set or
                    (self.transceiver is not None and self.transceiver.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-asr9k-lc-ethctrl-cfg:ethernet-control" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.small_frame_padding.is_set or self.small_frame_padding.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.small_frame_padding.get_name_leafdata())
                if (self.transport_mode.is_set or self.transport_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.transport_mode.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "transceiver"):
                    if (self.transceiver is None):
                        self.transceiver = InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver()
                        self.transceiver.parent = self
                        self._children_name_map["transceiver"] = "transceiver"
                    return self.transceiver

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "transceiver" or name == "small-frame-padding" or name == "transport-mode"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "small-frame-padding"):
                    self.small_frame_padding = value
                    self.small_frame_padding.value_namespace = name_space
                    self.small_frame_padding.value_namespace_prefix = name_space_prefix
                if(value_path == "transport-mode"):
                    self.transport_mode = value
                    self.transport_mode.value_namespace = name_space
                    self.transport_mode.value_namespace_prefix = name_space_prefix


        class PseudowireEther(Entity):
            """
            PW\-Ether attributes
            
            .. attribute:: generic_interface_list
            
            	Name of the interface list
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: l2_overhead
            
            	PW Ether L2 overhead requirement
            	**type**\:  int
            
            	**range:** 1..64
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.PseudowireEther, self).__init__()

                self.yang_name = "pseudowire-ether"
                self.yang_parent_name = "interface-configuration"

                self.generic_interface_list = YLeaf(YType.str, "generic-interface-list")

                self.l2_overhead = YLeaf(YType.uint32, "l2-overhead")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("generic_interface_list",
                                "l2_overhead") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.PseudowireEther, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.PseudowireEther, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.generic_interface_list.is_set or
                    self.l2_overhead.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.generic_interface_list.yfilter != YFilter.not_set or
                    self.l2_overhead.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2vpn-cfg:pseudowire-ether" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.generic_interface_list.is_set or self.generic_interface_list.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.generic_interface_list.get_name_leafdata())
                if (self.l2_overhead.is_set or self.l2_overhead.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.l2_overhead.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface-list" or name == "l2-overhead"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "generic-interface-list"):
                    self.generic_interface_list = value
                    self.generic_interface_list.value_namespace = name_space
                    self.generic_interface_list.value_namespace_prefix = name_space_prefix
                if(value_path == "l2-overhead"):
                    self.l2_overhead = value
                    self.l2_overhead.value_namespace = name_space
                    self.l2_overhead.value_namespace_prefix = name_space_prefix


        class PseudowireIw(Entity):
            """
            PW\-IW attributes
            
            .. attribute:: generic_interface_list
            
            	Name of the interface list
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: l2_overhead
            
            	L2 overhead size in bytes
            	**type**\:  int
            
            	**range:** 1..64
            
            	**units**\: byte
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.PseudowireIw, self).__init__()

                self.yang_name = "pseudowire-iw"
                self.yang_parent_name = "interface-configuration"

                self.generic_interface_list = YLeaf(YType.str, "generic-interface-list")

                self.l2_overhead = YLeaf(YType.uint32, "l2-overhead")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("generic_interface_list",
                                "l2_overhead") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.PseudowireIw, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.PseudowireIw, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.generic_interface_list.is_set or
                    self.l2_overhead.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.generic_interface_list.yfilter != YFilter.not_set or
                    self.l2_overhead.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2vpn-cfg:pseudowire-iw" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.generic_interface_list.is_set or self.generic_interface_list.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.generic_interface_list.get_name_leafdata())
                if (self.l2_overhead.is_set or self.l2_overhead.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.l2_overhead.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface-list" or name == "l2-overhead"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "generic-interface-list"):
                    self.generic_interface_list = value
                    self.generic_interface_list.value_namespace = name_space
                    self.generic_interface_list.value_namespace_prefix = name_space_prefix
                if(value_path == "l2-overhead"):
                    self.l2_overhead = value
                    self.l2_overhead.value_namespace = name_space
                    self.l2_overhead.value_namespace_prefix = name_space_prefix


        class Bvi(Entity):
            """
            BVI attributes
            
            .. attribute:: host_routing
            
            	Enable host\-routing on this BVI
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Bvi, self).__init__()

                self.yang_name = "bvi"
                self.yang_parent_name = "interface-configuration"

                self.host_routing = YLeaf(YType.empty, "host-routing")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("host_routing") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bvi, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Bvi, self).__setattr__(name, value)

            def has_data(self):
                return self.host_routing.is_set

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.host_routing.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2vpn-cfg:bvi" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.host_routing.is_set or self.host_routing.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.host_routing.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "host-routing"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "host-routing"):
                    self.host_routing = value
                    self.host_routing.value_namespace = name_space
                    self.host_routing.value_namespace_prefix = name_space_prefix


        class L2Transport(Entity):
            """
            Interface Layer 2 Transport service
            configuration data
            
            .. attribute:: atm_port_mode_parameters
            
            	ATM L2transport Port Mode Parameters Configuration
            	**type**\:   :py:class:`AtmPortModeParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters>`
            
            .. attribute:: cac
            
            	Connection Attachment Circuit configuration
            	**type**\:   :py:class:`Cac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac>`
            
            .. attribute:: enabled
            
            	This object is only valid on physical interfaces and it controls whether that interface is a port mode Layer 2 attachment circuit (note that for subinterfaces, the Layer 2 property is specified when the subinterface is created).The object must be set before any other L2Transport configuration is supplied for the interface, and must be the last per\-interface configuration object to be removed
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: l2_ethernet_features
            
            	L2 Ethernet Features Configuration
            	**type**\:   :py:class:`L2EthernetFeatures <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures>`
            
            .. attribute:: l2_protocols
            
            	Interface specific Layer 2 protocol handling
            	**type**\:   :py:class:`L2Protocols <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols>`
            
            .. attribute:: pac
            
            	Port Attachment Circuit configuration
            	**type**\:   :py:class:`Pac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac>`
            
            .. attribute:: propagate_remote_status
            
            	Enable propagation of the remote attachment\-circuit link state to the localattachment\-circuit link state
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: span_monitor_sessions
            
            	Monitor Session container for this source interface
            	**type**\:   :py:class:`SpanMonitorSessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions>`
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport, self).__init__()

                self.yang_name = "l2-transport"
                self.yang_parent_name = "interface-configuration"

                self.enabled = YLeaf(YType.empty, "enabled")

                self.propagate_remote_status = YLeaf(YType.empty, "Cisco-IOS-XR-l2-eth-infra-cfg:propagate-remote-status")

                self.atm_port_mode_parameters = InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters()
                self.atm_port_mode_parameters.parent = self
                self._children_name_map["atm_port_mode_parameters"] = "atm-port-mode-parameters"
                self._children_yang_names.add("atm-port-mode-parameters")

                self.cac = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac()
                self.cac.parent = self
                self._children_name_map["cac"] = "cac"
                self._children_yang_names.add("cac")

                self.l2_ethernet_features = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures()
                self.l2_ethernet_features.parent = self
                self._children_name_map["l2_ethernet_features"] = "l2-ethernet-features"
                self._children_yang_names.add("l2-ethernet-features")

                self.l2_protocols = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols()
                self.l2_protocols.parent = self
                self._children_name_map["l2_protocols"] = "l2-protocols"
                self._children_yang_names.add("l2-protocols")

                self.pac = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac()
                self.pac.parent = self
                self._children_name_map["pac"] = "pac"
                self._children_yang_names.add("pac")

                self.span_monitor_sessions = InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions()
                self.span_monitor_sessions.parent = self
                self._children_name_map["span_monitor_sessions"] = "span-monitor-sessions"
                self._children_yang_names.add("span-monitor-sessions")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("enabled",
                                "propagate_remote_status") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport, self).__setattr__(name, value)


            class AtmPortModeParameters(Entity):
                """
                ATM L2transport Port Mode Parameters
                Configuration
                
                .. attribute:: cell_packing
                
                	Configure cell\-packing parameters.  All parameters are mandatory
                	**type**\:   :py:class:`CellPacking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters, self).__init__()

                    self.yang_name = "atm-port-mode-parameters"
                    self.yang_parent_name = "l2-transport"

                    self.cell_packing = None
                    self._children_name_map["cell_packing"] = "cell-packing"
                    self._children_yang_names.add("cell-packing")


                class CellPacking(Entity):
                    """
                    Configure cell\-packing parameters.  All
                    parameters are mandatory.
                    
                    .. attribute:: cell_packing_timer_id
                    
                    	Which cell packing timer to use
                    	**type**\:  int
                    
                    	**range:** 1..3
                    
                    	**mandatory**\: True
                    
                    .. attribute:: maximum_cells_packed
                    
                    	Maximum number of cells to be packed in a packet
                    	**type**\:  int
                    
                    	**range:** 2..255
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking, self).__init__()

                        self.yang_name = "cell-packing"
                        self.yang_parent_name = "atm-port-mode-parameters"
                        self.is_presence_container = True

                        self.cell_packing_timer_id = YLeaf(YType.uint32, "cell-packing-timer-id")

                        self.maximum_cells_packed = YLeaf(YType.uint32, "maximum-cells-packed")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("cell_packing_timer_id",
                                        "maximum_cells_packed") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.cell_packing_timer_id.is_set or
                            self.maximum_cells_packed.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.cell_packing_timer_id.yfilter != YFilter.not_set or
                            self.maximum_cells_packed.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "cell-packing" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.cell_packing_timer_id.is_set or self.cell_packing_timer_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cell_packing_timer_id.get_name_leafdata())
                        if (self.maximum_cells_packed.is_set or self.maximum_cells_packed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_cells_packed.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "cell-packing-timer-id" or name == "maximum-cells-packed"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "cell-packing-timer-id"):
                            self.cell_packing_timer_id = value
                            self.cell_packing_timer_id.value_namespace = name_space
                            self.cell_packing_timer_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-cells-packed"):
                            self.maximum_cells_packed = value
                            self.maximum_cells_packed.value_namespace = name_space
                            self.maximum_cells_packed.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.cell_packing is not None)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.cell_packing is not None and self.cell_packing.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-atm-vcm-cfg:atm-port-mode-parameters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "cell-packing"):
                        if (self.cell_packing is None):
                            self.cell_packing = InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking()
                            self.cell_packing.parent = self
                            self._children_name_map["cell_packing"] = "cell-packing"
                        return self.cell_packing

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "cell-packing"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2Protocols(Entity):
                """
                Interface specific Layer 2 protocol handling
                
                .. attribute:: l2_protocol
                
                	Handling of a specific Layer 2 protocol
                	**type**\: list of    :py:class:`L2Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol>`
                
                

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols, self).__init__()

                    self.yang_name = "l2-protocols"
                    self.yang_parent_name = "l2-transport"

                    self.l2_protocol = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols, self).__setattr__(name, value)


                class L2Protocol(Entity):
                    """
                    Handling of a specific Layer 2 protocol
                    
                    .. attribute:: l2_protocol_name  <key>
                    
                    	Protocol name
                    	**type**\:   :py:class:`L2ProtocolName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.L2ProtocolName>`
                    
                    .. attribute:: mode
                    
                    	How to handle the protocol's packets
                    	**type**\:   :py:class:`L2ProtocolMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.L2ProtocolMode>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: mpls_exp_bits_value
                    
                    	The value to set the MPLS Exp bits to within the PW.This value may be specified if the mode is forward or tunnel and must not be specified if the mode is drop
                    	**type**\:  int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'l2-eth-infra-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol, self).__init__()

                        self.yang_name = "l2-protocol"
                        self.yang_parent_name = "l2-protocols"

                        self.l2_protocol_name = YLeaf(YType.enumeration, "l2-protocol-name")

                        self.mode = YLeaf(YType.enumeration, "mode")

                        self.mpls_exp_bits_value = YLeaf(YType.uint32, "mpls-exp-bits-value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("l2_protocol_name",
                                        "mode",
                                        "mpls_exp_bits_value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.l2_protocol_name.is_set or
                            self.mode.is_set or
                            self.mpls_exp_bits_value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.l2_protocol_name.yfilter != YFilter.not_set or
                            self.mode.yfilter != YFilter.not_set or
                            self.mpls_exp_bits_value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2-protocol" + "[l2-protocol-name='" + self.l2_protocol_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.l2_protocol_name.is_set or self.l2_protocol_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l2_protocol_name.get_name_leafdata())
                        if (self.mode.is_set or self.mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mode.get_name_leafdata())
                        if (self.mpls_exp_bits_value.is_set or self.mpls_exp_bits_value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mpls_exp_bits_value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2-protocol-name" or name == "mode" or name == "mpls-exp-bits-value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "l2-protocol-name"):
                            self.l2_protocol_name = value
                            self.l2_protocol_name.value_namespace = name_space
                            self.l2_protocol_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mode"):
                            self.mode = value
                            self.mode.value_namespace = name_space
                            self.mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "mpls-exp-bits-value"):
                            self.mpls_exp_bits_value = value
                            self.mpls_exp_bits_value.value_namespace = name_space
                            self.mpls_exp_bits_value.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2_protocol:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2_protocol:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:l2-protocols" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2-protocol"):
                        for c in self.l2_protocol:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2_protocol.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2-protocol"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2EthernetFeatures(Entity):
                """
                L2 Ethernet Features Configuration
                
                .. attribute:: egress_filtering
                
                	Egress Ethernet filtering
                	**type**\:   :py:class:`EgressFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.EgressFiltering>`
                
                	**default value**\: egress-filtering-type-default
                
                .. attribute:: source_bypass_egress_filtering
                
                	Mark all ingress packets to bypass any egress VLAN filter
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures, self).__init__()

                    self.yang_name = "l2-ethernet-features"
                    self.yang_parent_name = "l2-transport"

                    self.egress_filtering = YLeaf(YType.enumeration, "egress-filtering")

                    self.source_bypass_egress_filtering = YLeaf(YType.empty, "source-bypass-egress-filtering")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("egress_filtering",
                                    "source_bypass_egress_filtering") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.egress_filtering.is_set or
                        self.source_bypass_egress_filtering.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.egress_filtering.yfilter != YFilter.not_set or
                        self.source_bypass_egress_filtering.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:l2-ethernet-features" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.egress_filtering.is_set or self.egress_filtering.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.egress_filtering.get_name_leafdata())
                    if (self.source_bypass_egress_filtering.is_set or self.source_bypass_egress_filtering.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_bypass_egress_filtering.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "egress-filtering" or name == "source-bypass-egress-filtering"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "egress-filtering"):
                        self.egress_filtering = value
                        self.egress_filtering.value_namespace = name_space
                        self.egress_filtering.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-bypass-egress-filtering"):
                        self.source_bypass_egress_filtering = value
                        self.source_bypass_egress_filtering.value_namespace = name_space
                        self.source_bypass_egress_filtering.value_namespace_prefix = name_space_prefix


            class SpanMonitorSessions(Entity):
                """
                Monitor Session container for this source
                interface
                
                .. attribute:: span_monitor_session
                
                	Configuration for a particular class of Monitor Session
                	**type**\: list of    :py:class:`SpanMonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession>`
                
                

                """

                _prefix = 'ethernet-span-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions, self).__init__()

                    self.yang_name = "span-monitor-sessions"
                    self.yang_parent_name = "l2-transport"

                    self.span_monitor_session = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions, self).__setattr__(name, value)


                class SpanMonitorSession(Entity):
                    """
                    Configuration for a particular class of Monitor
                    Session
                    
                    .. attribute:: session_class  <key>
                    
                    	Session Class
                    	**type**\:   :py:class:`SpanSessionClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_datatypes.SpanSessionClass>`
                    
                    .. attribute:: acl
                    
                    	Enable ACL matching for traffic mirroring
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: attachment
                    
                    	Attach the interface to a Monitor Session
                    	**type**\:   :py:class:`Attachment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mirror_first
                    
                    	Mirror a specified number of bytes from start of packet
                    	**type**\:  int
                    
                    	**range:** 1..10000
                    
                    	**units**\: byte
                    
                    .. attribute:: mirror_interval
                    
                    	Specify the mirror interval
                    	**type**\:   :py:class:`SpanMirrorInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanMirrorInterval>`
                    
                    

                    """

                    _prefix = 'ethernet-span-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession, self).__init__()

                        self.yang_name = "span-monitor-session"
                        self.yang_parent_name = "span-monitor-sessions"

                        self.session_class = YLeaf(YType.enumeration, "session-class")

                        self.acl = YLeaf(YType.empty, "acl")

                        self.mirror_first = YLeaf(YType.uint32, "mirror-first")

                        self.mirror_interval = YLeaf(YType.enumeration, "mirror-interval")

                        self.attachment = None
                        self._children_name_map["attachment"] = "attachment"
                        self._children_yang_names.add("attachment")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_class",
                                        "acl",
                                        "mirror_first",
                                        "mirror_interval") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession, self).__setattr__(name, value)


                    class Attachment(Entity):
                        """
                        Attach the interface to a Monitor Session
                        
                        .. attribute:: direction
                        
                        	Specify the direction of traffic to replicate (optional)
                        	**type**\:   :py:class:`SpanTrafficDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanTrafficDirection>`
                        
                        .. attribute:: port_level_enable
                        
                        	Enable port level traffic mirroring
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: session_name
                        
                        	Session Name
                        	**type**\:  str
                        
                        	**length:** 1..79
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ethernet-span-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__init__()

                            self.yang_name = "attachment"
                            self.yang_parent_name = "span-monitor-session"
                            self.is_presence_container = True

                            self.direction = YLeaf(YType.enumeration, "direction")

                            self.port_level_enable = YLeaf(YType.empty, "port-level-enable")

                            self.session_name = YLeaf(YType.str, "session-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("direction",
                                            "port_level_enable",
                                            "session_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.direction.is_set or
                                self.port_level_enable.is_set or
                                self.session_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.direction.yfilter != YFilter.not_set or
                                self.port_level_enable.yfilter != YFilter.not_set or
                                self.session_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.direction.get_name_leafdata())
                            if (self.port_level_enable.is_set or self.port_level_enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_level_enable.get_name_leafdata())
                            if (self.session_name.is_set or self.session_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "direction" or name == "port-level-enable" or name == "session-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "direction"):
                                self.direction = value
                                self.direction.value_namespace = name_space
                                self.direction.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-level-enable"):
                                self.port_level_enable = value
                                self.port_level_enable.value_namespace = name_space
                                self.port_level_enable.value_namespace_prefix = name_space_prefix
                            if(value_path == "session-name"):
                                self.session_name = value
                                self.session_name.value_namespace = name_space
                                self.session_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_class.is_set or
                            self.acl.is_set or
                            self.mirror_first.is_set or
                            self.mirror_interval.is_set or
                            (self.attachment is not None))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_class.yfilter != YFilter.not_set or
                            self.acl.yfilter != YFilter.not_set or
                            self.mirror_first.yfilter != YFilter.not_set or
                            self.mirror_interval.yfilter != YFilter.not_set or
                            (self.attachment is not None and self.attachment.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "span-monitor-session" + "[session-class='" + self.session_class.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_class.is_set or self.session_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_class.get_name_leafdata())
                        if (self.acl.is_set or self.acl.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.acl.get_name_leafdata())
                        if (self.mirror_first.is_set or self.mirror_first.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mirror_first.get_name_leafdata())
                        if (self.mirror_interval.is_set or self.mirror_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mirror_interval.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment"):
                            if (self.attachment is None):
                                self.attachment = InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment()
                                self.attachment.parent = self
                                self._children_name_map["attachment"] = "attachment"
                            return self.attachment

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment" or name == "session-class" or name == "acl" or name == "mirror-first" or name == "mirror-interval"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-class"):
                            self.session_class = value
                            self.session_class.value_namespace = name_space
                            self.session_class.value_namespace_prefix = name_space_prefix
                        if(value_path == "acl"):
                            self.acl = value
                            self.acl.value_namespace = name_space
                            self.acl.value_namespace_prefix = name_space_prefix
                        if(value_path == "mirror-first"):
                            self.mirror_first = value
                            self.mirror_first.value_namespace = name_space
                            self.mirror_first.value_namespace_prefix = name_space_prefix
                        if(value_path == "mirror-interval"):
                            self.mirror_interval = value
                            self.mirror_interval.value_namespace = name_space
                            self.mirror_interval.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.span_monitor_session:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.span_monitor_session:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-Ethernet-SPAN-cfg:span-monitor-sessions" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "span-monitor-session"):
                        for c in self.span_monitor_session:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.span_monitor_session.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "span-monitor-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Pac(Entity):
                """
                Port Attachment Circuit configuration.
                
                .. attribute:: qos
                
                	Interface QOS configuration
                	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2016-12-23'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac, self).__init__()

                    self.yang_name = "pac"
                    self.yang_parent_name = "l2-transport"

                    self.qos = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._children_yang_names.add("qos")


                class Qos(Entity):
                    """
                    Interface QOS configuration
                    
                    .. attribute:: input
                    
                    	Ingress service policy
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input>`
                    
                    .. attribute:: output
                    
                    	Egress service policy
                    	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2016-12-23'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "pac"

                        self.input = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")

                        self.output = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                        self._children_yang_names.add("output")


                    class Output(Entity):
                        """
                        Egress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "qos"

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output, self).__setattr__(name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "output"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name",
                                                "account_type",
                                                "l1_user_defined",
                                                "resource_id",
                                                "service_fragment_parent_policy",
                                                "spi_name",
                                                "subscriber_parent_policy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    self.account_type.is_set or
                                    self.l1_user_defined.is_set or
                                    self.resource_id.is_set or
                                    self.service_fragment_parent_policy.is_set or
                                    self.spi_name.is_set or
                                    self.subscriber_parent_policy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    self.account_type.yfilter != YFilter.not_set or
                                    self.l1_user_defined.yfilter != YFilter.not_set or
                                    self.resource_id.yfilter != YFilter.not_set or
                                    self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                    self.spi_name.yfilter != YFilter.not_set or
                                    self.subscriber_parent_policy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())
                                if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.account_type.get_name_leafdata())
                                if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resource_id.get_name_leafdata())
                                if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spi_name.get_name_leafdata())
                                if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "service-policy-name" or name == "account-type" or name == "l1-user-defined" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "account-type"):
                                    self.account_type = value
                                    self.account_type.value_namespace = name_space
                                    self.account_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "l1-user-defined"):
                                    self.l1_user_defined = value
                                    self.l1_user_defined.value_namespace = name_space
                                    self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                if(value_path == "resource-id"):
                                    self.resource_id = value
                                    self.resource_id.value_namespace = name_space
                                    self.resource_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-fragment-parent-policy"):
                                    self.service_fragment_parent_policy = value
                                    self.service_fragment_parent_policy.value_namespace = name_space
                                    self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spi-name"):
                                    self.spi_name = value
                                    self.spi_name.value_namespace = name_space
                                    self.spi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-parent-policy"):
                                    self.subscriber_parent_policy = value
                                    self.subscriber_parent_policy.value_namespace = name_space
                                    self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "output"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos, self).__setattr__(name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.subscriber_group_name = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2016-12-23'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("subscriber_group_string",
                                                        "account_type",
                                                        "l1_user_defined",
                                                        "policy_merge",
                                                        "resource_id",
                                                        "service_fragment_parent_policy",
                                                        "spi_name",
                                                        "subscriber_parent_policy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.subscriber_group_string.is_set or
                                            self.account_type.is_set or
                                            self.l1_user_defined.is_set or
                                            self.policy_merge.is_set or
                                            self.resource_id.is_set or
                                            self.service_fragment_parent_policy.is_set or
                                            self.spi_name.is_set or
                                            self.subscriber_parent_policy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.subscriber_group_string.yfilter != YFilter.not_set or
                                            self.account_type.yfilter != YFilter.not_set or
                                            self.l1_user_defined.yfilter != YFilter.not_set or
                                            self.policy_merge.yfilter != YFilter.not_set or
                                            self.resource_id.yfilter != YFilter.not_set or
                                            self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                            self.spi_name.yfilter != YFilter.not_set or
                                            self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.subscriber_group_string.is_set or self.subscriber_group_string.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_group_string.get_name_leafdata())
                                        if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.account_type.get_name_leafdata())
                                        if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                        if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                        if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resource_id.get_name_leafdata())
                                        if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                        if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spi_name.get_name_leafdata())
                                        if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "subscriber-group-string" or name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "subscriber-group-string"):
                                            self.subscriber_group_string = value
                                            self.subscriber_group_string.value_namespace = name_space
                                            self.subscriber_group_string.value_namespace_prefix = name_space_prefix
                                        if(value_path == "account-type"):
                                            self.account_type = value
                                            self.account_type.value_namespace = name_space
                                            self.account_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l1-user-defined"):
                                            self.l1_user_defined = value
                                            self.l1_user_defined.value_namespace = name_space
                                            self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                        if(value_path == "policy-merge"):
                                            self.policy_merge = value
                                            self.policy_merge.value_namespace = name_space
                                            self.policy_merge.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resource-id"):
                                            self.resource_id = value
                                            self.resource_id.value_namespace = name_space
                                            self.resource_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "service-fragment-parent-policy"):
                                            self.service_fragment_parent_policy = value
                                            self.service_fragment_parent_policy.value_namespace = name_space
                                            self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spi-name"):
                                            self.spi_name = value
                                            self.spi_name.value_namespace = name_space
                                            self.spi_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "subscriber-parent-policy"):
                                            self.subscriber_parent_policy = value
                                            self.subscriber_parent_policy.value_namespace = name_space
                                            self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-group-names" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "subscriber-group-name"):
                                        for c in self.subscriber_group_name:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.subscriber_group_name.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "subscriber-group-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("account_type",
                                                    "l1_user_defined",
                                                    "policy_merge",
                                                    "resource_id",
                                                    "service_fragment_parent_policy",
                                                    "spi_name",
                                                    "subscriber_parent_policy") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.account_type.is_set or
                                        self.l1_user_defined.is_set or
                                        self.policy_merge.is_set or
                                        self.resource_id.is_set or
                                        self.service_fragment_parent_policy.is_set or
                                        self.spi_name.is_set or
                                        self.subscriber_parent_policy.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.account_type.yfilter != YFilter.not_set or
                                        self.l1_user_defined.yfilter != YFilter.not_set or
                                        self.policy_merge.yfilter != YFilter.not_set or
                                        self.resource_id.yfilter != YFilter.not_set or
                                        self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                        self.spi_name.yfilter != YFilter.not_set or
                                        self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-parent" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.account_type.get_name_leafdata())
                                    if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                    if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                    if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resource_id.get_name_leafdata())
                                    if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                    if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spi_name.get_name_leafdata())
                                    if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "account-type"):
                                        self.account_type = value
                                        self.account_type.value_namespace = name_space
                                        self.account_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l1-user-defined"):
                                        self.l1_user_defined = value
                                        self.l1_user_defined.value_namespace = name_space
                                        self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                    if(value_path == "policy-merge"):
                                        self.policy_merge = value
                                        self.policy_merge.value_namespace = name_space
                                        self.policy_merge.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resource-id"):
                                        self.resource_id = value
                                        self.resource_id.value_namespace = name_space
                                        self.resource_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service-fragment-parent-policy"):
                                        self.service_fragment_parent_policy = value
                                        self.service_fragment_parent_policy.value_namespace = name_space
                                        self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spi-name"):
                                        self.spi_name = value
                                        self.spi_name.value_namespace = name_space
                                        self.spi_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "subscriber-parent-policy"):
                                        self.subscriber_parent_policy = value
                                        self.subscriber_parent_policy.value_namespace = name_space
                                        self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_data()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_operation()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "subscriber-group-names"):
                                    if (self.subscriber_group_names is None):
                                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                        self.subscriber_group_names.parent = self
                                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                    return self.subscriber_group_names

                                if (child_yang_name == "subscriber-parent"):
                                    if (self.subscriber_parent is None):
                                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent()
                                        self.subscriber_parent.parent = self
                                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                    return self.subscriber_parent

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "subscriber-group-names" or name == "subscriber-parent" or name == "service-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.service_policy:
                                if (c.has_data()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.service_policy:
                                if (c.has_operation()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "output" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "service-policy"):
                                for c in self.service_policy:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy.append(c)
                                return c

                            if (child_yang_name == "service-policy-qos"):
                                for c in self.service_policy_qos:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy_qos.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy" or name == "service-policy-qos"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Input(Entity):
                        """
                        Ingress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input, self).__setattr__(name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "input"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name",
                                                "account_type",
                                                "l1_user_defined",
                                                "resource_id",
                                                "service_fragment_parent_policy",
                                                "spi_name",
                                                "subscriber_parent_policy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    self.account_type.is_set or
                                    self.l1_user_defined.is_set or
                                    self.resource_id.is_set or
                                    self.service_fragment_parent_policy.is_set or
                                    self.spi_name.is_set or
                                    self.subscriber_parent_policy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    self.account_type.yfilter != YFilter.not_set or
                                    self.l1_user_defined.yfilter != YFilter.not_set or
                                    self.resource_id.yfilter != YFilter.not_set or
                                    self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                    self.spi_name.yfilter != YFilter.not_set or
                                    self.subscriber_parent_policy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())
                                if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.account_type.get_name_leafdata())
                                if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resource_id.get_name_leafdata())
                                if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spi_name.get_name_leafdata())
                                if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "service-policy-name" or name == "account-type" or name == "l1-user-defined" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "account-type"):
                                    self.account_type = value
                                    self.account_type.value_namespace = name_space
                                    self.account_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "l1-user-defined"):
                                    self.l1_user_defined = value
                                    self.l1_user_defined.value_namespace = name_space
                                    self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                if(value_path == "resource-id"):
                                    self.resource_id = value
                                    self.resource_id.value_namespace = name_space
                                    self.resource_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-fragment-parent-policy"):
                                    self.service_fragment_parent_policy = value
                                    self.service_fragment_parent_policy.value_namespace = name_space
                                    self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spi-name"):
                                    self.spi_name = value
                                    self.spi_name.value_namespace = name_space
                                    self.spi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-parent-policy"):
                                    self.subscriber_parent_policy = value
                                    self.subscriber_parent_policy.value_namespace = name_space
                                    self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "input"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos, self).__setattr__(name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.subscriber_group_name = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2016-12-23'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("subscriber_group_string",
                                                        "account_type",
                                                        "l1_user_defined",
                                                        "policy_merge",
                                                        "resource_id",
                                                        "service_fragment_parent_policy",
                                                        "spi_name",
                                                        "subscriber_parent_policy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.subscriber_group_string.is_set or
                                            self.account_type.is_set or
                                            self.l1_user_defined.is_set or
                                            self.policy_merge.is_set or
                                            self.resource_id.is_set or
                                            self.service_fragment_parent_policy.is_set or
                                            self.spi_name.is_set or
                                            self.subscriber_parent_policy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.subscriber_group_string.yfilter != YFilter.not_set or
                                            self.account_type.yfilter != YFilter.not_set or
                                            self.l1_user_defined.yfilter != YFilter.not_set or
                                            self.policy_merge.yfilter != YFilter.not_set or
                                            self.resource_id.yfilter != YFilter.not_set or
                                            self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                            self.spi_name.yfilter != YFilter.not_set or
                                            self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.subscriber_group_string.is_set or self.subscriber_group_string.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_group_string.get_name_leafdata())
                                        if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.account_type.get_name_leafdata())
                                        if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                        if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                        if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resource_id.get_name_leafdata())
                                        if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                        if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spi_name.get_name_leafdata())
                                        if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "subscriber-group-string" or name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "subscriber-group-string"):
                                            self.subscriber_group_string = value
                                            self.subscriber_group_string.value_namespace = name_space
                                            self.subscriber_group_string.value_namespace_prefix = name_space_prefix
                                        if(value_path == "account-type"):
                                            self.account_type = value
                                            self.account_type.value_namespace = name_space
                                            self.account_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l1-user-defined"):
                                            self.l1_user_defined = value
                                            self.l1_user_defined.value_namespace = name_space
                                            self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                        if(value_path == "policy-merge"):
                                            self.policy_merge = value
                                            self.policy_merge.value_namespace = name_space
                                            self.policy_merge.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resource-id"):
                                            self.resource_id = value
                                            self.resource_id.value_namespace = name_space
                                            self.resource_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "service-fragment-parent-policy"):
                                            self.service_fragment_parent_policy = value
                                            self.service_fragment_parent_policy.value_namespace = name_space
                                            self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spi-name"):
                                            self.spi_name = value
                                            self.spi_name.value_namespace = name_space
                                            self.spi_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "subscriber-parent-policy"):
                                            self.subscriber_parent_policy = value
                                            self.subscriber_parent_policy.value_namespace = name_space
                                            self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-group-names" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "subscriber-group-name"):
                                        for c in self.subscriber_group_name:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.subscriber_group_name.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "subscriber-group-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("account_type",
                                                    "l1_user_defined",
                                                    "policy_merge",
                                                    "resource_id",
                                                    "service_fragment_parent_policy",
                                                    "spi_name",
                                                    "subscriber_parent_policy") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.account_type.is_set or
                                        self.l1_user_defined.is_set or
                                        self.policy_merge.is_set or
                                        self.resource_id.is_set or
                                        self.service_fragment_parent_policy.is_set or
                                        self.spi_name.is_set or
                                        self.subscriber_parent_policy.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.account_type.yfilter != YFilter.not_set or
                                        self.l1_user_defined.yfilter != YFilter.not_set or
                                        self.policy_merge.yfilter != YFilter.not_set or
                                        self.resource_id.yfilter != YFilter.not_set or
                                        self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                        self.spi_name.yfilter != YFilter.not_set or
                                        self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-parent" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.account_type.get_name_leafdata())
                                    if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                    if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                    if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resource_id.get_name_leafdata())
                                    if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                    if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spi_name.get_name_leafdata())
                                    if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "account-type"):
                                        self.account_type = value
                                        self.account_type.value_namespace = name_space
                                        self.account_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l1-user-defined"):
                                        self.l1_user_defined = value
                                        self.l1_user_defined.value_namespace = name_space
                                        self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                    if(value_path == "policy-merge"):
                                        self.policy_merge = value
                                        self.policy_merge.value_namespace = name_space
                                        self.policy_merge.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resource-id"):
                                        self.resource_id = value
                                        self.resource_id.value_namespace = name_space
                                        self.resource_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service-fragment-parent-policy"):
                                        self.service_fragment_parent_policy = value
                                        self.service_fragment_parent_policy.value_namespace = name_space
                                        self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spi-name"):
                                        self.spi_name = value
                                        self.spi_name.value_namespace = name_space
                                        self.spi_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "subscriber-parent-policy"):
                                        self.subscriber_parent_policy = value
                                        self.subscriber_parent_policy.value_namespace = name_space
                                        self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_data()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_operation()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "subscriber-group-names"):
                                    if (self.subscriber_group_names is None):
                                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                        self.subscriber_group_names.parent = self
                                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                    return self.subscriber_group_names

                                if (child_yang_name == "subscriber-parent"):
                                    if (self.subscriber_parent is None):
                                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent()
                                        self.subscriber_parent.parent = self
                                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                    return self.subscriber_parent

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "subscriber-group-names" or name == "subscriber-parent" or name == "service-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.service_policy:
                                if (c.has_data()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.service_policy:
                                if (c.has_operation()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "input" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "service-policy"):
                                for c in self.service_policy:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy.append(c)
                                return c

                            if (child_yang_name == "service-policy-qos"):
                                for c in self.service_policy_qos:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy_qos.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy" or name == "service-policy-qos"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.input is not None and self.input.has_data()) or
                            (self.output is not None and self.output.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.input is not None and self.input.has_operation()) or
                            (self.output is not None and self.output.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "qos" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "input"):
                            if (self.input is None):
                                self.input = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input()
                                self.input.parent = self
                                self._children_name_map["input"] = "input"
                            return self.input

                        if (child_yang_name == "output"):
                            if (self.output is None):
                                self.output = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output()
                                self.output.parent = self
                                self._children_name_map["output"] = "output"
                            return self.output

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "input" or name == "output"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.qos is not None and self.qos.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.qos is not None and self.qos.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-qos-ma-cfg:pac" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "qos"):
                        if (self.qos is None):
                            self.qos = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos()
                            self.qos.parent = self
                            self._children_name_map["qos"] = "qos"
                        return self.qos

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "qos"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Cac(Entity):
                """
                Connection Attachment Circuit configuration.
                
                .. attribute:: qos
                
                	Interface QOS configuration
                	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2016-12-23'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac, self).__init__()

                    self.yang_name = "cac"
                    self.yang_parent_name = "l2-transport"

                    self.qos = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._children_yang_names.add("qos")


                class Qos(Entity):
                    """
                    Interface QOS configuration
                    
                    .. attribute:: input
                    
                    	Ingress service policy
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input>`
                    
                    .. attribute:: output
                    
                    	Egress service policy
                    	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2016-12-23'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "cac"

                        self.input = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")

                        self.output = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                        self._children_yang_names.add("output")


                    class Output(Entity):
                        """
                        Egress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "qos"

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output, self).__setattr__(name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "output"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name",
                                                "account_type",
                                                "l1_user_defined",
                                                "resource_id",
                                                "service_fragment_parent_policy",
                                                "spi_name",
                                                "subscriber_parent_policy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    self.account_type.is_set or
                                    self.l1_user_defined.is_set or
                                    self.resource_id.is_set or
                                    self.service_fragment_parent_policy.is_set or
                                    self.spi_name.is_set or
                                    self.subscriber_parent_policy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    self.account_type.yfilter != YFilter.not_set or
                                    self.l1_user_defined.yfilter != YFilter.not_set or
                                    self.resource_id.yfilter != YFilter.not_set or
                                    self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                    self.spi_name.yfilter != YFilter.not_set or
                                    self.subscriber_parent_policy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())
                                if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.account_type.get_name_leafdata())
                                if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resource_id.get_name_leafdata())
                                if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spi_name.get_name_leafdata())
                                if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "service-policy-name" or name == "account-type" or name == "l1-user-defined" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "account-type"):
                                    self.account_type = value
                                    self.account_type.value_namespace = name_space
                                    self.account_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "l1-user-defined"):
                                    self.l1_user_defined = value
                                    self.l1_user_defined.value_namespace = name_space
                                    self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                if(value_path == "resource-id"):
                                    self.resource_id = value
                                    self.resource_id.value_namespace = name_space
                                    self.resource_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-fragment-parent-policy"):
                                    self.service_fragment_parent_policy = value
                                    self.service_fragment_parent_policy.value_namespace = name_space
                                    self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spi-name"):
                                    self.spi_name = value
                                    self.spi_name.value_namespace = name_space
                                    self.spi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-parent-policy"):
                                    self.subscriber_parent_policy = value
                                    self.subscriber_parent_policy.value_namespace = name_space
                                    self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "output"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos, self).__setattr__(name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.subscriber_group_name = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2016-12-23'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("subscriber_group_string",
                                                        "account_type",
                                                        "l1_user_defined",
                                                        "policy_merge",
                                                        "resource_id",
                                                        "service_fragment_parent_policy",
                                                        "spi_name",
                                                        "subscriber_parent_policy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.subscriber_group_string.is_set or
                                            self.account_type.is_set or
                                            self.l1_user_defined.is_set or
                                            self.policy_merge.is_set or
                                            self.resource_id.is_set or
                                            self.service_fragment_parent_policy.is_set or
                                            self.spi_name.is_set or
                                            self.subscriber_parent_policy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.subscriber_group_string.yfilter != YFilter.not_set or
                                            self.account_type.yfilter != YFilter.not_set or
                                            self.l1_user_defined.yfilter != YFilter.not_set or
                                            self.policy_merge.yfilter != YFilter.not_set or
                                            self.resource_id.yfilter != YFilter.not_set or
                                            self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                            self.spi_name.yfilter != YFilter.not_set or
                                            self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.subscriber_group_string.is_set or self.subscriber_group_string.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_group_string.get_name_leafdata())
                                        if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.account_type.get_name_leafdata())
                                        if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                        if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                        if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resource_id.get_name_leafdata())
                                        if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                        if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spi_name.get_name_leafdata())
                                        if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "subscriber-group-string" or name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "subscriber-group-string"):
                                            self.subscriber_group_string = value
                                            self.subscriber_group_string.value_namespace = name_space
                                            self.subscriber_group_string.value_namespace_prefix = name_space_prefix
                                        if(value_path == "account-type"):
                                            self.account_type = value
                                            self.account_type.value_namespace = name_space
                                            self.account_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l1-user-defined"):
                                            self.l1_user_defined = value
                                            self.l1_user_defined.value_namespace = name_space
                                            self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                        if(value_path == "policy-merge"):
                                            self.policy_merge = value
                                            self.policy_merge.value_namespace = name_space
                                            self.policy_merge.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resource-id"):
                                            self.resource_id = value
                                            self.resource_id.value_namespace = name_space
                                            self.resource_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "service-fragment-parent-policy"):
                                            self.service_fragment_parent_policy = value
                                            self.service_fragment_parent_policy.value_namespace = name_space
                                            self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spi-name"):
                                            self.spi_name = value
                                            self.spi_name.value_namespace = name_space
                                            self.spi_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "subscriber-parent-policy"):
                                            self.subscriber_parent_policy = value
                                            self.subscriber_parent_policy.value_namespace = name_space
                                            self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-group-names" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "subscriber-group-name"):
                                        for c in self.subscriber_group_name:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.subscriber_group_name.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "subscriber-group-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("account_type",
                                                    "l1_user_defined",
                                                    "policy_merge",
                                                    "resource_id",
                                                    "service_fragment_parent_policy",
                                                    "spi_name",
                                                    "subscriber_parent_policy") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.account_type.is_set or
                                        self.l1_user_defined.is_set or
                                        self.policy_merge.is_set or
                                        self.resource_id.is_set or
                                        self.service_fragment_parent_policy.is_set or
                                        self.spi_name.is_set or
                                        self.subscriber_parent_policy.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.account_type.yfilter != YFilter.not_set or
                                        self.l1_user_defined.yfilter != YFilter.not_set or
                                        self.policy_merge.yfilter != YFilter.not_set or
                                        self.resource_id.yfilter != YFilter.not_set or
                                        self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                        self.spi_name.yfilter != YFilter.not_set or
                                        self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-parent" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.account_type.get_name_leafdata())
                                    if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                    if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                    if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resource_id.get_name_leafdata())
                                    if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                    if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spi_name.get_name_leafdata())
                                    if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "account-type"):
                                        self.account_type = value
                                        self.account_type.value_namespace = name_space
                                        self.account_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l1-user-defined"):
                                        self.l1_user_defined = value
                                        self.l1_user_defined.value_namespace = name_space
                                        self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                    if(value_path == "policy-merge"):
                                        self.policy_merge = value
                                        self.policy_merge.value_namespace = name_space
                                        self.policy_merge.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resource-id"):
                                        self.resource_id = value
                                        self.resource_id.value_namespace = name_space
                                        self.resource_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service-fragment-parent-policy"):
                                        self.service_fragment_parent_policy = value
                                        self.service_fragment_parent_policy.value_namespace = name_space
                                        self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spi-name"):
                                        self.spi_name = value
                                        self.spi_name.value_namespace = name_space
                                        self.spi_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "subscriber-parent-policy"):
                                        self.subscriber_parent_policy = value
                                        self.subscriber_parent_policy.value_namespace = name_space
                                        self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_data()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_operation()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "subscriber-group-names"):
                                    if (self.subscriber_group_names is None):
                                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                        self.subscriber_group_names.parent = self
                                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                    return self.subscriber_group_names

                                if (child_yang_name == "subscriber-parent"):
                                    if (self.subscriber_parent is None):
                                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent()
                                        self.subscriber_parent.parent = self
                                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                    return self.subscriber_parent

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "subscriber-group-names" or name == "subscriber-parent" or name == "service-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.service_policy:
                                if (c.has_data()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.service_policy:
                                if (c.has_operation()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "output" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "service-policy"):
                                for c in self.service_policy:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy.append(c)
                                return c

                            if (child_yang_name == "service-policy-qos"):
                                for c in self.service_policy_qos:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy_qos.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy" or name == "service-policy-qos"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Input(Entity):
                        """
                        Ingress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input, self).__setattr__(name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "input"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name",
                                                "account_type",
                                                "l1_user_defined",
                                                "resource_id",
                                                "service_fragment_parent_policy",
                                                "spi_name",
                                                "subscriber_parent_policy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    self.account_type.is_set or
                                    self.l1_user_defined.is_set or
                                    self.resource_id.is_set or
                                    self.service_fragment_parent_policy.is_set or
                                    self.spi_name.is_set or
                                    self.subscriber_parent_policy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    self.account_type.yfilter != YFilter.not_set or
                                    self.l1_user_defined.yfilter != YFilter.not_set or
                                    self.resource_id.yfilter != YFilter.not_set or
                                    self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                    self.spi_name.yfilter != YFilter.not_set or
                                    self.subscriber_parent_policy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())
                                if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.account_type.get_name_leafdata())
                                if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resource_id.get_name_leafdata())
                                if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spi_name.get_name_leafdata())
                                if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "service-policy-name" or name == "account-type" or name == "l1-user-defined" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "account-type"):
                                    self.account_type = value
                                    self.account_type.value_namespace = name_space
                                    self.account_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "l1-user-defined"):
                                    self.l1_user_defined = value
                                    self.l1_user_defined.value_namespace = name_space
                                    self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                if(value_path == "resource-id"):
                                    self.resource_id = value
                                    self.resource_id.value_namespace = name_space
                                    self.resource_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-fragment-parent-policy"):
                                    self.service_fragment_parent_policy = value
                                    self.service_fragment_parent_policy.value_namespace = name_space
                                    self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spi-name"):
                                    self.spi_name = value
                                    self.spi_name.value_namespace = name_space
                                    self.spi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-parent-policy"):
                                    self.subscriber_parent_policy = value
                                    self.subscriber_parent_policy.value_namespace = name_space
                                    self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "input"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos, self).__setattr__(name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.subscriber_group_name = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2016-12-23'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("subscriber_group_string",
                                                        "account_type",
                                                        "l1_user_defined",
                                                        "policy_merge",
                                                        "resource_id",
                                                        "service_fragment_parent_policy",
                                                        "spi_name",
                                                        "subscriber_parent_policy") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.subscriber_group_string.is_set or
                                            self.account_type.is_set or
                                            self.l1_user_defined.is_set or
                                            self.policy_merge.is_set or
                                            self.resource_id.is_set or
                                            self.service_fragment_parent_policy.is_set or
                                            self.spi_name.is_set or
                                            self.subscriber_parent_policy.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.subscriber_group_string.yfilter != YFilter.not_set or
                                            self.account_type.yfilter != YFilter.not_set or
                                            self.l1_user_defined.yfilter != YFilter.not_set or
                                            self.policy_merge.yfilter != YFilter.not_set or
                                            self.resource_id.yfilter != YFilter.not_set or
                                            self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                            self.spi_name.yfilter != YFilter.not_set or
                                            self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.subscriber_group_string.is_set or self.subscriber_group_string.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_group_string.get_name_leafdata())
                                        if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.account_type.get_name_leafdata())
                                        if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                        if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                        if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resource_id.get_name_leafdata())
                                        if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                        if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.spi_name.get_name_leafdata())
                                        if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "subscriber-group-string" or name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "subscriber-group-string"):
                                            self.subscriber_group_string = value
                                            self.subscriber_group_string.value_namespace = name_space
                                            self.subscriber_group_string.value_namespace_prefix = name_space_prefix
                                        if(value_path == "account-type"):
                                            self.account_type = value
                                            self.account_type.value_namespace = name_space
                                            self.account_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l1-user-defined"):
                                            self.l1_user_defined = value
                                            self.l1_user_defined.value_namespace = name_space
                                            self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                        if(value_path == "policy-merge"):
                                            self.policy_merge = value
                                            self.policy_merge.value_namespace = name_space
                                            self.policy_merge.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resource-id"):
                                            self.resource_id = value
                                            self.resource_id.value_namespace = name_space
                                            self.resource_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "service-fragment-parent-policy"):
                                            self.service_fragment_parent_policy = value
                                            self.service_fragment_parent_policy.value_namespace = name_space
                                            self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "spi-name"):
                                            self.spi_name = value
                                            self.spi_name.value_namespace = name_space
                                            self.spi_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "subscriber-parent-policy"):
                                            self.subscriber_parent_policy = value
                                            self.subscriber_parent_policy.value_namespace = name_space
                                            self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.subscriber_group_name:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-group-names" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "subscriber-group-name"):
                                        for c in self.subscriber_group_name:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.subscriber_group_name.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "subscriber-group-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2016-12-23'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("account_type",
                                                    "l1_user_defined",
                                                    "policy_merge",
                                                    "resource_id",
                                                    "service_fragment_parent_policy",
                                                    "spi_name",
                                                    "subscriber_parent_policy") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.account_type.is_set or
                                        self.l1_user_defined.is_set or
                                        self.policy_merge.is_set or
                                        self.resource_id.is_set or
                                        self.service_fragment_parent_policy.is_set or
                                        self.spi_name.is_set or
                                        self.subscriber_parent_policy.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.account_type.yfilter != YFilter.not_set or
                                        self.l1_user_defined.yfilter != YFilter.not_set or
                                        self.policy_merge.yfilter != YFilter.not_set or
                                        self.resource_id.yfilter != YFilter.not_set or
                                        self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                        self.spi_name.yfilter != YFilter.not_set or
                                        self.subscriber_parent_policy.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-parent" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.account_type.get_name_leafdata())
                                    if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                    if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                    if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resource_id.get_name_leafdata())
                                    if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                    if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.spi_name.get_name_leafdata())
                                    if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "account-type"):
                                        self.account_type = value
                                        self.account_type.value_namespace = name_space
                                        self.account_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l1-user-defined"):
                                        self.l1_user_defined = value
                                        self.l1_user_defined.value_namespace = name_space
                                        self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                    if(value_path == "policy-merge"):
                                        self.policy_merge = value
                                        self.policy_merge.value_namespace = name_space
                                        self.policy_merge.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resource-id"):
                                        self.resource_id = value
                                        self.resource_id.value_namespace = name_space
                                        self.resource_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service-fragment-parent-policy"):
                                        self.service_fragment_parent_policy = value
                                        self.service_fragment_parent_policy.value_namespace = name_space
                                        self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "spi-name"):
                                        self.spi_name = value
                                        self.spi_name.value_namespace = name_space
                                        self.spi_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "subscriber-parent-policy"):
                                        self.subscriber_parent_policy = value
                                        self.subscriber_parent_policy.value_namespace = name_space
                                        self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.service_policy_name.is_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_data()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set or
                                    (self.subscriber_group_names is not None and self.subscriber_group_names.has_operation()) or
                                    (self.subscriber_parent is not None and self.subscriber_parent.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "subscriber-group-names"):
                                    if (self.subscriber_group_names is None):
                                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                        self.subscriber_group_names.parent = self
                                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                    return self.subscriber_group_names

                                if (child_yang_name == "subscriber-parent"):
                                    if (self.subscriber_parent is None):
                                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent()
                                        self.subscriber_parent.parent = self
                                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                    return self.subscriber_parent

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "subscriber-group-names" or name == "subscriber-parent" or name == "service-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.service_policy:
                                if (c.has_data()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.service_policy:
                                if (c.has_operation()):
                                    return True
                            for c in self.service_policy_qos:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "input" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "service-policy"):
                                for c in self.service_policy:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy.append(c)
                                return c

                            if (child_yang_name == "service-policy-qos"):
                                for c in self.service_policy_qos:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy_qos.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy" or name == "service-policy-qos"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.input is not None and self.input.has_data()) or
                            (self.output is not None and self.output.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.input is not None and self.input.has_operation()) or
                            (self.output is not None and self.output.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "qos" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "input"):
                            if (self.input is None):
                                self.input = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input()
                                self.input.parent = self
                                self._children_name_map["input"] = "input"
                            return self.input

                        if (child_yang_name == "output"):
                            if (self.output is None):
                                self.output = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output()
                                self.output.parent = self
                                self._children_name_map["output"] = "output"
                            return self.output

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "input" or name == "output"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.qos is not None and self.qos.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.qos is not None and self.qos.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-qos-ma-cfg:cac" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "qos"):
                        if (self.qos is None):
                            self.qos = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos()
                            self.qos.parent = self
                            self._children_name_map["qos"] = "qos"
                        return self.qos

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "qos"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.enabled.is_set or
                    self.propagate_remote_status.is_set or
                    (self.atm_port_mode_parameters is not None and self.atm_port_mode_parameters.has_data()) or
                    (self.cac is not None and self.cac.has_data()) or
                    (self.l2_ethernet_features is not None and self.l2_ethernet_features.has_data()) or
                    (self.l2_protocols is not None and self.l2_protocols.has_data()) or
                    (self.pac is not None and self.pac.has_data()) or
                    (self.span_monitor_sessions is not None and self.span_monitor_sessions.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.enabled.yfilter != YFilter.not_set or
                    self.propagate_remote_status.yfilter != YFilter.not_set or
                    (self.atm_port_mode_parameters is not None and self.atm_port_mode_parameters.has_operation()) or
                    (self.cac is not None and self.cac.has_operation()) or
                    (self.l2_ethernet_features is not None and self.l2_ethernet_features.has_operation()) or
                    (self.l2_protocols is not None and self.l2_protocols.has_operation()) or
                    (self.pac is not None and self.pac.has_operation()) or
                    (self.span_monitor_sessions is not None and self.span_monitor_sessions.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2vpn-cfg:l2-transport" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.enabled.is_set or self.enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.enabled.get_name_leafdata())
                if (self.propagate_remote_status.is_set or self.propagate_remote_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.propagate_remote_status.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "atm-port-mode-parameters"):
                    if (self.atm_port_mode_parameters is None):
                        self.atm_port_mode_parameters = InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters()
                        self.atm_port_mode_parameters.parent = self
                        self._children_name_map["atm_port_mode_parameters"] = "atm-port-mode-parameters"
                    return self.atm_port_mode_parameters

                if (child_yang_name == "cac"):
                    if (self.cac is None):
                        self.cac = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac()
                        self.cac.parent = self
                        self._children_name_map["cac"] = "cac"
                    return self.cac

                if (child_yang_name == "l2-ethernet-features"):
                    if (self.l2_ethernet_features is None):
                        self.l2_ethernet_features = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures()
                        self.l2_ethernet_features.parent = self
                        self._children_name_map["l2_ethernet_features"] = "l2-ethernet-features"
                    return self.l2_ethernet_features

                if (child_yang_name == "l2-protocols"):
                    if (self.l2_protocols is None):
                        self.l2_protocols = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols()
                        self.l2_protocols.parent = self
                        self._children_name_map["l2_protocols"] = "l2-protocols"
                    return self.l2_protocols

                if (child_yang_name == "pac"):
                    if (self.pac is None):
                        self.pac = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac()
                        self.pac.parent = self
                        self._children_name_map["pac"] = "pac"
                    return self.pac

                if (child_yang_name == "span-monitor-sessions"):
                    if (self.span_monitor_sessions is None):
                        self.span_monitor_sessions = InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions()
                        self.span_monitor_sessions.parent = self
                        self._children_name_map["span_monitor_sessions"] = "span-monitor-sessions"
                    return self.span_monitor_sessions

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "atm-port-mode-parameters" or name == "cac" or name == "l2-ethernet-features" or name == "l2-protocols" or name == "pac" or name == "span-monitor-sessions" or name == "enabled" or name == "propagate-remote-status"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "enabled"):
                    self.enabled = value
                    self.enabled.value_namespace = name_space
                    self.enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "propagate-remote-status"):
                    self.propagate_remote_status = value
                    self.propagate_remote_status.value_namespace = name_space
                    self.propagate_remote_status.value_namespace_prefix = name_space_prefix


        class Atm(Entity):
            """
            ATM Configuration
            
            .. attribute:: max_vpi_bits
            
            	Support 12\-bits VPI cell format
            	**type**\:   :py:class:`AtmVpiBitsMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_vcm_cfg.AtmVpiBitsMode>`
            
            .. attribute:: maximum_cell_packing_timers
            
            	Configure maximum cell\-packing timers.  All parameters are mandatory
            	**type**\:   :py:class:`MaximumCellPackingTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers>`
            
            	**presence node**\: True
            
            .. attribute:: pvcs
            
            	PVC Configuration
            	**type**\:   :py:class:`Pvcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs>`
            
            .. attribute:: pvps
            
            	PVP Configuration
            	**type**\:   :py:class:`Pvps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps>`
            
            .. attribute:: vc_class
            
            	Name of the VC class
            	**type**\:  str
            
            	**length:** 1..30
            
            .. attribute:: vp_tunnels
            
            	VP tunnel configuration
            	**type**\:   :py:class:`VpTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels>`
            
            

            """

            _prefix = 'atm-vcm-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Atm, self).__init__()

                self.yang_name = "atm"
                self.yang_parent_name = "interface-configuration"

                self.max_vpi_bits = YLeaf(YType.enumeration, "max-vpi-bits")

                self.vc_class = YLeaf(YType.str, "vc-class")

                self.maximum_cell_packing_timers = None
                self._children_name_map["maximum_cell_packing_timers"] = "maximum-cell-packing-timers"
                self._children_yang_names.add("maximum-cell-packing-timers")

                self.pvcs = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs()
                self.pvcs.parent = self
                self._children_name_map["pvcs"] = "pvcs"
                self._children_yang_names.add("pvcs")

                self.pvps = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps()
                self.pvps.parent = self
                self._children_name_map["pvps"] = "pvps"
                self._children_yang_names.add("pvps")

                self.vp_tunnels = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels()
                self.vp_tunnels.parent = self
                self._children_name_map["vp_tunnels"] = "vp-tunnels"
                self._children_yang_names.add("vp-tunnels")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("max_vpi_bits",
                                "vc_class") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm, self).__setattr__(name, value)


            class Pvps(Entity):
                """
                PVP Configuration
                
                .. attribute:: pvp
                
                	Configuration of particular PVP
                	**type**\: list of    :py:class:`Pvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp>`
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps, self).__init__()

                    self.yang_name = "pvps"
                    self.yang_parent_name = "atm"

                    self.pvp = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps, self).__setattr__(name, value)


                class Pvp(Entity):
                    """
                    Configuration of particular PVP
                    
                    .. attribute:: vpi  <key>
                    
                    	VPI value
                    	**type**\:  int
                    
                    	**range:** 0..4095
                    
                    .. attribute:: cell_packing
                    
                    	Configure cell\-packing parameters.  All parameters are mandatory
                    	**type**\:   :py:class:`CellPacking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: enable
                    
                    	Create the PVP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: oam_segment_endpoint
                    
                    	Enable L2VPN PVP OAM segment endpoint
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: shape
                    
                    	Configure traffic shaping parameters
                    	**type**\:   :py:class:`Shape <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape>`
                    
                    .. attribute:: test_mode
                    
                    	Configure the PVP test mode
                    	**type**\:   :py:class:`AtmPvpTestMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_vcm_cfg.AtmPvpTestMode>`
                    
                    

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp, self).__init__()

                        self.yang_name = "pvp"
                        self.yang_parent_name = "pvps"

                        self.vpi = YLeaf(YType.uint32, "vpi")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.oam_segment_endpoint = YLeaf(YType.empty, "oam-segment-endpoint")

                        self.test_mode = YLeaf(YType.enumeration, "test-mode")

                        self.cell_packing = None
                        self._children_name_map["cell_packing"] = "cell-packing"
                        self._children_yang_names.add("cell-packing")

                        self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._children_yang_names.add("shape")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vpi",
                                        "enable",
                                        "oam_segment_endpoint",
                                        "test_mode") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp, self).__setattr__(name, value)


                    class Shape(Entity):
                        """
                        Configure traffic shaping parameters
                        
                        .. attribute:: burst_size
                        
                        	Burst size in cells
                        	**type**\:  int
                        
                        	**range:** 1..8192
                        
                        .. attribute:: peak_cell_rate
                        
                        	Peak cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: sustained_cell_rate
                        
                        	Sustained cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: type
                        
                        	Traffic shaping type
                        	**type**\:   :py:class:`AtmPvcShaping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcShaping>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "pvp"

                            self.burst_size = YLeaf(YType.uint32, "burst-size")

                            self.peak_cell_rate = YLeaf(YType.uint32, "peak-cell-rate")

                            self.sustained_cell_rate = YLeaf(YType.uint32, "sustained-cell-rate")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("burst_size",
                                            "peak_cell_rate",
                                            "sustained_cell_rate",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.burst_size.is_set or
                                self.peak_cell_rate.is_set or
                                self.sustained_cell_rate.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.burst_size.yfilter != YFilter.not_set or
                                self.peak_cell_rate.yfilter != YFilter.not_set or
                                self.sustained_cell_rate.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "shape" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.burst_size.is_set or self.burst_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.burst_size.get_name_leafdata())
                            if (self.peak_cell_rate.is_set or self.peak_cell_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.peak_cell_rate.get_name_leafdata())
                            if (self.sustained_cell_rate.is_set or self.sustained_cell_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sustained_cell_rate.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "burst-size" or name == "peak-cell-rate" or name == "sustained-cell-rate" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "burst-size"):
                                self.burst_size = value
                                self.burst_size.value_namespace = name_space
                                self.burst_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "peak-cell-rate"):
                                self.peak_cell_rate = value
                                self.peak_cell_rate.value_namespace = name_space
                                self.peak_cell_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "sustained-cell-rate"):
                                self.sustained_cell_rate = value
                                self.sustained_cell_rate.value_namespace = name_space
                                self.sustained_cell_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class CellPacking(Entity):
                        """
                        Configure cell\-packing parameters.  All
                        parameters are mandatory.
                        
                        .. attribute:: cell_packing_timer_id
                        
                        	Which cell packing timer to use
                        	**type**\:  int
                        
                        	**range:** 1..3
                        
                        	**mandatory**\: True
                        
                        .. attribute:: maximum_cells_packed
                        
                        	Maximum number of cells to be packed in a packet
                        	**type**\:  int
                        
                        	**range:** 2..255
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking, self).__init__()

                            self.yang_name = "cell-packing"
                            self.yang_parent_name = "pvp"
                            self.is_presence_container = True

                            self.cell_packing_timer_id = YLeaf(YType.uint32, "cell-packing-timer-id")

                            self.maximum_cells_packed = YLeaf(YType.uint32, "maximum-cells-packed")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cell_packing_timer_id",
                                            "maximum_cells_packed") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.cell_packing_timer_id.is_set or
                                self.maximum_cells_packed.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cell_packing_timer_id.yfilter != YFilter.not_set or
                                self.maximum_cells_packed.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "cell-packing" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cell_packing_timer_id.is_set or self.cell_packing_timer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cell_packing_timer_id.get_name_leafdata())
                            if (self.maximum_cells_packed.is_set or self.maximum_cells_packed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_cells_packed.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "cell-packing-timer-id" or name == "maximum-cells-packed"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cell-packing-timer-id"):
                                self.cell_packing_timer_id = value
                                self.cell_packing_timer_id.value_namespace = name_space
                                self.cell_packing_timer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-cells-packed"):
                                self.maximum_cells_packed = value
                                self.maximum_cells_packed.value_namespace = name_space
                                self.maximum_cells_packed.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.vpi.is_set or
                            self.enable.is_set or
                            self.oam_segment_endpoint.is_set or
                            self.test_mode.is_set or
                            (self.shape is not None and self.shape.has_data()) or
                            (self.cell_packing is not None))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vpi.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.oam_segment_endpoint.yfilter != YFilter.not_set or
                            self.test_mode.yfilter != YFilter.not_set or
                            (self.cell_packing is not None and self.cell_packing.has_operation()) or
                            (self.shape is not None and self.shape.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pvp" + "[vpi='" + self.vpi.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpi.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.oam_segment_endpoint.is_set or self.oam_segment_endpoint.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.oam_segment_endpoint.get_name_leafdata())
                        if (self.test_mode.is_set or self.test_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.test_mode.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "cell-packing"):
                            if (self.cell_packing is None):
                                self.cell_packing = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking()
                                self.cell_packing.parent = self
                                self._children_name_map["cell_packing"] = "cell-packing"
                            return self.cell_packing

                        if (child_yang_name == "shape"):
                            if (self.shape is None):
                                self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape()
                                self.shape.parent = self
                                self._children_name_map["shape"] = "shape"
                            return self.shape

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "cell-packing" or name == "shape" or name == "vpi" or name == "enable" or name == "oam-segment-endpoint" or name == "test-mode"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vpi"):
                            self.vpi = value
                            self.vpi.value_namespace = name_space
                            self.vpi.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "oam-segment-endpoint"):
                            self.oam_segment_endpoint = value
                            self.oam_segment_endpoint.value_namespace = name_space
                            self.oam_segment_endpoint.value_namespace_prefix = name_space_prefix
                        if(value_path == "test-mode"):
                            self.test_mode = value
                            self.test_mode.value_namespace = name_space
                            self.test_mode.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.pvp:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.pvp:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pvps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pvp"):
                        for c in self.pvp:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pvp.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pvp"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Pvcs(Entity):
                """
                PVC Configuration
                
                .. attribute:: pvc
                
                	Configuration particular PVC
                	**type**\: list of    :py:class:`Pvc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc>`
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs, self).__init__()

                    self.yang_name = "pvcs"
                    self.yang_parent_name = "atm"

                    self.pvc = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs, self).__setattr__(name, value)


                class Pvc(Entity):
                    """
                    Configuration particular PVC
                    
                    .. attribute:: vpi  <key>
                    
                    	VPI value
                    	**type**\:  int
                    
                    	**range:** 0..4095
                    
                    .. attribute:: vci  <key>
                    
                    	VCI value
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: pv_ctype  <key>
                    
                    	PVC type
                    	**type**\:   :py:class:`AtmPvcData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcData>`
                    
                    .. attribute:: cell_packing
                    
                    	Configure cell\-packing parameters.  All parameters are mandatory
                    	**type**\:   :py:class:`CellPacking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: enable
                    
                    	Create the PVC
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: encapsulation
                    
                    	Configure encapsulation
                    	**type**\:   :py:class:`AtmPvcEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcEncapsulation>`
                    
                    .. attribute:: oam_emulation
                    
                    	L2VPN OAM emulation
                    	**type**\:   :py:class:`OamEmulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation>`
                    
                    .. attribute:: oam_segment_endpoint
                    
                    	Enable L2VPN PVC OAM segment endpoint
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: shape
                    
                    	Configure traffic shaping parameters
                    	**type**\:   :py:class:`Shape <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape>`
                    
                    .. attribute:: test_mode
                    
                    	Configure the PVC test mode
                    	**type**\:   :py:class:`AtmPvcTestMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_vcm_cfg.AtmPvcTestMode>`
                    
                    .. attribute:: vc_class
                    
                    	Name of the VC class
                    	**type**\:  str
                    
                    	**length:** 1..30
                    
                    

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc, self).__init__()

                        self.yang_name = "pvc"
                        self.yang_parent_name = "pvcs"

                        self.vpi = YLeaf(YType.uint32, "vpi")

                        self.vci = YLeaf(YType.uint32, "vci")

                        self.pv_ctype = YLeaf(YType.enumeration, "pv-ctype")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                        self.oam_segment_endpoint = YLeaf(YType.empty, "oam-segment-endpoint")

                        self.test_mode = YLeaf(YType.enumeration, "test-mode")

                        self.vc_class = YLeaf(YType.str, "vc-class")

                        self.cell_packing = None
                        self._children_name_map["cell_packing"] = "cell-packing"
                        self._children_yang_names.add("cell-packing")

                        self.oam_emulation = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation()
                        self.oam_emulation.parent = self
                        self._children_name_map["oam_emulation"] = "oam-emulation"
                        self._children_yang_names.add("oam-emulation")

                        self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._children_yang_names.add("shape")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vpi",
                                        "vci",
                                        "pv_ctype",
                                        "enable",
                                        "encapsulation",
                                        "oam_segment_endpoint",
                                        "test_mode",
                                        "vc_class") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc, self).__setattr__(name, value)


                    class Shape(Entity):
                        """
                        Configure traffic shaping parameters
                        
                        .. attribute:: burst_size
                        
                        	Burst size in cells
                        	**type**\:  int
                        
                        	**range:** 1..8192
                        
                        .. attribute:: peak_cell_rate
                        
                        	Peak cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: sustained_cell_rate
                        
                        	Sustained cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: type
                        
                        	Traffic shaping type
                        	**type**\:   :py:class:`AtmPvcShaping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcShaping>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "pvc"

                            self.burst_size = YLeaf(YType.uint32, "burst-size")

                            self.peak_cell_rate = YLeaf(YType.uint32, "peak-cell-rate")

                            self.sustained_cell_rate = YLeaf(YType.uint32, "sustained-cell-rate")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("burst_size",
                                            "peak_cell_rate",
                                            "sustained_cell_rate",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.burst_size.is_set or
                                self.peak_cell_rate.is_set or
                                self.sustained_cell_rate.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.burst_size.yfilter != YFilter.not_set or
                                self.peak_cell_rate.yfilter != YFilter.not_set or
                                self.sustained_cell_rate.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "shape" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.burst_size.is_set or self.burst_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.burst_size.get_name_leafdata())
                            if (self.peak_cell_rate.is_set or self.peak_cell_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.peak_cell_rate.get_name_leafdata())
                            if (self.sustained_cell_rate.is_set or self.sustained_cell_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sustained_cell_rate.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "burst-size" or name == "peak-cell-rate" or name == "sustained-cell-rate" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "burst-size"):
                                self.burst_size = value
                                self.burst_size.value_namespace = name_space
                                self.burst_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "peak-cell-rate"):
                                self.peak_cell_rate = value
                                self.peak_cell_rate.value_namespace = name_space
                                self.peak_cell_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "sustained-cell-rate"):
                                self.sustained_cell_rate = value
                                self.sustained_cell_rate.value_namespace = name_space
                                self.sustained_cell_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class OamEmulation(Entity):
                        """
                        L2VPN OAM emulation
                        
                        .. attribute:: ais_transmit_rate
                        
                        	AIS cell transmit rate (1 per x seconds)
                        	**type**\:  int
                        
                        	**range:** 0..60
                        
                        .. attribute:: enable
                        
                        	Enable OAM emulation
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation, self).__init__()

                            self.yang_name = "oam-emulation"
                            self.yang_parent_name = "pvc"

                            self.ais_transmit_rate = YLeaf(YType.uint32, "ais-transmit-rate")

                            self.enable = YLeaf(YType.empty, "enable")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ais_transmit_rate",
                                            "enable") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ais_transmit_rate.is_set or
                                self.enable.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ais_transmit_rate.yfilter != YFilter.not_set or
                                self.enable.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oam-emulation" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ais_transmit_rate.is_set or self.ais_transmit_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ais_transmit_rate.get_name_leafdata())
                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enable.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ais-transmit-rate" or name == "enable"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ais-transmit-rate"):
                                self.ais_transmit_rate = value
                                self.ais_transmit_rate.value_namespace = name_space
                                self.ais_transmit_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "enable"):
                                self.enable = value
                                self.enable.value_namespace = name_space
                                self.enable.value_namespace_prefix = name_space_prefix


                    class CellPacking(Entity):
                        """
                        Configure cell\-packing parameters.  All
                        parameters are mandatory.
                        
                        .. attribute:: cell_packing_timer_id
                        
                        	Which cell packing timer to use
                        	**type**\:  int
                        
                        	**range:** 1..3
                        
                        	**mandatory**\: True
                        
                        .. attribute:: maximum_cells_packed
                        
                        	Maximum number of cells to be packed in a packet
                        	**type**\:  int
                        
                        	**range:** 2..255
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking, self).__init__()

                            self.yang_name = "cell-packing"
                            self.yang_parent_name = "pvc"
                            self.is_presence_container = True

                            self.cell_packing_timer_id = YLeaf(YType.uint32, "cell-packing-timer-id")

                            self.maximum_cells_packed = YLeaf(YType.uint32, "maximum-cells-packed")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cell_packing_timer_id",
                                            "maximum_cells_packed") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.cell_packing_timer_id.is_set or
                                self.maximum_cells_packed.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cell_packing_timer_id.yfilter != YFilter.not_set or
                                self.maximum_cells_packed.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "cell-packing" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cell_packing_timer_id.is_set or self.cell_packing_timer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cell_packing_timer_id.get_name_leafdata())
                            if (self.maximum_cells_packed.is_set or self.maximum_cells_packed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_cells_packed.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "cell-packing-timer-id" or name == "maximum-cells-packed"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cell-packing-timer-id"):
                                self.cell_packing_timer_id = value
                                self.cell_packing_timer_id.value_namespace = name_space
                                self.cell_packing_timer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-cells-packed"):
                                self.maximum_cells_packed = value
                                self.maximum_cells_packed.value_namespace = name_space
                                self.maximum_cells_packed.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.vpi.is_set or
                            self.vci.is_set or
                            self.pv_ctype.is_set or
                            self.enable.is_set or
                            self.encapsulation.is_set or
                            self.oam_segment_endpoint.is_set or
                            self.test_mode.is_set or
                            self.vc_class.is_set or
                            (self.oam_emulation is not None and self.oam_emulation.has_data()) or
                            (self.shape is not None and self.shape.has_data()) or
                            (self.cell_packing is not None))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vpi.yfilter != YFilter.not_set or
                            self.vci.yfilter != YFilter.not_set or
                            self.pv_ctype.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.encapsulation.yfilter != YFilter.not_set or
                            self.oam_segment_endpoint.yfilter != YFilter.not_set or
                            self.test_mode.yfilter != YFilter.not_set or
                            self.vc_class.yfilter != YFilter.not_set or
                            (self.cell_packing is not None and self.cell_packing.has_operation()) or
                            (self.oam_emulation is not None and self.oam_emulation.has_operation()) or
                            (self.shape is not None and self.shape.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pvc" + "[vpi='" + self.vpi.get() + "']" + "[vci='" + self.vci.get() + "']" + "[pv-ctype='" + self.pv_ctype.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpi.get_name_leafdata())
                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vci.get_name_leafdata())
                        if (self.pv_ctype.is_set or self.pv_ctype.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pv_ctype.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation.get_name_leafdata())
                        if (self.oam_segment_endpoint.is_set or self.oam_segment_endpoint.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.oam_segment_endpoint.get_name_leafdata())
                        if (self.test_mode.is_set or self.test_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.test_mode.get_name_leafdata())
                        if (self.vc_class.is_set or self.vc_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vc_class.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "cell-packing"):
                            if (self.cell_packing is None):
                                self.cell_packing = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking()
                                self.cell_packing.parent = self
                                self._children_name_map["cell_packing"] = "cell-packing"
                            return self.cell_packing

                        if (child_yang_name == "oam-emulation"):
                            if (self.oam_emulation is None):
                                self.oam_emulation = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation()
                                self.oam_emulation.parent = self
                                self._children_name_map["oam_emulation"] = "oam-emulation"
                            return self.oam_emulation

                        if (child_yang_name == "shape"):
                            if (self.shape is None):
                                self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape()
                                self.shape.parent = self
                                self._children_name_map["shape"] = "shape"
                            return self.shape

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "cell-packing" or name == "oam-emulation" or name == "shape" or name == "vpi" or name == "vci" or name == "pv-ctype" or name == "enable" or name == "encapsulation" or name == "oam-segment-endpoint" or name == "test-mode" or name == "vc-class"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vpi"):
                            self.vpi = value
                            self.vpi.value_namespace = name_space
                            self.vpi.value_namespace_prefix = name_space_prefix
                        if(value_path == "vci"):
                            self.vci = value
                            self.vci.value_namespace = name_space
                            self.vci.value_namespace_prefix = name_space_prefix
                        if(value_path == "pv-ctype"):
                            self.pv_ctype = value
                            self.pv_ctype.value_namespace = name_space
                            self.pv_ctype.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation"):
                            self.encapsulation = value
                            self.encapsulation.value_namespace = name_space
                            self.encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "oam-segment-endpoint"):
                            self.oam_segment_endpoint = value
                            self.oam_segment_endpoint.value_namespace = name_space
                            self.oam_segment_endpoint.value_namespace_prefix = name_space_prefix
                        if(value_path == "test-mode"):
                            self.test_mode = value
                            self.test_mode.value_namespace = name_space
                            self.test_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "vc-class"):
                            self.vc_class = value
                            self.vc_class.value_namespace = name_space
                            self.vc_class.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.pvc:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.pvc:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pvcs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pvc"):
                        for c in self.pvc:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pvc.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pvc"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MaximumCellPackingTimers(Entity):
                """
                Configure maximum cell\-packing timers.  All
                parameters are mandatory.
                
                .. attribute:: cell_packing_timer1
                
                	Cell\-packing timer1 (micro seconds)
                	**type**\:  int
                
                	**range:** 50..4095
                
                	**mandatory**\: True
                
                .. attribute:: cell_packing_timer2
                
                	Cell\-packing timer2 (micro seconds)
                	**type**\:  int
                
                	**range:** 50..4095
                
                	**mandatory**\: True
                
                .. attribute:: cell_packing_timer3
                
                	Cell\-packing timer3 (micro seconds)
                	**type**\:  int
                
                	**range:** 50..4095
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers, self).__init__()

                    self.yang_name = "maximum-cell-packing-timers"
                    self.yang_parent_name = "atm"
                    self.is_presence_container = True

                    self.cell_packing_timer1 = YLeaf(YType.uint32, "cell-packing-timer1")

                    self.cell_packing_timer2 = YLeaf(YType.uint32, "cell-packing-timer2")

                    self.cell_packing_timer3 = YLeaf(YType.uint32, "cell-packing-timer3")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("cell_packing_timer1",
                                    "cell_packing_timer2",
                                    "cell_packing_timer3") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.cell_packing_timer1.is_set or
                        self.cell_packing_timer2.is_set or
                        self.cell_packing_timer3.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.cell_packing_timer1.yfilter != YFilter.not_set or
                        self.cell_packing_timer2.yfilter != YFilter.not_set or
                        self.cell_packing_timer3.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "maximum-cell-packing-timers" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.cell_packing_timer1.is_set or self.cell_packing_timer1.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cell_packing_timer1.get_name_leafdata())
                    if (self.cell_packing_timer2.is_set or self.cell_packing_timer2.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cell_packing_timer2.get_name_leafdata())
                    if (self.cell_packing_timer3.is_set or self.cell_packing_timer3.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cell_packing_timer3.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "cell-packing-timer1" or name == "cell-packing-timer2" or name == "cell-packing-timer3"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "cell-packing-timer1"):
                        self.cell_packing_timer1 = value
                        self.cell_packing_timer1.value_namespace = name_space
                        self.cell_packing_timer1.value_namespace_prefix = name_space_prefix
                    if(value_path == "cell-packing-timer2"):
                        self.cell_packing_timer2 = value
                        self.cell_packing_timer2.value_namespace = name_space
                        self.cell_packing_timer2.value_namespace_prefix = name_space_prefix
                    if(value_path == "cell-packing-timer3"):
                        self.cell_packing_timer3 = value
                        self.cell_packing_timer3.value_namespace = name_space
                        self.cell_packing_timer3.value_namespace_prefix = name_space_prefix


            class VpTunnels(Entity):
                """
                VP tunnel configuration
                
                .. attribute:: vp_tunnel
                
                	Configure a VP tunnel on this interface
                	**type**\: list of    :py:class:`VpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel>`
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels, self).__init__()

                    self.yang_name = "vp-tunnels"
                    self.yang_parent_name = "atm"

                    self.vp_tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels, self).__setattr__(name, value)


                class VpTunnel(Entity):
                    """
                    Configure a VP tunnel on this interface
                    
                    .. attribute:: vpi  <key>
                    
                    	VPI value
                    	**type**\:  int
                    
                    	**range:** 0..4095
                    
                    .. attribute:: disable_f4oam
                    
                    	Disable F4 OAM configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Create the VP Tunnel
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable_hierarchical_shaping
                    
                    	Enable Hierarchical Shaping configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: shape
                    
                    	Configure Traffic shaping parameters
                    	**type**\:   :py:class:`Shape <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape>`
                    
                    

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel, self).__init__()

                        self.yang_name = "vp-tunnel"
                        self.yang_parent_name = "vp-tunnels"

                        self.vpi = YLeaf(YType.uint32, "vpi")

                        self.disable_f4oam = YLeaf(YType.empty, "disable-f4oam")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.enable_hierarchical_shaping = YLeaf(YType.empty, "enable-hierarchical-shaping")

                        self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._children_yang_names.add("shape")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vpi",
                                        "disable_f4oam",
                                        "enable",
                                        "enable_hierarchical_shaping") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel, self).__setattr__(name, value)


                    class Shape(Entity):
                        """
                        Configure Traffic shaping parameters
                        
                        .. attribute:: burst_size
                        
                        	Burst size in cells
                        	**type**\:  int
                        
                        	**range:** 1..8192
                        
                        .. attribute:: peak_cell_rate
                        
                        	Peak cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: sustained_cell_rate
                        
                        	Sustained cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: type
                        
                        	Traffic shaping type
                        	**type**\:   :py:class:`AtmVpShaping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmVpShaping>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "vp-tunnel"

                            self.burst_size = YLeaf(YType.uint32, "burst-size")

                            self.peak_cell_rate = YLeaf(YType.uint32, "peak-cell-rate")

                            self.sustained_cell_rate = YLeaf(YType.uint32, "sustained-cell-rate")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("burst_size",
                                            "peak_cell_rate",
                                            "sustained_cell_rate",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.burst_size.is_set or
                                self.peak_cell_rate.is_set or
                                self.sustained_cell_rate.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.burst_size.yfilter != YFilter.not_set or
                                self.peak_cell_rate.yfilter != YFilter.not_set or
                                self.sustained_cell_rate.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "shape" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.burst_size.is_set or self.burst_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.burst_size.get_name_leafdata())
                            if (self.peak_cell_rate.is_set or self.peak_cell_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.peak_cell_rate.get_name_leafdata())
                            if (self.sustained_cell_rate.is_set or self.sustained_cell_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sustained_cell_rate.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "burst-size" or name == "peak-cell-rate" or name == "sustained-cell-rate" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "burst-size"):
                                self.burst_size = value
                                self.burst_size.value_namespace = name_space
                                self.burst_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "peak-cell-rate"):
                                self.peak_cell_rate = value
                                self.peak_cell_rate.value_namespace = name_space
                                self.peak_cell_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "sustained-cell-rate"):
                                self.sustained_cell_rate = value
                                self.sustained_cell_rate.value_namespace = name_space
                                self.sustained_cell_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.vpi.is_set or
                            self.disable_f4oam.is_set or
                            self.enable.is_set or
                            self.enable_hierarchical_shaping.is_set or
                            (self.shape is not None and self.shape.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vpi.yfilter != YFilter.not_set or
                            self.disable_f4oam.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.enable_hierarchical_shaping.yfilter != YFilter.not_set or
                            (self.shape is not None and self.shape.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vp-tunnel" + "[vpi='" + self.vpi.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpi.get_name_leafdata())
                        if (self.disable_f4oam.is_set or self.disable_f4oam.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_f4oam.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.enable_hierarchical_shaping.is_set or self.enable_hierarchical_shaping.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable_hierarchical_shaping.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "shape"):
                            if (self.shape is None):
                                self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape()
                                self.shape.parent = self
                                self._children_name_map["shape"] = "shape"
                            return self.shape

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "shape" or name == "vpi" or name == "disable-f4oam" or name == "enable" or name == "enable-hierarchical-shaping"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vpi"):
                            self.vpi = value
                            self.vpi.value_namespace = name_space
                            self.vpi.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-f4oam"):
                            self.disable_f4oam = value
                            self.disable_f4oam.value_namespace = name_space
                            self.disable_f4oam.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable-hierarchical-shaping"):
                            self.enable_hierarchical_shaping = value
                            self.enable_hierarchical_shaping.value_namespace = name_space
                            self.enable_hierarchical_shaping.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.vp_tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.vp_tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vp-tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "vp-tunnel"):
                        for c in self.vp_tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.vp_tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vp-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.max_vpi_bits.is_set or
                    self.vc_class.is_set or
                    (self.pvcs is not None and self.pvcs.has_data()) or
                    (self.pvps is not None and self.pvps.has_data()) or
                    (self.vp_tunnels is not None and self.vp_tunnels.has_data()) or
                    (self.maximum_cell_packing_timers is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.max_vpi_bits.yfilter != YFilter.not_set or
                    self.vc_class.yfilter != YFilter.not_set or
                    (self.maximum_cell_packing_timers is not None and self.maximum_cell_packing_timers.has_operation()) or
                    (self.pvcs is not None and self.pvcs.has_operation()) or
                    (self.pvps is not None and self.pvps.has_operation()) or
                    (self.vp_tunnels is not None and self.vp_tunnels.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-atm-vcm-cfg:atm" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.max_vpi_bits.is_set or self.max_vpi_bits.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.max_vpi_bits.get_name_leafdata())
                if (self.vc_class.is_set or self.vc_class.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vc_class.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "maximum-cell-packing-timers"):
                    if (self.maximum_cell_packing_timers is None):
                        self.maximum_cell_packing_timers = InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers()
                        self.maximum_cell_packing_timers.parent = self
                        self._children_name_map["maximum_cell_packing_timers"] = "maximum-cell-packing-timers"
                    return self.maximum_cell_packing_timers

                if (child_yang_name == "pvcs"):
                    if (self.pvcs is None):
                        self.pvcs = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs()
                        self.pvcs.parent = self
                        self._children_name_map["pvcs"] = "pvcs"
                    return self.pvcs

                if (child_yang_name == "pvps"):
                    if (self.pvps is None):
                        self.pvps = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps()
                        self.pvps.parent = self
                        self._children_name_map["pvps"] = "pvps"
                    return self.pvps

                if (child_yang_name == "vp-tunnels"):
                    if (self.vp_tunnels is None):
                        self.vp_tunnels = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels()
                        self.vp_tunnels.parent = self
                        self._children_name_map["vp_tunnels"] = "vp-tunnels"
                    return self.vp_tunnels

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "maximum-cell-packing-timers" or name == "pvcs" or name == "pvps" or name == "vp-tunnels" or name == "max-vpi-bits" or name == "vc-class"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "max-vpi-bits"):
                    self.max_vpi_bits = value
                    self.max_vpi_bits.value_namespace = name_space
                    self.max_vpi_bits.value_namespace_prefix = name_space_prefix
                if(value_path == "vc-class"):
                    self.vc_class = value
                    self.vc_class.value_namespace = name_space
                    self.vc_class.value_namespace_prefix = name_space_prefix


        class Bfd(Entity):
            """
            BFD over bundle members configuration
            
            .. attribute:: address_family
            
            	Configuration of BFDoBM for all address families
            	**type**\:   :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily>`
            
            .. attribute:: mode
            
            	Configuration of BFDoBM mode [cisco\|ietf]
            	**type**\:   :py:class:`BfdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BfdMode>`
            
            	**default value**\: no-cfg
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2016-12-16'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Bfd, self).__init__()

                self.yang_name = "bfd"
                self.yang_parent_name = "interface-configuration"

                self.mode = YLeaf(YType.enumeration, "mode")

                self.address_family = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"
                self._children_yang_names.add("address-family")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("mode") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd, self).__setattr__(name, value)


            class AddressFamily(Entity):
                """
                Configuration of BFDoBM for all address
                families
                
                .. attribute:: ipv4
                
                	Configuration of BFDoBM for IPv4 address family
                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4>`
                
                .. attribute:: ipv6
                
                	Configuration of BFDoBM for IPv6 address family
                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6>`
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "bfd"

                    self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._children_yang_names.add("ipv4")

                    self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._children_yang_names.add("ipv6")


                class Ipv6(Entity):
                    """
                    Configuration of BFDoBM for IPv6 address
                    family
                    
                    .. attribute:: ipv6_destination_address
                    
                    	IPv6 Destination address for BFD sessions created by bundlemgr
                    	**type**\:  str
                    
                    .. attribute:: ipv6_detection_multiplier
                    
                    	IPv6 Detection multiplier for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 2..50
                    
                    .. attribute:: ipv6_fast_detect
                    
                    	Configure to enable BFD over bundle members
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv6_interval
                    
                    	IPV6 Hello interval for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 3..30000
                    
                    .. attribute:: ipv6_timers
                    
                    	Timers associated with BFDoBM
                    	**type**\:   :py:class:`Ipv6Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers>`
                    
                    

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2016-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "address-family"

                        self.ipv6_destination_address = YLeaf(YType.str, "ipv6-destination-address")

                        self.ipv6_detection_multiplier = YLeaf(YType.uint32, "ipv6-detection-multiplier")

                        self.ipv6_fast_detect = YLeaf(YType.empty, "ipv6-fast-detect")

                        self.ipv6_interval = YLeaf(YType.uint32, "ipv6-interval")

                        self.ipv6_timers = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers()
                        self.ipv6_timers.parent = self
                        self._children_name_map["ipv6_timers"] = "ipv6-timers"
                        self._children_yang_names.add("ipv6-timers")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ipv6_destination_address",
                                        "ipv6_detection_multiplier",
                                        "ipv6_fast_detect",
                                        "ipv6_interval") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6, self).__setattr__(name, value)


                    class Ipv6Timers(Entity):
                        """
                        Timers associated with BFDoBM
                        
                        .. attribute:: ipv6_nbor_unconfig_timer
                        
                        	IPv6 Timer associated with aggressiveness on BFD session peer being unconfigured
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        .. attribute:: ipv6_start_timer
                        
                        	IPv6 Timer associated with aggressiveness on BFD session creation
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        

                        """

                        _prefix = 'bundlemgr-cfg'
                        _revision = '2016-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers, self).__init__()

                            self.yang_name = "ipv6-timers"
                            self.yang_parent_name = "ipv6"

                            self.ipv6_nbor_unconfig_timer = YLeaf(YType.uint32, "ipv6-nbor-unconfig-timer")

                            self.ipv6_start_timer = YLeaf(YType.uint32, "ipv6-start-timer")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv6_nbor_unconfig_timer",
                                            "ipv6_start_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv6_nbor_unconfig_timer.is_set or
                                self.ipv6_start_timer.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv6_nbor_unconfig_timer.yfilter != YFilter.not_set or
                                self.ipv6_start_timer.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv6-timers" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv6_nbor_unconfig_timer.is_set or self.ipv6_nbor_unconfig_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_nbor_unconfig_timer.get_name_leafdata())
                            if (self.ipv6_start_timer.is_set or self.ipv6_start_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_start_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv6-nbor-unconfig-timer" or name == "ipv6-start-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv6-nbor-unconfig-timer"):
                                self.ipv6_nbor_unconfig_timer = value
                                self.ipv6_nbor_unconfig_timer.value_namespace = name_space
                                self.ipv6_nbor_unconfig_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-start-timer"):
                                self.ipv6_start_timer = value
                                self.ipv6_start_timer.value_namespace = name_space
                                self.ipv6_start_timer.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ipv6_destination_address.is_set or
                            self.ipv6_detection_multiplier.is_set or
                            self.ipv6_fast_detect.is_set or
                            self.ipv6_interval.is_set or
                            (self.ipv6_timers is not None and self.ipv6_timers.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ipv6_destination_address.yfilter != YFilter.not_set or
                            self.ipv6_detection_multiplier.yfilter != YFilter.not_set or
                            self.ipv6_fast_detect.yfilter != YFilter.not_set or
                            self.ipv6_interval.yfilter != YFilter.not_set or
                            (self.ipv6_timers is not None and self.ipv6_timers.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv6" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ipv6_destination_address.is_set or self.ipv6_destination_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_destination_address.get_name_leafdata())
                        if (self.ipv6_detection_multiplier.is_set or self.ipv6_detection_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_detection_multiplier.get_name_leafdata())
                        if (self.ipv6_fast_detect.is_set or self.ipv6_fast_detect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_fast_detect.get_name_leafdata())
                        if (self.ipv6_interval.is_set or self.ipv6_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_interval.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv6-timers"):
                            if (self.ipv6_timers is None):
                                self.ipv6_timers = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers()
                                self.ipv6_timers.parent = self
                                self._children_name_map["ipv6_timers"] = "ipv6-timers"
                            return self.ipv6_timers

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv6-timers" or name == "ipv6-destination-address" or name == "ipv6-detection-multiplier" or name == "ipv6-fast-detect" or name == "ipv6-interval"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ipv6-destination-address"):
                            self.ipv6_destination_address = value
                            self.ipv6_destination_address.value_namespace = name_space
                            self.ipv6_destination_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-detection-multiplier"):
                            self.ipv6_detection_multiplier = value
                            self.ipv6_detection_multiplier.value_namespace = name_space
                            self.ipv6_detection_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-fast-detect"):
                            self.ipv6_fast_detect = value
                            self.ipv6_fast_detect.value_namespace = name_space
                            self.ipv6_fast_detect.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-interval"):
                            self.ipv6_interval = value
                            self.ipv6_interval.value_namespace = name_space
                            self.ipv6_interval.value_namespace_prefix = name_space_prefix


                class Ipv4(Entity):
                    """
                    Configuration of BFDoBM for IPv4 address
                    family
                    
                    .. attribute:: destination_address
                    
                    	Destination address for BFD sessions created by bundlemgr
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection multiplier for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 2..50
                    
                    .. attribute:: echo
                    
                    	Container for Echo min\-multiplier
                    	**type**\:   :py:class:`Echo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo>`
                    
                    .. attribute:: fast_detect
                    
                    	Configure to enable BFD over bundle members
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interval
                    
                    	Hello interval for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 3..30000
                    
                    .. attribute:: timers
                    
                    	Timers associated with BFDoBM
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers>`
                    
                    

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2016-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"

                        self.destination_address = YLeaf(YType.str, "destination-address")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.fast_detect = YLeaf(YType.empty, "fast-detect")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.echo = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo()
                        self.echo.parent = self
                        self._children_name_map["echo"] = "echo"
                        self._children_yang_names.add("echo")

                        self.timers = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._children_yang_names.add("timers")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("destination_address",
                                        "detection_multiplier",
                                        "fast_detect",
                                        "interval") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4, self).__setattr__(name, value)


                    class Echo(Entity):
                        """
                        Container for Echo min\-multiplier
                        
                        .. attribute:: min_interval
                        
                        	Configure echo min\-interval for bundle interface
                        	**type**\:  int
                        
                        	**range:** 15..2000
                        
                        

                        """

                        _prefix = 'bundlemgr-cfg'
                        _revision = '2016-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo, self).__init__()

                            self.yang_name = "echo"
                            self.yang_parent_name = "ipv4"

                            self.min_interval = YLeaf(YType.uint32, "min-interval")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("min_interval") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo, self).__setattr__(name, value)

                        def has_data(self):
                            return self.min_interval.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.min_interval.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "echo" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.min_interval.is_set or self.min_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.min_interval.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "min-interval"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "min-interval"):
                                self.min_interval = value
                                self.min_interval.value_namespace = name_space
                                self.min_interval.value_namespace_prefix = name_space_prefix


                    class Timers(Entity):
                        """
                        Timers associated with BFDoBM
                        
                        .. attribute:: nbor_unconfig_timer
                        
                        	Timer associated with aggressiveness on BFD session peer being unconfigured
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        .. attribute:: start_timer
                        
                        	Timer associated with aggressiveness on BFD session creation
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        

                        """

                        _prefix = 'bundlemgr-cfg'
                        _revision = '2016-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "ipv4"

                            self.nbor_unconfig_timer = YLeaf(YType.uint32, "nbor-unconfig-timer")

                            self.start_timer = YLeaf(YType.uint32, "start-timer")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nbor_unconfig_timer",
                                            "start_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nbor_unconfig_timer.is_set or
                                self.start_timer.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nbor_unconfig_timer.yfilter != YFilter.not_set or
                                self.start_timer.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "timers" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nbor_unconfig_timer.is_set or self.nbor_unconfig_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nbor_unconfig_timer.get_name_leafdata())
                            if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.start_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nbor-unconfig-timer" or name == "start-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nbor-unconfig-timer"):
                                self.nbor_unconfig_timer = value
                                self.nbor_unconfig_timer.value_namespace = name_space
                                self.nbor_unconfig_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "start-timer"):
                                self.start_timer = value
                                self.start_timer.value_namespace = name_space
                                self.start_timer.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.destination_address.is_set or
                            self.detection_multiplier.is_set or
                            self.fast_detect.is_set or
                            self.interval.is_set or
                            (self.echo is not None and self.echo.has_data()) or
                            (self.timers is not None and self.timers.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.destination_address.yfilter != YFilter.not_set or
                            self.detection_multiplier.yfilter != YFilter.not_set or
                            self.fast_detect.yfilter != YFilter.not_set or
                            self.interval.yfilter != YFilter.not_set or
                            (self.echo is not None and self.echo.has_operation()) or
                            (self.timers is not None and self.timers.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv4" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                        if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_detect.get_name_leafdata())
                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interval.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "echo"):
                            if (self.echo is None):
                                self.echo = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo()
                                self.echo.parent = self
                                self._children_name_map["echo"] = "echo"
                            return self.echo

                        if (child_yang_name == "timers"):
                            if (self.timers is None):
                                self.timers = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                            return self.timers

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "echo" or name == "timers" or name == "destination-address" or name == "detection-multiplier" or name == "fast-detect" or name == "interval"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "destination-address"):
                            self.destination_address = value
                            self.destination_address.value_namespace = name_space
                            self.destination_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "detection-multiplier"):
                            self.detection_multiplier = value
                            self.detection_multiplier.value_namespace = name_space
                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-detect"):
                            self.fast_detect = value
                            self.fast_detect.value_namespace = name_space
                            self.fast_detect.value_namespace_prefix = name_space_prefix
                        if(value_path == "interval"):
                            self.interval = value
                            self.interval.value_namespace = name_space
                            self.interval.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        (self.ipv4 is not None and self.ipv4.has_data()) or
                        (self.ipv6 is not None and self.ipv6.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ipv4 is not None and self.ipv4.has_operation()) or
                        (self.ipv6 is not None and self.ipv6.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "address-family" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv4"):
                        if (self.ipv4 is None):
                            self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                        return self.ipv4

                    if (child_yang_name == "ipv6"):
                        if (self.ipv6 is None):
                            self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                        return self.ipv6

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv4" or name == "ipv6"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.mode.is_set or
                    (self.address_family is not None and self.address_family.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.mode.yfilter != YFilter.not_set or
                    (self.address_family is not None and self.address_family.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-bundlemgr-cfg:bfd" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.mode.is_set or self.mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mode.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "address-family"):
                    if (self.address_family is None):
                        self.address_family = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily()
                        self.address_family.parent = self
                        self._children_name_map["address_family"] = "address-family"
                    return self.address_family

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "address-family" or name == "mode"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "mode"):
                    self.mode = value
                    self.mode.value_namespace = name_space
                    self.mode.value_namespace_prefix = name_space_prefix


        class Bundle(Entity):
            """
            Generic per\-bundle configuration
            
            .. attribute:: bundle_load_balancing
            
            	Load\-balance configuration
            	**type**\:   :py:class:`BundleLoadBalancing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing>`
            
            .. attribute:: lacp_delay
            
            	Set the lacp\-delay timeout for members of this bundle
            	**type**\:  int
            
            	**range:** 1000..15000
            
            .. attribute:: maximum_active
            
            	Set a limit on the number of links that can be active
            	**type**\:   :py:class:`MaximumActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive>`
            
            .. attribute:: minimum_active
            
            	Minimum criteria for a bundle to be active
            	**type**\:   :py:class:`MinimumActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive>`
            
            .. attribute:: shutdown
            
            	Deactivate all member links (down to Standby state)
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: wait_while
            
            	Set the wait\-while timeout for members of this bundle
            	**type**\:  int
            
            	**range:** 0..2000
            
            	**default value**\: 2000
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2016-12-16'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Bundle, self).__init__()

                self.yang_name = "bundle"
                self.yang_parent_name = "interface-configuration"

                self.lacp_delay = YLeaf(YType.uint32, "lacp-delay")

                self.shutdown = YLeaf(YType.empty, "shutdown")

                self.wait_while = YLeaf(YType.uint32, "wait-while")

                self.bundle_load_balancing = InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing()
                self.bundle_load_balancing.parent = self
                self._children_name_map["bundle_load_balancing"] = "bundle-load-balancing"
                self._children_yang_names.add("bundle-load-balancing")

                self.maximum_active = InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive()
                self.maximum_active.parent = self
                self._children_name_map["maximum_active"] = "maximum-active"
                self._children_yang_names.add("maximum-active")

                self.minimum_active = InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive()
                self.minimum_active.parent = self
                self._children_name_map["minimum_active"] = "minimum-active"
                self._children_yang_names.add("minimum-active")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("lacp_delay",
                                "shutdown",
                                "wait_while") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bundle, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle, self).__setattr__(name, value)


            class BundleLoadBalancing(Entity):
                """
                Load\-balance configuration
                
                .. attribute:: hash_function
                
                	Enable loadbalancing on this Bundle / EFP
                	**type**\:   :py:class:`HashFunction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction>`
                
                	**presence node**\: True
                
                .. attribute:: localize_links
                
                	Set thresholds for forwarding bundle traffic within a rack
                	**type**\:  int
                
                	**range:** 1..64
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing, self).__init__()

                    self.yang_name = "bundle-load-balancing"
                    self.yang_parent_name = "bundle"

                    self.localize_links = YLeaf(YType.uint32, "localize-links")

                    self.hash_function = None
                    self._children_name_map["hash_function"] = "hash-function"
                    self._children_yang_names.add("hash-function")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("localize_links") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing, self).__setattr__(name, value)


                class HashFunction(Entity):
                    """
                    Enable loadbalancing on this Bundle / EFP
                    
                    .. attribute:: hash_type
                    
                    	The specified hash function to use
                    	**type**\:   :py:class:`BundleLoadBalance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleLoadBalance>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: hash_value
                    
                    	The loadbalance hash value selected. For non\-EFP Value methods, this value must be set to 1
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2016-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction, self).__init__()

                        self.yang_name = "hash-function"
                        self.yang_parent_name = "bundle-load-balancing"
                        self.is_presence_container = True

                        self.hash_type = YLeaf(YType.enumeration, "hash-type")

                        self.hash_value = YLeaf(YType.uint32, "hash-value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("hash_type",
                                        "hash_value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.hash_type.is_set or
                            self.hash_value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.hash_type.yfilter != YFilter.not_set or
                            self.hash_value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hash-function" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.hash_type.is_set or self.hash_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hash_type.get_name_leafdata())
                        if (self.hash_value.is_set or self.hash_value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hash_value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hash-type" or name == "hash-value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "hash-type"):
                            self.hash_type = value
                            self.hash_type.value_namespace = name_space
                            self.hash_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "hash-value"):
                            self.hash_value = value
                            self.hash_value.value_namespace = name_space
                            self.hash_value.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.localize_links.is_set or
                        (self.hash_function is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.localize_links.yfilter != YFilter.not_set or
                        (self.hash_function is not None and self.hash_function.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-load-balancing" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.localize_links.is_set or self.localize_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.localize_links.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "hash-function"):
                        if (self.hash_function is None):
                            self.hash_function = InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction()
                            self.hash_function.parent = self
                            self._children_name_map["hash_function"] = "hash-function"
                        return self.hash_function

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hash-function" or name == "localize-links"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "localize-links"):
                        self.localize_links = value
                        self.localize_links.value_namespace = name_space
                        self.localize_links.value_namespace_prefix = name_space_prefix


            class MinimumActive(Entity):
                """
                Minimum criteria for a bundle to be active
                
                .. attribute:: bandwidth
                
                	Bandwidth (in kbps) needed to bring up a bundle
                	**type**\:   :py:class:`Bandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth>`
                
                	**presence node**\: True
                
                .. attribute:: links
                
                	Number of active links needed to bring up a bundle
                	**type**\:  int
                
                	**range:** 1..64
                
                	**default value**\: 1
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive, self).__init__()

                    self.yang_name = "minimum-active"
                    self.yang_parent_name = "bundle"

                    self.links = YLeaf(YType.uint32, "links")

                    self.bandwidth = None
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._children_yang_names.add("bandwidth")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("links") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive, self).__setattr__(name, value)


                class Bandwidth(Entity):
                    """
                    Bandwidth (in kbps) needed to bring up a
                    bundle
                    
                    .. attribute:: bandwidth
                    
                    	Bandwidth
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    	**mandatory**\: True
                    
                    .. attribute:: min_bandwidth_range
                    
                    	Minimum Bandwidth Range
                    	**type**\:   :py:class:`BundleMinimumBandwidthRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleMinimumBandwidthRange>`
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2016-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "minimum-active"
                        self.is_presence_container = True

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.min_bandwidth_range = YLeaf(YType.enumeration, "min-bandwidth-range")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bandwidth",
                                        "min_bandwidth_range") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bandwidth.is_set or
                            self.min_bandwidth_range.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bandwidth.yfilter != YFilter.not_set or
                            self.min_bandwidth_range.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bandwidth" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth.get_name_leafdata())
                        if (self.min_bandwidth_range.is_set or self.min_bandwidth_range.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.min_bandwidth_range.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bandwidth" or name == "min-bandwidth-range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bandwidth"):
                            self.bandwidth = value
                            self.bandwidth.value_namespace = name_space
                            self.bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "min-bandwidth-range"):
                            self.min_bandwidth_range = value
                            self.min_bandwidth_range.value_namespace = name_space
                            self.min_bandwidth_range.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.links.is_set or
                        (self.bandwidth is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.links.yfilter != YFilter.not_set or
                        (self.bandwidth is not None and self.bandwidth.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "minimum-active" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.links.is_set or self.links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.links.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bandwidth"):
                        if (self.bandwidth is None):
                            self.bandwidth = InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth()
                            self.bandwidth.parent = self
                            self._children_name_map["bandwidth"] = "bandwidth"
                        return self.bandwidth

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bandwidth" or name == "links"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "links"):
                        self.links = value
                        self.links.value_namespace = name_space
                        self.links.value_namespace_prefix = name_space_prefix


            class MaximumActive(Entity):
                """
                Set a limit on the number of links that can be
                active
                
                .. attribute:: links
                
                	Maximum number of active links in a bundle
                	**type**\:   :py:class:`Links <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive, self).__init__()

                    self.yang_name = "maximum-active"
                    self.yang_parent_name = "bundle"

                    self.links = None
                    self._children_name_map["links"] = "links"
                    self._children_yang_names.add("links")


                class Links(Entity):
                    """
                    Maximum number of active links in a bundle
                    
                    .. attribute:: links
                    
                    	Number of active links
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    	**mandatory**\: True
                    
                    .. attribute:: max_active_links_mode
                    
                    	Maximum active links mode
                    	**type**\:   :py:class:`BundleMaximumActiveLinksMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleMaximumActiveLinksMode>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2016-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links, self).__init__()

                        self.yang_name = "links"
                        self.yang_parent_name = "maximum-active"
                        self.is_presence_container = True

                        self.links = YLeaf(YType.uint32, "links")

                        self.max_active_links_mode = YLeaf(YType.enumeration, "max-active-links-mode")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("links",
                                        "max_active_links_mode") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.links.is_set or
                            self.max_active_links_mode.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.links.yfilter != YFilter.not_set or
                            self.max_active_links_mode.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "links" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.links.is_set or self.links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.links.get_name_leafdata())
                        if (self.max_active_links_mode.is_set or self.max_active_links_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_active_links_mode.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "links" or name == "max-active-links-mode"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "links"):
                            self.links = value
                            self.links.value_namespace = name_space
                            self.links.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-active-links-mode"):
                            self.max_active_links_mode = value
                            self.max_active_links_mode.value_namespace = name_space
                            self.max_active_links_mode.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.links is not None)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.links is not None and self.links.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "maximum-active" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "links"):
                        if (self.links is None):
                            self.links = InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links()
                            self.links.parent = self
                            self._children_name_map["links"] = "links"
                        return self.links

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "links"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.lacp_delay.is_set or
                    self.shutdown.is_set or
                    self.wait_while.is_set or
                    (self.bundle_load_balancing is not None and self.bundle_load_balancing.has_data()) or
                    (self.maximum_active is not None and self.maximum_active.has_data()) or
                    (self.minimum_active is not None and self.minimum_active.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.lacp_delay.yfilter != YFilter.not_set or
                    self.shutdown.yfilter != YFilter.not_set or
                    self.wait_while.yfilter != YFilter.not_set or
                    (self.bundle_load_balancing is not None and self.bundle_load_balancing.has_operation()) or
                    (self.maximum_active is not None and self.maximum_active.has_operation()) or
                    (self.minimum_active is not None and self.minimum_active.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-bundlemgr-cfg:bundle" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.lacp_delay.is_set or self.lacp_delay.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lacp_delay.get_name_leafdata())
                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                if (self.wait_while.is_set or self.wait_while.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.wait_while.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle-load-balancing"):
                    if (self.bundle_load_balancing is None):
                        self.bundle_load_balancing = InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing()
                        self.bundle_load_balancing.parent = self
                        self._children_name_map["bundle_load_balancing"] = "bundle-load-balancing"
                    return self.bundle_load_balancing

                if (child_yang_name == "maximum-active"):
                    if (self.maximum_active is None):
                        self.maximum_active = InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive()
                        self.maximum_active.parent = self
                        self._children_name_map["maximum_active"] = "maximum-active"
                    return self.maximum_active

                if (child_yang_name == "minimum-active"):
                    if (self.minimum_active is None):
                        self.minimum_active = InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive()
                        self.minimum_active.parent = self
                        self._children_name_map["minimum_active"] = "minimum-active"
                    return self.minimum_active

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle-load-balancing" or name == "maximum-active" or name == "minimum-active" or name == "lacp-delay" or name == "shutdown" or name == "wait-while"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "lacp-delay"):
                    self.lacp_delay = value
                    self.lacp_delay.value_namespace = name_space
                    self.lacp_delay.value_namespace_prefix = name_space_prefix
                if(value_path == "shutdown"):
                    self.shutdown = value
                    self.shutdown.value_namespace = name_space
                    self.shutdown.value_namespace_prefix = name_space_prefix
                if(value_path == "wait-while"):
                    self.wait_while = value
                    self.wait_while.value_namespace = name_space
                    self.wait_while.value_namespace_prefix = name_space_prefix


        class Lacp(Entity):
            """
            Link Aggregation Control Protocol per\-interface
            configuration (for bundle or member)
            
            .. attribute:: churn_logging
            
            	Log churn notifications on the specified system(s)
            	**type**\:   :py:class:`ChurnLogging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.ChurnLogging>`
            
            .. attribute:: cisco_extensions
            
            	Enable bundle Cisco extensions
            	**type**\:   :py:class:`CiscoExtensions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions>`
            
            	**presence node**\: True
            
            .. attribute:: collector_max_delay
            
            	Collector Max Delay value to signal to the LACP partner
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: fast_switchover
            
            	Configure to enable the fast\-switchover mode
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: lacp_nonrevertive
            
            	Configure to enable lacp non\-revertive mode
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: mode
            
            	Lacp mode for the bundle
            	**type**\:   :py:class:`BundleMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleMode>`
            
            .. attribute:: period
            
            	Lacp period for the bundle
            	**type**\: one of the below types:
            
            	**type**\:   :py:class:`BundlePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundlePeriod>`
            
            
            ----
            	**type**\:  int
            
            	**range:** 1..1000
            
            
            ----
            .. attribute:: period_short
            
            	LACP period to request from the partner (LACP standard short period, or rate in milliseconds for use with Cisco\-specific extensions). Default is LACP standard long period (30s)
            	**type**\: one of the below types:
            
            	**type**\:   :py:class:`PeriodShortEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.PeriodShortEnum>`
            
            	**units**\: millisecond
            
            
            ----
            	**type**\:  int
            
            	**range:** 1..1000
            
            	**units**\: millisecond
            
            
            ----
            .. attribute:: suppress_flaps
            
            	Suppress flaps on switchover for the specified period (in ms)
            	**type**\:  int
            
            	**range:** 100..65535
            
            .. attribute:: system_mac
            
            	System identifier for this bundle
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: system_priority
            
            	System priority for this bundle. Lower value is higher priority
            	**type**\:  int
            
            	**range:** 1..65535
            
            .. attribute:: timeout
            
            	Set timeout values for LACP\-related timers
            	**type**\:   :py:class:`Timeout <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout>`
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2016-12-16'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Lacp, self).__init__()

                self.yang_name = "lacp"
                self.yang_parent_name = "interface-configuration"

                self.churn_logging = YLeaf(YType.enumeration, "churn-logging")

                self.collector_max_delay = YLeaf(YType.uint32, "collector-max-delay")

                self.fast_switchover = YLeaf(YType.empty, "fast-switchover")

                self.lacp_nonrevertive = YLeaf(YType.empty, "lacp-nonrevertive")

                self.mode = YLeaf(YType.enumeration, "mode")

                self.period = YLeaf(YType.str, "period")

                self.period_short = YLeaf(YType.str, "period-short")

                self.suppress_flaps = YLeaf(YType.uint32, "suppress-flaps")

                self.system_mac = YLeaf(YType.str, "system-mac")

                self.system_priority = YLeaf(YType.uint32, "system-priority")

                self.cisco_extensions = None
                self._children_name_map["cisco_extensions"] = "cisco-extensions"
                self._children_yang_names.add("cisco-extensions")

                self.timeout = InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout()
                self.timeout.parent = self
                self._children_name_map["timeout"] = "timeout"
                self._children_yang_names.add("timeout")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("churn_logging",
                                "collector_max_delay",
                                "fast_switchover",
                                "lacp_nonrevertive",
                                "mode",
                                "period",
                                "period_short",
                                "suppress_flaps",
                                "system_mac",
                                "system_priority") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Lacp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Lacp, self).__setattr__(name, value)


            class CiscoExtensions(Entity):
                """
                Enable bundle Cisco extensions
                
                .. attribute:: cisco_ext
                
                	Cisco extensions
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                	**mandatory**\: True
                
                .. attribute:: cisco_ext_type
                
                	Specific Cisco extension to enable / disable
                	**type**\:   :py:class:`BundleCiscoExtTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleCiscoExtTypes>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions, self).__init__()

                    self.yang_name = "cisco-extensions"
                    self.yang_parent_name = "lacp"
                    self.is_presence_container = True

                    self.cisco_ext = YLeaf(YType.empty, "cisco-ext")

                    self.cisco_ext_type = YLeaf(YType.enumeration, "cisco-ext-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("cisco_ext",
                                    "cisco_ext_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.cisco_ext.is_set or
                        self.cisco_ext_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.cisco_ext.yfilter != YFilter.not_set or
                        self.cisco_ext_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "cisco-extensions" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.cisco_ext.is_set or self.cisco_ext.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cisco_ext.get_name_leafdata())
                    if (self.cisco_ext_type.is_set or self.cisco_ext_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cisco_ext_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "cisco-ext" or name == "cisco-ext-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "cisco-ext"):
                        self.cisco_ext = value
                        self.cisco_ext.value_namespace = name_space
                        self.cisco_ext.value_namespace_prefix = name_space_prefix
                    if(value_path == "cisco-ext-type"):
                        self.cisco_ext_type = value
                        self.cisco_ext_type.value_namespace = name_space
                        self.cisco_ext_type.value_namespace_prefix = name_space_prefix


            class Timeout(Entity):
                """
                Set timeout values for LACP\-related timers
                
                .. attribute:: actor_churn
                
                	The time in milliseconds for which to run the timer
                	**type**\:  int
                
                	**range:** 0..120
                
                .. attribute:: partner_churn
                
                	Set the timeout to use before declaring partner churn
                	**type**\:  int
                
                	**range:** 0..120
                
                .. attribute:: rx_default
                
                	Set the timeout between expired and defaulted states
                	**type**\:  int
                
                	**range:** 0..3000
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout, self).__init__()

                    self.yang_name = "timeout"
                    self.yang_parent_name = "lacp"

                    self.actor_churn = YLeaf(YType.uint32, "actor-churn")

                    self.partner_churn = YLeaf(YType.uint32, "partner-churn")

                    self.rx_default = YLeaf(YType.uint32, "rx-default")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("actor_churn",
                                    "partner_churn",
                                    "rx_default") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.actor_churn.is_set or
                        self.partner_churn.is_set or
                        self.rx_default.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.actor_churn.yfilter != YFilter.not_set or
                        self.partner_churn.yfilter != YFilter.not_set or
                        self.rx_default.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "timeout" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.actor_churn.is_set or self.actor_churn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_churn.get_name_leafdata())
                    if (self.partner_churn.is_set or self.partner_churn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_churn.get_name_leafdata())
                    if (self.rx_default.is_set or self.rx_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_default.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "actor-churn" or name == "partner-churn" or name == "rx-default"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "actor-churn"):
                        self.actor_churn = value
                        self.actor_churn.value_namespace = name_space
                        self.actor_churn.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-churn"):
                        self.partner_churn = value
                        self.partner_churn.value_namespace = name_space
                        self.partner_churn.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-default"):
                        self.rx_default = value
                        self.rx_default.value_namespace = name_space
                        self.rx_default.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.churn_logging.is_set or
                    self.collector_max_delay.is_set or
                    self.fast_switchover.is_set or
                    self.lacp_nonrevertive.is_set or
                    self.mode.is_set or
                    self.period.is_set or
                    self.period_short.is_set or
                    self.suppress_flaps.is_set or
                    self.system_mac.is_set or
                    self.system_priority.is_set or
                    (self.timeout is not None and self.timeout.has_data()) or
                    (self.cisco_extensions is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.churn_logging.yfilter != YFilter.not_set or
                    self.collector_max_delay.yfilter != YFilter.not_set or
                    self.fast_switchover.yfilter != YFilter.not_set or
                    self.lacp_nonrevertive.yfilter != YFilter.not_set or
                    self.mode.yfilter != YFilter.not_set or
                    self.period.yfilter != YFilter.not_set or
                    self.period_short.yfilter != YFilter.not_set or
                    self.suppress_flaps.yfilter != YFilter.not_set or
                    self.system_mac.yfilter != YFilter.not_set or
                    self.system_priority.yfilter != YFilter.not_set or
                    (self.cisco_extensions is not None and self.cisco_extensions.has_operation()) or
                    (self.timeout is not None and self.timeout.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-bundlemgr-cfg:lacp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.churn_logging.is_set or self.churn_logging.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.churn_logging.get_name_leafdata())
                if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                if (self.fast_switchover.is_set or self.fast_switchover.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.fast_switchover.get_name_leafdata())
                if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                if (self.mode.is_set or self.mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mode.get_name_leafdata())
                if (self.period.is_set or self.period.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.period.get_name_leafdata())
                if (self.period_short.is_set or self.period_short.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.period_short.get_name_leafdata())
                if (self.suppress_flaps.is_set or self.suppress_flaps.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.suppress_flaps.get_name_leafdata())
                if (self.system_mac.is_set or self.system_mac.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.system_mac.get_name_leafdata())
                if (self.system_priority.is_set or self.system_priority.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.system_priority.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "cisco-extensions"):
                    if (self.cisco_extensions is None):
                        self.cisco_extensions = InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions()
                        self.cisco_extensions.parent = self
                        self._children_name_map["cisco_extensions"] = "cisco-extensions"
                    return self.cisco_extensions

                if (child_yang_name == "timeout"):
                    if (self.timeout is None):
                        self.timeout = InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout()
                        self.timeout.parent = self
                        self._children_name_map["timeout"] = "timeout"
                    return self.timeout

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "cisco-extensions" or name == "timeout" or name == "churn-logging" or name == "collector-max-delay" or name == "fast-switchover" or name == "lacp-nonrevertive" or name == "mode" or name == "period" or name == "period-short" or name == "suppress-flaps" or name == "system-mac" or name == "system-priority"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "churn-logging"):
                    self.churn_logging = value
                    self.churn_logging.value_namespace = name_space
                    self.churn_logging.value_namespace_prefix = name_space_prefix
                if(value_path == "collector-max-delay"):
                    self.collector_max_delay = value
                    self.collector_max_delay.value_namespace = name_space
                    self.collector_max_delay.value_namespace_prefix = name_space_prefix
                if(value_path == "fast-switchover"):
                    self.fast_switchover = value
                    self.fast_switchover.value_namespace = name_space
                    self.fast_switchover.value_namespace_prefix = name_space_prefix
                if(value_path == "lacp-nonrevertive"):
                    self.lacp_nonrevertive = value
                    self.lacp_nonrevertive.value_namespace = name_space
                    self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                if(value_path == "mode"):
                    self.mode = value
                    self.mode.value_namespace = name_space
                    self.mode.value_namespace_prefix = name_space_prefix
                if(value_path == "period"):
                    self.period = value
                    self.period.value_namespace = name_space
                    self.period.value_namespace_prefix = name_space_prefix
                if(value_path == "period-short"):
                    self.period_short = value
                    self.period_short.value_namespace = name_space
                    self.period_short.value_namespace_prefix = name_space_prefix
                if(value_path == "suppress-flaps"):
                    self.suppress_flaps = value
                    self.suppress_flaps.value_namespace = name_space
                    self.suppress_flaps.value_namespace_prefix = name_space_prefix
                if(value_path == "system-mac"):
                    self.system_mac = value
                    self.system_mac.value_namespace = name_space
                    self.system_mac.value_namespace_prefix = name_space_prefix
                if(value_path == "system-priority"):
                    self.system_priority = value
                    self.system_priority.value_namespace = name_space
                    self.system_priority.value_namespace_prefix = name_space_prefix


        class BundleMember(Entity):
            """
            Generic per\-member configuration
            
            .. attribute:: id
            
            	Add the port to an aggregated interface
            	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id>`
            
            .. attribute:: port_priority
            
            	Priority for this port. Lower value is higher priority
            	**type**\:  int
            
            	**range:** 1..65535
            
            	**default value**\: 32768
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2016-12-16'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.BundleMember, self).__init__()

                self.yang_name = "bundle-member"
                self.yang_parent_name = "interface-configuration"

                self.port_priority = YLeaf(YType.uint16, "port-priority")

                self.id = InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id()
                self.id.parent = self
                self._children_name_map["id"] = "id"
                self._children_yang_names.add("id")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("port_priority") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.BundleMember, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.BundleMember, self).__setattr__(name, value)


            class Id(Entity):
                """
                Add the port to an aggregated interface.
                
                .. attribute:: bundle_id
                
                	Identifier of the bundle to add the port to
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: port_activity
                
                	Port Activity
                	**type**\:   :py:class:`BundlePortActivity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundlePortActivity>`
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id, self).__init__()

                    self.yang_name = "id"
                    self.yang_parent_name = "bundle-member"

                    self.bundle_id = YLeaf(YType.uint32, "bundle-id")

                    self.port_activity = YLeaf(YType.enumeration, "port-activity")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_id",
                                    "port_activity") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bundle_id.is_set or
                        self.port_activity.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_id.yfilter != YFilter.not_set or
                        self.port_activity.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "id" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_id.is_set or self.bundle_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_id.get_name_leafdata())
                    if (self.port_activity.is_set or self.port_activity.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.port_activity.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-id" or name == "port-activity"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-id"):
                        self.bundle_id = value
                        self.bundle_id.value_namespace = name_space
                        self.bundle_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "port-activity"):
                        self.port_activity = value
                        self.port_activity.value_namespace = name_space
                        self.port_activity.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.port_priority.is_set or
                    (self.id is not None and self.id.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.port_priority.yfilter != YFilter.not_set or
                    (self.id is not None and self.id.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-bundlemgr-cfg:bundle-member" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.port_priority.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "id"):
                    if (self.id is None):
                        self.id = InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id()
                        self.id.parent = self
                        self._children_name_map["id"] = "id"
                    return self.id

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "id" or name == "port-priority"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "port-priority"):
                    self.port_priority = value
                    self.port_priority.value_namespace = name_space
                    self.port_priority.value_namespace_prefix = name_space_prefix


        class Mlacp(Entity):
            """
            Multi\-chassis LACP configuration
            
            .. attribute:: iccp_group
            
            	Specify an ICCP Group in which this bundle should operate
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: maximize
            
            	Set parameters to maximize between the mLACP peers
            	**type**\:   :py:class:`Maximize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize>`
            
            	**presence node**\: True
            
            .. attribute:: port_priority
            
            	The LACP port priority (lower value is higher priority)
            	**type**\:  int
            
            	**range:** 1..65535
            
            	**default value**\: 32768
            
            .. attribute:: recovery_delay
            
            	Set the delay before the bundle becomes active after recovery from failure
            	**type**\:  int
            
            	**range:** 0..65535
            
            	**default value**\: 300
            
            .. attribute:: switchover_type
            
            	Set the type of mLACP switchover to use for this bundle
            	**type**\:   :py:class:`MlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.MlacpSwitchover>`
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2016-12-16'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Mlacp, self).__init__()

                self.yang_name = "mlacp"
                self.yang_parent_name = "interface-configuration"

                self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                self.port_priority = YLeaf(YType.uint16, "port-priority")

                self.recovery_delay = YLeaf(YType.uint32, "recovery-delay")

                self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                self.maximize = None
                self._children_name_map["maximize"] = "maximize"
                self._children_yang_names.add("maximize")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("iccp_group",
                                "port_priority",
                                "recovery_delay",
                                "switchover_type") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Mlacp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Mlacp, self).__setattr__(name, value)


            class Maximize(Entity):
                """
                Set parameters to maximize between the mLACP
                peers
                
                .. attribute:: bandwidth_threshold
                
                	The bandwidth (in kbps) below which to switch to the peer if it has more bandwidth available . Only applicable if maximizing by bandwidth. If 0, no threshold is applied
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: link_threshold
                
                	The number of links below which to switch to the peer if it has more links available. Only applicable if maximizing by links. If 0, no threshold is applied
                	**type**\:  int
                
                	**range:** 0..64
                
                .. attribute:: maximize_by
                
                	The paramenter which should be maximized
                	**type**\:   :py:class:`MlacpMaximizeParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.MlacpMaximizeParameter>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2016-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize, self).__init__()

                    self.yang_name = "maximize"
                    self.yang_parent_name = "mlacp"
                    self.is_presence_container = True

                    self.bandwidth_threshold = YLeaf(YType.uint32, "bandwidth-threshold")

                    self.link_threshold = YLeaf(YType.uint32, "link-threshold")

                    self.maximize_by = YLeaf(YType.enumeration, "maximize-by")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bandwidth_threshold",
                                    "link_threshold",
                                    "maximize_by") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bandwidth_threshold.is_set or
                        self.link_threshold.is_set or
                        self.maximize_by.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bandwidth_threshold.yfilter != YFilter.not_set or
                        self.link_threshold.yfilter != YFilter.not_set or
                        self.maximize_by.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "maximize" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bandwidth_threshold.is_set or self.bandwidth_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth_threshold.get_name_leafdata())
                    if (self.link_threshold.is_set or self.link_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.link_threshold.get_name_leafdata())
                    if (self.maximize_by.is_set or self.maximize_by.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximize_by.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bandwidth-threshold" or name == "link-threshold" or name == "maximize-by"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bandwidth-threshold"):
                        self.bandwidth_threshold = value
                        self.bandwidth_threshold.value_namespace = name_space
                        self.bandwidth_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "link-threshold"):
                        self.link_threshold = value
                        self.link_threshold.value_namespace = name_space
                        self.link_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximize-by"):
                        self.maximize_by = value
                        self.maximize_by.value_namespace = name_space
                        self.maximize_by.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.iccp_group.is_set or
                    self.port_priority.is_set or
                    self.recovery_delay.is_set or
                    self.switchover_type.is_set or
                    (self.maximize is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.iccp_group.yfilter != YFilter.not_set or
                    self.port_priority.yfilter != YFilter.not_set or
                    self.recovery_delay.yfilter != YFilter.not_set or
                    self.switchover_type.yfilter != YFilter.not_set or
                    (self.maximize is not None and self.maximize.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-bundlemgr-cfg:mlacp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.iccp_group.get_name_leafdata())
                if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.port_priority.get_name_leafdata())
                if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.switchover_type.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "maximize"):
                    if (self.maximize is None):
                        self.maximize = InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize()
                        self.maximize.parent = self
                        self._children_name_map["maximize"] = "maximize"
                    return self.maximize

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "maximize" or name == "iccp-group" or name == "port-priority" or name == "recovery-delay" or name == "switchover-type"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "iccp-group"):
                    self.iccp_group = value
                    self.iccp_group.value_namespace = name_space
                    self.iccp_group.value_namespace_prefix = name_space_prefix
                if(value_path == "port-priority"):
                    self.port_priority = value
                    self.port_priority.value_namespace = name_space
                    self.port_priority.value_namespace_prefix = name_space_prefix
                if(value_path == "recovery-delay"):
                    self.recovery_delay = value
                    self.recovery_delay.value_namespace = name_space
                    self.recovery_delay.value_namespace_prefix = name_space_prefix
                if(value_path == "switchover-type"):
                    self.switchover_type = value
                    self.switchover_type.value_namespace = name_space
                    self.switchover_type.value_namespace_prefix = name_space_prefix


        class Cdp(Entity):
            """
            Interface specific CDP configuration
            
            .. attribute:: enable
            
            	Enable or disable CDP on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'cdp-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Cdp, self).__init__()

                self.yang_name = "cdp"
                self.yang_parent_name = "interface-configuration"

                self.enable = YLeaf(YType.empty, "enable")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("enable") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Cdp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Cdp, self).__setattr__(name, value)

            def has_data(self):
                return self.enable.is_set

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.enable.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-cdp-cfg:cdp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.enable.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "enable"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "enable"):
                    self.enable = value
                    self.enable.value_namespace = name_space
                    self.enable.value_namespace_prefix = name_space_prefix


        class Optics(Entity):
            """
            Optics controller configuration
            
            .. attribute:: breakout
            
            	breakout mode configuration
            	**type**\:  str
            
            	**pattern:** (4x10)\|(4x25)
            
            .. attribute:: optics_cd_high_threshold
            
            	Select chromatic dispersion high threshold(in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_cd_low_threshold
            
            	Select chromatic dispersion low threshold(in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_cd_max
            
            	Select max chromatic dispersion (in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_cd_min
            
            	Select min chromatic dispersion (in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_description
            
            	Configure optics port description 
            	**type**\:  str
            
            	**length:** 1..255
            
            .. attribute:: optics_dgd_high_threshold
            
            	Select DGD high threshold(in units of 0.1ps)
            	**type**\:  int
            
            	**range:** 0..18000
            
            .. attribute:: optics_dwdm_carrier
            
            	Configure optics DWDM Carrier
            	**type**\:   :py:class:`OpticsDwdmCarrier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier>`
            
            	**presence node**\: True
            
            .. attribute:: optics_fec
            
            	Configure optics fec 
            	**type**\:   :py:class:`OpticsFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsFec>`
            
            	**default value**\: fec-none
            
            .. attribute:: optics_lanes
            
            	Optics lanes
            	**type**\:   :py:class:`OpticsLanes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes>`
            
            .. attribute:: optics_lbc_high_threshold
            
            	Select power level (in units of percentage)
            	**type**\:  int
            
            	**range:** 0..100
            
            .. attribute:: optics_loopback
            
            	Configure optics loopback mode 
            	**type**\:   :py:class:`OpticsLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsLoopback>`
            
            	**default value**\: none
            
            .. attribute:: optics_network_srlgs
            
            	Configure Network srlgs
            	**type**\:   :py:class:`OpticsNetworkSrlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs>`
            
            .. attribute:: optics_osnr_low_threshold
            
            	Select OSNR low threshold(in units of 0.01db)
            	**type**\:  int
            
            	**range:** 0..4000
            
            .. attribute:: optics_ots_amplifier_channel_power
            
            	Select Amplifier Channel Power(in units of 0 .1dBm)
            	**type**\:  int
            
            	**range:** \-500..300
            
            .. attribute:: optics_ots_amplifier_control_mode
            
            	Configure amplifier working mode
            	**type**\:   :py:class:`OpticsOtsAmpliControlMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsOtsAmpliControlMode>`
            
            .. attribute:: optics_ots_amplifier_gain
            
            	Select Amplifier Gain value(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..500
            
            .. attribute:: optics_ots_amplifier_gain_degrade_high_threshold
            
            	Select Amplifier Gain Degrade High Threshold(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..500
            
            .. attribute:: optics_ots_amplifier_gain_degrade_low_threshold
            
            	Select Amplifier Gain Degrade Low Threshold(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..500
            
            .. attribute:: optics_ots_amplifier_gain_range
            
            	Normal or extended Ampli Gain Range
            	**type**\:   :py:class:`OpticsOtsAmpliGainRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsOtsAmpliGainRange>`
            
            .. attribute:: optics_ots_amplifier_tilt
            
            	Select Amplifier Tilt value(in units of 0.1dB)
            	**type**\:  int
            
            	**range:** \-50..50
            
            .. attribute:: optics_ots_channel_power_max_delta
            
            	Configure max delta among all measured channel powers 
            	**type**\:  int
            
            	**range:** \-500..300
            
            .. attribute:: optics_ots_osri
            
            	Configure Optical safety remote interlock (OSRI)
            	**type**\:  bool
            
            .. attribute:: optics_ots_rx_voa_attenuation
            
            	Select RX Voa Attenuation Setpoint(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..200
            
            .. attribute:: optics_ots_safety_control_mode
            
            	Configure safety Control Mode
            	**type**\:   :py:class:`OpticsOtsSafetyControlMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsOtsSafetyControlMode>`
            
            .. attribute:: optics_ots_tx_voa_attenuation
            
            	Select TX Voa Attenuation Setpoint(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..200
            
            .. attribute:: optics_performance_monitoring
            
            	Select Performance Monitoring as Enable or Disable
            	**type**\:  bool
            
            	**default value**\: true
            
            .. attribute:: optics_transmit_power
            
            	Select power level (in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** \-190..20
            
            .. attribute:: optics_transmit_shutdown
            
            	Configure optics transmit laser shutdown 
            	**type**\:  bool
            
            .. attribute:: rx_thresholds
            
            	Configure Rx threshold
            	**type**\:   :py:class:`RxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds>`
            
            .. attribute:: tx_thresholds
            
            	Configure Tx threshold
            	**type**\:   :py:class:`TxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds>`
            
            

            """

            _prefix = 'controller-optics-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Optics, self).__init__()

                self.yang_name = "optics"
                self.yang_parent_name = "interface-configuration"

                self.breakout = YLeaf(YType.str, "Cisco-IOS-XR-optics-driver-cfg:breakout")

                self.optics_cd_high_threshold = YLeaf(YType.int32, "optics-cd-high-threshold")

                self.optics_cd_low_threshold = YLeaf(YType.int32, "optics-cd-low-threshold")

                self.optics_cd_max = YLeaf(YType.int32, "optics-cd-max")

                self.optics_cd_min = YLeaf(YType.int32, "optics-cd-min")

                self.optics_description = YLeaf(YType.str, "optics-description")

                self.optics_dgd_high_threshold = YLeaf(YType.int32, "optics-dgd-high-threshold")

                self.optics_fec = YLeaf(YType.enumeration, "optics-fec")

                self.optics_lbc_high_threshold = YLeaf(YType.int32, "optics-lbc-high-threshold")

                self.optics_loopback = YLeaf(YType.enumeration, "optics-loopback")

                self.optics_osnr_low_threshold = YLeaf(YType.int32, "optics-osnr-low-threshold")

                self.optics_ots_amplifier_channel_power = YLeaf(YType.int32, "optics-ots-amplifier-channel-power")

                self.optics_ots_amplifier_control_mode = YLeaf(YType.enumeration, "optics-ots-amplifier-control-mode")

                self.optics_ots_amplifier_gain = YLeaf(YType.int32, "optics-ots-amplifier-gain")

                self.optics_ots_amplifier_gain_degrade_high_threshold = YLeaf(YType.int32, "optics-ots-amplifier-gain-degrade-high-threshold")

                self.optics_ots_amplifier_gain_degrade_low_threshold = YLeaf(YType.int32, "optics-ots-amplifier-gain-degrade-low-threshold")

                self.optics_ots_amplifier_gain_range = YLeaf(YType.enumeration, "optics-ots-amplifier-gain-range")

                self.optics_ots_amplifier_tilt = YLeaf(YType.int32, "optics-ots-amplifier-tilt")

                self.optics_ots_channel_power_max_delta = YLeaf(YType.int32, "optics-ots-channel-power-max-delta")

                self.optics_ots_osri = YLeaf(YType.boolean, "optics-ots-osri")

                self.optics_ots_rx_voa_attenuation = YLeaf(YType.int32, "optics-ots-rx-voa-attenuation")

                self.optics_ots_safety_control_mode = YLeaf(YType.enumeration, "optics-ots-safety-control-mode")

                self.optics_ots_tx_voa_attenuation = YLeaf(YType.int32, "optics-ots-tx-voa-attenuation")

                self.optics_performance_monitoring = YLeaf(YType.boolean, "optics-performance-monitoring")

                self.optics_transmit_power = YLeaf(YType.int32, "optics-transmit-power")

                self.optics_transmit_shutdown = YLeaf(YType.boolean, "optics-transmit-shutdown")

                self.optics_dwdm_carrier = None
                self._children_name_map["optics_dwdm_carrier"] = "optics-dwdm-carrier"
                self._children_yang_names.add("optics-dwdm-carrier")

                self.optics_lanes = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes()
                self.optics_lanes.parent = self
                self._children_name_map["optics_lanes"] = "optics-lanes"
                self._children_yang_names.add("optics-lanes")

                self.optics_network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs()
                self.optics_network_srlgs.parent = self
                self._children_name_map["optics_network_srlgs"] = "optics-network-srlgs"
                self._children_yang_names.add("optics-network-srlgs")

                self.rx_thresholds = InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds()
                self.rx_thresholds.parent = self
                self._children_name_map["rx_thresholds"] = "rx-thresholds"
                self._children_yang_names.add("rx-thresholds")

                self.tx_thresholds = InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds()
                self.tx_thresholds.parent = self
                self._children_name_map["tx_thresholds"] = "tx-thresholds"
                self._children_yang_names.add("tx-thresholds")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("breakout",
                                "optics_cd_high_threshold",
                                "optics_cd_low_threshold",
                                "optics_cd_max",
                                "optics_cd_min",
                                "optics_description",
                                "optics_dgd_high_threshold",
                                "optics_fec",
                                "optics_lbc_high_threshold",
                                "optics_loopback",
                                "optics_osnr_low_threshold",
                                "optics_ots_amplifier_channel_power",
                                "optics_ots_amplifier_control_mode",
                                "optics_ots_amplifier_gain",
                                "optics_ots_amplifier_gain_degrade_high_threshold",
                                "optics_ots_amplifier_gain_degrade_low_threshold",
                                "optics_ots_amplifier_gain_range",
                                "optics_ots_amplifier_tilt",
                                "optics_ots_channel_power_max_delta",
                                "optics_ots_osri",
                                "optics_ots_rx_voa_attenuation",
                                "optics_ots_safety_control_mode",
                                "optics_ots_tx_voa_attenuation",
                                "optics_performance_monitoring",
                                "optics_transmit_power",
                                "optics_transmit_shutdown") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Optics, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics, self).__setattr__(name, value)


            class RxThresholds(Entity):
                """
                Configure Rx threshold
                
                .. attribute:: rx_threshold
                
                	Optics RX Low or high threshold configuration
                	**type**\: list of    :py:class:`RxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds, self).__init__()

                    self.yang_name = "rx-thresholds"
                    self.yang_parent_name = "optics"

                    self.rx_threshold = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds, self).__setattr__(name, value)


                class RxThreshold(Entity):
                    """
                    Optics RX Low or high threshold configuration
                    
                    .. attribute:: rx_threshold_type  <key>
                    
                    	Low or high rx threshold
                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.Threshold>`
                    
                    .. attribute:: rx_threshold
                    
                    	Select power level (in units of 0.1dBm)
                    	**type**\:  int
                    
                    	**range:** \-400..300
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold, self).__init__()

                        self.yang_name = "rx-threshold"
                        self.yang_parent_name = "rx-thresholds"

                        self.rx_threshold_type = YLeaf(YType.enumeration, "rx-threshold-type")

                        self.rx_threshold = YLeaf(YType.int32, "rx-threshold")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rx_threshold_type",
                                        "rx_threshold") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.rx_threshold_type.is_set or
                            self.rx_threshold.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rx_threshold_type.yfilter != YFilter.not_set or
                            self.rx_threshold.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rx-threshold" + "[rx-threshold-type='" + self.rx_threshold_type.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rx_threshold_type.is_set or self.rx_threshold_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rx_threshold_type.get_name_leafdata())
                        if (self.rx_threshold.is_set or self.rx_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rx_threshold.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rx-threshold-type" or name == "rx-threshold"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rx-threshold-type"):
                            self.rx_threshold_type = value
                            self.rx_threshold_type.value_namespace = name_space
                            self.rx_threshold_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "rx-threshold"):
                            self.rx_threshold = value
                            self.rx_threshold.value_namespace = name_space
                            self.rx_threshold.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.rx_threshold:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.rx_threshold:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rx-thresholds" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rx-threshold"):
                        for c in self.rx_threshold:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.rx_threshold.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rx-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OpticsNetworkSrlgs(Entity):
                """
                Configure Network srlgs
                
                .. attribute:: optics_network_srlg
                
                	Configure network srlg sets
                	**type**\: list of    :py:class:`OpticsNetworkSrlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs, self).__init__()

                    self.yang_name = "optics-network-srlgs"
                    self.yang_parent_name = "optics"

                    self.optics_network_srlg = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs, self).__setattr__(name, value)


                class OpticsNetworkSrlg(Entity):
                    """
                    Configure network srlg sets
                    
                    .. attribute:: set_id  <key>
                    
                    	Set index
                    	**type**\:  int
                    
                    	**range:** 1..17
                    
                    .. attribute:: srlg1
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg2
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg3
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg4
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg5
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg6
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg, self).__init__()

                        self.yang_name = "optics-network-srlg"
                        self.yang_parent_name = "optics-network-srlgs"

                        self.set_id = YLeaf(YType.uint32, "set-id")

                        self.srlg1 = YLeaf(YType.uint32, "srlg1")

                        self.srlg2 = YLeaf(YType.uint32, "srlg2")

                        self.srlg3 = YLeaf(YType.uint32, "srlg3")

                        self.srlg4 = YLeaf(YType.uint32, "srlg4")

                        self.srlg5 = YLeaf(YType.uint32, "srlg5")

                        self.srlg6 = YLeaf(YType.uint32, "srlg6")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("set_id",
                                        "srlg1",
                                        "srlg2",
                                        "srlg3",
                                        "srlg4",
                                        "srlg5",
                                        "srlg6") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.set_id.is_set or
                            self.srlg1.is_set or
                            self.srlg2.is_set or
                            self.srlg3.is_set or
                            self.srlg4.is_set or
                            self.srlg5.is_set or
                            self.srlg6.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.set_id.yfilter != YFilter.not_set or
                            self.srlg1.yfilter != YFilter.not_set or
                            self.srlg2.yfilter != YFilter.not_set or
                            self.srlg3.yfilter != YFilter.not_set or
                            self.srlg4.yfilter != YFilter.not_set or
                            self.srlg5.yfilter != YFilter.not_set or
                            self.srlg6.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "optics-network-srlg" + "[set-id='" + self.set_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.set_id.is_set or self.set_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.set_id.get_name_leafdata())
                        if (self.srlg1.is_set or self.srlg1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg1.get_name_leafdata())
                        if (self.srlg2.is_set or self.srlg2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg2.get_name_leafdata())
                        if (self.srlg3.is_set or self.srlg3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg3.get_name_leafdata())
                        if (self.srlg4.is_set or self.srlg4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg4.get_name_leafdata())
                        if (self.srlg5.is_set or self.srlg5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg5.get_name_leafdata())
                        if (self.srlg6.is_set or self.srlg6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg6.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "set-id" or name == "srlg1" or name == "srlg2" or name == "srlg3" or name == "srlg4" or name == "srlg5" or name == "srlg6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "set-id"):
                            self.set_id = value
                            self.set_id.value_namespace = name_space
                            self.set_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg1"):
                            self.srlg1 = value
                            self.srlg1.value_namespace = name_space
                            self.srlg1.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg2"):
                            self.srlg2 = value
                            self.srlg2.value_namespace = name_space
                            self.srlg2.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg3"):
                            self.srlg3 = value
                            self.srlg3.value_namespace = name_space
                            self.srlg3.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg4"):
                            self.srlg4 = value
                            self.srlg4.value_namespace = name_space
                            self.srlg4.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg5"):
                            self.srlg5 = value
                            self.srlg5.value_namespace = name_space
                            self.srlg5.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg6"):
                            self.srlg6 = value
                            self.srlg6.value_namespace = name_space
                            self.srlg6.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.optics_network_srlg:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.optics_network_srlg:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "optics-network-srlgs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "optics-network-srlg"):
                        for c in self.optics_network_srlg:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.optics_network_srlg.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "optics-network-srlg"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OpticsDwdmCarrier(Entity):
                """
                Configure optics DWDM Carrier
                
                .. attribute:: grid_type
                
                	DWDM Channel Grid Type
                	**type**\:   :py:class:`OpticsDwdmCarrierGrid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsDwdmCarrierGrid>`
                
                	**mandatory**\: True
                
                .. attribute:: param_type
                
                	DWDM Channel Parameter Type ITU\-Channel or Frequency or Wavelength
                	**type**\:   :py:class:`OpticsDwdmCarrierParam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsDwdmCarrierParam>`
                
                	**mandatory**\: True
                
                .. attribute:: param_value
                
                	Type ITU\-Channel Range 1\-100, Frequency Range 19115\-19610, Wavelength Range 1528773\-1568362, 100MHz Frequency Range 1911500\-1961000
                	**type**\:  int
                
                	**range:** 1..1961000
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier, self).__init__()

                    self.yang_name = "optics-dwdm-carrier"
                    self.yang_parent_name = "optics"
                    self.is_presence_container = True

                    self.grid_type = YLeaf(YType.enumeration, "grid-type")

                    self.param_type = YLeaf(YType.enumeration, "param-type")

                    self.param_value = YLeaf(YType.uint32, "param-value")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("grid_type",
                                    "param_type",
                                    "param_value") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.grid_type.is_set or
                        self.param_type.is_set or
                        self.param_value.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.grid_type.yfilter != YFilter.not_set or
                        self.param_type.yfilter != YFilter.not_set or
                        self.param_value.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "optics-dwdm-carrier" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.grid_type.is_set or self.grid_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.grid_type.get_name_leafdata())
                    if (self.param_type.is_set or self.param_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.param_type.get_name_leafdata())
                    if (self.param_value.is_set or self.param_value.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.param_value.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "grid-type" or name == "param-type" or name == "param-value"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "grid-type"):
                        self.grid_type = value
                        self.grid_type.value_namespace = name_space
                        self.grid_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "param-type"):
                        self.param_type = value
                        self.param_type.value_namespace = name_space
                        self.param_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "param-value"):
                        self.param_value = value
                        self.param_value.value_namespace = name_space
                        self.param_value.value_namespace_prefix = name_space_prefix


            class OpticsLanes(Entity):
                """
                Optics lanes
                
                .. attribute:: optics_lane
                
                	Lane
                	**type**\: list of    :py:class:`OpticsLane <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes, self).__init__()

                    self.yang_name = "optics-lanes"
                    self.yang_parent_name = "optics"

                    self.optics_lane = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes, self).__setattr__(name, value)


                class OpticsLane(Entity):
                    """
                    Lane
                    
                    .. attribute:: index  <key>
                    
                    	Lane Number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: description
                    
                    	Configure description for this Lane
                    	**type**\:  str
                    
                    	**length:** 1..255
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane, self).__init__()

                        self.yang_name = "optics-lane"
                        self.yang_parent_name = "optics-lanes"

                        self.index = YLeaf(YType.int32, "index")

                        self.description = YLeaf(YType.str, "description")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("index",
                                        "description") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.index.is_set or
                            self.description.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.index.yfilter != YFilter.not_set or
                            self.description.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "optics-lane" + "[index='" + self.index.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.index.get_name_leafdata())
                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.description.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "index" or name == "description"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "index"):
                            self.index = value
                            self.index.value_namespace = name_space
                            self.index.value_namespace_prefix = name_space_prefix
                        if(value_path == "description"):
                            self.description = value
                            self.description.value_namespace = name_space
                            self.description.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.optics_lane:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.optics_lane:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "optics-lanes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "optics-lane"):
                        for c in self.optics_lane:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.optics_lane.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "optics-lane"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TxThresholds(Entity):
                """
                Configure Tx threshold
                
                .. attribute:: tx_threshold
                
                	Optics TX Low or high threshold configuration
                	**type**\: list of    :py:class:`TxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds, self).__init__()

                    self.yang_name = "tx-thresholds"
                    self.yang_parent_name = "optics"

                    self.tx_threshold = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds, self).__setattr__(name, value)


                class TxThreshold(Entity):
                    """
                    Optics TX Low or high threshold configuration
                    
                    .. attribute:: tx_threshold_type  <key>
                    
                    	Low or high tx threshold
                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.Threshold>`
                    
                    .. attribute:: tx_threshold
                    
                    	Select power level (in units of 0.1dBm)
                    	**type**\:  int
                    
                    	**range:** \-400..300
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold, self).__init__()

                        self.yang_name = "tx-threshold"
                        self.yang_parent_name = "tx-thresholds"

                        self.tx_threshold_type = YLeaf(YType.enumeration, "tx-threshold-type")

                        self.tx_threshold = YLeaf(YType.int32, "tx-threshold")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tx_threshold_type",
                                        "tx_threshold") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.tx_threshold_type.is_set or
                            self.tx_threshold.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tx_threshold_type.yfilter != YFilter.not_set or
                            self.tx_threshold.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tx-threshold" + "[tx-threshold-type='" + self.tx_threshold_type.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tx_threshold_type.is_set or self.tx_threshold_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tx_threshold_type.get_name_leafdata())
                        if (self.tx_threshold.is_set or self.tx_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tx_threshold.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "tx-threshold-type" or name == "tx-threshold"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tx-threshold-type"):
                            self.tx_threshold_type = value
                            self.tx_threshold_type.value_namespace = name_space
                            self.tx_threshold_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "tx-threshold"):
                            self.tx_threshold = value
                            self.tx_threshold.value_namespace = name_space
                            self.tx_threshold.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.tx_threshold:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.tx_threshold:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "tx-thresholds" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "tx-threshold"):
                        for c in self.tx_threshold:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.tx_threshold.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "tx-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.breakout.is_set or
                    self.optics_cd_high_threshold.is_set or
                    self.optics_cd_low_threshold.is_set or
                    self.optics_cd_max.is_set or
                    self.optics_cd_min.is_set or
                    self.optics_description.is_set or
                    self.optics_dgd_high_threshold.is_set or
                    self.optics_fec.is_set or
                    self.optics_lbc_high_threshold.is_set or
                    self.optics_loopback.is_set or
                    self.optics_osnr_low_threshold.is_set or
                    self.optics_ots_amplifier_channel_power.is_set or
                    self.optics_ots_amplifier_control_mode.is_set or
                    self.optics_ots_amplifier_gain.is_set or
                    self.optics_ots_amplifier_gain_degrade_high_threshold.is_set or
                    self.optics_ots_amplifier_gain_degrade_low_threshold.is_set or
                    self.optics_ots_amplifier_gain_range.is_set or
                    self.optics_ots_amplifier_tilt.is_set or
                    self.optics_ots_channel_power_max_delta.is_set or
                    self.optics_ots_osri.is_set or
                    self.optics_ots_rx_voa_attenuation.is_set or
                    self.optics_ots_safety_control_mode.is_set or
                    self.optics_ots_tx_voa_attenuation.is_set or
                    self.optics_performance_monitoring.is_set or
                    self.optics_transmit_power.is_set or
                    self.optics_transmit_shutdown.is_set or
                    (self.optics_lanes is not None and self.optics_lanes.has_data()) or
                    (self.optics_network_srlgs is not None and self.optics_network_srlgs.has_data()) or
                    (self.rx_thresholds is not None and self.rx_thresholds.has_data()) or
                    (self.tx_thresholds is not None and self.tx_thresholds.has_data()) or
                    (self.optics_dwdm_carrier is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.breakout.yfilter != YFilter.not_set or
                    self.optics_cd_high_threshold.yfilter != YFilter.not_set or
                    self.optics_cd_low_threshold.yfilter != YFilter.not_set or
                    self.optics_cd_max.yfilter != YFilter.not_set or
                    self.optics_cd_min.yfilter != YFilter.not_set or
                    self.optics_description.yfilter != YFilter.not_set or
                    self.optics_dgd_high_threshold.yfilter != YFilter.not_set or
                    self.optics_fec.yfilter != YFilter.not_set or
                    self.optics_lbc_high_threshold.yfilter != YFilter.not_set or
                    self.optics_loopback.yfilter != YFilter.not_set or
                    self.optics_osnr_low_threshold.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_channel_power.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_control_mode.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_gain.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_gain_degrade_high_threshold.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_gain_degrade_low_threshold.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_gain_range.yfilter != YFilter.not_set or
                    self.optics_ots_amplifier_tilt.yfilter != YFilter.not_set or
                    self.optics_ots_channel_power_max_delta.yfilter != YFilter.not_set or
                    self.optics_ots_osri.yfilter != YFilter.not_set or
                    self.optics_ots_rx_voa_attenuation.yfilter != YFilter.not_set or
                    self.optics_ots_safety_control_mode.yfilter != YFilter.not_set or
                    self.optics_ots_tx_voa_attenuation.yfilter != YFilter.not_set or
                    self.optics_performance_monitoring.yfilter != YFilter.not_set or
                    self.optics_transmit_power.yfilter != YFilter.not_set or
                    self.optics_transmit_shutdown.yfilter != YFilter.not_set or
                    (self.optics_dwdm_carrier is not None and self.optics_dwdm_carrier.has_operation()) or
                    (self.optics_lanes is not None and self.optics_lanes.has_operation()) or
                    (self.optics_network_srlgs is not None and self.optics_network_srlgs.has_operation()) or
                    (self.rx_thresholds is not None and self.rx_thresholds.has_operation()) or
                    (self.tx_thresholds is not None and self.tx_thresholds.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-controller-optics-cfg:optics" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.breakout.is_set or self.breakout.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.breakout.get_name_leafdata())
                if (self.optics_cd_high_threshold.is_set or self.optics_cd_high_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_cd_high_threshold.get_name_leafdata())
                if (self.optics_cd_low_threshold.is_set or self.optics_cd_low_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_cd_low_threshold.get_name_leafdata())
                if (self.optics_cd_max.is_set or self.optics_cd_max.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_cd_max.get_name_leafdata())
                if (self.optics_cd_min.is_set or self.optics_cd_min.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_cd_min.get_name_leafdata())
                if (self.optics_description.is_set or self.optics_description.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_description.get_name_leafdata())
                if (self.optics_dgd_high_threshold.is_set or self.optics_dgd_high_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_dgd_high_threshold.get_name_leafdata())
                if (self.optics_fec.is_set or self.optics_fec.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_fec.get_name_leafdata())
                if (self.optics_lbc_high_threshold.is_set or self.optics_lbc_high_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_lbc_high_threshold.get_name_leafdata())
                if (self.optics_loopback.is_set or self.optics_loopback.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_loopback.get_name_leafdata())
                if (self.optics_osnr_low_threshold.is_set or self.optics_osnr_low_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_osnr_low_threshold.get_name_leafdata())
                if (self.optics_ots_amplifier_channel_power.is_set or self.optics_ots_amplifier_channel_power.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_channel_power.get_name_leafdata())
                if (self.optics_ots_amplifier_control_mode.is_set or self.optics_ots_amplifier_control_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_control_mode.get_name_leafdata())
                if (self.optics_ots_amplifier_gain.is_set or self.optics_ots_amplifier_gain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_gain.get_name_leafdata())
                if (self.optics_ots_amplifier_gain_degrade_high_threshold.is_set or self.optics_ots_amplifier_gain_degrade_high_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_gain_degrade_high_threshold.get_name_leafdata())
                if (self.optics_ots_amplifier_gain_degrade_low_threshold.is_set or self.optics_ots_amplifier_gain_degrade_low_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_gain_degrade_low_threshold.get_name_leafdata())
                if (self.optics_ots_amplifier_gain_range.is_set or self.optics_ots_amplifier_gain_range.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_gain_range.get_name_leafdata())
                if (self.optics_ots_amplifier_tilt.is_set or self.optics_ots_amplifier_tilt.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_amplifier_tilt.get_name_leafdata())
                if (self.optics_ots_channel_power_max_delta.is_set or self.optics_ots_channel_power_max_delta.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_channel_power_max_delta.get_name_leafdata())
                if (self.optics_ots_osri.is_set or self.optics_ots_osri.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_osri.get_name_leafdata())
                if (self.optics_ots_rx_voa_attenuation.is_set or self.optics_ots_rx_voa_attenuation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_rx_voa_attenuation.get_name_leafdata())
                if (self.optics_ots_safety_control_mode.is_set or self.optics_ots_safety_control_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_safety_control_mode.get_name_leafdata())
                if (self.optics_ots_tx_voa_attenuation.is_set or self.optics_ots_tx_voa_attenuation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_ots_tx_voa_attenuation.get_name_leafdata())
                if (self.optics_performance_monitoring.is_set or self.optics_performance_monitoring.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_performance_monitoring.get_name_leafdata())
                if (self.optics_transmit_power.is_set or self.optics_transmit_power.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_transmit_power.get_name_leafdata())
                if (self.optics_transmit_shutdown.is_set or self.optics_transmit_shutdown.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.optics_transmit_shutdown.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "optics-dwdm-carrier"):
                    if (self.optics_dwdm_carrier is None):
                        self.optics_dwdm_carrier = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier()
                        self.optics_dwdm_carrier.parent = self
                        self._children_name_map["optics_dwdm_carrier"] = "optics-dwdm-carrier"
                    return self.optics_dwdm_carrier

                if (child_yang_name == "optics-lanes"):
                    if (self.optics_lanes is None):
                        self.optics_lanes = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes()
                        self.optics_lanes.parent = self
                        self._children_name_map["optics_lanes"] = "optics-lanes"
                    return self.optics_lanes

                if (child_yang_name == "optics-network-srlgs"):
                    if (self.optics_network_srlgs is None):
                        self.optics_network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs()
                        self.optics_network_srlgs.parent = self
                        self._children_name_map["optics_network_srlgs"] = "optics-network-srlgs"
                    return self.optics_network_srlgs

                if (child_yang_name == "rx-thresholds"):
                    if (self.rx_thresholds is None):
                        self.rx_thresholds = InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds()
                        self.rx_thresholds.parent = self
                        self._children_name_map["rx_thresholds"] = "rx-thresholds"
                    return self.rx_thresholds

                if (child_yang_name == "tx-thresholds"):
                    if (self.tx_thresholds is None):
                        self.tx_thresholds = InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds()
                        self.tx_thresholds.parent = self
                        self._children_name_map["tx_thresholds"] = "tx-thresholds"
                    return self.tx_thresholds

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "optics-dwdm-carrier" or name == "optics-lanes" or name == "optics-network-srlgs" or name == "rx-thresholds" or name == "tx-thresholds" or name == "breakout" or name == "optics-cd-high-threshold" or name == "optics-cd-low-threshold" or name == "optics-cd-max" or name == "optics-cd-min" or name == "optics-description" or name == "optics-dgd-high-threshold" or name == "optics-fec" or name == "optics-lbc-high-threshold" or name == "optics-loopback" or name == "optics-osnr-low-threshold" or name == "optics-ots-amplifier-channel-power" or name == "optics-ots-amplifier-control-mode" or name == "optics-ots-amplifier-gain" or name == "optics-ots-amplifier-gain-degrade-high-threshold" or name == "optics-ots-amplifier-gain-degrade-low-threshold" or name == "optics-ots-amplifier-gain-range" or name == "optics-ots-amplifier-tilt" or name == "optics-ots-channel-power-max-delta" or name == "optics-ots-osri" or name == "optics-ots-rx-voa-attenuation" or name == "optics-ots-safety-control-mode" or name == "optics-ots-tx-voa-attenuation" or name == "optics-performance-monitoring" or name == "optics-transmit-power" or name == "optics-transmit-shutdown"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "breakout"):
                    self.breakout = value
                    self.breakout.value_namespace = name_space
                    self.breakout.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-cd-high-threshold"):
                    self.optics_cd_high_threshold = value
                    self.optics_cd_high_threshold.value_namespace = name_space
                    self.optics_cd_high_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-cd-low-threshold"):
                    self.optics_cd_low_threshold = value
                    self.optics_cd_low_threshold.value_namespace = name_space
                    self.optics_cd_low_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-cd-max"):
                    self.optics_cd_max = value
                    self.optics_cd_max.value_namespace = name_space
                    self.optics_cd_max.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-cd-min"):
                    self.optics_cd_min = value
                    self.optics_cd_min.value_namespace = name_space
                    self.optics_cd_min.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-description"):
                    self.optics_description = value
                    self.optics_description.value_namespace = name_space
                    self.optics_description.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-dgd-high-threshold"):
                    self.optics_dgd_high_threshold = value
                    self.optics_dgd_high_threshold.value_namespace = name_space
                    self.optics_dgd_high_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-fec"):
                    self.optics_fec = value
                    self.optics_fec.value_namespace = name_space
                    self.optics_fec.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-lbc-high-threshold"):
                    self.optics_lbc_high_threshold = value
                    self.optics_lbc_high_threshold.value_namespace = name_space
                    self.optics_lbc_high_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-loopback"):
                    self.optics_loopback = value
                    self.optics_loopback.value_namespace = name_space
                    self.optics_loopback.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-osnr-low-threshold"):
                    self.optics_osnr_low_threshold = value
                    self.optics_osnr_low_threshold.value_namespace = name_space
                    self.optics_osnr_low_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-channel-power"):
                    self.optics_ots_amplifier_channel_power = value
                    self.optics_ots_amplifier_channel_power.value_namespace = name_space
                    self.optics_ots_amplifier_channel_power.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-control-mode"):
                    self.optics_ots_amplifier_control_mode = value
                    self.optics_ots_amplifier_control_mode.value_namespace = name_space
                    self.optics_ots_amplifier_control_mode.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-gain"):
                    self.optics_ots_amplifier_gain = value
                    self.optics_ots_amplifier_gain.value_namespace = name_space
                    self.optics_ots_amplifier_gain.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-gain-degrade-high-threshold"):
                    self.optics_ots_amplifier_gain_degrade_high_threshold = value
                    self.optics_ots_amplifier_gain_degrade_high_threshold.value_namespace = name_space
                    self.optics_ots_amplifier_gain_degrade_high_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-gain-degrade-low-threshold"):
                    self.optics_ots_amplifier_gain_degrade_low_threshold = value
                    self.optics_ots_amplifier_gain_degrade_low_threshold.value_namespace = name_space
                    self.optics_ots_amplifier_gain_degrade_low_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-gain-range"):
                    self.optics_ots_amplifier_gain_range = value
                    self.optics_ots_amplifier_gain_range.value_namespace = name_space
                    self.optics_ots_amplifier_gain_range.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-amplifier-tilt"):
                    self.optics_ots_amplifier_tilt = value
                    self.optics_ots_amplifier_tilt.value_namespace = name_space
                    self.optics_ots_amplifier_tilt.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-channel-power-max-delta"):
                    self.optics_ots_channel_power_max_delta = value
                    self.optics_ots_channel_power_max_delta.value_namespace = name_space
                    self.optics_ots_channel_power_max_delta.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-osri"):
                    self.optics_ots_osri = value
                    self.optics_ots_osri.value_namespace = name_space
                    self.optics_ots_osri.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-rx-voa-attenuation"):
                    self.optics_ots_rx_voa_attenuation = value
                    self.optics_ots_rx_voa_attenuation.value_namespace = name_space
                    self.optics_ots_rx_voa_attenuation.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-safety-control-mode"):
                    self.optics_ots_safety_control_mode = value
                    self.optics_ots_safety_control_mode.value_namespace = name_space
                    self.optics_ots_safety_control_mode.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-ots-tx-voa-attenuation"):
                    self.optics_ots_tx_voa_attenuation = value
                    self.optics_ots_tx_voa_attenuation.value_namespace = name_space
                    self.optics_ots_tx_voa_attenuation.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-performance-monitoring"):
                    self.optics_performance_monitoring = value
                    self.optics_performance_monitoring.value_namespace = name_space
                    self.optics_performance_monitoring.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-transmit-power"):
                    self.optics_transmit_power = value
                    self.optics_transmit_power.value_namespace = name_space
                    self.optics_transmit_power.value_namespace_prefix = name_space_prefix
                if(value_path == "optics-transmit-shutdown"):
                    self.optics_transmit_shutdown = value
                    self.optics_transmit_shutdown.value_namespace = name_space
                    self.optics_transmit_shutdown.value_namespace_prefix = name_space_prefix


        class Otu(Entity):
            """
            OTU port controller configuration
            
            .. attribute:: fec
            
            	Configure forward error correction
            	**type**\:   :py:class:`OtuForwardErrorCorrection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtuForwardErrorCorrection>`
            
            	**default value**\: none
            
            .. attribute:: gcc
            
            	General Communication Channel configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: loopback
            
            	Type of Loopback
            	**type**\:   :py:class:`OtnLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnLoopback>`
            
            .. attribute:: network_srlgs
            
            	Configure Network srlgs
            	**type**\:   :py:class:`NetworkSrlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs>`
            
            .. attribute:: otn_expected_tti
            
            	Configure OTN Expected TTI value for Full ASCII/HEX
            	**type**\:   :py:class:`OtnExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti>`
            
            .. attribute:: otn_expected_ttisapi
            
            	Configure OTN Expected TTI value for SAPI configs
            	**type**\:   :py:class:`OtnExpectedTtisapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi>`
            
            .. attribute:: otn_expected_ttitcmdapi
            
            	Configure OTN Expected TTI value for DAPI configs
            	**type**\:   :py:class:`OtnExpectedTtitcmdapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi>`
            
            .. attribute:: otn_expected_ttitcmos
            
            	Configure OTN Expected TTI value for OS config
            	**type**\:   :py:class:`OtnExpectedTtitcmos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos>`
            
            .. attribute:: otn_send_tti
            
            	Configure OTN Send TTI value for Full ASCII/HEX
            	**type**\:   :py:class:`OtnSendTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti>`
            
            .. attribute:: otn_send_ttisapi
            
            	Configure OTN Send TTI value for SAPI configs
            	**type**\:   :py:class:`OtnSendTtisapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi>`
            
            .. attribute:: otn_send_ttitcmdapi
            
            	Configure OTN Send TTI value for DAPI configs
            	**type**\:   :py:class:`OtnSendTtitcmdapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi>`
            
            .. attribute:: otn_send_ttitcmos
            
            	Configure OTN Send TTI value for OS config
            	**type**\:   :py:class:`OtnSendTtitcmos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos>`
            
            .. attribute:: performance_monitoring
            
            	Configure performance monitoring
            	**type**\:   :py:class:`OtnPerMon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnPerMon>`
            
            	**default value**\: enable
            
            .. attribute:: proactive_protection
            
            	Configure Proactive Protection
            	**type**\:   :py:class:`ProactiveProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection>`
            
            .. attribute:: sd
            
            	Signal degrade threshold
            	**type**\:  int
            
            	**range:** 5..9
            
            .. attribute:: secondary_admin_state
            
            	Configure secondary admin state 
            	**type**\:   :py:class:`OtnSecAdminState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSecAdminState>`
            
            	**default value**\: normal
            
            .. attribute:: sf
            
            	Signal failure threshold
            	**type**\:  int
            
            	**range:** 5..9
            
            

            """

            _prefix = 'controller-otu-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Otu, self).__init__()

                self.yang_name = "otu"
                self.yang_parent_name = "interface-configuration"

                self.fec = YLeaf(YType.enumeration, "fec")

                self.gcc = YLeaf(YType.empty, "gcc")

                self.loopback = YLeaf(YType.enumeration, "loopback")

                self.performance_monitoring = YLeaf(YType.enumeration, "performance-monitoring")

                self.sd = YLeaf(YType.uint32, "sd")

                self.secondary_admin_state = YLeaf(YType.enumeration, "secondary-admin-state")

                self.sf = YLeaf(YType.uint32, "sf")

                self.network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs()
                self.network_srlgs.parent = self
                self._children_name_map["network_srlgs"] = "network-srlgs"
                self._children_yang_names.add("network-srlgs")

                self.otn_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti()
                self.otn_expected_tti.parent = self
                self._children_name_map["otn_expected_tti"] = "otn-expected-tti"
                self._children_yang_names.add("otn-expected-tti")

                self.otn_expected_ttisapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi()
                self.otn_expected_ttisapi.parent = self
                self._children_name_map["otn_expected_ttisapi"] = "otn-expected-ttisapi"
                self._children_yang_names.add("otn-expected-ttisapi")

                self.otn_expected_ttitcmdapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi()
                self.otn_expected_ttitcmdapi.parent = self
                self._children_name_map["otn_expected_ttitcmdapi"] = "otn-expected-ttitcmdapi"
                self._children_yang_names.add("otn-expected-ttitcmdapi")

                self.otn_expected_ttitcmos = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos()
                self.otn_expected_ttitcmos.parent = self
                self._children_name_map["otn_expected_ttitcmos"] = "otn-expected-ttitcmos"
                self._children_yang_names.add("otn-expected-ttitcmos")

                self.otn_send_tti = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti()
                self.otn_send_tti.parent = self
                self._children_name_map["otn_send_tti"] = "otn-send-tti"
                self._children_yang_names.add("otn-send-tti")

                self.otn_send_ttisapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi()
                self.otn_send_ttisapi.parent = self
                self._children_name_map["otn_send_ttisapi"] = "otn-send-ttisapi"
                self._children_yang_names.add("otn-send-ttisapi")

                self.otn_send_ttitcmdapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi()
                self.otn_send_ttitcmdapi.parent = self
                self._children_name_map["otn_send_ttitcmdapi"] = "otn-send-ttitcmdapi"
                self._children_yang_names.add("otn-send-ttitcmdapi")

                self.otn_send_ttitcmos = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos()
                self.otn_send_ttitcmos.parent = self
                self._children_name_map["otn_send_ttitcmos"] = "otn-send-ttitcmos"
                self._children_yang_names.add("otn-send-ttitcmos")

                self.proactive_protection = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection()
                self.proactive_protection.parent = self
                self._children_name_map["proactive_protection"] = "proactive-protection"
                self._children_yang_names.add("proactive-protection")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("fec",
                                "gcc",
                                "loopback",
                                "performance_monitoring",
                                "sd",
                                "secondary_admin_state",
                                "sf") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu, self).__setattr__(name, value)


            class OtnSendTtitcmos(Entity):
                """
                Configure OTN Send TTI value for OS config
                
                .. attribute:: osascii_string
                
                	OS ASCII text (Max 32 characters)
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: oshex_string
                
                	OS HEX text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeOs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeOs>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos, self).__init__()

                    self.yang_name = "otn-send-ttitcmos"
                    self.yang_parent_name = "otu"

                    self.osascii_string = YLeaf(YType.str, "osascii-string")

                    self.oshex_string = YLeaf(YType.str, "oshex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("osascii_string",
                                    "oshex_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.osascii_string.is_set or
                        self.oshex_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.osascii_string.yfilter != YFilter.not_set or
                        self.oshex_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-send-ttitcmos" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.osascii_string.is_set or self.osascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.osascii_string.get_name_leafdata())
                    if (self.oshex_string.is_set or self.oshex_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.oshex_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "osascii-string" or name == "oshex-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "osascii-string"):
                        self.osascii_string = value
                        self.osascii_string.value_namespace = name_space
                        self.osascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "oshex-string"):
                        self.oshex_string = value
                        self.oshex_string.value_namespace = name_space
                        self.oshex_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class OtnSendTtitcmdapi(Entity):
                """
                Configure OTN Send TTI value for DAPI configs
                
                .. attribute:: dapi_ascii_string
                
                	DAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeDapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeDapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi, self).__init__()

                    self.yang_name = "otn-send-ttitcmdapi"
                    self.yang_parent_name = "otu"

                    self.dapi_ascii_string = YLeaf(YType.str, "dapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dapi_ascii_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.dapi_ascii_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dapi_ascii_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-send-ttitcmdapi" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dapi_ascii_string.is_set or self.dapi_ascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dapi_ascii_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "dapi-ascii-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dapi-ascii-string"):
                        self.dapi_ascii_string = value
                        self.dapi_ascii_string.value_namespace = name_space
                        self.dapi_ascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class OtnExpectedTtisapi(Entity):
                """
                Configure OTN Expected TTI value for SAPI
                configs
                
                .. attribute:: sapi_ascii_string
                
                	SAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeSapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeSapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi, self).__init__()

                    self.yang_name = "otn-expected-ttisapi"
                    self.yang_parent_name = "otu"

                    self.sapi_ascii_string = YLeaf(YType.str, "sapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("sapi_ascii_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.sapi_ascii_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.sapi_ascii_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-expected-ttisapi" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.sapi_ascii_string.is_set or self.sapi_ascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sapi_ascii_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sapi-ascii-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "sapi-ascii-string"):
                        self.sapi_ascii_string = value
                        self.sapi_ascii_string.value_namespace = name_space
                        self.sapi_ascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class ProactiveProtection(Entity):
                """
                Configure Proactive Protection
                
                .. attribute:: revert_threshold
                
                	Proactive Protection Threshold
                	**type**\:   :py:class:`RevertThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold>`
                
                .. attribute:: revert_window
                
                	Proactive Protection Window
                	**type**\:   :py:class:`RevertWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow>`
                
                .. attribute:: status
                
                	Enable Proactive Protection
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: trigger_threshold
                
                	Proactive Protection Threshold
                	**type**\:   :py:class:`TriggerThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold>`
                
                .. attribute:: trigger_window
                
                	Proactive Protection Window
                	**type**\:   :py:class:`TriggerWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection, self).__init__()

                    self.yang_name = "proactive-protection"
                    self.yang_parent_name = "otu"

                    self.status = YLeaf(YType.empty, "status")

                    self.revert_threshold = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold()
                    self.revert_threshold.parent = self
                    self._children_name_map["revert_threshold"] = "revert-threshold"
                    self._children_yang_names.add("revert-threshold")

                    self.revert_window = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow()
                    self.revert_window.parent = self
                    self._children_name_map["revert_window"] = "revert-window"
                    self._children_yang_names.add("revert-window")

                    self.trigger_threshold = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold()
                    self.trigger_threshold.parent = self
                    self._children_name_map["trigger_threshold"] = "trigger-threshold"
                    self._children_yang_names.add("trigger-threshold")

                    self.trigger_window = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow()
                    self.trigger_window.parent = self
                    self._children_name_map["trigger_window"] = "trigger-window"
                    self._children_yang_names.add("trigger-window")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("status") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection, self).__setattr__(name, value)


                class TriggerThreshold(Entity):
                    """
                    Proactive Protection Threshold
                    
                    .. attribute:: coefficient
                    
                    	Bit error rate coefficient
                    	**type**\:  int
                    
                    	**range:** 1..9
                    
                    .. attribute:: enable
                    
                    	Proactive Protection supported
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power
                    
                    	Bit error rate power
                    	**type**\:  int
                    
                    	**range:** 3..9
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold, self).__init__()

                        self.yang_name = "trigger-threshold"
                        self.yang_parent_name = "proactive-protection"

                        self.coefficient = YLeaf(YType.uint32, "coefficient")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.power = YLeaf(YType.uint32, "power")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("coefficient",
                                        "enable",
                                        "power") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.coefficient.is_set or
                            self.enable.is_set or
                            self.power.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.coefficient.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.power.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "trigger-threshold" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.coefficient.is_set or self.coefficient.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.coefficient.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.power.is_set or self.power.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.power.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "coefficient" or name == "enable" or name == "power"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "coefficient"):
                            self.coefficient = value
                            self.coefficient.value_namespace = name_space
                            self.coefficient.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "power"):
                            self.power = value
                            self.power.value_namespace = name_space
                            self.power.value_namespace_prefix = name_space_prefix


                class RevertWindow(Entity):
                    """
                    Proactive Protection Window
                    
                    .. attribute:: enable
                    
                    	Enable Proactive Protection
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value
                    
                    	Integration window for FRR trigger in MS
                    	**type**\:  int
                    
                    	**range:** 2000..10000
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow, self).__init__()

                        self.yang_name = "revert-window"
                        self.yang_parent_name = "proactive-protection"

                        self.enable = YLeaf(YType.empty, "enable")

                        self.value = YLeaf(YType.uint32, "value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("enable",
                                        "value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.enable.is_set or
                            self.value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "revert-window" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "enable" or name == "value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "value"):
                            self.value = value
                            self.value.value_namespace = name_space
                            self.value.value_namespace_prefix = name_space_prefix


                class TriggerWindow(Entity):
                    """
                    Proactive Protection Window
                    
                    .. attribute:: enable
                    
                    	Enable Proactive Protection
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value
                    
                    	Integration window for FRR trigger in MS
                    	**type**\:  int
                    
                    	**range:** 10..10000
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow, self).__init__()

                        self.yang_name = "trigger-window"
                        self.yang_parent_name = "proactive-protection"

                        self.enable = YLeaf(YType.empty, "enable")

                        self.value = YLeaf(YType.uint32, "value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("enable",
                                        "value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.enable.is_set or
                            self.value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "trigger-window" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "enable" or name == "value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "value"):
                            self.value = value
                            self.value.value_namespace = name_space
                            self.value.value_namespace_prefix = name_space_prefix


                class RevertThreshold(Entity):
                    """
                    Proactive Protection Threshold
                    
                    .. attribute:: coefficient
                    
                    	Bit error rate coefficient
                    	**type**\:  int
                    
                    	**range:** 1..9
                    
                    .. attribute:: enable
                    
                    	Proactive Protection supported
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power
                    
                    	Bit error rate power
                    	**type**\:  int
                    
                    	**range:** 4..10
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold, self).__init__()

                        self.yang_name = "revert-threshold"
                        self.yang_parent_name = "proactive-protection"

                        self.coefficient = YLeaf(YType.uint32, "coefficient")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.power = YLeaf(YType.uint32, "power")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("coefficient",
                                        "enable",
                                        "power") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.coefficient.is_set or
                            self.enable.is_set or
                            self.power.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.coefficient.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.power.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "revert-threshold" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.coefficient.is_set or self.coefficient.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.coefficient.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.power.is_set or self.power.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.power.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "coefficient" or name == "enable" or name == "power"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "coefficient"):
                            self.coefficient = value
                            self.coefficient.value_namespace = name_space
                            self.coefficient.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "power"):
                            self.power = value
                            self.power.value_namespace = name_space
                            self.power.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.status.is_set or
                        (self.revert_threshold is not None and self.revert_threshold.has_data()) or
                        (self.revert_window is not None and self.revert_window.has_data()) or
                        (self.trigger_threshold is not None and self.trigger_threshold.has_data()) or
                        (self.trigger_window is not None and self.trigger_window.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.status.yfilter != YFilter.not_set or
                        (self.revert_threshold is not None and self.revert_threshold.has_operation()) or
                        (self.revert_window is not None and self.revert_window.has_operation()) or
                        (self.trigger_threshold is not None and self.trigger_threshold.has_operation()) or
                        (self.trigger_window is not None and self.trigger_window.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "proactive-protection" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.status.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "revert-threshold"):
                        if (self.revert_threshold is None):
                            self.revert_threshold = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold()
                            self.revert_threshold.parent = self
                            self._children_name_map["revert_threshold"] = "revert-threshold"
                        return self.revert_threshold

                    if (child_yang_name == "revert-window"):
                        if (self.revert_window is None):
                            self.revert_window = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow()
                            self.revert_window.parent = self
                            self._children_name_map["revert_window"] = "revert-window"
                        return self.revert_window

                    if (child_yang_name == "trigger-threshold"):
                        if (self.trigger_threshold is None):
                            self.trigger_threshold = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold()
                            self.trigger_threshold.parent = self
                            self._children_name_map["trigger_threshold"] = "trigger-threshold"
                        return self.trigger_threshold

                    if (child_yang_name == "trigger-window"):
                        if (self.trigger_window is None):
                            self.trigger_window = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow()
                            self.trigger_window.parent = self
                            self._children_name_map["trigger_window"] = "trigger-window"
                        return self.trigger_window

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "revert-threshold" or name == "revert-window" or name == "trigger-threshold" or name == "trigger-window" or name == "status"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "status"):
                        self.status = value
                        self.status.value_namespace = name_space
                        self.status.value_namespace_prefix = name_space_prefix


            class NetworkSrlgs(Entity):
                """
                Configure Network srlgs
                
                .. attribute:: network_srlg
                
                	Configure network srlg sets
                	**type**\: list of    :py:class:`NetworkSrlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs, self).__init__()

                    self.yang_name = "network-srlgs"
                    self.yang_parent_name = "otu"

                    self.network_srlg = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs, self).__setattr__(name, value)


                class NetworkSrlg(Entity):
                    """
                    Configure network srlg sets
                    
                    .. attribute:: set_id  <key>
                    
                    	Set index
                    	**type**\:  int
                    
                    	**range:** 1..17
                    
                    .. attribute:: srlg1
                    
                    	First value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg2
                    
                    	Second value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg3
                    
                    	Third value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg4
                    
                    	Forth value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg5
                    
                    	Fifth value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg6
                    
                    	Sixth value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg, self).__init__()

                        self.yang_name = "network-srlg"
                        self.yang_parent_name = "network-srlgs"

                        self.set_id = YLeaf(YType.uint32, "set-id")

                        self.srlg1 = YLeaf(YType.uint32, "srlg1")

                        self.srlg2 = YLeaf(YType.uint32, "srlg2")

                        self.srlg3 = YLeaf(YType.uint32, "srlg3")

                        self.srlg4 = YLeaf(YType.uint32, "srlg4")

                        self.srlg5 = YLeaf(YType.uint32, "srlg5")

                        self.srlg6 = YLeaf(YType.uint32, "srlg6")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("set_id",
                                        "srlg1",
                                        "srlg2",
                                        "srlg3",
                                        "srlg4",
                                        "srlg5",
                                        "srlg6") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.set_id.is_set or
                            self.srlg1.is_set or
                            self.srlg2.is_set or
                            self.srlg3.is_set or
                            self.srlg4.is_set or
                            self.srlg5.is_set or
                            self.srlg6.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.set_id.yfilter != YFilter.not_set or
                            self.srlg1.yfilter != YFilter.not_set or
                            self.srlg2.yfilter != YFilter.not_set or
                            self.srlg3.yfilter != YFilter.not_set or
                            self.srlg4.yfilter != YFilter.not_set or
                            self.srlg5.yfilter != YFilter.not_set or
                            self.srlg6.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "network-srlg" + "[set-id='" + self.set_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.set_id.is_set or self.set_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.set_id.get_name_leafdata())
                        if (self.srlg1.is_set or self.srlg1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg1.get_name_leafdata())
                        if (self.srlg2.is_set or self.srlg2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg2.get_name_leafdata())
                        if (self.srlg3.is_set or self.srlg3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg3.get_name_leafdata())
                        if (self.srlg4.is_set or self.srlg4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg4.get_name_leafdata())
                        if (self.srlg5.is_set or self.srlg5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg5.get_name_leafdata())
                        if (self.srlg6.is_set or self.srlg6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg6.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "set-id" or name == "srlg1" or name == "srlg2" or name == "srlg3" or name == "srlg4" or name == "srlg5" or name == "srlg6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "set-id"):
                            self.set_id = value
                            self.set_id.value_namespace = name_space
                            self.set_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg1"):
                            self.srlg1 = value
                            self.srlg1.value_namespace = name_space
                            self.srlg1.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg2"):
                            self.srlg2 = value
                            self.srlg2.value_namespace = name_space
                            self.srlg2.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg3"):
                            self.srlg3 = value
                            self.srlg3.value_namespace = name_space
                            self.srlg3.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg4"):
                            self.srlg4 = value
                            self.srlg4.value_namespace = name_space
                            self.srlg4.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg5"):
                            self.srlg5 = value
                            self.srlg5.value_namespace = name_space
                            self.srlg5.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg6"):
                            self.srlg6 = value
                            self.srlg6.value_namespace = name_space
                            self.srlg6.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.network_srlg:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.network_srlg:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "network-srlgs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "network-srlg"):
                        for c in self.network_srlg:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.network_srlg.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "network-srlg"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OtnSendTti(Entity):
                """
                Configure OTN Send TTI value for Full ASCII/HEX
                
                .. attribute:: full_ascii_string
                
                	Full ASCII text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: hex_string
                
                	Hex nibbles (Max 128 \- The string length should be an even number)
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeFull <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeFull>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti, self).__init__()

                    self.yang_name = "otn-send-tti"
                    self.yang_parent_name = "otu"

                    self.full_ascii_string = YLeaf(YType.str, "full-ascii-string")

                    self.hex_string = YLeaf(YType.str, "hex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("full_ascii_string",
                                    "hex_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.full_ascii_string.is_set or
                        self.hex_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.full_ascii_string.yfilter != YFilter.not_set or
                        self.hex_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-send-tti" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.full_ascii_string.is_set or self.full_ascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.full_ascii_string.get_name_leafdata())
                    if (self.hex_string.is_set or self.hex_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hex_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "full-ascii-string" or name == "hex-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "full-ascii-string"):
                        self.full_ascii_string = value
                        self.full_ascii_string.value_namespace = name_space
                        self.full_ascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "hex-string"):
                        self.hex_string = value
                        self.hex_string.value_namespace = name_space
                        self.hex_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class OtnExpectedTtitcmdapi(Entity):
                """
                Configure OTN Expected TTI value for DAPI
                configs
                
                .. attribute:: dapi_ascii_string
                
                	DAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeDapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeDapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi, self).__init__()

                    self.yang_name = "otn-expected-ttitcmdapi"
                    self.yang_parent_name = "otu"

                    self.dapi_ascii_string = YLeaf(YType.str, "dapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dapi_ascii_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.dapi_ascii_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dapi_ascii_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-expected-ttitcmdapi" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dapi_ascii_string.is_set or self.dapi_ascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dapi_ascii_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "dapi-ascii-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dapi-ascii-string"):
                        self.dapi_ascii_string = value
                        self.dapi_ascii_string.value_namespace = name_space
                        self.dapi_ascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class OtnSendTtisapi(Entity):
                """
                Configure OTN Send TTI value for SAPI configs
                
                .. attribute:: sapi_ascii_string
                
                	SAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeSapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeSapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi, self).__init__()

                    self.yang_name = "otn-send-ttisapi"
                    self.yang_parent_name = "otu"

                    self.sapi_ascii_string = YLeaf(YType.str, "sapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("sapi_ascii_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.sapi_ascii_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.sapi_ascii_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-send-ttisapi" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.sapi_ascii_string.is_set or self.sapi_ascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sapi_ascii_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sapi-ascii-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "sapi-ascii-string"):
                        self.sapi_ascii_string = value
                        self.sapi_ascii_string.value_namespace = name_space
                        self.sapi_ascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class OtnExpectedTtitcmos(Entity):
                """
                Configure OTN Expected TTI value for OS config
                
                .. attribute:: osascii_string
                
                	OS ASCII text (Max 32 characters)
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: oshex_string
                
                	OS HEX text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeOs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeOs>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos, self).__init__()

                    self.yang_name = "otn-expected-ttitcmos"
                    self.yang_parent_name = "otu"

                    self.osascii_string = YLeaf(YType.str, "osascii-string")

                    self.oshex_string = YLeaf(YType.str, "oshex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("osascii_string",
                                    "oshex_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.osascii_string.is_set or
                        self.oshex_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.osascii_string.yfilter != YFilter.not_set or
                        self.oshex_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-expected-ttitcmos" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.osascii_string.is_set or self.osascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.osascii_string.get_name_leafdata())
                    if (self.oshex_string.is_set or self.oshex_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.oshex_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "osascii-string" or name == "oshex-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "osascii-string"):
                        self.osascii_string = value
                        self.osascii_string.value_namespace = name_space
                        self.osascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "oshex-string"):
                        self.oshex_string = value
                        self.oshex_string.value_namespace = name_space
                        self.oshex_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix


            class OtnExpectedTti(Entity):
                """
                Configure OTN Expected TTI value for Full
                ASCII/HEX
                
                .. attribute:: full_ascii_string
                
                	Full ASCII text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: hex_string
                
                	Hex nibbles (Max 128 \- The string length should be an even number)
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeFull <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeFull>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti, self).__init__()

                    self.yang_name = "otn-expected-tti"
                    self.yang_parent_name = "otu"

                    self.full_ascii_string = YLeaf(YType.str, "full-ascii-string")

                    self.hex_string = YLeaf(YType.str, "hex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("full_ascii_string",
                                    "hex_string",
                                    "string_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.full_ascii_string.is_set or
                        self.hex_string.is_set or
                        self.string_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.full_ascii_string.yfilter != YFilter.not_set or
                        self.hex_string.yfilter != YFilter.not_set or
                        self.string_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otn-expected-tti" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.full_ascii_string.is_set or self.full_ascii_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.full_ascii_string.get_name_leafdata())
                    if (self.hex_string.is_set or self.hex_string.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hex_string.get_name_leafdata())
                    if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.string_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "full-ascii-string" or name == "hex-string" or name == "string-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "full-ascii-string"):
                        self.full_ascii_string = value
                        self.full_ascii_string.value_namespace = name_space
                        self.full_ascii_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "hex-string"):
                        self.hex_string = value
                        self.hex_string.value_namespace = name_space
                        self.hex_string.value_namespace_prefix = name_space_prefix
                    if(value_path == "string-type"):
                        self.string_type = value
                        self.string_type.value_namespace = name_space
                        self.string_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.fec.is_set or
                    self.gcc.is_set or
                    self.loopback.is_set or
                    self.performance_monitoring.is_set or
                    self.sd.is_set or
                    self.secondary_admin_state.is_set or
                    self.sf.is_set or
                    (self.network_srlgs is not None and self.network_srlgs.has_data()) or
                    (self.otn_expected_tti is not None and self.otn_expected_tti.has_data()) or
                    (self.otn_expected_ttisapi is not None and self.otn_expected_ttisapi.has_data()) or
                    (self.otn_expected_ttitcmdapi is not None and self.otn_expected_ttitcmdapi.has_data()) or
                    (self.otn_expected_ttitcmos is not None and self.otn_expected_ttitcmos.has_data()) or
                    (self.otn_send_tti is not None and self.otn_send_tti.has_data()) or
                    (self.otn_send_ttisapi is not None and self.otn_send_ttisapi.has_data()) or
                    (self.otn_send_ttitcmdapi is not None and self.otn_send_ttitcmdapi.has_data()) or
                    (self.otn_send_ttitcmos is not None and self.otn_send_ttitcmos.has_data()) or
                    (self.proactive_protection is not None and self.proactive_protection.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.fec.yfilter != YFilter.not_set or
                    self.gcc.yfilter != YFilter.not_set or
                    self.loopback.yfilter != YFilter.not_set or
                    self.performance_monitoring.yfilter != YFilter.not_set or
                    self.sd.yfilter != YFilter.not_set or
                    self.secondary_admin_state.yfilter != YFilter.not_set or
                    self.sf.yfilter != YFilter.not_set or
                    (self.network_srlgs is not None and self.network_srlgs.has_operation()) or
                    (self.otn_expected_tti is not None and self.otn_expected_tti.has_operation()) or
                    (self.otn_expected_ttisapi is not None and self.otn_expected_ttisapi.has_operation()) or
                    (self.otn_expected_ttitcmdapi is not None and self.otn_expected_ttitcmdapi.has_operation()) or
                    (self.otn_expected_ttitcmos is not None and self.otn_expected_ttitcmos.has_operation()) or
                    (self.otn_send_tti is not None and self.otn_send_tti.has_operation()) or
                    (self.otn_send_ttisapi is not None and self.otn_send_ttisapi.has_operation()) or
                    (self.otn_send_ttitcmdapi is not None and self.otn_send_ttitcmdapi.has_operation()) or
                    (self.otn_send_ttitcmos is not None and self.otn_send_ttitcmos.has_operation()) or
                    (self.proactive_protection is not None and self.proactive_protection.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-controller-otu-cfg:otu" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.fec.is_set or self.fec.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.fec.get_name_leafdata())
                if (self.gcc.is_set or self.gcc.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.gcc.get_name_leafdata())
                if (self.loopback.is_set or self.loopback.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.loopback.get_name_leafdata())
                if (self.performance_monitoring.is_set or self.performance_monitoring.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.performance_monitoring.get_name_leafdata())
                if (self.sd.is_set or self.sd.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sd.get_name_leafdata())
                if (self.secondary_admin_state.is_set or self.secondary_admin_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.secondary_admin_state.get_name_leafdata())
                if (self.sf.is_set or self.sf.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sf.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "network-srlgs"):
                    if (self.network_srlgs is None):
                        self.network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs()
                        self.network_srlgs.parent = self
                        self._children_name_map["network_srlgs"] = "network-srlgs"
                    return self.network_srlgs

                if (child_yang_name == "otn-expected-tti"):
                    if (self.otn_expected_tti is None):
                        self.otn_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti()
                        self.otn_expected_tti.parent = self
                        self._children_name_map["otn_expected_tti"] = "otn-expected-tti"
                    return self.otn_expected_tti

                if (child_yang_name == "otn-expected-ttisapi"):
                    if (self.otn_expected_ttisapi is None):
                        self.otn_expected_ttisapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi()
                        self.otn_expected_ttisapi.parent = self
                        self._children_name_map["otn_expected_ttisapi"] = "otn-expected-ttisapi"
                    return self.otn_expected_ttisapi

                if (child_yang_name == "otn-expected-ttitcmdapi"):
                    if (self.otn_expected_ttitcmdapi is None):
                        self.otn_expected_ttitcmdapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi()
                        self.otn_expected_ttitcmdapi.parent = self
                        self._children_name_map["otn_expected_ttitcmdapi"] = "otn-expected-ttitcmdapi"
                    return self.otn_expected_ttitcmdapi

                if (child_yang_name == "otn-expected-ttitcmos"):
                    if (self.otn_expected_ttitcmos is None):
                        self.otn_expected_ttitcmos = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos()
                        self.otn_expected_ttitcmos.parent = self
                        self._children_name_map["otn_expected_ttitcmos"] = "otn-expected-ttitcmos"
                    return self.otn_expected_ttitcmos

                if (child_yang_name == "otn-send-tti"):
                    if (self.otn_send_tti is None):
                        self.otn_send_tti = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti()
                        self.otn_send_tti.parent = self
                        self._children_name_map["otn_send_tti"] = "otn-send-tti"
                    return self.otn_send_tti

                if (child_yang_name == "otn-send-ttisapi"):
                    if (self.otn_send_ttisapi is None):
                        self.otn_send_ttisapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi()
                        self.otn_send_ttisapi.parent = self
                        self._children_name_map["otn_send_ttisapi"] = "otn-send-ttisapi"
                    return self.otn_send_ttisapi

                if (child_yang_name == "otn-send-ttitcmdapi"):
                    if (self.otn_send_ttitcmdapi is None):
                        self.otn_send_ttitcmdapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi()
                        self.otn_send_ttitcmdapi.parent = self
                        self._children_name_map["otn_send_ttitcmdapi"] = "otn-send-ttitcmdapi"
                    return self.otn_send_ttitcmdapi

                if (child_yang_name == "otn-send-ttitcmos"):
                    if (self.otn_send_ttitcmos is None):
                        self.otn_send_ttitcmos = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos()
                        self.otn_send_ttitcmos.parent = self
                        self._children_name_map["otn_send_ttitcmos"] = "otn-send-ttitcmos"
                    return self.otn_send_ttitcmos

                if (child_yang_name == "proactive-protection"):
                    if (self.proactive_protection is None):
                        self.proactive_protection = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection()
                        self.proactive_protection.parent = self
                        self._children_name_map["proactive_protection"] = "proactive-protection"
                    return self.proactive_protection

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "network-srlgs" or name == "otn-expected-tti" or name == "otn-expected-ttisapi" or name == "otn-expected-ttitcmdapi" or name == "otn-expected-ttitcmos" or name == "otn-send-tti" or name == "otn-send-ttisapi" or name == "otn-send-ttitcmdapi" or name == "otn-send-ttitcmos" or name == "proactive-protection" or name == "fec" or name == "gcc" or name == "loopback" or name == "performance-monitoring" or name == "sd" or name == "secondary-admin-state" or name == "sf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "fec"):
                    self.fec = value
                    self.fec.value_namespace = name_space
                    self.fec.value_namespace_prefix = name_space_prefix
                if(value_path == "gcc"):
                    self.gcc = value
                    self.gcc.value_namespace = name_space
                    self.gcc.value_namespace_prefix = name_space_prefix
                if(value_path == "loopback"):
                    self.loopback = value
                    self.loopback.value_namespace = name_space
                    self.loopback.value_namespace_prefix = name_space_prefix
                if(value_path == "performance-monitoring"):
                    self.performance_monitoring = value
                    self.performance_monitoring.value_namespace = name_space
                    self.performance_monitoring.value_namespace_prefix = name_space_prefix
                if(value_path == "sd"):
                    self.sd = value
                    self.sd.value_namespace = name_space
                    self.sd.value_namespace_prefix = name_space_prefix
                if(value_path == "secondary-admin-state"):
                    self.secondary_admin_state = value
                    self.secondary_admin_state.value_namespace = name_space
                    self.secondary_admin_state.value_namespace_prefix = name_space_prefix
                if(value_path == "sf"):
                    self.sf = value
                    self.sf.value_namespace = name_space
                    self.sf.value_namespace_prefix = name_space_prefix


        class Macsec(Entity):
            """
            MACSec service for an interface
            
            .. attribute:: eap
            
            	Enabling MACSec eap Configuration on Interface
            	**type**\:   :py:class:`Eap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap>`
            
            .. attribute:: macsec_service
            
            	macsec\-service configuration on interface
            	**type**\:   :py:class:`MacsecService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService>`
            
            	**presence node**\: True
            
            .. attribute:: psk_key_chain
            
            	MACSec MKA Configuration on Interface
            	**type**\:   :py:class:`PskKeyChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'crypto-macsec-mka-if-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Macsec, self).__init__()

                self.yang_name = "macsec"
                self.yang_parent_name = "interface-configuration"

                self.eap = InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap()
                self.eap.parent = self
                self._children_name_map["eap"] = "eap"
                self._children_yang_names.add("eap")

                self.macsec_service = None
                self._children_name_map["macsec_service"] = "macsec-service"
                self._children_yang_names.add("macsec-service")

                self.psk_key_chain = None
                self._children_name_map["psk_key_chain"] = "psk-key-chain"
                self._children_yang_names.add("psk-key-chain")


            class MacsecService(Entity):
                """
                macsec\-service configuration on interface
                
                .. attribute:: decrypt_port
                
                	macsec service decryption port
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                	**mandatory**\: True
                
                .. attribute:: key_chain
                
                	name of keychain
                	**type**\:  str
                
                	**length:** 1..32
                
                	**mandatory**\: True
                
                .. attribute:: policy
                
                	name of policy
                	**type**\:  str
                
                	**length:** 1..16
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'crypto-macsec-mka-if-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService, self).__init__()

                    self.yang_name = "macsec-service"
                    self.yang_parent_name = "macsec"
                    self.is_presence_container = True

                    self.decrypt_port = YLeaf(YType.str, "decrypt-port")

                    self.key_chain = YLeaf(YType.str, "key-chain")

                    self.policy = YLeaf(YType.str, "policy")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("decrypt_port",
                                    "key_chain",
                                    "policy") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.decrypt_port.is_set or
                        self.key_chain.is_set or
                        self.policy.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.decrypt_port.yfilter != YFilter.not_set or
                        self.key_chain.yfilter != YFilter.not_set or
                        self.policy.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "macsec-service" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.decrypt_port.is_set or self.decrypt_port.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.decrypt_port.get_name_leafdata())
                    if (self.key_chain.is_set or self.key_chain.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_chain.get_name_leafdata())
                    if (self.policy.is_set or self.policy.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.policy.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "decrypt-port" or name == "key-chain" or name == "policy"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "decrypt-port"):
                        self.decrypt_port = value
                        self.decrypt_port.value_namespace = name_space
                        self.decrypt_port.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-chain"):
                        self.key_chain = value
                        self.key_chain.value_namespace = name_space
                        self.key_chain.value_namespace_prefix = name_space_prefix
                    if(value_path == "policy"):
                        self.policy = value
                        self.policy.value_namespace = name_space
                        self.policy.value_namespace_prefix = name_space_prefix


            class Eap(Entity):
                """
                Enabling MACSec eap Configuration on Interface
                
                .. attribute:: eap_config
                
                	Eap config
                	**type**\:  str
                
                	**pattern:** (eap)
                
                .. attribute:: policy_name
                
                	Name of Policy
                	**type**\:  str
                
                	**length:** 1..16
                
                

                """

                _prefix = 'crypto-macsec-mka-if-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap, self).__init__()

                    self.yang_name = "eap"
                    self.yang_parent_name = "macsec"

                    self.eap_config = YLeaf(YType.str, "eap-config")

                    self.policy_name = YLeaf(YType.str, "policy-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("eap_config",
                                    "policy_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.eap_config.is_set or
                        self.policy_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.eap_config.yfilter != YFilter.not_set or
                        self.policy_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "eap" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.eap_config.is_set or self.eap_config.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.eap_config.get_name_leafdata())
                    if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.policy_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "eap-config" or name == "policy-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "eap-config"):
                        self.eap_config = value
                        self.eap_config.value_namespace = name_space
                        self.eap_config.value_namespace_prefix = name_space_prefix
                    if(value_path == "policy-name"):
                        self.policy_name = value
                        self.policy_name.value_namespace = name_space
                        self.policy_name.value_namespace_prefix = name_space_prefix


            class PskKeyChain(Entity):
                """
                MACSec MKA Configuration on Interface
                
                .. attribute:: fallback_key_chain
                
                	name of fallback keychain
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: key_chain_name
                
                	Name of KeyChainName
                	**type**\:  str
                
                	**length:** 1..32
                
                	**mandatory**\: True
                
                .. attribute:: policy_name
                
                	Name of Policy
                	**type**\:  str
                
                	**length:** 1..16
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'crypto-macsec-mka-if-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain, self).__init__()

                    self.yang_name = "psk-key-chain"
                    self.yang_parent_name = "macsec"
                    self.is_presence_container = True

                    self.fallback_key_chain = YLeaf(YType.str, "fallback-key-chain")

                    self.key_chain_name = YLeaf(YType.str, "key-chain-name")

                    self.policy_name = YLeaf(YType.str, "policy-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("fallback_key_chain",
                                    "key_chain_name",
                                    "policy_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.fallback_key_chain.is_set or
                        self.key_chain_name.is_set or
                        self.policy_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.fallback_key_chain.yfilter != YFilter.not_set or
                        self.key_chain_name.yfilter != YFilter.not_set or
                        self.policy_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "psk-key-chain" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.fallback_key_chain.is_set or self.fallback_key_chain.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.fallback_key_chain.get_name_leafdata())
                    if (self.key_chain_name.is_set or self.key_chain_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_chain_name.get_name_leafdata())
                    if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.policy_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "fallback-key-chain" or name == "key-chain-name" or name == "policy-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "fallback-key-chain"):
                        self.fallback_key_chain = value
                        self.fallback_key_chain.value_namespace = name_space
                        self.fallback_key_chain.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-chain-name"):
                        self.key_chain_name = value
                        self.key_chain_name.value_namespace = name_space
                        self.key_chain_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "policy-name"):
                        self.policy_name = value
                        self.policy_name.value_namespace = name_space
                        self.policy_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.eap is not None and self.eap.has_data()) or
                    (self.macsec_service is not None) or
                    (self.psk_key_chain is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.eap is not None and self.eap.has_operation()) or
                    (self.macsec_service is not None and self.macsec_service.has_operation()) or
                    (self.psk_key_chain is not None and self.psk_key_chain.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-crypto-macsec-mka-if-cfg:macsec" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "eap"):
                    if (self.eap is None):
                        self.eap = InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap()
                        self.eap.parent = self
                        self._children_name_map["eap"] = "eap"
                    return self.eap

                if (child_yang_name == "macsec-service"):
                    if (self.macsec_service is None):
                        self.macsec_service = InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService()
                        self.macsec_service.parent = self
                        self._children_name_map["macsec_service"] = "macsec-service"
                    return self.macsec_service

                if (child_yang_name == "psk-key-chain"):
                    if (self.psk_key_chain is None):
                        self.psk_key_chain = InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain()
                        self.psk_key_chain.parent = self
                        self._children_name_map["psk_key_chain"] = "psk-key-chain"
                    return self.psk_key_chain

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "eap" or name == "macsec-service" or name == "psk-key-chain"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Ethernet(Entity):
            """
            Ether specific interface configuration
            
            .. attribute:: auto_negotiation
            
            	Link auto\-negotiation
            	**type**\:   :py:class:`EthernetAutoNegotiation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetAutoNegotiation>`
            
            .. attribute:: carrier_delay
            
            	Set the carrier transition delay on an interface in msecs
            	**type**\:   :py:class:`CarrierDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay>`
            
            .. attribute:: duplex
            
            	Configure duplex operational mode
            	**type**\:   :py:class:`EthernetDuplex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetDuplex>`
            
            .. attribute:: flow_control
            
            	Configure flow\-control mode
            	**type**\:   :py:class:`EthernetFlowCtrl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetFlowCtrl>`
            
            .. attribute:: forward_error_correction
            
            	Forward Error Correction
            	**type**\:   :py:class:`EthernetFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetFec>`
            
            .. attribute:: inter_packet_gap
            
            	Inter\-packet gap
            	**type**\:   :py:class:`EthernetIpg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetIpg>`
            
            .. attribute:: loopback
            
            	Configure loopback mode
            	**type**\:   :py:class:`EthernetLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetLoopback>`
            
            .. attribute:: optical_power_degrade
            
            	Optical power degrade handling options
            	**type**\:   :py:class:`OpticalPowerDegrade <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade>`
            
            .. attribute:: priority_flow_control
            
            	Configure priority flow\-control mode
            	**type**\:   :py:class:`EthernetPfc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetPfc>`
            
            .. attribute:: signal_degrade_bit_error_rate
            
            	Signal Degrade Bit Error Rate handling options
            	**type**\:   :py:class:`SignalDegradeBitErrorRate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate>`
            
            .. attribute:: signal_fail_bit_error_rate
            
            	Signal Fail Bit Error Rate handling options
            	**type**\:   :py:class:`SignalFailBitErrorRate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate>`
            
            .. attribute:: speed
            
            	Set the ethernet speed on an interface
            	**type**\:   :py:class:`EthernetSpeed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetSpeed>`
            
            

            """

            _prefix = 'drivers-media-eth-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ethernet, self).__init__()

                self.yang_name = "ethernet"
                self.yang_parent_name = "interface-configuration"

                self.auto_negotiation = YLeaf(YType.enumeration, "auto-negotiation")

                self.duplex = YLeaf(YType.enumeration, "duplex")

                self.flow_control = YLeaf(YType.enumeration, "flow-control")

                self.forward_error_correction = YLeaf(YType.enumeration, "forward-error-correction")

                self.inter_packet_gap = YLeaf(YType.enumeration, "inter-packet-gap")

                self.loopback = YLeaf(YType.enumeration, "loopback")

                self.priority_flow_control = YLeaf(YType.enumeration, "priority-flow-control")

                self.speed = YLeaf(YType.enumeration, "speed")

                self.carrier_delay = InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "carrier-delay"
                self._children_yang_names.add("carrier-delay")

                self.optical_power_degrade = InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade()
                self.optical_power_degrade.parent = self
                self._children_name_map["optical_power_degrade"] = "optical-power-degrade"
                self._children_yang_names.add("optical-power-degrade")

                self.signal_degrade_bit_error_rate = InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate()
                self.signal_degrade_bit_error_rate.parent = self
                self._children_name_map["signal_degrade_bit_error_rate"] = "signal-degrade-bit-error-rate"
                self._children_yang_names.add("signal-degrade-bit-error-rate")

                self.signal_fail_bit_error_rate = InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate()
                self.signal_fail_bit_error_rate.parent = self
                self._children_name_map["signal_fail_bit_error_rate"] = "signal-fail-bit-error-rate"
                self._children_yang_names.add("signal-fail-bit-error-rate")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("auto_negotiation",
                                "duplex",
                                "flow_control",
                                "forward_error_correction",
                                "inter_packet_gap",
                                "loopback",
                                "priority_flow_control",
                                "speed") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ethernet, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Ethernet, self).__setattr__(name, value)


            class SignalFailBitErrorRate(Entity):
                """
                Signal Fail Bit Error Rate handling options
                
                .. attribute:: signal_fail_report_disable
                
                	Disable generation of an alarm whenever the SF\-BER threshold is crossed for this interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: signal_fail_threshold
                
                	Set the Signal Fail bit error rate threshold on an interface to a value of 10e\-x, where x is the value passed in here
                	**type**\:  int
                
                	**range:** 4..12
                
                	**default value**\: 4
                
                .. attribute:: signal_remote_fault
                
                	Signal a remote fault to the peer device whenever the link is taken down due to crossing the SF\-BER threshold
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate, self).__init__()

                    self.yang_name = "signal-fail-bit-error-rate"
                    self.yang_parent_name = "ethernet"

                    self.signal_fail_report_disable = YLeaf(YType.empty, "signal-fail-report-disable")

                    self.signal_fail_threshold = YLeaf(YType.uint32, "signal-fail-threshold")

                    self.signal_remote_fault = YLeaf(YType.empty, "signal-remote-fault")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("signal_fail_report_disable",
                                    "signal_fail_threshold",
                                    "signal_remote_fault") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.signal_fail_report_disable.is_set or
                        self.signal_fail_threshold.is_set or
                        self.signal_remote_fault.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.signal_fail_report_disable.yfilter != YFilter.not_set or
                        self.signal_fail_threshold.yfilter != YFilter.not_set or
                        self.signal_remote_fault.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "signal-fail-bit-error-rate" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.signal_fail_report_disable.is_set or self.signal_fail_report_disable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.signal_fail_report_disable.get_name_leafdata())
                    if (self.signal_fail_threshold.is_set or self.signal_fail_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.signal_fail_threshold.get_name_leafdata())
                    if (self.signal_remote_fault.is_set or self.signal_remote_fault.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.signal_remote_fault.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "signal-fail-report-disable" or name == "signal-fail-threshold" or name == "signal-remote-fault"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "signal-fail-report-disable"):
                        self.signal_fail_report_disable = value
                        self.signal_fail_report_disable.value_namespace = name_space
                        self.signal_fail_report_disable.value_namespace_prefix = name_space_prefix
                    if(value_path == "signal-fail-threshold"):
                        self.signal_fail_threshold = value
                        self.signal_fail_threshold.value_namespace = name_space
                        self.signal_fail_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "signal-remote-fault"):
                        self.signal_remote_fault = value
                        self.signal_remote_fault.value_namespace = name_space
                        self.signal_remote_fault.value_namespace_prefix = name_space_prefix


            class OpticalPowerDegrade(Entity):
                """
                Optical power degrade handling options
                
                .. attribute:: rx_alarm_threshold
                
                	Set the value of the received optical power degrade alarm threshold on an interface
                	**type**\:  int
                
                	**range:** \-300..50
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade, self).__init__()

                    self.yang_name = "optical-power-degrade"
                    self.yang_parent_name = "ethernet"

                    self.rx_alarm_threshold = YLeaf(YType.int32, "rx-alarm-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("rx_alarm_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade, self).__setattr__(name, value)

                def has_data(self):
                    return self.rx_alarm_threshold.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.rx_alarm_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "optical-power-degrade" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.rx_alarm_threshold.is_set or self.rx_alarm_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_alarm_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rx-alarm-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "rx-alarm-threshold"):
                        self.rx_alarm_threshold = value
                        self.rx_alarm_threshold.value_namespace = name_space
                        self.rx_alarm_threshold.value_namespace_prefix = name_space_prefix


            class SignalDegradeBitErrorRate(Entity):
                """
                Signal Degrade Bit Error Rate handling options
                
                .. attribute:: signal_degrade_report
                
                	Generate an alarm whenever the SD\-BER threshold is crossed for this interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: signal_degrade_threshold
                
                	Set the Signal Degrade bit error rate threshold on an interface to a value of 10e\-x, where x is the value passed in here
                	**type**\:  int
                
                	**range:** 3..12
                
                	**default value**\: 6
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate, self).__init__()

                    self.yang_name = "signal-degrade-bit-error-rate"
                    self.yang_parent_name = "ethernet"

                    self.signal_degrade_report = YLeaf(YType.empty, "signal-degrade-report")

                    self.signal_degrade_threshold = YLeaf(YType.uint32, "signal-degrade-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("signal_degrade_report",
                                    "signal_degrade_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.signal_degrade_report.is_set or
                        self.signal_degrade_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.signal_degrade_report.yfilter != YFilter.not_set or
                        self.signal_degrade_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "signal-degrade-bit-error-rate" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.signal_degrade_report.is_set or self.signal_degrade_report.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.signal_degrade_report.get_name_leafdata())
                    if (self.signal_degrade_threshold.is_set or self.signal_degrade_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.signal_degrade_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "signal-degrade-report" or name == "signal-degrade-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "signal-degrade-report"):
                        self.signal_degrade_report = value
                        self.signal_degrade_report.value_namespace = name_space
                        self.signal_degrade_report.value_namespace_prefix = name_space_prefix
                    if(value_path == "signal-degrade-threshold"):
                        self.signal_degrade_threshold = value
                        self.signal_degrade_threshold.value_namespace = name_space
                        self.signal_degrade_threshold.value_namespace_prefix = name_space_prefix


            class CarrierDelay(Entity):
                """
                Set the carrier transition delay on an
                interface in msecs
                
                .. attribute:: carrier_delay_down
                
                	Carrier Delay (down) in msecs
                	**type**\:  int
                
                	**range:** 0..2147483647
                
                .. attribute:: carrier_delay_up
                
                	Carrier Delay (up) in msecs
                	**type**\:  int
                
                	**range:** 0..2147483647
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "ethernet"

                    self.carrier_delay_down = YLeaf(YType.uint32, "carrier-delay-down")

                    self.carrier_delay_up = YLeaf(YType.uint32, "carrier-delay-up")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("carrier_delay_down",
                                    "carrier_delay_up") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.carrier_delay_down.is_set or
                        self.carrier_delay_up.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.carrier_delay_down.yfilter != YFilter.not_set or
                        self.carrier_delay_up.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "carrier-delay" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.carrier_delay_down.is_set or self.carrier_delay_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.carrier_delay_down.get_name_leafdata())
                    if (self.carrier_delay_up.is_set or self.carrier_delay_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.carrier_delay_up.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "carrier-delay-down" or name == "carrier-delay-up"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "carrier-delay-down"):
                        self.carrier_delay_down = value
                        self.carrier_delay_down.value_namespace = name_space
                        self.carrier_delay_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "carrier-delay-up"):
                        self.carrier_delay_up = value
                        self.carrier_delay_up.value_namespace = name_space
                        self.carrier_delay_up.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.auto_negotiation.is_set or
                    self.duplex.is_set or
                    self.flow_control.is_set or
                    self.forward_error_correction.is_set or
                    self.inter_packet_gap.is_set or
                    self.loopback.is_set or
                    self.priority_flow_control.is_set or
                    self.speed.is_set or
                    (self.carrier_delay is not None and self.carrier_delay.has_data()) or
                    (self.optical_power_degrade is not None and self.optical_power_degrade.has_data()) or
                    (self.signal_degrade_bit_error_rate is not None and self.signal_degrade_bit_error_rate.has_data()) or
                    (self.signal_fail_bit_error_rate is not None and self.signal_fail_bit_error_rate.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.auto_negotiation.yfilter != YFilter.not_set or
                    self.duplex.yfilter != YFilter.not_set or
                    self.flow_control.yfilter != YFilter.not_set or
                    self.forward_error_correction.yfilter != YFilter.not_set or
                    self.inter_packet_gap.yfilter != YFilter.not_set or
                    self.loopback.yfilter != YFilter.not_set or
                    self.priority_flow_control.yfilter != YFilter.not_set or
                    self.speed.yfilter != YFilter.not_set or
                    (self.carrier_delay is not None and self.carrier_delay.has_operation()) or
                    (self.optical_power_degrade is not None and self.optical_power_degrade.has_operation()) or
                    (self.signal_degrade_bit_error_rate is not None and self.signal_degrade_bit_error_rate.has_operation()) or
                    (self.signal_fail_bit_error_rate is not None and self.signal_fail_bit_error_rate.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-drivers-media-eth-cfg:ethernet" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.auto_negotiation.is_set or self.auto_negotiation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.auto_negotiation.get_name_leafdata())
                if (self.duplex.is_set or self.duplex.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.duplex.get_name_leafdata())
                if (self.flow_control.is_set or self.flow_control.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.flow_control.get_name_leafdata())
                if (self.forward_error_correction.is_set or self.forward_error_correction.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.forward_error_correction.get_name_leafdata())
                if (self.inter_packet_gap.is_set or self.inter_packet_gap.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.inter_packet_gap.get_name_leafdata())
                if (self.loopback.is_set or self.loopback.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.loopback.get_name_leafdata())
                if (self.priority_flow_control.is_set or self.priority_flow_control.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.priority_flow_control.get_name_leafdata())
                if (self.speed.is_set or self.speed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.speed.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "carrier-delay"):
                    if (self.carrier_delay is None):
                        self.carrier_delay = InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay()
                        self.carrier_delay.parent = self
                        self._children_name_map["carrier_delay"] = "carrier-delay"
                    return self.carrier_delay

                if (child_yang_name == "optical-power-degrade"):
                    if (self.optical_power_degrade is None):
                        self.optical_power_degrade = InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade()
                        self.optical_power_degrade.parent = self
                        self._children_name_map["optical_power_degrade"] = "optical-power-degrade"
                    return self.optical_power_degrade

                if (child_yang_name == "signal-degrade-bit-error-rate"):
                    if (self.signal_degrade_bit_error_rate is None):
                        self.signal_degrade_bit_error_rate = InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate()
                        self.signal_degrade_bit_error_rate.parent = self
                        self._children_name_map["signal_degrade_bit_error_rate"] = "signal-degrade-bit-error-rate"
                    return self.signal_degrade_bit_error_rate

                if (child_yang_name == "signal-fail-bit-error-rate"):
                    if (self.signal_fail_bit_error_rate is None):
                        self.signal_fail_bit_error_rate = InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate()
                        self.signal_fail_bit_error_rate.parent = self
                        self._children_name_map["signal_fail_bit_error_rate"] = "signal-fail-bit-error-rate"
                    return self.signal_fail_bit_error_rate

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "carrier-delay" or name == "optical-power-degrade" or name == "signal-degrade-bit-error-rate" or name == "signal-fail-bit-error-rate" or name == "auto-negotiation" or name == "duplex" or name == "flow-control" or name == "forward-error-correction" or name == "inter-packet-gap" or name == "loopback" or name == "priority-flow-control" or name == "speed"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "auto-negotiation"):
                    self.auto_negotiation = value
                    self.auto_negotiation.value_namespace = name_space
                    self.auto_negotiation.value_namespace_prefix = name_space_prefix
                if(value_path == "duplex"):
                    self.duplex = value
                    self.duplex.value_namespace = name_space
                    self.duplex.value_namespace_prefix = name_space_prefix
                if(value_path == "flow-control"):
                    self.flow_control = value
                    self.flow_control.value_namespace = name_space
                    self.flow_control.value_namespace_prefix = name_space_prefix
                if(value_path == "forward-error-correction"):
                    self.forward_error_correction = value
                    self.forward_error_correction.value_namespace = name_space
                    self.forward_error_correction.value_namespace_prefix = name_space_prefix
                if(value_path == "inter-packet-gap"):
                    self.inter_packet_gap = value
                    self.inter_packet_gap.value_namespace = name_space
                    self.inter_packet_gap.value_namespace_prefix = name_space_prefix
                if(value_path == "loopback"):
                    self.loopback = value
                    self.loopback.value_namespace = name_space
                    self.loopback.value_namespace_prefix = name_space_prefix
                if(value_path == "priority-flow-control"):
                    self.priority_flow_control = value
                    self.priority_flow_control.value_namespace = name_space
                    self.priority_flow_control.value_namespace_prefix = name_space_prefix
                if(value_path == "speed"):
                    self.speed = value
                    self.speed.value_namespace = name_space
                    self.speed.value_namespace_prefix = name_space_prefix


        class Dwdm(Entity):
            """
            DWDM port controller configuration
            
            .. attribute:: enable_vtxp
            
            	Disable or Enable VTXP configuration
            	**type**\:  bool
            
            .. attribute:: g709
            
            	Configure G709 parameters
            	**type**\:   :py:class:`G709 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709>`
            
            .. attribute:: laser
            
            	Configure laser off/on
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: loopback
            
            	Configure loopback mode 
            	**type**\:   :py:class:`DwdmLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.DwdmLoopback>`
            
            	**default value**\: none
            
            .. attribute:: network_connection_id
            
            	Configure network connection id
            	**type**\:  str
            
            	**length:** 1..64
            
            .. attribute:: network_port_id
            
            	Configure network port id
            	**type**\:  str
            
            	**length:** 1..64
            
            .. attribute:: network_srlgs
            
            	Configure Network srlgs
            	**type**\:   :py:class:`NetworkSrlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs>`
            
            .. attribute:: rx_threshold
            
            	Select power level (in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** \-350..50
            
            .. attribute:: transmit_power
            
            	Select power level (in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** \-190..10
            
            .. attribute:: transport_admin_state
            
            	Configure transport admin state
            	**type**\:   :py:class:`DwdmAdminState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.DwdmAdminState>`
            
            	**default value**\: out-of-service
            
            .. attribute:: wavelength
            
            	Configure transponder wavelength
            	**type**\:   :py:class:`Wavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'dwdm-ui-cfg'
            _revision = '2015-12-16'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm, self).__init__()

                self.yang_name = "dwdm"
                self.yang_parent_name = "interface-configuration"

                self.enable_vtxp = YLeaf(YType.boolean, "enable-vtxp")

                self.laser = YLeaf(YType.empty, "laser")

                self.loopback = YLeaf(YType.enumeration, "loopback")

                self.network_connection_id = YLeaf(YType.str, "network-connection-id")

                self.network_port_id = YLeaf(YType.str, "network-port-id")

                self.rx_threshold = YLeaf(YType.int32, "rx-threshold")

                self.transmit_power = YLeaf(YType.int32, "transmit-power")

                self.transport_admin_state = YLeaf(YType.enumeration, "transport-admin-state")

                self.g709 = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709()
                self.g709.parent = self
                self._children_name_map["g709"] = "g709"
                self._children_yang_names.add("g709")

                self.network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs()
                self.network_srlgs.parent = self
                self._children_name_map["network_srlgs"] = "network-srlgs"
                self._children_yang_names.add("network-srlgs")

                self.wavelength = None
                self._children_name_map["wavelength"] = "wavelength"
                self._children_yang_names.add("wavelength")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("enable_vtxp",
                                "laser",
                                "loopback",
                                "network_connection_id",
                                "network_port_id",
                                "rx_threshold",
                                "transmit_power",
                                "transport_admin_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm, self).__setattr__(name, value)


            class NetworkSrlgs(Entity):
                """
                Configure Network srlgs
                
                .. attribute:: network_srlg
                
                	Configure network srlg sets
                	**type**\: list of    :py:class:`NetworkSrlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg>`
                
                

                """

                _prefix = 'dwdm-ui-cfg'
                _revision = '2015-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs, self).__init__()

                    self.yang_name = "network-srlgs"
                    self.yang_parent_name = "dwdm"

                    self.network_srlg = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs, self).__setattr__(name, value)


                class NetworkSrlg(Entity):
                    """
                    Configure network srlg sets
                    
                    .. attribute:: set_id  <key>
                    
                    	Set index
                    	**type**\:  int
                    
                    	**range:** 1..17
                    
                    .. attribute:: srlg1
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg2
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg3
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg4
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg5
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg6
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2015-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg, self).__init__()

                        self.yang_name = "network-srlg"
                        self.yang_parent_name = "network-srlgs"

                        self.set_id = YLeaf(YType.uint32, "set-id")

                        self.srlg1 = YLeaf(YType.uint32, "srlg1")

                        self.srlg2 = YLeaf(YType.uint32, "srlg2")

                        self.srlg3 = YLeaf(YType.uint32, "srlg3")

                        self.srlg4 = YLeaf(YType.uint32, "srlg4")

                        self.srlg5 = YLeaf(YType.uint32, "srlg5")

                        self.srlg6 = YLeaf(YType.uint32, "srlg6")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("set_id",
                                        "srlg1",
                                        "srlg2",
                                        "srlg3",
                                        "srlg4",
                                        "srlg5",
                                        "srlg6") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.set_id.is_set or
                            self.srlg1.is_set or
                            self.srlg2.is_set or
                            self.srlg3.is_set or
                            self.srlg4.is_set or
                            self.srlg5.is_set or
                            self.srlg6.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.set_id.yfilter != YFilter.not_set or
                            self.srlg1.yfilter != YFilter.not_set or
                            self.srlg2.yfilter != YFilter.not_set or
                            self.srlg3.yfilter != YFilter.not_set or
                            self.srlg4.yfilter != YFilter.not_set or
                            self.srlg5.yfilter != YFilter.not_set or
                            self.srlg6.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "network-srlg" + "[set-id='" + self.set_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.set_id.is_set or self.set_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.set_id.get_name_leafdata())
                        if (self.srlg1.is_set or self.srlg1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg1.get_name_leafdata())
                        if (self.srlg2.is_set or self.srlg2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg2.get_name_leafdata())
                        if (self.srlg3.is_set or self.srlg3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg3.get_name_leafdata())
                        if (self.srlg4.is_set or self.srlg4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg4.get_name_leafdata())
                        if (self.srlg5.is_set or self.srlg5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg5.get_name_leafdata())
                        if (self.srlg6.is_set or self.srlg6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srlg6.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "set-id" or name == "srlg1" or name == "srlg2" or name == "srlg3" or name == "srlg4" or name == "srlg5" or name == "srlg6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "set-id"):
                            self.set_id = value
                            self.set_id.value_namespace = name_space
                            self.set_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg1"):
                            self.srlg1 = value
                            self.srlg1.value_namespace = name_space
                            self.srlg1.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg2"):
                            self.srlg2 = value
                            self.srlg2.value_namespace = name_space
                            self.srlg2.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg3"):
                            self.srlg3 = value
                            self.srlg3.value_namespace = name_space
                            self.srlg3.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg4"):
                            self.srlg4 = value
                            self.srlg4.value_namespace = name_space
                            self.srlg4.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg5"):
                            self.srlg5 = value
                            self.srlg5.value_namespace = name_space
                            self.srlg5.value_namespace_prefix = name_space_prefix
                        if(value_path == "srlg6"):
                            self.srlg6 = value
                            self.srlg6.value_namespace = name_space
                            self.srlg6.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.network_srlg:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.network_srlg:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "network-srlgs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "network-srlg"):
                        for c in self.network_srlg:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.network_srlg.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "network-srlg"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class G709(Entity):
                """
                Configure G709 parameters
                
                .. attribute:: bdi_to_gais
                
                	Enable GAIS insertion
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enable
                
                	Disable or Enable g709 framing
                	**type**\:  bool
                
                .. attribute:: fec
                
                	Configure FEC mode
                	**type**\:   :py:class:`Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec>`
                
                	**presence node**\: True
                
                .. attribute:: framing
                
                	Over clocking mode for client signal bw compatibility
                	**type**\:   :py:class:`Framing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Framing>`
                
                .. attribute:: odu
                
                	Configure ODU parameters
                	**type**\:   :py:class:`Odu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu>`
                
                .. attribute:: otu
                
                	Configure OTU parameters
                	**type**\:   :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu>`
                
                .. attribute:: prbs
                
                	Configure PRBS mode and pattern
                	**type**\:   :py:class:`Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs>`
                
                	**presence node**\: True
                
                .. attribute:: proactive
                
                	Enable proactive protectioni Graceful or Default mode
                	**type**\:   :py:class:`Proactive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Proactive>`
                
                .. attribute:: proactive_logging_file
                
                	Configure proactive protection log file
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: tim_to_gais
                
                	Configure Trace Identifier Mismatch alarm consequence
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: tti_processing
                
                	Configure Trail Trace Identifier  processing
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'dwdm-ui-cfg'
                _revision = '2015-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709, self).__init__()

                    self.yang_name = "g709"
                    self.yang_parent_name = "dwdm"

                    self.bdi_to_gais = YLeaf(YType.empty, "bdi-to-gais")

                    self.enable = YLeaf(YType.boolean, "enable")

                    self.framing = YLeaf(YType.enumeration, "framing")

                    self.proactive = YLeaf(YType.enumeration, "proactive")

                    self.proactive_logging_file = YLeaf(YType.str, "proactive-logging-file")

                    self.tim_to_gais = YLeaf(YType.empty, "tim-to-gais")

                    self.tti_processing = YLeaf(YType.empty, "tti-processing")

                    self.fec = None
                    self._children_name_map["fec"] = "fec"
                    self._children_yang_names.add("fec")

                    self.odu = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu()
                    self.odu.parent = self
                    self._children_name_map["odu"] = "odu"
                    self._children_yang_names.add("odu")

                    self.otu = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu()
                    self.otu.parent = self
                    self._children_name_map["otu"] = "otu"
                    self._children_yang_names.add("otu")

                    self.prbs = None
                    self._children_name_map["prbs"] = "prbs"
                    self._children_yang_names.add("prbs")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bdi_to_gais",
                                    "enable",
                                    "framing",
                                    "proactive",
                                    "proactive_logging_file",
                                    "tim_to_gais",
                                    "tti_processing") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709, self).__setattr__(name, value)


                class Odu(Entity):
                    """
                    Configure ODU parameters
                    
                    .. attribute:: odu_expected_tti
                    
                    	Configure ODU Expected TTI value
                    	**type**\:   :py:class:`OduExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti>`
                    
                    .. attribute:: odu_reports
                    
                    	Configure ODU alarm reporting
                    	**type**\:   :py:class:`OduReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports>`
                    
                    .. attribute:: odu_thresholds
                    
                    	Configure ODU threshold value
                    	**type**\:   :py:class:`OduThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds>`
                    
                    .. attribute:: odu_tx_tti
                    
                    	Configure ODU TTI value
                    	**type**\:   :py:class:`OduTxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti>`
                    
                    

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2015-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu, self).__init__()

                        self.yang_name = "odu"
                        self.yang_parent_name = "g709"

                        self.odu_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti()
                        self.odu_expected_tti.parent = self
                        self._children_name_map["odu_expected_tti"] = "odu-expected-tti"
                        self._children_yang_names.add("odu-expected-tti")

                        self.odu_reports = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports()
                        self.odu_reports.parent = self
                        self._children_name_map["odu_reports"] = "odu-reports"
                        self._children_yang_names.add("odu-reports")

                        self.odu_thresholds = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds()
                        self.odu_thresholds.parent = self
                        self._children_name_map["odu_thresholds"] = "odu-thresholds"
                        self._children_yang_names.add("odu-thresholds")

                        self.odu_tx_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti()
                        self.odu_tx_tti.parent = self
                        self._children_name_map["odu_tx_tti"] = "odu-tx-tti"
                        self._children_yang_names.add("odu-tx-tti")


                    class OduReports(Entity):
                        """
                        Configure ODU alarm reporting
                        
                        .. attribute:: odu_report
                        
                        	none
                        	**type**\: list of    :py:class:`OduReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports, self).__init__()

                            self.yang_name = "odu-reports"
                            self.yang_parent_name = "odu"

                            self.odu_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports, self).__setattr__(name, value)


                        class OduReport(Entity):
                            """
                            none
                            
                            .. attribute:: alarm  <key>
                            
                            	ODU alarm type
                            	**type**\:   :py:class:`OduAlarm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OduAlarm>`
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport, self).__init__()

                                self.yang_name = "odu-report"
                                self.yang_parent_name = "odu-reports"

                                self.alarm = YLeaf(YType.enumeration, "alarm")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("alarm") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.alarm.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.alarm.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-report" + "[alarm='" + self.alarm.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.alarm.is_set or self.alarm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.alarm.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "alarm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "alarm"):
                                    self.alarm = value
                                    self.alarm.value_namespace = name_space
                                    self.alarm.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.odu_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.odu_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "odu-report"):
                                for c in self.odu_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.odu_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "odu-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OduThresholds(Entity):
                        """
                        Configure ODU threshold value
                        
                        .. attribute:: odu_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OduThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds, self).__init__()

                            self.yang_name = "odu-thresholds"
                            self.yang_parent_name = "odu"

                            self.odu_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds, self).__setattr__(name, value)


                        class OduThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: threshold  <key>
                            
                            	ODU Threshold type
                            	**type**\:   :py:class:`OduThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OduThreshold>`
                            
                            .. attribute:: threshold_value
                            
                            	Bit error rate (10 to the minus n)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold, self).__init__()

                                self.yang_name = "odu-threshold"
                                self.yang_parent_name = "odu-thresholds"

                                self.threshold = YLeaf(YType.enumeration, "threshold")

                                self.threshold_value = YLeaf(YType.uint32, "threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("threshold",
                                                "threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.threshold.is_set or
                                    self.threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.threshold.yfilter != YFilter.not_set or
                                    self.threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-threshold" + "[threshold='" + self.threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold.get_name_leafdata())
                                if (self.threshold_value.is_set or self.threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "threshold" or name == "threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "threshold"):
                                    self.threshold = value
                                    self.threshold.value_namespace = name_space
                                    self.threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-value"):
                                    self.threshold_value = value
                                    self.threshold_value.value_namespace = name_space
                                    self.threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.odu_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.odu_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "odu-threshold"):
                                for c in self.odu_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.odu_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "odu-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OduExpectedTti(Entity):
                        """
                        Configure ODU Expected TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`ExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.ExpectedTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti, self).__init__()

                            self.yang_name = "odu-expected-tti"
                            self.yang_parent_name = "odu"

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ascii_string",
                                            "hex_string",
                                            "string_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ascii_string.is_set or
                                self.hex_string.is_set or
                                self.string_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ascii_string.yfilter != YFilter.not_set or
                                self.hex_string.yfilter != YFilter.not_set or
                                self.string_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-expected-tti" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ascii_string.is_set or self.ascii_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ascii_string.get_name_leafdata())
                            if (self.hex_string.is_set or self.hex_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hex_string.get_name_leafdata())
                            if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.string_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ascii-string" or name == "hex-string" or name == "string-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ascii-string"):
                                self.ascii_string = value
                                self.ascii_string.value_namespace = name_space
                                self.ascii_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "hex-string"):
                                self.hex_string = value
                                self.hex_string.value_namespace = name_space
                                self.hex_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "string-type"):
                                self.string_type = value
                                self.string_type.value_namespace = name_space
                                self.string_type.value_namespace_prefix = name_space_prefix


                    class OduTxTti(Entity):
                        """
                        Configure ODU TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`TxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.TxTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti, self).__init__()

                            self.yang_name = "odu-tx-tti"
                            self.yang_parent_name = "odu"

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ascii_string",
                                            "hex_string",
                                            "string_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ascii_string.is_set or
                                self.hex_string.is_set or
                                self.string_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ascii_string.yfilter != YFilter.not_set or
                                self.hex_string.yfilter != YFilter.not_set or
                                self.string_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-tx-tti" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ascii_string.is_set or self.ascii_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ascii_string.get_name_leafdata())
                            if (self.hex_string.is_set or self.hex_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hex_string.get_name_leafdata())
                            if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.string_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ascii-string" or name == "hex-string" or name == "string-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ascii-string"):
                                self.ascii_string = value
                                self.ascii_string.value_namespace = name_space
                                self.ascii_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "hex-string"):
                                self.hex_string = value
                                self.hex_string.value_namespace = name_space
                                self.hex_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "string-type"):
                                self.string_type = value
                                self.string_type.value_namespace = name_space
                                self.string_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.odu_expected_tti is not None and self.odu_expected_tti.has_data()) or
                            (self.odu_reports is not None and self.odu_reports.has_data()) or
                            (self.odu_thresholds is not None and self.odu_thresholds.has_data()) or
                            (self.odu_tx_tti is not None and self.odu_tx_tti.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.odu_expected_tti is not None and self.odu_expected_tti.has_operation()) or
                            (self.odu_reports is not None and self.odu_reports.has_operation()) or
                            (self.odu_thresholds is not None and self.odu_thresholds.has_operation()) or
                            (self.odu_tx_tti is not None and self.odu_tx_tti.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "odu" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "odu-expected-tti"):
                            if (self.odu_expected_tti is None):
                                self.odu_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti()
                                self.odu_expected_tti.parent = self
                                self._children_name_map["odu_expected_tti"] = "odu-expected-tti"
                            return self.odu_expected_tti

                        if (child_yang_name == "odu-reports"):
                            if (self.odu_reports is None):
                                self.odu_reports = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports()
                                self.odu_reports.parent = self
                                self._children_name_map["odu_reports"] = "odu-reports"
                            return self.odu_reports

                        if (child_yang_name == "odu-thresholds"):
                            if (self.odu_thresholds is None):
                                self.odu_thresholds = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds()
                                self.odu_thresholds.parent = self
                                self._children_name_map["odu_thresholds"] = "odu-thresholds"
                            return self.odu_thresholds

                        if (child_yang_name == "odu-tx-tti"):
                            if (self.odu_tx_tti is None):
                                self.odu_tx_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti()
                                self.odu_tx_tti.parent = self
                                self._children_name_map["odu_tx_tti"] = "odu-tx-tti"
                            return self.odu_tx_tti

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "odu-expected-tti" or name == "odu-reports" or name == "odu-thresholds" or name == "odu-tx-tti"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Otu(Entity):
                    """
                    Configure OTU parameters
                    
                    .. attribute:: frr
                    
                    	Configure FRR thresholds and Window for trigger and revert
                    	**type**\:   :py:class:`Frr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr>`
                    
                    .. attribute:: otu_expected_tti
                    
                    	Configure OTU Expected TTI value
                    	**type**\:   :py:class:`OtuExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti>`
                    
                    .. attribute:: otu_reports
                    
                    	Configure OTU alarm reporting
                    	**type**\:   :py:class:`OtuReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports>`
                    
                    .. attribute:: otu_thresholds
                    
                    	Configure OTU threshold value
                    	**type**\:   :py:class:`OtuThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds>`
                    
                    .. attribute:: otu_tx_tti
                    
                    	Configure OTU TTI value
                    	**type**\:   :py:class:`OtuTxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti>`
                    
                    

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2015-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu, self).__init__()

                        self.yang_name = "otu"
                        self.yang_parent_name = "g709"

                        self.frr = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr()
                        self.frr.parent = self
                        self._children_name_map["frr"] = "frr"
                        self._children_yang_names.add("frr")

                        self.otu_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti()
                        self.otu_expected_tti.parent = self
                        self._children_name_map["otu_expected_tti"] = "otu-expected-tti"
                        self._children_yang_names.add("otu-expected-tti")

                        self.otu_reports = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports()
                        self.otu_reports.parent = self
                        self._children_name_map["otu_reports"] = "otu-reports"
                        self._children_yang_names.add("otu-reports")

                        self.otu_thresholds = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds()
                        self.otu_thresholds.parent = self
                        self._children_name_map["otu_thresholds"] = "otu-thresholds"
                        self._children_yang_names.add("otu-thresholds")

                        self.otu_tx_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti()
                        self.otu_tx_tti.parent = self
                        self._children_name_map["otu_tx_tti"] = "otu-tx-tti"
                        self._children_yang_names.add("otu-tx-tti")


                    class OtuExpectedTti(Entity):
                        """
                        Configure OTU Expected TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`ExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.ExpectedTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti, self).__init__()

                            self.yang_name = "otu-expected-tti"
                            self.yang_parent_name = "otu"

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ascii_string",
                                            "hex_string",
                                            "string_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ascii_string.is_set or
                                self.hex_string.is_set or
                                self.string_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ascii_string.yfilter != YFilter.not_set or
                                self.hex_string.yfilter != YFilter.not_set or
                                self.string_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-expected-tti" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ascii_string.is_set or self.ascii_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ascii_string.get_name_leafdata())
                            if (self.hex_string.is_set or self.hex_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hex_string.get_name_leafdata())
                            if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.string_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ascii-string" or name == "hex-string" or name == "string-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ascii-string"):
                                self.ascii_string = value
                                self.ascii_string.value_namespace = name_space
                                self.ascii_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "hex-string"):
                                self.hex_string = value
                                self.hex_string.value_namespace = name_space
                                self.hex_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "string-type"):
                                self.string_type = value
                                self.string_type.value_namespace = name_space
                                self.string_type.value_namespace_prefix = name_space_prefix


                    class OtuThresholds(Entity):
                        """
                        Configure OTU threshold value
                        
                        .. attribute:: otu_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OtuThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds, self).__init__()

                            self.yang_name = "otu-thresholds"
                            self.yang_parent_name = "otu"

                            self.otu_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds, self).__setattr__(name, value)


                        class OtuThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: threshold  <key>
                            
                            	OTU Threshold type
                            	**type**\:   :py:class:`OtuThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OtuThreshold>`
                            
                            .. attribute:: threshold_value
                            
                            	Bit error rate (10 to the minus n)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold, self).__init__()

                                self.yang_name = "otu-threshold"
                                self.yang_parent_name = "otu-thresholds"

                                self.threshold = YLeaf(YType.enumeration, "threshold")

                                self.threshold_value = YLeaf(YType.uint32, "threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("threshold",
                                                "threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.threshold.is_set or
                                    self.threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.threshold.yfilter != YFilter.not_set or
                                    self.threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-threshold" + "[threshold='" + self.threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold.get_name_leafdata())
                                if (self.threshold_value.is_set or self.threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "threshold" or name == "threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "threshold"):
                                    self.threshold = value
                                    self.threshold.value_namespace = name_space
                                    self.threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-value"):
                                    self.threshold_value = value
                                    self.threshold_value.value_namespace = name_space
                                    self.threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.otu_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.otu_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "otu-threshold"):
                                for c in self.otu_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.otu_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "otu-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Frr(Entity):
                        """
                        Configure FRR thresholds and Window for
                        trigger and revert
                        
                        .. attribute:: revert_threshold
                        
                        	Configure proactive protection revert threshold
                        	**type**\:   :py:class:`RevertThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: revert_window
                        
                        	Configure FRR revert window
                        	**type**\:   :py:class:`RevertWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: trigger_threshold
                        
                        	Configure proactive protection trigger threshold
                        	**type**\:   :py:class:`TriggerThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: trigger_window
                        
                        	Configure FRR trigger window
                        	**type**\:   :py:class:`TriggerWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr, self).__init__()

                            self.yang_name = "frr"
                            self.yang_parent_name = "otu"

                            self.revert_threshold = None
                            self._children_name_map["revert_threshold"] = "revert-threshold"
                            self._children_yang_names.add("revert-threshold")

                            self.revert_window = None
                            self._children_name_map["revert_window"] = "revert-window"
                            self._children_yang_names.add("revert-window")

                            self.trigger_threshold = None
                            self._children_name_map["trigger_threshold"] = "trigger-threshold"
                            self._children_yang_names.add("trigger-threshold")

                            self.trigger_window = None
                            self._children_name_map["trigger_window"] = "trigger-window"
                            self._children_yang_names.add("trigger-window")


                        class TriggerWindow(Entity):
                            """
                            Configure FRR trigger window
                            
                            .. attribute:: dummy
                            
                            	Just a Dummy for window for FRR revert in MS
                            	**type**\:  int
                            
                            	**range:** 0..2
                            
                            .. attribute:: window
                            
                            	Integration window for FRR trigger in MS
                            	**type**\:  int
                            
                            	**range:** 10..10000
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow, self).__init__()

                                self.yang_name = "trigger-window"
                                self.yang_parent_name = "frr"
                                self.is_presence_container = True

                                self.dummy = YLeaf(YType.uint32, "dummy")

                                self.window = YLeaf(YType.uint32, "window")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dummy",
                                                "window") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dummy.is_set or
                                    self.window.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dummy.yfilter != YFilter.not_set or
                                    self.window.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "trigger-window" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dummy.is_set or self.dummy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dummy.get_name_leafdata())
                                if (self.window.is_set or self.window.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.window.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dummy" or name == "window"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dummy"):
                                    self.dummy = value
                                    self.dummy.value_namespace = name_space
                                    self.dummy.value_namespace_prefix = name_space_prefix
                                if(value_path == "window"):
                                    self.window = value
                                    self.window.value_namespace = name_space
                                    self.window.value_namespace_prefix = name_space_prefix


                        class RevertThreshold(Entity):
                            """
                            Configure proactive protection revert
                            threshold
                            
                            .. attribute:: ber_base
                            
                            	Bit error rate base (x of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            .. attribute:: ber_power
                            
                            	Bit error rate power (y of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 3..10
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold, self).__init__()

                                self.yang_name = "revert-threshold"
                                self.yang_parent_name = "frr"
                                self.is_presence_container = True

                                self.ber_base = YLeaf(YType.uint32, "ber-base")

                                self.ber_power = YLeaf(YType.uint32, "ber-power")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ber_base",
                                                "ber_power") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ber_base.is_set or
                                    self.ber_power.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ber_base.yfilter != YFilter.not_set or
                                    self.ber_power.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "revert-threshold" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ber_base.is_set or self.ber_base.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ber_base.get_name_leafdata())
                                if (self.ber_power.is_set or self.ber_power.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ber_power.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ber-base" or name == "ber-power"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ber-base"):
                                    self.ber_base = value
                                    self.ber_base.value_namespace = name_space
                                    self.ber_base.value_namespace_prefix = name_space_prefix
                                if(value_path == "ber-power"):
                                    self.ber_power = value
                                    self.ber_power.value_namespace = name_space
                                    self.ber_power.value_namespace_prefix = name_space_prefix


                        class TriggerThreshold(Entity):
                            """
                            Configure proactive protection trigger
                            threshold
                            
                            .. attribute:: ber_base
                            
                            	Bit error rate base (x of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            .. attribute:: ber_power
                            
                            	Bit error rate power (y of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 2..9
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold, self).__init__()

                                self.yang_name = "trigger-threshold"
                                self.yang_parent_name = "frr"
                                self.is_presence_container = True

                                self.ber_base = YLeaf(YType.uint32, "ber-base")

                                self.ber_power = YLeaf(YType.uint32, "ber-power")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ber_base",
                                                "ber_power") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ber_base.is_set or
                                    self.ber_power.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ber_base.yfilter != YFilter.not_set or
                                    self.ber_power.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "trigger-threshold" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ber_base.is_set or self.ber_base.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ber_base.get_name_leafdata())
                                if (self.ber_power.is_set or self.ber_power.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ber_power.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ber-base" or name == "ber-power"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ber-base"):
                                    self.ber_base = value
                                    self.ber_base.value_namespace = name_space
                                    self.ber_base.value_namespace_prefix = name_space_prefix
                                if(value_path == "ber-power"):
                                    self.ber_power = value
                                    self.ber_power.value_namespace = name_space
                                    self.ber_power.value_namespace_prefix = name_space_prefix


                        class RevertWindow(Entity):
                            """
                            Configure FRR revert window
                            
                            .. attribute:: dummy
                            
                            	Just a Dummy for window for FRR revert in MS
                            	**type**\:  int
                            
                            	**range:** 0..2
                            
                            .. attribute:: window
                            
                            	Integration window for FRR revert in MS
                            	**type**\:  int
                            
                            	**range:** 500..100000
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow, self).__init__()

                                self.yang_name = "revert-window"
                                self.yang_parent_name = "frr"
                                self.is_presence_container = True

                                self.dummy = YLeaf(YType.uint32, "dummy")

                                self.window = YLeaf(YType.uint32, "window")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dummy",
                                                "window") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dummy.is_set or
                                    self.window.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dummy.yfilter != YFilter.not_set or
                                    self.window.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "revert-window" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dummy.is_set or self.dummy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dummy.get_name_leafdata())
                                if (self.window.is_set or self.window.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.window.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dummy" or name == "window"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dummy"):
                                    self.dummy = value
                                    self.dummy.value_namespace = name_space
                                    self.dummy.value_namespace_prefix = name_space_prefix
                                if(value_path == "window"):
                                    self.window = value
                                    self.window.value_namespace = name_space
                                    self.window.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.revert_threshold is not None) or
                                (self.revert_window is not None) or
                                (self.trigger_threshold is not None) or
                                (self.trigger_window is not None))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.revert_threshold is not None and self.revert_threshold.has_operation()) or
                                (self.revert_window is not None and self.revert_window.has_operation()) or
                                (self.trigger_threshold is not None and self.trigger_threshold.has_operation()) or
                                (self.trigger_window is not None and self.trigger_window.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "frr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "revert-threshold"):
                                if (self.revert_threshold is None):
                                    self.revert_threshold = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold()
                                    self.revert_threshold.parent = self
                                    self._children_name_map["revert_threshold"] = "revert-threshold"
                                return self.revert_threshold

                            if (child_yang_name == "revert-window"):
                                if (self.revert_window is None):
                                    self.revert_window = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow()
                                    self.revert_window.parent = self
                                    self._children_name_map["revert_window"] = "revert-window"
                                return self.revert_window

                            if (child_yang_name == "trigger-threshold"):
                                if (self.trigger_threshold is None):
                                    self.trigger_threshold = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold()
                                    self.trigger_threshold.parent = self
                                    self._children_name_map["trigger_threshold"] = "trigger-threshold"
                                return self.trigger_threshold

                            if (child_yang_name == "trigger-window"):
                                if (self.trigger_window is None):
                                    self.trigger_window = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow()
                                    self.trigger_window.parent = self
                                    self._children_name_map["trigger_window"] = "trigger-window"
                                return self.trigger_window

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "revert-threshold" or name == "revert-window" or name == "trigger-threshold" or name == "trigger-window"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OtuReports(Entity):
                        """
                        Configure OTU alarm reporting
                        
                        .. attribute:: otu_report
                        
                        	none
                        	**type**\: list of    :py:class:`OtuReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports, self).__init__()

                            self.yang_name = "otu-reports"
                            self.yang_parent_name = "otu"

                            self.otu_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports, self).__setattr__(name, value)


                        class OtuReport(Entity):
                            """
                            none
                            
                            .. attribute:: alarm  <key>
                            
                            	OTU alarm type
                            	**type**\:   :py:class:`OtuAlarm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OtuAlarm>`
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2015-12-16'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport, self).__init__()

                                self.yang_name = "otu-report"
                                self.yang_parent_name = "otu-reports"

                                self.alarm = YLeaf(YType.enumeration, "alarm")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("alarm") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.alarm.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.alarm.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-report" + "[alarm='" + self.alarm.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.alarm.is_set or self.alarm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.alarm.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "alarm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "alarm"):
                                    self.alarm = value
                                    self.alarm.value_namespace = name_space
                                    self.alarm.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.otu_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.otu_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "otu-report"):
                                for c in self.otu_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.otu_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "otu-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OtuTxTti(Entity):
                        """
                        Configure OTU TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`TxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.TxTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2015-12-16'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti, self).__init__()

                            self.yang_name = "otu-tx-tti"
                            self.yang_parent_name = "otu"

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ascii_string",
                                            "hex_string",
                                            "string_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ascii_string.is_set or
                                self.hex_string.is_set or
                                self.string_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ascii_string.yfilter != YFilter.not_set or
                                self.hex_string.yfilter != YFilter.not_set or
                                self.string_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-tx-tti" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ascii_string.is_set or self.ascii_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ascii_string.get_name_leafdata())
                            if (self.hex_string.is_set or self.hex_string.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hex_string.get_name_leafdata())
                            if (self.string_type.is_set or self.string_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.string_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ascii-string" or name == "hex-string" or name == "string-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ascii-string"):
                                self.ascii_string = value
                                self.ascii_string.value_namespace = name_space
                                self.ascii_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "hex-string"):
                                self.hex_string = value
                                self.hex_string.value_namespace = name_space
                                self.hex_string.value_namespace_prefix = name_space_prefix
                            if(value_path == "string-type"):
                                self.string_type = value
                                self.string_type.value_namespace = name_space
                                self.string_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.frr is not None and self.frr.has_data()) or
                            (self.otu_expected_tti is not None and self.otu_expected_tti.has_data()) or
                            (self.otu_reports is not None and self.otu_reports.has_data()) or
                            (self.otu_thresholds is not None and self.otu_thresholds.has_data()) or
                            (self.otu_tx_tti is not None and self.otu_tx_tti.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.frr is not None and self.frr.has_operation()) or
                            (self.otu_expected_tti is not None and self.otu_expected_tti.has_operation()) or
                            (self.otu_reports is not None and self.otu_reports.has_operation()) or
                            (self.otu_thresholds is not None and self.otu_thresholds.has_operation()) or
                            (self.otu_tx_tti is not None and self.otu_tx_tti.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "otu" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "frr"):
                            if (self.frr is None):
                                self.frr = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr()
                                self.frr.parent = self
                                self._children_name_map["frr"] = "frr"
                            return self.frr

                        if (child_yang_name == "otu-expected-tti"):
                            if (self.otu_expected_tti is None):
                                self.otu_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti()
                                self.otu_expected_tti.parent = self
                                self._children_name_map["otu_expected_tti"] = "otu-expected-tti"
                            return self.otu_expected_tti

                        if (child_yang_name == "otu-reports"):
                            if (self.otu_reports is None):
                                self.otu_reports = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports()
                                self.otu_reports.parent = self
                                self._children_name_map["otu_reports"] = "otu-reports"
                            return self.otu_reports

                        if (child_yang_name == "otu-thresholds"):
                            if (self.otu_thresholds is None):
                                self.otu_thresholds = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds()
                                self.otu_thresholds.parent = self
                                self._children_name_map["otu_thresholds"] = "otu-thresholds"
                            return self.otu_thresholds

                        if (child_yang_name == "otu-tx-tti"):
                            if (self.otu_tx_tti is None):
                                self.otu_tx_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti()
                                self.otu_tx_tti.parent = self
                                self._children_name_map["otu_tx_tti"] = "otu-tx-tti"
                            return self.otu_tx_tti

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "frr" or name == "otu-expected-tti" or name == "otu-reports" or name == "otu-thresholds" or name == "otu-tx-tti"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Prbs(Entity):
                    """
                    Configure PRBS mode and pattern
                    
                    .. attribute:: prbs_mode
                    
                    	Enable PRBS with mode
                    	**type**\:   :py:class:`PrbsMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.PrbsMode>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: prbs_pattern
                    
                    	Enable prbs test with pattern
                    	**type**\:   :py:class:`PrbsPattern <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.PrbsPattern>`
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2015-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs, self).__init__()

                        self.yang_name = "prbs"
                        self.yang_parent_name = "g709"
                        self.is_presence_container = True

                        self.prbs_mode = YLeaf(YType.enumeration, "prbs-mode")

                        self.prbs_pattern = YLeaf(YType.enumeration, "prbs-pattern")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("prbs_mode",
                                        "prbs_pattern") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.prbs_mode.is_set or
                            self.prbs_pattern.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.prbs_mode.yfilter != YFilter.not_set or
                            self.prbs_pattern.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "prbs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.prbs_mode.is_set or self.prbs_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prbs_mode.get_name_leafdata())
                        if (self.prbs_pattern.is_set or self.prbs_pattern.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prbs_pattern.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "prbs-mode" or name == "prbs-pattern"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "prbs-mode"):
                            self.prbs_mode = value
                            self.prbs_mode.value_namespace = name_space
                            self.prbs_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "prbs-pattern"):
                            self.prbs_pattern = value
                            self.prbs_pattern.value_namespace = name_space
                            self.prbs_pattern.value_namespace_prefix = name_space_prefix


                class Fec(Entity):
                    """
                    Configure FEC mode
                    
                    .. attribute:: efec_mode
                    
                    	Enhanced FECMode to use i.4, i.7, Other FECMode to use None
                    	**type**\:   :py:class:`Efec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Efec>`
                    
                    	**default value**\: none
                    
                    .. attribute:: fec_mode
                    
                    	None, Standard, Enhanced, High\-Gain, Long\-Haul, Ci\-BCH
                    	**type**\:   :py:class:`Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Fec>`
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2015-12-16'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec, self).__init__()

                        self.yang_name = "fec"
                        self.yang_parent_name = "g709"
                        self.is_presence_container = True

                        self.efec_mode = YLeaf(YType.enumeration, "efec-mode")

                        self.fec_mode = YLeaf(YType.enumeration, "fec-mode")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("efec_mode",
                                        "fec_mode") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.efec_mode.is_set or
                            self.fec_mode.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.efec_mode.yfilter != YFilter.not_set or
                            self.fec_mode.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "fec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.efec_mode.is_set or self.efec_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.efec_mode.get_name_leafdata())
                        if (self.fec_mode.is_set or self.fec_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fec_mode.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "efec-mode" or name == "fec-mode"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "efec-mode"):
                            self.efec_mode = value
                            self.efec_mode.value_namespace = name_space
                            self.efec_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "fec-mode"):
                            self.fec_mode = value
                            self.fec_mode.value_namespace = name_space
                            self.fec_mode.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bdi_to_gais.is_set or
                        self.enable.is_set or
                        self.framing.is_set or
                        self.proactive.is_set or
                        self.proactive_logging_file.is_set or
                        self.tim_to_gais.is_set or
                        self.tti_processing.is_set or
                        (self.odu is not None and self.odu.has_data()) or
                        (self.otu is not None and self.otu.has_data()) or
                        (self.fec is not None) or
                        (self.prbs is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bdi_to_gais.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        self.framing.yfilter != YFilter.not_set or
                        self.proactive.yfilter != YFilter.not_set or
                        self.proactive_logging_file.yfilter != YFilter.not_set or
                        self.tim_to_gais.yfilter != YFilter.not_set or
                        self.tti_processing.yfilter != YFilter.not_set or
                        (self.fec is not None and self.fec.has_operation()) or
                        (self.odu is not None and self.odu.has_operation()) or
                        (self.otu is not None and self.otu.has_operation()) or
                        (self.prbs is not None and self.prbs.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "g709" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bdi_to_gais.is_set or self.bdi_to_gais.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bdi_to_gais.get_name_leafdata())
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())
                    if (self.framing.is_set or self.framing.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.framing.get_name_leafdata())
                    if (self.proactive.is_set or self.proactive.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.proactive.get_name_leafdata())
                    if (self.proactive_logging_file.is_set or self.proactive_logging_file.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.proactive_logging_file.get_name_leafdata())
                    if (self.tim_to_gais.is_set or self.tim_to_gais.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tim_to_gais.get_name_leafdata())
                    if (self.tti_processing.is_set or self.tti_processing.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tti_processing.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "fec"):
                        if (self.fec is None):
                            self.fec = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec()
                            self.fec.parent = self
                            self._children_name_map["fec"] = "fec"
                        return self.fec

                    if (child_yang_name == "odu"):
                        if (self.odu is None):
                            self.odu = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu()
                            self.odu.parent = self
                            self._children_name_map["odu"] = "odu"
                        return self.odu

                    if (child_yang_name == "otu"):
                        if (self.otu is None):
                            self.otu = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu()
                            self.otu.parent = self
                            self._children_name_map["otu"] = "otu"
                        return self.otu

                    if (child_yang_name == "prbs"):
                        if (self.prbs is None):
                            self.prbs = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs()
                            self.prbs.parent = self
                            self._children_name_map["prbs"] = "prbs"
                        return self.prbs

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "fec" or name == "odu" or name == "otu" or name == "prbs" or name == "bdi-to-gais" or name == "enable" or name == "framing" or name == "proactive" or name == "proactive-logging-file" or name == "tim-to-gais" or name == "tti-processing"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bdi-to-gais"):
                        self.bdi_to_gais = value
                        self.bdi_to_gais.value_namespace = name_space
                        self.bdi_to_gais.value_namespace_prefix = name_space_prefix
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix
                    if(value_path == "framing"):
                        self.framing = value
                        self.framing.value_namespace = name_space
                        self.framing.value_namespace_prefix = name_space_prefix
                    if(value_path == "proactive"):
                        self.proactive = value
                        self.proactive.value_namespace = name_space
                        self.proactive.value_namespace_prefix = name_space_prefix
                    if(value_path == "proactive-logging-file"):
                        self.proactive_logging_file = value
                        self.proactive_logging_file.value_namespace = name_space
                        self.proactive_logging_file.value_namespace_prefix = name_space_prefix
                    if(value_path == "tim-to-gais"):
                        self.tim_to_gais = value
                        self.tim_to_gais.value_namespace = name_space
                        self.tim_to_gais.value_namespace_prefix = name_space_prefix
                    if(value_path == "tti-processing"):
                        self.tti_processing = value
                        self.tti_processing.value_namespace = name_space
                        self.tti_processing.value_namespace_prefix = name_space_prefix


            class Wavelength(Entity):
                """
                Configure transponder wavelength
                
                .. attribute:: prog_frequency
                
                	Enter Frequency Data in THz
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: wave_channel
                
                	Select a ITU channel number,channel range for C\-band\: 1~82,L\-band\:106~185,spacing\:50GHZ or 100MHz
                	**type**\:  int
                
                	**range:** 1..1568362
                
                	**mandatory**\: True
                
                .. attribute:: wave_channel_number
                
                	Wave Channel Number
                	**type**\:   :py:class:`WaveChannelNum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.WaveChannelNum>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'dwdm-ui-cfg'
                _revision = '2015-12-16'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength, self).__init__()

                    self.yang_name = "wavelength"
                    self.yang_parent_name = "dwdm"
                    self.is_presence_container = True

                    self.prog_frequency = YLeaf(YType.str, "prog-frequency")

                    self.wave_channel = YLeaf(YType.uint32, "wave-channel")

                    self.wave_channel_number = YLeaf(YType.enumeration, "wave-channel-number")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("prog_frequency",
                                    "wave_channel",
                                    "wave_channel_number") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.prog_frequency.is_set or
                        self.wave_channel.is_set or
                        self.wave_channel_number.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.prog_frequency.yfilter != YFilter.not_set or
                        self.wave_channel.yfilter != YFilter.not_set or
                        self.wave_channel_number.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "wavelength" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.prog_frequency.is_set or self.prog_frequency.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.prog_frequency.get_name_leafdata())
                    if (self.wave_channel.is_set or self.wave_channel.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wave_channel.get_name_leafdata())
                    if (self.wave_channel_number.is_set or self.wave_channel_number.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wave_channel_number.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "prog-frequency" or name == "wave-channel" or name == "wave-channel-number"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "prog-frequency"):
                        self.prog_frequency = value
                        self.prog_frequency.value_namespace = name_space
                        self.prog_frequency.value_namespace_prefix = name_space_prefix
                    if(value_path == "wave-channel"):
                        self.wave_channel = value
                        self.wave_channel.value_namespace = name_space
                        self.wave_channel.value_namespace_prefix = name_space_prefix
                    if(value_path == "wave-channel-number"):
                        self.wave_channel_number = value
                        self.wave_channel_number.value_namespace = name_space
                        self.wave_channel_number.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.enable_vtxp.is_set or
                    self.laser.is_set or
                    self.loopback.is_set or
                    self.network_connection_id.is_set or
                    self.network_port_id.is_set or
                    self.rx_threshold.is_set or
                    self.transmit_power.is_set or
                    self.transport_admin_state.is_set or
                    (self.g709 is not None and self.g709.has_data()) or
                    (self.network_srlgs is not None and self.network_srlgs.has_data()) or
                    (self.wavelength is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.enable_vtxp.yfilter != YFilter.not_set or
                    self.laser.yfilter != YFilter.not_set or
                    self.loopback.yfilter != YFilter.not_set or
                    self.network_connection_id.yfilter != YFilter.not_set or
                    self.network_port_id.yfilter != YFilter.not_set or
                    self.rx_threshold.yfilter != YFilter.not_set or
                    self.transmit_power.yfilter != YFilter.not_set or
                    self.transport_admin_state.yfilter != YFilter.not_set or
                    (self.g709 is not None and self.g709.has_operation()) or
                    (self.network_srlgs is not None and self.network_srlgs.has_operation()) or
                    (self.wavelength is not None and self.wavelength.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-dwdm-ui-cfg:dwdm" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.enable_vtxp.is_set or self.enable_vtxp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.enable_vtxp.get_name_leafdata())
                if (self.laser.is_set or self.laser.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.laser.get_name_leafdata())
                if (self.loopback.is_set or self.loopback.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.loopback.get_name_leafdata())
                if (self.network_connection_id.is_set or self.network_connection_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.network_connection_id.get_name_leafdata())
                if (self.network_port_id.is_set or self.network_port_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.network_port_id.get_name_leafdata())
                if (self.rx_threshold.is_set or self.rx_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rx_threshold.get_name_leafdata())
                if (self.transmit_power.is_set or self.transmit_power.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.transmit_power.get_name_leafdata())
                if (self.transport_admin_state.is_set or self.transport_admin_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.transport_admin_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "g709"):
                    if (self.g709 is None):
                        self.g709 = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709()
                        self.g709.parent = self
                        self._children_name_map["g709"] = "g709"
                    return self.g709

                if (child_yang_name == "network-srlgs"):
                    if (self.network_srlgs is None):
                        self.network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs()
                        self.network_srlgs.parent = self
                        self._children_name_map["network_srlgs"] = "network-srlgs"
                    return self.network_srlgs

                if (child_yang_name == "wavelength"):
                    if (self.wavelength is None):
                        self.wavelength = InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength()
                        self.wavelength.parent = self
                        self._children_name_map["wavelength"] = "wavelength"
                    return self.wavelength

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "g709" or name == "network-srlgs" or name == "wavelength" or name == "enable-vtxp" or name == "laser" or name == "loopback" or name == "network-connection-id" or name == "network-port-id" or name == "rx-threshold" or name == "transmit-power" or name == "transport-admin-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "enable-vtxp"):
                    self.enable_vtxp = value
                    self.enable_vtxp.value_namespace = name_space
                    self.enable_vtxp.value_namespace_prefix = name_space_prefix
                if(value_path == "laser"):
                    self.laser = value
                    self.laser.value_namespace = name_space
                    self.laser.value_namespace_prefix = name_space_prefix
                if(value_path == "loopback"):
                    self.loopback = value
                    self.loopback.value_namespace = name_space
                    self.loopback.value_namespace_prefix = name_space_prefix
                if(value_path == "network-connection-id"):
                    self.network_connection_id = value
                    self.network_connection_id.value_namespace = name_space
                    self.network_connection_id.value_namespace_prefix = name_space_prefix
                if(value_path == "network-port-id"):
                    self.network_port_id = value
                    self.network_port_id.value_namespace = name_space
                    self.network_port_id.value_namespace_prefix = name_space_prefix
                if(value_path == "rx-threshold"):
                    self.rx_threshold = value
                    self.rx_threshold.value_namespace = name_space
                    self.rx_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "transmit-power"):
                    self.transmit_power = value
                    self.transmit_power.value_namespace = name_space
                    self.transmit_power.value_namespace_prefix = name_space_prefix
                if(value_path == "transport-admin-state"):
                    self.transport_admin_state = value
                    self.transport_admin_state.value_namespace = name_space
                    self.transport_admin_state.value_namespace_prefix = name_space_prefix


        class VlanSubConfiguration(Entity):
            """
            IEEE 802.1Q VLAN subinterface configuration
            
            .. attribute:: vlan_identifier
            
            	The VLAN tag stack associated with this sub\-interface
            	**type**\:   :py:class:`VlanIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration, self).__init__()

                self.yang_name = "vlan-sub-configuration"
                self.yang_parent_name = "interface-configuration"

                self.vlan_identifier = None
                self._children_name_map["vlan_identifier"] = "vlan-identifier"
                self._children_yang_names.add("vlan-identifier")


            class VlanIdentifier(Entity):
                """
                The VLAN tag stack associated with this
                sub\-interface.
                
                .. attribute:: first_tag
                
                	First (outermost) VLAN tag value
                	**type**\:  int
                
                	**range:** 1..4094
                
                	**mandatory**\: True
                
                .. attribute:: second_tag
                
                	Second VLAN tag value. The any value may only be used for Layer 2 subinterfaces
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrNull <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrNull>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 0..4094
                
                
                ----
                .. attribute:: vlan_type
                
                	Whether this sub\-interface is dot1ad or dot1Q
                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Vlan>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier, self).__init__()

                    self.yang_name = "vlan-identifier"
                    self.yang_parent_name = "vlan-sub-configuration"
                    self.is_presence_container = True

                    self.first_tag = YLeaf(YType.uint32, "first-tag")

                    self.second_tag = YLeaf(YType.str, "second-tag")

                    self.vlan_type = YLeaf(YType.enumeration, "vlan-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("first_tag",
                                    "second_tag",
                                    "vlan_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.first_tag.is_set or
                        self.second_tag.is_set or
                        self.vlan_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.first_tag.yfilter != YFilter.not_set or
                        self.second_tag.yfilter != YFilter.not_set or
                        self.vlan_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vlan-identifier" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.first_tag.is_set or self.first_tag.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.first_tag.get_name_leafdata())
                    if (self.second_tag.is_set or self.second_tag.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.second_tag.get_name_leafdata())
                    if (self.vlan_type.is_set or self.vlan_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "first-tag" or name == "second-tag" or name == "vlan-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "first-tag"):
                        self.first_tag = value
                        self.first_tag.value_namespace = name_space
                        self.first_tag.value_namespace_prefix = name_space_prefix
                    if(value_path == "second-tag"):
                        self.second_tag = value
                        self.second_tag.value_namespace = name_space
                        self.second_tag.value_namespace_prefix = name_space_prefix
                    if(value_path == "vlan-type"):
                        self.vlan_type = value
                        self.vlan_type.value_namespace = name_space
                        self.vlan_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.vlan_identifier is not None)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.vlan_identifier is not None and self.vlan_identifier.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:vlan-sub-configuration" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vlan-identifier"):
                    if (self.vlan_identifier is None):
                        self.vlan_identifier = InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier()
                        self.vlan_identifier.parent = self
                        self._children_name_map["vlan_identifier"] = "vlan-identifier"
                    return self.vlan_identifier

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vlan-identifier"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EthernetService(Entity):
            """
            Ethernet service configuration
            
            .. attribute:: encapsulation
            
            	The encapsulation of this Ethernet service
            	**type**\:   :py:class:`Encapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation>`
            
            	**presence node**\: True
            
            .. attribute:: local_traffic_default_encapsulation
            
            	The default encapsulation to be used for locally\-sourced packets
            	**type**\:   :py:class:`LocalTrafficDefaultEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation>`
            
            	**presence node**\: True
            
            .. attribute:: rewrite
            
            	The rewrite operation for the Ethernet service
            	**type**\:   :py:class:`Rewrite <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetService, self).__init__()

                self.yang_name = "ethernet-service"
                self.yang_parent_name = "interface-configuration"

                self.encapsulation = None
                self._children_name_map["encapsulation"] = "encapsulation"
                self._children_yang_names.add("encapsulation")

                self.local_traffic_default_encapsulation = None
                self._children_name_map["local_traffic_default_encapsulation"] = "local-traffic-default-encapsulation"
                self._children_yang_names.add("local-traffic-default-encapsulation")

                self.rewrite = None
                self._children_name_map["rewrite"] = "rewrite"
                self._children_yang_names.add("rewrite")


            class LocalTrafficDefaultEncapsulation(Entity):
                """
                The default encapsulation to be used for
                locally\-sourced packets
                
                .. attribute:: inner_vlan_id
                
                	Optional VLAN Id for inner Dot1Q tag
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: outer_tag_type
                
                	Type of outer tag
                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Vlan>`
                
                	**mandatory**\: True
                
                .. attribute:: outer_vlan_id
                
                	VLAN id for outer tag
                	**type**\:  int
                
                	**range:** 1..4094
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation, self).__init__()

                    self.yang_name = "local-traffic-default-encapsulation"
                    self.yang_parent_name = "ethernet-service"
                    self.is_presence_container = True

                    self.inner_vlan_id = YLeaf(YType.uint32, "inner-vlan-id")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.outer_vlan_id = YLeaf(YType.uint32, "outer-vlan-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("inner_vlan_id",
                                    "outer_tag_type",
                                    "outer_vlan_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.inner_vlan_id.is_set or
                        self.outer_tag_type.is_set or
                        self.outer_vlan_id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.inner_vlan_id.yfilter != YFilter.not_set or
                        self.outer_tag_type.yfilter != YFilter.not_set or
                        self.outer_vlan_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "local-traffic-default-encapsulation" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.inner_vlan_id.is_set or self.inner_vlan_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_vlan_id.get_name_leafdata())
                    if (self.outer_tag_type.is_set or self.outer_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_tag_type.get_name_leafdata())
                    if (self.outer_vlan_id.is_set or self.outer_vlan_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_vlan_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "inner-vlan-id" or name == "outer-tag-type" or name == "outer-vlan-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "inner-vlan-id"):
                        self.inner_vlan_id = value
                        self.inner_vlan_id.value_namespace = name_space
                        self.inner_vlan_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-tag-type"):
                        self.outer_tag_type = value
                        self.outer_tag_type.value_namespace = name_space
                        self.outer_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-vlan-id"):
                        self.outer_vlan_id = value
                        self.outer_vlan_id.value_namespace = name_space
                        self.outer_vlan_id.value_namespace_prefix = name_space_prefix


            class Encapsulation(Entity):
                """
                The encapsulation of this Ethernet service
                
                .. attribute:: additional_range1_high
                
                	High value of first additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range1_low
                
                	Low value of first additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range2_high
                
                	High value of second additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range2_low
                
                	Low value of second additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range3_high
                
                	High value of third additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range3_low
                
                	Low value of third additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range4_high
                
                	High value of forth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range4_low
                
                	Low value of forth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range5_high
                
                	High value of fifth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range5_low
                
                	Low value of fifth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range6_high
                
                	High value of sixth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range6_low
                
                	Low value of sixth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range7_high
                
                	High value of seventh additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range7_low
                
                	Low value of seventh additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range8_high
                
                	High value of eighth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range8_low
                
                	Low value of eighth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: exact
                
                	Only match packets with no more tags than explicitly matched
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ingress_destination_mac
                
                	Destination MAC address to match on egress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: ingress_source_mac
                
                	Source MAC address to match on ingress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: inner_class_of_service
                
                	Value to match against Class Of Service bits for inner tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: inner_range1_high
                
                	High value of first range for inner tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: inner_range1_low
                
                	Low value of first range for inner tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: inner_tag_type
                
                	Type of tag for inner match (if present)
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: outer_class_of_service
                
                	Value to match against Class Of Service bits for outer tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: outer_range1_high
                
                	High value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrNative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrNative>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65535
                
                
                ----
                .. attribute:: outer_range1_low
                
                	Low value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: outer_tag_type
                
                	Whether to match all unmatched packets, untagged packets or tagged packets, and if matching tagged packets, the outer tag type to match
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                	**mandatory**\: True
                
                .. attribute:: payload_ethertype_match
                
                	Which payload ethertype values to match
                	**type**\:   :py:class:`EthertypeMatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.EthertypeMatch>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "ethernet-service"
                    self.is_presence_container = True

                    self.additional_range1_high = YLeaf(YType.uint32, "additional-range1-high")

                    self.additional_range1_low = YLeaf(YType.str, "additional-range1-low")

                    self.additional_range2_high = YLeaf(YType.uint32, "additional-range2-high")

                    self.additional_range2_low = YLeaf(YType.str, "additional-range2-low")

                    self.additional_range3_high = YLeaf(YType.uint32, "additional-range3-high")

                    self.additional_range3_low = YLeaf(YType.str, "additional-range3-low")

                    self.additional_range4_high = YLeaf(YType.uint32, "additional-range4-high")

                    self.additional_range4_low = YLeaf(YType.str, "additional-range4-low")

                    self.additional_range5_high = YLeaf(YType.uint32, "additional-range5-high")

                    self.additional_range5_low = YLeaf(YType.str, "additional-range5-low")

                    self.additional_range6_high = YLeaf(YType.uint32, "additional-range6-high")

                    self.additional_range6_low = YLeaf(YType.str, "additional-range6-low")

                    self.additional_range7_high = YLeaf(YType.uint32, "additional-range7-high")

                    self.additional_range7_low = YLeaf(YType.str, "additional-range7-low")

                    self.additional_range8_high = YLeaf(YType.uint32, "additional-range8-high")

                    self.additional_range8_low = YLeaf(YType.str, "additional-range8-low")

                    self.exact = YLeaf(YType.empty, "exact")

                    self.ingress_destination_mac = YLeaf(YType.str, "ingress-destination-mac")

                    self.ingress_source_mac = YLeaf(YType.str, "ingress-source-mac")

                    self.inner_class_of_service = YLeaf(YType.uint32, "inner-class-of-service")

                    self.inner_range1_high = YLeaf(YType.uint32, "inner-range1-high")

                    self.inner_range1_low = YLeaf(YType.str, "inner-range1-low")

                    self.inner_tag_type = YLeaf(YType.enumeration, "inner-tag-type")

                    self.outer_class_of_service = YLeaf(YType.uint32, "outer-class-of-service")

                    self.outer_range1_high = YLeaf(YType.str, "outer-range1-high")

                    self.outer_range1_low = YLeaf(YType.str, "outer-range1-low")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.payload_ethertype_match = YLeaf(YType.enumeration, "payload-ethertype-match")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("additional_range1_high",
                                    "additional_range1_low",
                                    "additional_range2_high",
                                    "additional_range2_low",
                                    "additional_range3_high",
                                    "additional_range3_low",
                                    "additional_range4_high",
                                    "additional_range4_low",
                                    "additional_range5_high",
                                    "additional_range5_low",
                                    "additional_range6_high",
                                    "additional_range6_low",
                                    "additional_range7_high",
                                    "additional_range7_low",
                                    "additional_range8_high",
                                    "additional_range8_low",
                                    "exact",
                                    "ingress_destination_mac",
                                    "ingress_source_mac",
                                    "inner_class_of_service",
                                    "inner_range1_high",
                                    "inner_range1_low",
                                    "inner_tag_type",
                                    "outer_class_of_service",
                                    "outer_range1_high",
                                    "outer_range1_low",
                                    "outer_tag_type",
                                    "payload_ethertype_match") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.additional_range1_high.is_set or
                        self.additional_range1_low.is_set or
                        self.additional_range2_high.is_set or
                        self.additional_range2_low.is_set or
                        self.additional_range3_high.is_set or
                        self.additional_range3_low.is_set or
                        self.additional_range4_high.is_set or
                        self.additional_range4_low.is_set or
                        self.additional_range5_high.is_set or
                        self.additional_range5_low.is_set or
                        self.additional_range6_high.is_set or
                        self.additional_range6_low.is_set or
                        self.additional_range7_high.is_set or
                        self.additional_range7_low.is_set or
                        self.additional_range8_high.is_set or
                        self.additional_range8_low.is_set or
                        self.exact.is_set or
                        self.ingress_destination_mac.is_set or
                        self.ingress_source_mac.is_set or
                        self.inner_class_of_service.is_set or
                        self.inner_range1_high.is_set or
                        self.inner_range1_low.is_set or
                        self.inner_tag_type.is_set or
                        self.outer_class_of_service.is_set or
                        self.outer_range1_high.is_set or
                        self.outer_range1_low.is_set or
                        self.outer_tag_type.is_set or
                        self.payload_ethertype_match.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.additional_range1_high.yfilter != YFilter.not_set or
                        self.additional_range1_low.yfilter != YFilter.not_set or
                        self.additional_range2_high.yfilter != YFilter.not_set or
                        self.additional_range2_low.yfilter != YFilter.not_set or
                        self.additional_range3_high.yfilter != YFilter.not_set or
                        self.additional_range3_low.yfilter != YFilter.not_set or
                        self.additional_range4_high.yfilter != YFilter.not_set or
                        self.additional_range4_low.yfilter != YFilter.not_set or
                        self.additional_range5_high.yfilter != YFilter.not_set or
                        self.additional_range5_low.yfilter != YFilter.not_set or
                        self.additional_range6_high.yfilter != YFilter.not_set or
                        self.additional_range6_low.yfilter != YFilter.not_set or
                        self.additional_range7_high.yfilter != YFilter.not_set or
                        self.additional_range7_low.yfilter != YFilter.not_set or
                        self.additional_range8_high.yfilter != YFilter.not_set or
                        self.additional_range8_low.yfilter != YFilter.not_set or
                        self.exact.yfilter != YFilter.not_set or
                        self.ingress_destination_mac.yfilter != YFilter.not_set or
                        self.ingress_source_mac.yfilter != YFilter.not_set or
                        self.inner_class_of_service.yfilter != YFilter.not_set or
                        self.inner_range1_high.yfilter != YFilter.not_set or
                        self.inner_range1_low.yfilter != YFilter.not_set or
                        self.inner_tag_type.yfilter != YFilter.not_set or
                        self.outer_class_of_service.yfilter != YFilter.not_set or
                        self.outer_range1_high.yfilter != YFilter.not_set or
                        self.outer_range1_low.yfilter != YFilter.not_set or
                        self.outer_tag_type.yfilter != YFilter.not_set or
                        self.payload_ethertype_match.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "encapsulation" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.additional_range1_high.is_set or self.additional_range1_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range1_high.get_name_leafdata())
                    if (self.additional_range1_low.is_set or self.additional_range1_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range1_low.get_name_leafdata())
                    if (self.additional_range2_high.is_set or self.additional_range2_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range2_high.get_name_leafdata())
                    if (self.additional_range2_low.is_set or self.additional_range2_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range2_low.get_name_leafdata())
                    if (self.additional_range3_high.is_set or self.additional_range3_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range3_high.get_name_leafdata())
                    if (self.additional_range3_low.is_set or self.additional_range3_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range3_low.get_name_leafdata())
                    if (self.additional_range4_high.is_set or self.additional_range4_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range4_high.get_name_leafdata())
                    if (self.additional_range4_low.is_set or self.additional_range4_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range4_low.get_name_leafdata())
                    if (self.additional_range5_high.is_set or self.additional_range5_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range5_high.get_name_leafdata())
                    if (self.additional_range5_low.is_set or self.additional_range5_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range5_low.get_name_leafdata())
                    if (self.additional_range6_high.is_set or self.additional_range6_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range6_high.get_name_leafdata())
                    if (self.additional_range6_low.is_set or self.additional_range6_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range6_low.get_name_leafdata())
                    if (self.additional_range7_high.is_set or self.additional_range7_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range7_high.get_name_leafdata())
                    if (self.additional_range7_low.is_set or self.additional_range7_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range7_low.get_name_leafdata())
                    if (self.additional_range8_high.is_set or self.additional_range8_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range8_high.get_name_leafdata())
                    if (self.additional_range8_low.is_set or self.additional_range8_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range8_low.get_name_leafdata())
                    if (self.exact.is_set or self.exact.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.exact.get_name_leafdata())
                    if (self.ingress_destination_mac.is_set or self.ingress_destination_mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ingress_destination_mac.get_name_leafdata())
                    if (self.ingress_source_mac.is_set or self.ingress_source_mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ingress_source_mac.get_name_leafdata())
                    if (self.inner_class_of_service.is_set or self.inner_class_of_service.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_class_of_service.get_name_leafdata())
                    if (self.inner_range1_high.is_set or self.inner_range1_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_range1_high.get_name_leafdata())
                    if (self.inner_range1_low.is_set or self.inner_range1_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_range1_low.get_name_leafdata())
                    if (self.inner_tag_type.is_set or self.inner_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_tag_type.get_name_leafdata())
                    if (self.outer_class_of_service.is_set or self.outer_class_of_service.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_class_of_service.get_name_leafdata())
                    if (self.outer_range1_high.is_set or self.outer_range1_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_range1_high.get_name_leafdata())
                    if (self.outer_range1_low.is_set or self.outer_range1_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_range1_low.get_name_leafdata())
                    if (self.outer_tag_type.is_set or self.outer_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_tag_type.get_name_leafdata())
                    if (self.payload_ethertype_match.is_set or self.payload_ethertype_match.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.payload_ethertype_match.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "additional-range1-high" or name == "additional-range1-low" or name == "additional-range2-high" or name == "additional-range2-low" or name == "additional-range3-high" or name == "additional-range3-low" or name == "additional-range4-high" or name == "additional-range4-low" or name == "additional-range5-high" or name == "additional-range5-low" or name == "additional-range6-high" or name == "additional-range6-low" or name == "additional-range7-high" or name == "additional-range7-low" or name == "additional-range8-high" or name == "additional-range8-low" or name == "exact" or name == "ingress-destination-mac" or name == "ingress-source-mac" or name == "inner-class-of-service" or name == "inner-range1-high" or name == "inner-range1-low" or name == "inner-tag-type" or name == "outer-class-of-service" or name == "outer-range1-high" or name == "outer-range1-low" or name == "outer-tag-type" or name == "payload-ethertype-match"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "additional-range1-high"):
                        self.additional_range1_high = value
                        self.additional_range1_high.value_namespace = name_space
                        self.additional_range1_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range1-low"):
                        self.additional_range1_low = value
                        self.additional_range1_low.value_namespace = name_space
                        self.additional_range1_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range2-high"):
                        self.additional_range2_high = value
                        self.additional_range2_high.value_namespace = name_space
                        self.additional_range2_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range2-low"):
                        self.additional_range2_low = value
                        self.additional_range2_low.value_namespace = name_space
                        self.additional_range2_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range3-high"):
                        self.additional_range3_high = value
                        self.additional_range3_high.value_namespace = name_space
                        self.additional_range3_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range3-low"):
                        self.additional_range3_low = value
                        self.additional_range3_low.value_namespace = name_space
                        self.additional_range3_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range4-high"):
                        self.additional_range4_high = value
                        self.additional_range4_high.value_namespace = name_space
                        self.additional_range4_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range4-low"):
                        self.additional_range4_low = value
                        self.additional_range4_low.value_namespace = name_space
                        self.additional_range4_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range5-high"):
                        self.additional_range5_high = value
                        self.additional_range5_high.value_namespace = name_space
                        self.additional_range5_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range5-low"):
                        self.additional_range5_low = value
                        self.additional_range5_low.value_namespace = name_space
                        self.additional_range5_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range6-high"):
                        self.additional_range6_high = value
                        self.additional_range6_high.value_namespace = name_space
                        self.additional_range6_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range6-low"):
                        self.additional_range6_low = value
                        self.additional_range6_low.value_namespace = name_space
                        self.additional_range6_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range7-high"):
                        self.additional_range7_high = value
                        self.additional_range7_high.value_namespace = name_space
                        self.additional_range7_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range7-low"):
                        self.additional_range7_low = value
                        self.additional_range7_low.value_namespace = name_space
                        self.additional_range7_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range8-high"):
                        self.additional_range8_high = value
                        self.additional_range8_high.value_namespace = name_space
                        self.additional_range8_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range8-low"):
                        self.additional_range8_low = value
                        self.additional_range8_low.value_namespace = name_space
                        self.additional_range8_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "exact"):
                        self.exact = value
                        self.exact.value_namespace = name_space
                        self.exact.value_namespace_prefix = name_space_prefix
                    if(value_path == "ingress-destination-mac"):
                        self.ingress_destination_mac = value
                        self.ingress_destination_mac.value_namespace = name_space
                        self.ingress_destination_mac.value_namespace_prefix = name_space_prefix
                    if(value_path == "ingress-source-mac"):
                        self.ingress_source_mac = value
                        self.ingress_source_mac.value_namespace = name_space
                        self.ingress_source_mac.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-class-of-service"):
                        self.inner_class_of_service = value
                        self.inner_class_of_service.value_namespace = name_space
                        self.inner_class_of_service.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-range1-high"):
                        self.inner_range1_high = value
                        self.inner_range1_high.value_namespace = name_space
                        self.inner_range1_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-range1-low"):
                        self.inner_range1_low = value
                        self.inner_range1_low.value_namespace = name_space
                        self.inner_range1_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-tag-type"):
                        self.inner_tag_type = value
                        self.inner_tag_type.value_namespace = name_space
                        self.inner_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-class-of-service"):
                        self.outer_class_of_service = value
                        self.outer_class_of_service.value_namespace = name_space
                        self.outer_class_of_service.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-range1-high"):
                        self.outer_range1_high = value
                        self.outer_range1_high.value_namespace = name_space
                        self.outer_range1_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-range1-low"):
                        self.outer_range1_low = value
                        self.outer_range1_low.value_namespace = name_space
                        self.outer_range1_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-tag-type"):
                        self.outer_tag_type = value
                        self.outer_tag_type.value_namespace = name_space
                        self.outer_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "payload-ethertype-match"):
                        self.payload_ethertype_match = value
                        self.payload_ethertype_match.value_namespace = name_space
                        self.payload_ethertype_match.value_namespace_prefix = name_space_prefix


            class Rewrite(Entity):
                """
                The rewrite operation for the Ethernet service
                
                .. attribute:: inner_tag_type
                
                	Type of innermost tag to be pushed
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: inner_tag_value
                
                	VLAN Id of innermost tag to be pushed
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: outer_tag_type
                
                	Type of outermost tag to be pushed
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: outer_tag_value
                
                	VLAN Id of outermost tag to be pushed
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: rewrite_type
                
                	The type of rewrite to perform
                	**type**\:   :py:class:`Rewrite <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Rewrite>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite, self).__init__()

                    self.yang_name = "rewrite"
                    self.yang_parent_name = "ethernet-service"
                    self.is_presence_container = True

                    self.inner_tag_type = YLeaf(YType.enumeration, "inner-tag-type")

                    self.inner_tag_value = YLeaf(YType.uint32, "inner-tag-value")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.outer_tag_value = YLeaf(YType.uint32, "outer-tag-value")

                    self.rewrite_type = YLeaf(YType.enumeration, "rewrite-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("inner_tag_type",
                                    "inner_tag_value",
                                    "outer_tag_type",
                                    "outer_tag_value",
                                    "rewrite_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.inner_tag_type.is_set or
                        self.inner_tag_value.is_set or
                        self.outer_tag_type.is_set or
                        self.outer_tag_value.is_set or
                        self.rewrite_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.inner_tag_type.yfilter != YFilter.not_set or
                        self.inner_tag_value.yfilter != YFilter.not_set or
                        self.outer_tag_type.yfilter != YFilter.not_set or
                        self.outer_tag_value.yfilter != YFilter.not_set or
                        self.rewrite_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rewrite" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.inner_tag_type.is_set or self.inner_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_tag_type.get_name_leafdata())
                    if (self.inner_tag_value.is_set or self.inner_tag_value.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_tag_value.get_name_leafdata())
                    if (self.outer_tag_type.is_set or self.outer_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_tag_type.get_name_leafdata())
                    if (self.outer_tag_value.is_set or self.outer_tag_value.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_tag_value.get_name_leafdata())
                    if (self.rewrite_type.is_set or self.rewrite_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rewrite_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "inner-tag-type" or name == "inner-tag-value" or name == "outer-tag-type" or name == "outer-tag-value" or name == "rewrite-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "inner-tag-type"):
                        self.inner_tag_type = value
                        self.inner_tag_type.value_namespace = name_space
                        self.inner_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-tag-value"):
                        self.inner_tag_value = value
                        self.inner_tag_value.value_namespace = name_space
                        self.inner_tag_value.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-tag-type"):
                        self.outer_tag_type = value
                        self.outer_tag_type.value_namespace = name_space
                        self.outer_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-tag-value"):
                        self.outer_tag_value = value
                        self.outer_tag_value.value_namespace = name_space
                        self.outer_tag_value.value_namespace_prefix = name_space_prefix
                    if(value_path == "rewrite-type"):
                        self.rewrite_type = value
                        self.rewrite_type.value_namespace = name_space
                        self.rewrite_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.encapsulation is not None) or
                    (self.local_traffic_default_encapsulation is not None) or
                    (self.rewrite is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.encapsulation is not None and self.encapsulation.has_operation()) or
                    (self.local_traffic_default_encapsulation is not None and self.local_traffic_default_encapsulation.has_operation()) or
                    (self.rewrite is not None and self.rewrite.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:ethernet-service" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "encapsulation"):
                    if (self.encapsulation is None):
                        self.encapsulation = InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation()
                        self.encapsulation.parent = self
                        self._children_name_map["encapsulation"] = "encapsulation"
                    return self.encapsulation

                if (child_yang_name == "local-traffic-default-encapsulation"):
                    if (self.local_traffic_default_encapsulation is None):
                        self.local_traffic_default_encapsulation = InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation()
                        self.local_traffic_default_encapsulation.parent = self
                        self._children_name_map["local_traffic_default_encapsulation"] = "local-traffic-default-encapsulation"
                    return self.local_traffic_default_encapsulation

                if (child_yang_name == "rewrite"):
                    if (self.rewrite is None):
                        self.rewrite = InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite()
                        self.rewrite.parent = self
                        self._children_name_map["rewrite"] = "rewrite"
                    return self.rewrite

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "encapsulation" or name == "local-traffic-default-encapsulation" or name == "rewrite"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EthernetBng(Entity):
            """
            Ethernet Infra BNG specific configuration
            
            .. attribute:: ambiguous_encapsulation
            
            	L3 Ambiguous encapsulation
            	**type**\:   :py:class:`AmbiguousEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetBng, self).__init__()

                self.yang_name = "ethernet-bng"
                self.yang_parent_name = "interface-configuration"

                self.ambiguous_encapsulation = None
                self._children_name_map["ambiguous_encapsulation"] = "ambiguous-encapsulation"
                self._children_yang_names.add("ambiguous-encapsulation")


            class AmbiguousEncapsulation(Entity):
                """
                L3 Ambiguous encapsulation
                
                .. attribute:: additional_range1_high
                
                	High value of first additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range1_low
                
                	Low value of first additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range2_high
                
                	High value of second additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range2_low
                
                	Low value of second additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range3_high
                
                	High value of third additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range3_low
                
                	Low value of third additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range4_high
                
                	High value of forth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range4_low
                
                	Low value of forth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range5_high
                
                	High value of fifth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range5_low
                
                	Low value of fifth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range6_high
                
                	High value of sixth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range6_low
                
                	Low value of sixth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range7_high
                
                	High value of seventh additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range7_low
                
                	Low value of seventh additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range8_high
                
                	High value of eighth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range8_low
                
                	Low value of eighth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: exact
                
                	Only match packets with no more tags than explicitly matched
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ingress_destination_mac
                
                	Destination MAC address to match on egress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: ingress_source_mac
                
                	Source MAC address to match on ingress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: inner_class_of_service
                
                	Value to match against Class Of Service bits for inner tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: inner_range1_high
                
                	High value of first range for inner tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: inner_range1_low
                
                	Low value of first range for inner tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: inner_tag_type
                
                	Type of tag for inner match (if present)
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: outer_class_of_service
                
                	Value to match against Class Of Service bits for outer tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: outer_range1_high
                
                	High value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrNative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrNative>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65535
                
                
                ----
                .. attribute:: outer_range1_low
                
                	Low value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: outer_tag_type
                
                	Whether to match all unmatched packets, untagged packets or tagged packets, and if matching tagged packets, the outer tag type to match
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                	**mandatory**\: True
                
                .. attribute:: payload_ethertype_match
                
                	Which payload ethertype values to match
                	**type**\:   :py:class:`EthertypeMatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.EthertypeMatch>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation, self).__init__()

                    self.yang_name = "ambiguous-encapsulation"
                    self.yang_parent_name = "ethernet-bng"
                    self.is_presence_container = True

                    self.additional_range1_high = YLeaf(YType.uint32, "additional-range1-high")

                    self.additional_range1_low = YLeaf(YType.str, "additional-range1-low")

                    self.additional_range2_high = YLeaf(YType.uint32, "additional-range2-high")

                    self.additional_range2_low = YLeaf(YType.str, "additional-range2-low")

                    self.additional_range3_high = YLeaf(YType.uint32, "additional-range3-high")

                    self.additional_range3_low = YLeaf(YType.str, "additional-range3-low")

                    self.additional_range4_high = YLeaf(YType.uint32, "additional-range4-high")

                    self.additional_range4_low = YLeaf(YType.str, "additional-range4-low")

                    self.additional_range5_high = YLeaf(YType.uint32, "additional-range5-high")

                    self.additional_range5_low = YLeaf(YType.str, "additional-range5-low")

                    self.additional_range6_high = YLeaf(YType.uint32, "additional-range6-high")

                    self.additional_range6_low = YLeaf(YType.str, "additional-range6-low")

                    self.additional_range7_high = YLeaf(YType.uint32, "additional-range7-high")

                    self.additional_range7_low = YLeaf(YType.str, "additional-range7-low")

                    self.additional_range8_high = YLeaf(YType.uint32, "additional-range8-high")

                    self.additional_range8_low = YLeaf(YType.str, "additional-range8-low")

                    self.exact = YLeaf(YType.empty, "exact")

                    self.ingress_destination_mac = YLeaf(YType.str, "ingress-destination-mac")

                    self.ingress_source_mac = YLeaf(YType.str, "ingress-source-mac")

                    self.inner_class_of_service = YLeaf(YType.uint32, "inner-class-of-service")

                    self.inner_range1_high = YLeaf(YType.uint32, "inner-range1-high")

                    self.inner_range1_low = YLeaf(YType.str, "inner-range1-low")

                    self.inner_tag_type = YLeaf(YType.enumeration, "inner-tag-type")

                    self.outer_class_of_service = YLeaf(YType.uint32, "outer-class-of-service")

                    self.outer_range1_high = YLeaf(YType.str, "outer-range1-high")

                    self.outer_range1_low = YLeaf(YType.str, "outer-range1-low")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.payload_ethertype_match = YLeaf(YType.enumeration, "payload-ethertype-match")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("additional_range1_high",
                                    "additional_range1_low",
                                    "additional_range2_high",
                                    "additional_range2_low",
                                    "additional_range3_high",
                                    "additional_range3_low",
                                    "additional_range4_high",
                                    "additional_range4_low",
                                    "additional_range5_high",
                                    "additional_range5_low",
                                    "additional_range6_high",
                                    "additional_range6_low",
                                    "additional_range7_high",
                                    "additional_range7_low",
                                    "additional_range8_high",
                                    "additional_range8_low",
                                    "exact",
                                    "ingress_destination_mac",
                                    "ingress_source_mac",
                                    "inner_class_of_service",
                                    "inner_range1_high",
                                    "inner_range1_low",
                                    "inner_tag_type",
                                    "outer_class_of_service",
                                    "outer_range1_high",
                                    "outer_range1_low",
                                    "outer_tag_type",
                                    "payload_ethertype_match") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.additional_range1_high.is_set or
                        self.additional_range1_low.is_set or
                        self.additional_range2_high.is_set or
                        self.additional_range2_low.is_set or
                        self.additional_range3_high.is_set or
                        self.additional_range3_low.is_set or
                        self.additional_range4_high.is_set or
                        self.additional_range4_low.is_set or
                        self.additional_range5_high.is_set or
                        self.additional_range5_low.is_set or
                        self.additional_range6_high.is_set or
                        self.additional_range6_low.is_set or
                        self.additional_range7_high.is_set or
                        self.additional_range7_low.is_set or
                        self.additional_range8_high.is_set or
                        self.additional_range8_low.is_set or
                        self.exact.is_set or
                        self.ingress_destination_mac.is_set or
                        self.ingress_source_mac.is_set or
                        self.inner_class_of_service.is_set or
                        self.inner_range1_high.is_set or
                        self.inner_range1_low.is_set or
                        self.inner_tag_type.is_set or
                        self.outer_class_of_service.is_set or
                        self.outer_range1_high.is_set or
                        self.outer_range1_low.is_set or
                        self.outer_tag_type.is_set or
                        self.payload_ethertype_match.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.additional_range1_high.yfilter != YFilter.not_set or
                        self.additional_range1_low.yfilter != YFilter.not_set or
                        self.additional_range2_high.yfilter != YFilter.not_set or
                        self.additional_range2_low.yfilter != YFilter.not_set or
                        self.additional_range3_high.yfilter != YFilter.not_set or
                        self.additional_range3_low.yfilter != YFilter.not_set or
                        self.additional_range4_high.yfilter != YFilter.not_set or
                        self.additional_range4_low.yfilter != YFilter.not_set or
                        self.additional_range5_high.yfilter != YFilter.not_set or
                        self.additional_range5_low.yfilter != YFilter.not_set or
                        self.additional_range6_high.yfilter != YFilter.not_set or
                        self.additional_range6_low.yfilter != YFilter.not_set or
                        self.additional_range7_high.yfilter != YFilter.not_set or
                        self.additional_range7_low.yfilter != YFilter.not_set or
                        self.additional_range8_high.yfilter != YFilter.not_set or
                        self.additional_range8_low.yfilter != YFilter.not_set or
                        self.exact.yfilter != YFilter.not_set or
                        self.ingress_destination_mac.yfilter != YFilter.not_set or
                        self.ingress_source_mac.yfilter != YFilter.not_set or
                        self.inner_class_of_service.yfilter != YFilter.not_set or
                        self.inner_range1_high.yfilter != YFilter.not_set or
                        self.inner_range1_low.yfilter != YFilter.not_set or
                        self.inner_tag_type.yfilter != YFilter.not_set or
                        self.outer_class_of_service.yfilter != YFilter.not_set or
                        self.outer_range1_high.yfilter != YFilter.not_set or
                        self.outer_range1_low.yfilter != YFilter.not_set or
                        self.outer_tag_type.yfilter != YFilter.not_set or
                        self.payload_ethertype_match.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ambiguous-encapsulation" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.additional_range1_high.is_set or self.additional_range1_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range1_high.get_name_leafdata())
                    if (self.additional_range1_low.is_set or self.additional_range1_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range1_low.get_name_leafdata())
                    if (self.additional_range2_high.is_set or self.additional_range2_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range2_high.get_name_leafdata())
                    if (self.additional_range2_low.is_set or self.additional_range2_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range2_low.get_name_leafdata())
                    if (self.additional_range3_high.is_set or self.additional_range3_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range3_high.get_name_leafdata())
                    if (self.additional_range3_low.is_set or self.additional_range3_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range3_low.get_name_leafdata())
                    if (self.additional_range4_high.is_set or self.additional_range4_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range4_high.get_name_leafdata())
                    if (self.additional_range4_low.is_set or self.additional_range4_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range4_low.get_name_leafdata())
                    if (self.additional_range5_high.is_set or self.additional_range5_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range5_high.get_name_leafdata())
                    if (self.additional_range5_low.is_set or self.additional_range5_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range5_low.get_name_leafdata())
                    if (self.additional_range6_high.is_set or self.additional_range6_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range6_high.get_name_leafdata())
                    if (self.additional_range6_low.is_set or self.additional_range6_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range6_low.get_name_leafdata())
                    if (self.additional_range7_high.is_set or self.additional_range7_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range7_high.get_name_leafdata())
                    if (self.additional_range7_low.is_set or self.additional_range7_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range7_low.get_name_leafdata())
                    if (self.additional_range8_high.is_set or self.additional_range8_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range8_high.get_name_leafdata())
                    if (self.additional_range8_low.is_set or self.additional_range8_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.additional_range8_low.get_name_leafdata())
                    if (self.exact.is_set or self.exact.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.exact.get_name_leafdata())
                    if (self.ingress_destination_mac.is_set or self.ingress_destination_mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ingress_destination_mac.get_name_leafdata())
                    if (self.ingress_source_mac.is_set or self.ingress_source_mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ingress_source_mac.get_name_leafdata())
                    if (self.inner_class_of_service.is_set or self.inner_class_of_service.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_class_of_service.get_name_leafdata())
                    if (self.inner_range1_high.is_set or self.inner_range1_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_range1_high.get_name_leafdata())
                    if (self.inner_range1_low.is_set or self.inner_range1_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_range1_low.get_name_leafdata())
                    if (self.inner_tag_type.is_set or self.inner_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inner_tag_type.get_name_leafdata())
                    if (self.outer_class_of_service.is_set or self.outer_class_of_service.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_class_of_service.get_name_leafdata())
                    if (self.outer_range1_high.is_set or self.outer_range1_high.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_range1_high.get_name_leafdata())
                    if (self.outer_range1_low.is_set or self.outer_range1_low.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_range1_low.get_name_leafdata())
                    if (self.outer_tag_type.is_set or self.outer_tag_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outer_tag_type.get_name_leafdata())
                    if (self.payload_ethertype_match.is_set or self.payload_ethertype_match.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.payload_ethertype_match.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "additional-range1-high" or name == "additional-range1-low" or name == "additional-range2-high" or name == "additional-range2-low" or name == "additional-range3-high" or name == "additional-range3-low" or name == "additional-range4-high" or name == "additional-range4-low" or name == "additional-range5-high" or name == "additional-range5-low" or name == "additional-range6-high" or name == "additional-range6-low" or name == "additional-range7-high" or name == "additional-range7-low" or name == "additional-range8-high" or name == "additional-range8-low" or name == "exact" or name == "ingress-destination-mac" or name == "ingress-source-mac" or name == "inner-class-of-service" or name == "inner-range1-high" or name == "inner-range1-low" or name == "inner-tag-type" or name == "outer-class-of-service" or name == "outer-range1-high" or name == "outer-range1-low" or name == "outer-tag-type" or name == "payload-ethertype-match"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "additional-range1-high"):
                        self.additional_range1_high = value
                        self.additional_range1_high.value_namespace = name_space
                        self.additional_range1_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range1-low"):
                        self.additional_range1_low = value
                        self.additional_range1_low.value_namespace = name_space
                        self.additional_range1_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range2-high"):
                        self.additional_range2_high = value
                        self.additional_range2_high.value_namespace = name_space
                        self.additional_range2_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range2-low"):
                        self.additional_range2_low = value
                        self.additional_range2_low.value_namespace = name_space
                        self.additional_range2_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range3-high"):
                        self.additional_range3_high = value
                        self.additional_range3_high.value_namespace = name_space
                        self.additional_range3_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range3-low"):
                        self.additional_range3_low = value
                        self.additional_range3_low.value_namespace = name_space
                        self.additional_range3_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range4-high"):
                        self.additional_range4_high = value
                        self.additional_range4_high.value_namespace = name_space
                        self.additional_range4_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range4-low"):
                        self.additional_range4_low = value
                        self.additional_range4_low.value_namespace = name_space
                        self.additional_range4_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range5-high"):
                        self.additional_range5_high = value
                        self.additional_range5_high.value_namespace = name_space
                        self.additional_range5_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range5-low"):
                        self.additional_range5_low = value
                        self.additional_range5_low.value_namespace = name_space
                        self.additional_range5_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range6-high"):
                        self.additional_range6_high = value
                        self.additional_range6_high.value_namespace = name_space
                        self.additional_range6_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range6-low"):
                        self.additional_range6_low = value
                        self.additional_range6_low.value_namespace = name_space
                        self.additional_range6_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range7-high"):
                        self.additional_range7_high = value
                        self.additional_range7_high.value_namespace = name_space
                        self.additional_range7_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range7-low"):
                        self.additional_range7_low = value
                        self.additional_range7_low.value_namespace = name_space
                        self.additional_range7_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range8-high"):
                        self.additional_range8_high = value
                        self.additional_range8_high.value_namespace = name_space
                        self.additional_range8_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "additional-range8-low"):
                        self.additional_range8_low = value
                        self.additional_range8_low.value_namespace = name_space
                        self.additional_range8_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "exact"):
                        self.exact = value
                        self.exact.value_namespace = name_space
                        self.exact.value_namespace_prefix = name_space_prefix
                    if(value_path == "ingress-destination-mac"):
                        self.ingress_destination_mac = value
                        self.ingress_destination_mac.value_namespace = name_space
                        self.ingress_destination_mac.value_namespace_prefix = name_space_prefix
                    if(value_path == "ingress-source-mac"):
                        self.ingress_source_mac = value
                        self.ingress_source_mac.value_namespace = name_space
                        self.ingress_source_mac.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-class-of-service"):
                        self.inner_class_of_service = value
                        self.inner_class_of_service.value_namespace = name_space
                        self.inner_class_of_service.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-range1-high"):
                        self.inner_range1_high = value
                        self.inner_range1_high.value_namespace = name_space
                        self.inner_range1_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-range1-low"):
                        self.inner_range1_low = value
                        self.inner_range1_low.value_namespace = name_space
                        self.inner_range1_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "inner-tag-type"):
                        self.inner_tag_type = value
                        self.inner_tag_type.value_namespace = name_space
                        self.inner_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-class-of-service"):
                        self.outer_class_of_service = value
                        self.outer_class_of_service.value_namespace = name_space
                        self.outer_class_of_service.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-range1-high"):
                        self.outer_range1_high = value
                        self.outer_range1_high.value_namespace = name_space
                        self.outer_range1_high.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-range1-low"):
                        self.outer_range1_low = value
                        self.outer_range1_low.value_namespace = name_space
                        self.outer_range1_low.value_namespace_prefix = name_space_prefix
                    if(value_path == "outer-tag-type"):
                        self.outer_tag_type = value
                        self.outer_tag_type.value_namespace = name_space
                        self.outer_tag_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "payload-ethertype-match"):
                        self.payload_ethertype_match = value
                        self.payload_ethertype_match.value_namespace = name_space
                        self.payload_ethertype_match.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.ambiguous_encapsulation is not None)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.ambiguous_encapsulation is not None and self.ambiguous_encapsulation.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:ethernet-bng" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ambiguous-encapsulation"):
                    if (self.ambiguous_encapsulation is None):
                        self.ambiguous_encapsulation = InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation()
                        self.ambiguous_encapsulation.parent = self
                        self._children_name_map["ambiguous_encapsulation"] = "ambiguous-encapsulation"
                    return self.ambiguous_encapsulation

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ambiguous-encapsulation"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MacAccounting(Entity):
            """
            MAC Accounting Configuration
            
            .. attribute:: egress
            
            	Per MAC address accounting statistics
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ingress
            
            	Per MAC address accounting statistics
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.MacAccounting, self).__init__()

                self.yang_name = "mac-accounting"
                self.yang_parent_name = "interface-configuration"

                self.egress = YLeaf(YType.empty, "egress")

                self.ingress = YLeaf(YType.empty, "ingress")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("egress",
                                "ingress") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.MacAccounting, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.MacAccounting, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.egress.is_set or
                    self.ingress.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.egress.yfilter != YFilter.not_set or
                    self.ingress.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:mac-accounting" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.egress.is_set or self.egress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.egress.get_name_leafdata())
                if (self.ingress.is_set or self.ingress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ingress.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "egress" or name == "ingress"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "egress"):
                    self.egress = value
                    self.egress.value_namespace = name_space
                    self.egress.value_namespace_prefix = name_space_prefix
                if(value_path == "ingress"):
                    self.ingress = value
                    self.ingress.value_namespace = name_space
                    self.ingress.value_namespace_prefix = name_space_prefix


        class EthernetFeatures(Entity):
            """
            Ethernet Features Configuration
            
            .. attribute:: cfm
            
            	CFM interface configuration
            	**type**\:   :py:class:`Cfm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm>`
            
            .. attribute:: ether_link_oam
            
            	Ethernet Link OAM Interface Configuration
            	**type**\:   :py:class:`EtherLinkOam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam>`
            
            .. attribute:: ether_link_oam_enable
            
            	Enable Ethernet Link OAM on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: filtering
            
            	Ingress Ethernet frame filtering
            	**type**\:   :py:class:`Filtering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.Filtering>`
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures, self).__init__()

                self.yang_name = "ethernet-features"
                self.yang_parent_name = "interface-configuration"

                self.ether_link_oam_enable = YLeaf(YType.empty, "Cisco-IOS-XR-ethernet-link-oam-cfg:ether-link-oam-enable")

                self.filtering = YLeaf(YType.enumeration, "filtering")

                self.cfm = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm()
                self.cfm.parent = self
                self._children_name_map["cfm"] = "cfm"
                self._children_yang_names.add("cfm")

                self.ether_link_oam = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam()
                self.ether_link_oam.parent = self
                self._children_name_map["ether_link_oam"] = "ether-link-oam"
                self._children_yang_names.add("ether-link-oam")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("ether_link_oam_enable",
                                "filtering") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures, self).__setattr__(name, value)


            class Cfm(Entity):
                """
                CFM interface configuration
                
                .. attribute:: ais_up
                
                	Interface specific AIS configuration
                	**type**\:   :py:class:`AisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp>`
                
                .. attribute:: domains
                
                	Domain\-specific interface configuration
                	**type**\:   :py:class:`Domains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains>`
                
                

                """

                _prefix = 'ethernet-cfm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm, self).__init__()

                    self.yang_name = "cfm"
                    self.yang_parent_name = "ethernet-features"

                    self.ais_up = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp()
                    self.ais_up.parent = self
                    self._children_name_map["ais_up"] = "ais-up"
                    self._children_yang_names.add("ais-up")

                    self.domains = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains()
                    self.domains.parent = self
                    self._children_name_map["domains"] = "domains"
                    self._children_yang_names.add("domains")


                class Domains(Entity):
                    """
                    Domain\-specific interface configuration
                    
                    .. attribute:: domain
                    
                    	Configuration for a particular Maintenance Domain
                    	**type**\: list of    :py:class:`Domain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain>`
                    
                    

                    """

                    _prefix = 'ethernet-cfm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains, self).__init__()

                        self.yang_name = "domains"
                        self.yang_parent_name = "cfm"

                        self.domain = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains, self).__setattr__(name, value)


                    class Domain(Entity):
                        """
                        Configuration for a particular Maintenance
                        Domain
                        
                        .. attribute:: domain  <key>
                        
                        	Maintenance Domain
                        	**type**\:  str
                        
                        	**length:** 1..79
                        
                        .. attribute:: mep
                        
                        	MEP Configuration
                        	**type**\:   :py:class:`Mep <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep>`
                        
                        

                        """

                        _prefix = 'ethernet-cfm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain, self).__init__()

                            self.yang_name = "domain"
                            self.yang_parent_name = "domains"

                            self.domain = YLeaf(YType.str, "domain")

                            self.mep = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"
                            self._children_yang_names.add("mep")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("domain") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain, self).__setattr__(name, value)


                        class Mep(Entity):
                            """
                            MEP Configuration
                            
                            .. attribute:: cos
                            
                            	The Class of Service bits for this MEP
                            	**type**\:  int
                            
                            	**range:** 0..7
                            
                            .. attribute:: loss_measurement_counters
                            
                            	Loss\-measurement specific configuration
                            	**type**\:   :py:class:`LossMeasurementCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: mep_properties
                            
                            	Properties for this MEP
                            	**type**\:   :py:class:`MepProperties <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: sla_profile_target_mep_ids
                            
                            	SLA specific configuration
                            	**type**\:   :py:class:`SlaProfileTargetMepIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds>`
                            
                            

                            """

                            _prefix = 'ethernet-cfm-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "domain"

                                self.cos = YLeaf(YType.uint32, "cos")

                                self.loss_measurement_counters = None
                                self._children_name_map["loss_measurement_counters"] = "loss-measurement-counters"
                                self._children_yang_names.add("loss-measurement-counters")

                                self.mep_properties = None
                                self._children_name_map["mep_properties"] = "mep-properties"
                                self._children_yang_names.add("mep-properties")

                                self.sla_profile_target_mep_ids = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds()
                                self.sla_profile_target_mep_ids.parent = self
                                self._children_name_map["sla_profile_target_mep_ids"] = "sla-profile-target-mep-ids"
                                self._children_yang_names.add("sla-profile-target-mep-ids")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("cos") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep, self).__setattr__(name, value)


                            class SlaProfileTargetMepIds(Entity):
                                """
                                SLA specific configuration
                                
                                .. attribute:: sla_profile_target_mac_address
                                
                                	Configuration for a particular SLA operation
                                	**type**\: list of    :py:class:`SlaProfileTargetMacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress>`
                                
                                .. attribute:: sla_profile_target_mep_id
                                
                                	Configuration for a particular SLA operation
                                	**type**\: list of    :py:class:`SlaProfileTargetMepId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId>`
                                
                                

                                """

                                _prefix = 'ethernet-cfm-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds, self).__init__()

                                    self.yang_name = "sla-profile-target-mep-ids"
                                    self.yang_parent_name = "mep"

                                    self.sla_profile_target_mac_address = YList(self)
                                    self.sla_profile_target_mep_id = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds, self).__setattr__(name, value)


                                class SlaProfileTargetMepId(Entity):
                                    """
                                    Configuration for a particular SLA
                                    operation
                                    
                                    .. attribute:: profile  <key>
                                    
                                    	SLA profile name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: target_mep_id  <key>
                                    
                                    	Target MEP\-ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8191
                                    
                                    

                                    """

                                    _prefix = 'ethernet-cfm-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId, self).__init__()

                                        self.yang_name = "sla-profile-target-mep-id"
                                        self.yang_parent_name = "sla-profile-target-mep-ids"

                                        self.profile = YLeaf(YType.str, "profile")

                                        self.target_mep_id = YLeaf(YType.uint32, "target-mep-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile",
                                                        "target_mep_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.profile.is_set or
                                            self.target_mep_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile.yfilter != YFilter.not_set or
                                            self.target_mep_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sla-profile-target-mep-id" + "[profile='" + self.profile.get() + "']" + "[target-mep-id='" + self.target_mep_id.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile.is_set or self.profile.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile.get_name_leafdata())
                                        if (self.target_mep_id.is_set or self.target_mep_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.target_mep_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile" or name == "target-mep-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile"):
                                            self.profile = value
                                            self.profile.value_namespace = name_space
                                            self.profile.value_namespace_prefix = name_space_prefix
                                        if(value_path == "target-mep-id"):
                                            self.target_mep_id = value
                                            self.target_mep_id.value_namespace = name_space
                                            self.target_mep_id.value_namespace_prefix = name_space_prefix


                                class SlaProfileTargetMacAddress(Entity):
                                    """
                                    Configuration for a particular SLA
                                    operation
                                    
                                    .. attribute:: profile  <key>
                                    
                                    	SLA profile name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: target_mac_address  <key>
                                    
                                    	Target MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'ethernet-cfm-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress, self).__init__()

                                        self.yang_name = "sla-profile-target-mac-address"
                                        self.yang_parent_name = "sla-profile-target-mep-ids"

                                        self.profile = YLeaf(YType.str, "profile")

                                        self.target_mac_address = YLeaf(YType.str, "target-mac-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile",
                                                        "target_mac_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.profile.is_set or
                                            self.target_mac_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile.yfilter != YFilter.not_set or
                                            self.target_mac_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sla-profile-target-mac-address" + "[profile='" + self.profile.get() + "']" + "[target-mac-address='" + self.target_mac_address.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile.is_set or self.profile.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile.get_name_leafdata())
                                        if (self.target_mac_address.is_set or self.target_mac_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.target_mac_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile" or name == "target-mac-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile"):
                                            self.profile = value
                                            self.profile.value_namespace = name_space
                                            self.profile.value_namespace_prefix = name_space_prefix
                                        if(value_path == "target-mac-address"):
                                            self.target_mac_address = value
                                            self.target_mac_address.value_namespace = name_space
                                            self.target_mac_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sla_profile_target_mac_address:
                                        if (c.has_data()):
                                            return True
                                    for c in self.sla_profile_target_mep_id:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sla_profile_target_mac_address:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.sla_profile_target_mep_id:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sla-profile-target-mep-ids" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sla-profile-target-mac-address"):
                                        for c in self.sla_profile_target_mac_address:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sla_profile_target_mac_address.append(c)
                                        return c

                                    if (child_yang_name == "sla-profile-target-mep-id"):
                                        for c in self.sla_profile_target_mep_id:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sla_profile_target_mep_id.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sla-profile-target-mac-address" or name == "sla-profile-target-mep-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class MepProperties(Entity):
                                """
                                Properties for this MEP
                                
                                .. attribute:: mep_id
                                
                                	MEP ID
                                	**type**\:  int
                                
                                	**range:** 1..8191
                                
                                	**mandatory**\: True
                                
                                .. attribute:: service
                                
                                	Service (Maintenance Association)
                                	**type**\:  str
                                
                                	**length:** 1..79
                                
                                	**mandatory**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ethernet-cfm-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties, self).__init__()

                                    self.yang_name = "mep-properties"
                                    self.yang_parent_name = "mep"
                                    self.is_presence_container = True

                                    self.mep_id = YLeaf(YType.uint32, "mep-id")

                                    self.service = YLeaf(YType.str, "service")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mep_id",
                                                    "service") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.mep_id.is_set or
                                        self.service.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mep_id.yfilter != YFilter.not_set or
                                        self.service.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mep-properties" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mep_id.is_set or self.mep_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mep_id.get_name_leafdata())
                                    if (self.service.is_set or self.service.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mep-id" or name == "service"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mep-id"):
                                        self.mep_id = value
                                        self.mep_id.value_namespace = name_space
                                        self.mep_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service"):
                                        self.service = value
                                        self.service.value_namespace = name_space
                                        self.service.value_namespace_prefix = name_space_prefix


                            class LossMeasurementCounters(Entity):
                                """
                                Loss\-measurement specific configuration
                                
                                .. attribute:: cfg_type
                                
                                	Aggregate, List, or Range
                                	**type**\:   :py:class:`CfmLmCountersCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_cfm_cfg.CfmLmCountersCfg>`
                                
                                	**mandatory**\: True
                                
                                .. attribute:: cos0
                                
                                	CoS bits for per\-CoS counters \- start of range or list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos1
                                
                                	CoS bits for per\-CoS counters \- end of range or list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos2
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos3
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos4
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos5
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos6
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos7
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ethernet-cfm-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters, self).__init__()

                                    self.yang_name = "loss-measurement-counters"
                                    self.yang_parent_name = "mep"
                                    self.is_presence_container = True

                                    self.cfg_type = YLeaf(YType.enumeration, "cfg-type")

                                    self.cos0 = YLeaf(YType.uint32, "cos0")

                                    self.cos1 = YLeaf(YType.uint32, "cos1")

                                    self.cos2 = YLeaf(YType.uint32, "cos2")

                                    self.cos3 = YLeaf(YType.uint32, "cos3")

                                    self.cos4 = YLeaf(YType.uint32, "cos4")

                                    self.cos5 = YLeaf(YType.uint32, "cos5")

                                    self.cos6 = YLeaf(YType.uint32, "cos6")

                                    self.cos7 = YLeaf(YType.uint32, "cos7")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("cfg_type",
                                                    "cos0",
                                                    "cos1",
                                                    "cos2",
                                                    "cos3",
                                                    "cos4",
                                                    "cos5",
                                                    "cos6",
                                                    "cos7") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.cfg_type.is_set or
                                        self.cos0.is_set or
                                        self.cos1.is_set or
                                        self.cos2.is_set or
                                        self.cos3.is_set or
                                        self.cos4.is_set or
                                        self.cos5.is_set or
                                        self.cos6.is_set or
                                        self.cos7.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.cfg_type.yfilter != YFilter.not_set or
                                        self.cos0.yfilter != YFilter.not_set or
                                        self.cos1.yfilter != YFilter.not_set or
                                        self.cos2.yfilter != YFilter.not_set or
                                        self.cos3.yfilter != YFilter.not_set or
                                        self.cos4.yfilter != YFilter.not_set or
                                        self.cos5.yfilter != YFilter.not_set or
                                        self.cos6.yfilter != YFilter.not_set or
                                        self.cos7.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "loss-measurement-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.cfg_type.is_set or self.cfg_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cfg_type.get_name_leafdata())
                                    if (self.cos0.is_set or self.cos0.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos0.get_name_leafdata())
                                    if (self.cos1.is_set or self.cos1.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos1.get_name_leafdata())
                                    if (self.cos2.is_set or self.cos2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos2.get_name_leafdata())
                                    if (self.cos3.is_set or self.cos3.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos3.get_name_leafdata())
                                    if (self.cos4.is_set or self.cos4.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos4.get_name_leafdata())
                                    if (self.cos5.is_set or self.cos5.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos5.get_name_leafdata())
                                    if (self.cos6.is_set or self.cos6.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos6.get_name_leafdata())
                                    if (self.cos7.is_set or self.cos7.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cos7.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cfg-type" or name == "cos0" or name == "cos1" or name == "cos2" or name == "cos3" or name == "cos4" or name == "cos5" or name == "cos6" or name == "cos7"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "cfg-type"):
                                        self.cfg_type = value
                                        self.cfg_type.value_namespace = name_space
                                        self.cfg_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos0"):
                                        self.cos0 = value
                                        self.cos0.value_namespace = name_space
                                        self.cos0.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos1"):
                                        self.cos1 = value
                                        self.cos1.value_namespace = name_space
                                        self.cos1.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos2"):
                                        self.cos2 = value
                                        self.cos2.value_namespace = name_space
                                        self.cos2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos3"):
                                        self.cos3 = value
                                        self.cos3.value_namespace = name_space
                                        self.cos3.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos4"):
                                        self.cos4 = value
                                        self.cos4.value_namespace = name_space
                                        self.cos4.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos5"):
                                        self.cos5 = value
                                        self.cos5.value_namespace = name_space
                                        self.cos5.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos6"):
                                        self.cos6 = value
                                        self.cos6.value_namespace = name_space
                                        self.cos6.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cos7"):
                                        self.cos7 = value
                                        self.cos7.value_namespace = name_space
                                        self.cos7.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.cos.is_set or
                                    (self.sla_profile_target_mep_ids is not None and self.sla_profile_target_mep_ids.has_data()) or
                                    (self.loss_measurement_counters is not None) or
                                    (self.mep_properties is not None))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.cos.yfilter != YFilter.not_set or
                                    (self.loss_measurement_counters is not None and self.loss_measurement_counters.has_operation()) or
                                    (self.mep_properties is not None and self.mep_properties.has_operation()) or
                                    (self.sla_profile_target_mep_ids is not None and self.sla_profile_target_mep_ids.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mep" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.cos.is_set or self.cos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cos.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "loss-measurement-counters"):
                                    if (self.loss_measurement_counters is None):
                                        self.loss_measurement_counters = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters()
                                        self.loss_measurement_counters.parent = self
                                        self._children_name_map["loss_measurement_counters"] = "loss-measurement-counters"
                                    return self.loss_measurement_counters

                                if (child_yang_name == "mep-properties"):
                                    if (self.mep_properties is None):
                                        self.mep_properties = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties()
                                        self.mep_properties.parent = self
                                        self._children_name_map["mep_properties"] = "mep-properties"
                                    return self.mep_properties

                                if (child_yang_name == "sla-profile-target-mep-ids"):
                                    if (self.sla_profile_target_mep_ids is None):
                                        self.sla_profile_target_mep_ids = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds()
                                        self.sla_profile_target_mep_ids.parent = self
                                        self._children_name_map["sla_profile_target_mep_ids"] = "sla-profile-target-mep-ids"
                                    return self.sla_profile_target_mep_ids

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "loss-measurement-counters" or name == "mep-properties" or name == "sla-profile-target-mep-ids" or name == "cos"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "cos"):
                                    self.cos = value
                                    self.cos.value_namespace = name_space
                                    self.cos.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.domain.is_set or
                                (self.mep is not None and self.mep.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.domain.yfilter != YFilter.not_set or
                                (self.mep is not None and self.mep.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "domain" + "[domain='" + self.domain.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.domain.is_set or self.domain.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.domain.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mep"):
                                if (self.mep is None):
                                    self.mep = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep()
                                    self.mep.parent = self
                                    self._children_name_map["mep"] = "mep"
                                return self.mep

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mep" or name == "domain"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "domain"):
                                self.domain = value
                                self.domain.value_namespace = name_space
                                self.domain.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.domain:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.domain:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "domains" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "domain"):
                            for c in self.domain:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.domain.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "domain"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AisUp(Entity):
                    """
                    Interface specific AIS configuration
                    
                    .. attribute:: transmission
                    
                    	AIS transmission configuration
                    	**type**\:   :py:class:`Transmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ethernet-cfm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp, self).__init__()

                        self.yang_name = "ais-up"
                        self.yang_parent_name = "cfm"

                        self.transmission = None
                        self._children_name_map["transmission"] = "transmission"
                        self._children_yang_names.add("transmission")


                    class Transmission(Entity):
                        """
                        AIS transmission configuration
                        
                        .. attribute:: ais_interval
                        
                        	AIS Interval
                        	**type**\:   :py:class:`CfmAisInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_cfm_datatypes.CfmAisInterval>`
                        
                        .. attribute:: cos
                        
                        	Class of Service bits
                        	**type**\:  int
                        
                        	**range:** 0..7
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ethernet-cfm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission, self).__init__()

                            self.yang_name = "transmission"
                            self.yang_parent_name = "ais-up"
                            self.is_presence_container = True

                            self.ais_interval = YLeaf(YType.enumeration, "ais-interval")

                            self.cos = YLeaf(YType.uint32, "cos")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ais_interval",
                                            "cos") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ais_interval.is_set or
                                self.cos.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ais_interval.yfilter != YFilter.not_set or
                                self.cos.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "transmission" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ais_interval.is_set or self.ais_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ais_interval.get_name_leafdata())
                            if (self.cos.is_set or self.cos.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cos.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ais-interval" or name == "cos"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ais-interval"):
                                self.ais_interval = value
                                self.ais_interval.value_namespace = name_space
                                self.ais_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "cos"):
                                self.cos = value
                                self.cos.value_namespace = name_space
                                self.cos.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.transmission is not None)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.transmission is not None and self.transmission.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ais-up" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "transmission"):
                            if (self.transmission is None):
                                self.transmission = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission()
                                self.transmission.parent = self
                                self._children_name_map["transmission"] = "transmission"
                            return self.transmission

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "transmission"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.ais_up is not None and self.ais_up.has_data()) or
                        (self.domains is not None and self.domains.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ais_up is not None and self.ais_up.has_operation()) or
                        (self.domains is not None and self.domains.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-ethernet-cfm-cfg:cfm" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ais-up"):
                        if (self.ais_up is None):
                            self.ais_up = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp()
                            self.ais_up.parent = self
                            self._children_name_map["ais_up"] = "ais-up"
                        return self.ais_up

                    if (child_yang_name == "domains"):
                        if (self.domains is None):
                            self.domains = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains()
                            self.domains.parent = self
                            self._children_name_map["domains"] = "domains"
                        return self.domains

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ais-up" or name == "domains"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EtherLinkOam(Entity):
                """
                Ethernet Link OAM Interface Configuration
                
                .. attribute:: action
                
                	Configure action parameters
                	**type**\:   :py:class:`Action <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action>`
                
                .. attribute:: hello_interval
                
                	Possible Ethernet Link OAM hello intervals
                	**type**\:   :py:class:`EtherLinkOamHelloIntervalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamHelloIntervalEnum>`
                
                .. attribute:: link_monitoring
                
                	Configure link monitor parameters
                	**type**\:   :py:class:`LinkMonitoring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring>`
                
                .. attribute:: mib_retrieval
                
                	Enable or disable MIB retrieval
                	**type**\:  bool
                
                .. attribute:: mode
                
                	Possible Ethernet Link OAM modes
                	**type**\:   :py:class:`EtherLinkOamModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamModeEnum>`
                
                .. attribute:: profile_name
                
                	Set the profile to use on the interface
                	**type**\:  str
                
                .. attribute:: remote_loopback
                
                	Enable or disable remote loopback
                	**type**\:  bool
                
                .. attribute:: require_remote
                
                	Configure remote requirement parameters
                	**type**\:   :py:class:`RequireRemote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote>`
                
                .. attribute:: timeout
                
                	Connection timeout period in number of lost heartbeats
                	**type**\:  int
                
                	**range:** 2..30
                
                .. attribute:: udlf
                
                	Enable or disable uni\-directional link\-fault detection
                	**type**\:  bool
                
                

                """

                _prefix = 'ethernet-link-oam-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam, self).__init__()

                    self.yang_name = "ether-link-oam"
                    self.yang_parent_name = "ethernet-features"

                    self.hello_interval = YLeaf(YType.enumeration, "hello-interval")

                    self.mib_retrieval = YLeaf(YType.boolean, "mib-retrieval")

                    self.mode = YLeaf(YType.enumeration, "mode")

                    self.profile_name = YLeaf(YType.str, "profile-name")

                    self.remote_loopback = YLeaf(YType.boolean, "remote-loopback")

                    self.timeout = YLeaf(YType.uint32, "timeout")

                    self.udlf = YLeaf(YType.boolean, "udlf")

                    self.action = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._children_yang_names.add("action")

                    self.link_monitoring = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring()
                    self.link_monitoring.parent = self
                    self._children_name_map["link_monitoring"] = "link-monitoring"
                    self._children_yang_names.add("link-monitoring")

                    self.require_remote = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote()
                    self.require_remote.parent = self
                    self._children_name_map["require_remote"] = "require-remote"
                    self._children_yang_names.add("require-remote")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("hello_interval",
                                    "mib_retrieval",
                                    "mode",
                                    "profile_name",
                                    "remote_loopback",
                                    "timeout",
                                    "udlf") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam, self).__setattr__(name, value)


                class Action(Entity):
                    """
                    Configure action parameters
                    
                    .. attribute:: capabilities_conflict
                    
                    	Action to perform when a capabilities conflict occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: critical_event
                    
                    	Action to perform when a critical event occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnum>`
                    
                    .. attribute:: discovery_timeout
                    
                    	Action to perform when discovery timeout occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: dying_gasp
                    
                    	Action to perform when a dying gasp occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnum>`
                    
                    .. attribute:: high_threshold
                    
                    	Action to perform when a high\-threshold event occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnum>`
                    
                    .. attribute:: link_fault
                    
                    	Action to perform when a link fault occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: remote_loopback
                    
                    	Action to perform when remote loopback is entered or exited
                    	**type**\:   :py:class:`EtherLinkOamEventActionPrimEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionPrimEnum>`
                    
                    .. attribute:: session_down
                    
                    	Action to perform when a session comes down
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: session_up
                    
                    	Action to perform when a session comes up
                    	**type**\:   :py:class:`EtherLinkOamEventActionPrimEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionPrimEnum>`
                    
                    .. attribute:: wiring_conflict
                    
                    	Action to perform when a wiring conflict occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    

                    """

                    _prefix = 'ethernet-link-oam-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "ether-link-oam"

                        self.capabilities_conflict = YLeaf(YType.enumeration, "capabilities-conflict")

                        self.critical_event = YLeaf(YType.enumeration, "critical-event")

                        self.discovery_timeout = YLeaf(YType.enumeration, "discovery-timeout")

                        self.dying_gasp = YLeaf(YType.enumeration, "dying-gasp")

                        self.high_threshold = YLeaf(YType.enumeration, "high-threshold")

                        self.link_fault = YLeaf(YType.enumeration, "link-fault")

                        self.remote_loopback = YLeaf(YType.enumeration, "remote-loopback")

                        self.session_down = YLeaf(YType.enumeration, "session-down")

                        self.session_up = YLeaf(YType.enumeration, "session-up")

                        self.wiring_conflict = YLeaf(YType.enumeration, "wiring-conflict")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("capabilities_conflict",
                                        "critical_event",
                                        "discovery_timeout",
                                        "dying_gasp",
                                        "high_threshold",
                                        "link_fault",
                                        "remote_loopback",
                                        "session_down",
                                        "session_up",
                                        "wiring_conflict") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.capabilities_conflict.is_set or
                            self.critical_event.is_set or
                            self.discovery_timeout.is_set or
                            self.dying_gasp.is_set or
                            self.high_threshold.is_set or
                            self.link_fault.is_set or
                            self.remote_loopback.is_set or
                            self.session_down.is_set or
                            self.session_up.is_set or
                            self.wiring_conflict.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.capabilities_conflict.yfilter != YFilter.not_set or
                            self.critical_event.yfilter != YFilter.not_set or
                            self.discovery_timeout.yfilter != YFilter.not_set or
                            self.dying_gasp.yfilter != YFilter.not_set or
                            self.high_threshold.yfilter != YFilter.not_set or
                            self.link_fault.yfilter != YFilter.not_set or
                            self.remote_loopback.yfilter != YFilter.not_set or
                            self.session_down.yfilter != YFilter.not_set or
                            self.session_up.yfilter != YFilter.not_set or
                            self.wiring_conflict.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "action" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.capabilities_conflict.is_set or self.capabilities_conflict.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.capabilities_conflict.get_name_leafdata())
                        if (self.critical_event.is_set or self.critical_event.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.critical_event.get_name_leafdata())
                        if (self.discovery_timeout.is_set or self.discovery_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.discovery_timeout.get_name_leafdata())
                        if (self.dying_gasp.is_set or self.dying_gasp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dying_gasp.get_name_leafdata())
                        if (self.high_threshold.is_set or self.high_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.high_threshold.get_name_leafdata())
                        if (self.link_fault.is_set or self.link_fault.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_fault.get_name_leafdata())
                        if (self.remote_loopback.is_set or self.remote_loopback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_loopback.get_name_leafdata())
                        if (self.session_down.is_set or self.session_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_down.get_name_leafdata())
                        if (self.session_up.is_set or self.session_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_up.get_name_leafdata())
                        if (self.wiring_conflict.is_set or self.wiring_conflict.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wiring_conflict.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "capabilities-conflict" or name == "critical-event" or name == "discovery-timeout" or name == "dying-gasp" or name == "high-threshold" or name == "link-fault" or name == "remote-loopback" or name == "session-down" or name == "session-up" or name == "wiring-conflict"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "capabilities-conflict"):
                            self.capabilities_conflict = value
                            self.capabilities_conflict.value_namespace = name_space
                            self.capabilities_conflict.value_namespace_prefix = name_space_prefix
                        if(value_path == "critical-event"):
                            self.critical_event = value
                            self.critical_event.value_namespace = name_space
                            self.critical_event.value_namespace_prefix = name_space_prefix
                        if(value_path == "discovery-timeout"):
                            self.discovery_timeout = value
                            self.discovery_timeout.value_namespace = name_space
                            self.discovery_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "dying-gasp"):
                            self.dying_gasp = value
                            self.dying_gasp.value_namespace = name_space
                            self.dying_gasp.value_namespace_prefix = name_space_prefix
                        if(value_path == "high-threshold"):
                            self.high_threshold = value
                            self.high_threshold.value_namespace = name_space
                            self.high_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-fault"):
                            self.link_fault = value
                            self.link_fault.value_namespace = name_space
                            self.link_fault.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-loopback"):
                            self.remote_loopback = value
                            self.remote_loopback.value_namespace = name_space
                            self.remote_loopback.value_namespace_prefix = name_space_prefix
                        if(value_path == "session-down"):
                            self.session_down = value
                            self.session_down.value_namespace = name_space
                            self.session_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "session-up"):
                            self.session_up = value
                            self.session_up.value_namespace = name_space
                            self.session_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "wiring-conflict"):
                            self.wiring_conflict = value
                            self.wiring_conflict.value_namespace = name_space
                            self.wiring_conflict.value_namespace_prefix = name_space_prefix


                class RequireRemote(Entity):
                    """
                    Configure remote requirement parameters
                    
                    .. attribute:: link_monitoring
                    
                    	Enable or disable link monitoring peer requirement
                    	**type**\:  bool
                    
                    .. attribute:: mib_retrieval
                    
                    	Enable or disable MIB retrieval peer requirement
                    	**type**\:  bool
                    
                    .. attribute:: mode
                    
                    	Possible required peer modes
                    	**type**\:   :py:class:`EtherLinkOamRequireModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamRequireModeEnum>`
                    
                    .. attribute:: remote_loopback
                    
                    	Enable or disable remote loopback peer requirement
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ethernet-link-oam-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote, self).__init__()

                        self.yang_name = "require-remote"
                        self.yang_parent_name = "ether-link-oam"

                        self.link_monitoring = YLeaf(YType.boolean, "link-monitoring")

                        self.mib_retrieval = YLeaf(YType.boolean, "mib-retrieval")

                        self.mode = YLeaf(YType.enumeration, "mode")

                        self.remote_loopback = YLeaf(YType.boolean, "remote-loopback")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("link_monitoring",
                                        "mib_retrieval",
                                        "mode",
                                        "remote_loopback") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.link_monitoring.is_set or
                            self.mib_retrieval.is_set or
                            self.mode.is_set or
                            self.remote_loopback.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.link_monitoring.yfilter != YFilter.not_set or
                            self.mib_retrieval.yfilter != YFilter.not_set or
                            self.mode.yfilter != YFilter.not_set or
                            self.remote_loopback.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "require-remote" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.link_monitoring.is_set or self.link_monitoring.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_monitoring.get_name_leafdata())
                        if (self.mib_retrieval.is_set or self.mib_retrieval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mib_retrieval.get_name_leafdata())
                        if (self.mode.is_set or self.mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mode.get_name_leafdata())
                        if (self.remote_loopback.is_set or self.remote_loopback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_loopback.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "link-monitoring" or name == "mib-retrieval" or name == "mode" or name == "remote-loopback"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "link-monitoring"):
                            self.link_monitoring = value
                            self.link_monitoring.value_namespace = name_space
                            self.link_monitoring.value_namespace_prefix = name_space_prefix
                        if(value_path == "mib-retrieval"):
                            self.mib_retrieval = value
                            self.mib_retrieval.value_namespace = name_space
                            self.mib_retrieval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mode"):
                            self.mode = value
                            self.mode.value_namespace = name_space
                            self.mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-loopback"):
                            self.remote_loopback = value
                            self.remote_loopback.value_namespace = name_space
                            self.remote_loopback.value_namespace_prefix = name_space_prefix


                class LinkMonitoring(Entity):
                    """
                    Configure link monitor parameters
                    
                    .. attribute:: frame
                    
                    	Frame event configuration
                    	**type**\:   :py:class:`Frame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame>`
                    
                    .. attribute:: frame_period
                    
                    	Frame\-period event configuration
                    	**type**\:   :py:class:`FramePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod>`
                    
                    .. attribute:: frame_seconds
                    
                    	Frame\-seconds event configuration
                    	**type**\:   :py:class:`FrameSeconds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds>`
                    
                    .. attribute:: monitoring
                    
                    	Enable or disable monitoring
                    	**type**\:  bool
                    
                    .. attribute:: symbol_period
                    
                    	Symbol\-period event configuration
                    	**type**\:   :py:class:`SymbolPeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod>`
                    
                    

                    """

                    _prefix = 'ethernet-link-oam-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring, self).__init__()

                        self.yang_name = "link-monitoring"
                        self.yang_parent_name = "ether-link-oam"

                        self.monitoring = YLeaf(YType.boolean, "monitoring")

                        self.frame = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame()
                        self.frame.parent = self
                        self._children_name_map["frame"] = "frame"
                        self._children_yang_names.add("frame")

                        self.frame_period = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod()
                        self.frame_period.parent = self
                        self._children_name_map["frame_period"] = "frame-period"
                        self._children_yang_names.add("frame-period")

                        self.frame_seconds = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds()
                        self.frame_seconds.parent = self
                        self._children_name_map["frame_seconds"] = "frame-seconds"
                        self._children_yang_names.add("frame-seconds")

                        self.symbol_period = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod()
                        self.symbol_period.parent = self
                        self._children_name_map["symbol_period"] = "symbol-period"
                        self._children_yang_names.add("symbol-period")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("monitoring") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring, self).__setattr__(name, value)


                    class SymbolPeriod(Entity):
                        """
                        Symbol\-period event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for symbol\-period events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for symbol\-period events
                        	**type**\:   :py:class:`Window <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod, self).__init__()

                            self.yang_name = "symbol-period"
                            self.yang_parent_name = "link-monitoring"

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")

                            self.window = None
                            self._children_name_map["window"] = "window"
                            self._children_yang_names.add("window")


                        class Window(Entity):
                            """
                            Window size configuration for symbol\-period
                            events
                            
                            .. attribute:: multiplier
                            
                            	The multiplier to use for this window (only valid if 'Units' is Symbols and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: units
                            
                            	Units to use for this window
                            	**type**\:   :py:class:`EtherLinkOamWindowUnitsSymbolsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamWindowUnitsSymbolsEnum>`
                            
                            	**mandatory**\: True
                            
                            .. attribute:: window
                            
                            	Size of the symbol\-period window
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window, self).__init__()

                                self.yang_name = "window"
                                self.yang_parent_name = "symbol-period"
                                self.is_presence_container = True

                                self.multiplier = YLeaf(YType.enumeration, "multiplier")

                                self.units = YLeaf(YType.enumeration, "units")

                                self.window = YLeaf(YType.uint32, "window")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("multiplier",
                                                "units",
                                                "window") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.multiplier.is_set or
                                    self.units.is_set or
                                    self.window.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.multiplier.yfilter != YFilter.not_set or
                                    self.units.yfilter != YFilter.not_set or
                                    self.window.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "window" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier.get_name_leafdata())
                                if (self.units.is_set or self.units.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.units.get_name_leafdata())
                                if (self.window.is_set or self.window.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.window.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multiplier" or name == "units" or name == "window"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "multiplier"):
                                    self.multiplier = value
                                    self.multiplier.value_namespace = name_space
                                    self.multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "units"):
                                    self.units = value
                                    self.units.value_namespace = name_space
                                    self.units.value_namespace_prefix = name_space_prefix
                                if(value_path == "window"):
                                    self.window = value
                                    self.window.value_namespace = name_space
                                    self.window.value_namespace_prefix = name_space_prefix


                        class Threshold(Entity):
                            """
                            Threshold configuration for symbol\-period
                            events
                            
                            .. attribute:: multiplier_high
                            
                            	The multiplier to use for the high threshold (only valid if 'Units' is Symbols and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            .. attribute:: multiplier_low
                            
                            	The multiplier to use for the low threshold (only valid if 'Units' is Symbols and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for symbol\-period
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for symbol\-period
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**default value**\: 1
                            
                            .. attribute:: units
                            
                            	The units to use for these thresholds
                            	**type**\:   :py:class:`EtherLinkOamThresholdUnitsSymbolsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdUnitsSymbolsEnum>`
                            
                            	**default value**\: symbols
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "symbol-period"

                                self.multiplier_high = YLeaf(YType.enumeration, "multiplier-high")

                                self.multiplier_low = YLeaf(YType.enumeration, "multiplier-low")

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")

                                self.units = YLeaf(YType.enumeration, "units")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("multiplier_high",
                                                "multiplier_low",
                                                "threshold_high",
                                                "threshold_low",
                                                "units") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.multiplier_high.is_set or
                                    self.multiplier_low.is_set or
                                    self.threshold_high.is_set or
                                    self.threshold_low.is_set or
                                    self.units.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.multiplier_high.yfilter != YFilter.not_set or
                                    self.multiplier_low.yfilter != YFilter.not_set or
                                    self.threshold_high.yfilter != YFilter.not_set or
                                    self.threshold_low.yfilter != YFilter.not_set or
                                    self.units.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "threshold" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.multiplier_high.is_set or self.multiplier_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier_high.get_name_leafdata())
                                if (self.multiplier_low.is_set or self.multiplier_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier_low.get_name_leafdata())
                                if (self.threshold_high.is_set or self.threshold_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_high.get_name_leafdata())
                                if (self.threshold_low.is_set or self.threshold_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_low.get_name_leafdata())
                                if (self.units.is_set or self.units.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.units.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multiplier-high" or name == "multiplier-low" or name == "threshold-high" or name == "threshold-low" or name == "units"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "multiplier-high"):
                                    self.multiplier_high = value
                                    self.multiplier_high.value_namespace = name_space
                                    self.multiplier_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "multiplier-low"):
                                    self.multiplier_low = value
                                    self.multiplier_low.value_namespace = name_space
                                    self.multiplier_low.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-high"):
                                    self.threshold_high = value
                                    self.threshold_high.value_namespace = name_space
                                    self.threshold_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-low"):
                                    self.threshold_low = value
                                    self.threshold_low.value_namespace = name_space
                                    self.threshold_low.value_namespace_prefix = name_space_prefix
                                if(value_path == "units"):
                                    self.units = value
                                    self.units.value_namespace = name_space
                                    self.units.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.threshold is not None and self.threshold.has_data()) or
                                (self.window is not None))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.threshold is not None and self.threshold.has_operation()) or
                                (self.window is not None and self.window.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "symbol-period" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "threshold"):
                                if (self.threshold is None):
                                    self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                return self.threshold

                            if (child_yang_name == "window"):
                                if (self.window is None):
                                    self.window = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window()
                                    self.window.parent = self
                                    self._children_name_map["window"] = "window"
                                return self.window

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "threshold" or name == "window"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class FramePeriod(Entity):
                        """
                        Frame\-period event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for frame\-period events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for frame\-period events
                        	**type**\:   :py:class:`Window <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod, self).__init__()

                            self.yang_name = "frame-period"
                            self.yang_parent_name = "link-monitoring"

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")

                            self.window = None
                            self._children_name_map["window"] = "window"
                            self._children_yang_names.add("window")


                        class Window(Entity):
                            """
                            Window size configuration for frame\-period
                            events
                            
                            .. attribute:: multiplier
                            
                            	The multiplier to use for this window (only valid if 'Units' is Frames and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: units
                            
                            	The units to use for this window
                            	**type**\:   :py:class:`EtherLinkOamWindowUnitsFramesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamWindowUnitsFramesEnum>`
                            
                            	**mandatory**\: True
                            
                            .. attribute:: window
                            
                            	Size of the frame\-period window
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window, self).__init__()

                                self.yang_name = "window"
                                self.yang_parent_name = "frame-period"
                                self.is_presence_container = True

                                self.multiplier = YLeaf(YType.enumeration, "multiplier")

                                self.units = YLeaf(YType.enumeration, "units")

                                self.window = YLeaf(YType.uint32, "window")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("multiplier",
                                                "units",
                                                "window") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.multiplier.is_set or
                                    self.units.is_set or
                                    self.window.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.multiplier.yfilter != YFilter.not_set or
                                    self.units.yfilter != YFilter.not_set or
                                    self.window.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "window" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier.get_name_leafdata())
                                if (self.units.is_set or self.units.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.units.get_name_leafdata())
                                if (self.window.is_set or self.window.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.window.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multiplier" or name == "units" or name == "window"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "multiplier"):
                                    self.multiplier = value
                                    self.multiplier.value_namespace = name_space
                                    self.multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "units"):
                                    self.units = value
                                    self.units.value_namespace = name_space
                                    self.units.value_namespace_prefix = name_space_prefix
                                if(value_path == "window"):
                                    self.window = value
                                    self.window.value_namespace = name_space
                                    self.window.value_namespace_prefix = name_space_prefix


                        class Threshold(Entity):
                            """
                            Threshold configuration for frame\-period
                            events
                            
                            .. attribute:: multiplier_high
                            
                            	The multiplier to use for the high threshold (only valid if 'Units' is Frames and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            .. attribute:: multiplier_low
                            
                            	The multiplier to use for the low threshold (only valid if 'Units' is Frames and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for frame\-period events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for frame\-period events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**default value**\: 1
                            
                            .. attribute:: units
                            
                            	The units to use for these thresholds
                            	**type**\:   :py:class:`EtherLinkOamThresholdUnitsFramesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdUnitsFramesEnum>`
                            
                            	**default value**\: ppm
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "frame-period"

                                self.multiplier_high = YLeaf(YType.enumeration, "multiplier-high")

                                self.multiplier_low = YLeaf(YType.enumeration, "multiplier-low")

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")

                                self.units = YLeaf(YType.enumeration, "units")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("multiplier_high",
                                                "multiplier_low",
                                                "threshold_high",
                                                "threshold_low",
                                                "units") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.multiplier_high.is_set or
                                    self.multiplier_low.is_set or
                                    self.threshold_high.is_set or
                                    self.threshold_low.is_set or
                                    self.units.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.multiplier_high.yfilter != YFilter.not_set or
                                    self.multiplier_low.yfilter != YFilter.not_set or
                                    self.threshold_high.yfilter != YFilter.not_set or
                                    self.threshold_low.yfilter != YFilter.not_set or
                                    self.units.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "threshold" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.multiplier_high.is_set or self.multiplier_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier_high.get_name_leafdata())
                                if (self.multiplier_low.is_set or self.multiplier_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier_low.get_name_leafdata())
                                if (self.threshold_high.is_set or self.threshold_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_high.get_name_leafdata())
                                if (self.threshold_low.is_set or self.threshold_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_low.get_name_leafdata())
                                if (self.units.is_set or self.units.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.units.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multiplier-high" or name == "multiplier-low" or name == "threshold-high" or name == "threshold-low" or name == "units"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "multiplier-high"):
                                    self.multiplier_high = value
                                    self.multiplier_high.value_namespace = name_space
                                    self.multiplier_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "multiplier-low"):
                                    self.multiplier_low = value
                                    self.multiplier_low.value_namespace = name_space
                                    self.multiplier_low.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-high"):
                                    self.threshold_high = value
                                    self.threshold_high.value_namespace = name_space
                                    self.threshold_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-low"):
                                    self.threshold_low = value
                                    self.threshold_low.value_namespace = name_space
                                    self.threshold_low.value_namespace_prefix = name_space_prefix
                                if(value_path == "units"):
                                    self.units = value
                                    self.units.value_namespace = name_space
                                    self.units.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.threshold is not None and self.threshold.has_data()) or
                                (self.window is not None))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.threshold is not None and self.threshold.has_operation()) or
                                (self.window is not None and self.window.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "frame-period" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "threshold"):
                                if (self.threshold is None):
                                    self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                return self.threshold

                            if (child_yang_name == "window"):
                                if (self.window is None):
                                    self.window = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window()
                                    self.window.parent = self
                                    self._children_name_map["window"] = "window"
                                return self.window

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "threshold" or name == "window"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class FrameSeconds(Entity):
                        """
                        Frame\-seconds event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for frame\-seconds events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for frame\-seconds events
                        	**type**\:  int
                        
                        	**range:** 10000..900000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 60000
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds, self).__init__()

                            self.yang_name = "frame-seconds"
                            self.yang_parent_name = "link-monitoring"

                            self.window = YLeaf(YType.uint32, "window")

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("window") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds, self).__setattr__(name, value)


                        class Threshold(Entity):
                            """
                            Threshold configuration for frame\-seconds
                            events
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for frame\-seconds events
                            	**type**\:  int
                            
                            	**range:** 1..900
                            
                            	**units**\: second
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for frame\-seconds events
                            	**type**\:  int
                            
                            	**range:** 1..900
                            
                            	**units**\: second
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "frame-seconds"

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("threshold_high",
                                                "threshold_low") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.threshold_high.is_set or
                                    self.threshold_low.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.threshold_high.yfilter != YFilter.not_set or
                                    self.threshold_low.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "threshold" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.threshold_high.is_set or self.threshold_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_high.get_name_leafdata())
                                if (self.threshold_low.is_set or self.threshold_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_low.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "threshold-high" or name == "threshold-low"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "threshold-high"):
                                    self.threshold_high = value
                                    self.threshold_high.value_namespace = name_space
                                    self.threshold_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-low"):
                                    self.threshold_low = value
                                    self.threshold_low.value_namespace = name_space
                                    self.threshold_low.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.window.is_set or
                                (self.threshold is not None and self.threshold.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.window.yfilter != YFilter.not_set or
                                (self.threshold is not None and self.threshold.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "frame-seconds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.window.is_set or self.window.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.window.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "threshold"):
                                if (self.threshold is None):
                                    self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                return self.threshold

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "threshold" or name == "window"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "window"):
                                self.window = value
                                self.window.value_namespace = name_space
                                self.window.value_namespace_prefix = name_space_prefix


                    class Frame(Entity):
                        """
                        Frame event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for frame events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for frame events
                        	**type**\:  int
                        
                        	**range:** 1000..60000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 1000
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame, self).__init__()

                            self.yang_name = "frame"
                            self.yang_parent_name = "link-monitoring"

                            self.window = YLeaf(YType.uint32, "window")

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("window") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame, self).__setattr__(name, value)


                        class Threshold(Entity):
                            """
                            Threshold configuration for frame events
                            
                            .. attribute:: multiplier_high
                            
                            	The multiplier to use for the high threshold (treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            .. attribute:: multiplier_low
                            
                            	The multiplier to use for the low threshold (treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for frame events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for frame events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "frame"

                                self.multiplier_high = YLeaf(YType.enumeration, "multiplier-high")

                                self.multiplier_low = YLeaf(YType.enumeration, "multiplier-low")

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("multiplier_high",
                                                "multiplier_low",
                                                "threshold_high",
                                                "threshold_low") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.multiplier_high.is_set or
                                    self.multiplier_low.is_set or
                                    self.threshold_high.is_set or
                                    self.threshold_low.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.multiplier_high.yfilter != YFilter.not_set or
                                    self.multiplier_low.yfilter != YFilter.not_set or
                                    self.threshold_high.yfilter != YFilter.not_set or
                                    self.threshold_low.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "threshold" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.multiplier_high.is_set or self.multiplier_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier_high.get_name_leafdata())
                                if (self.multiplier_low.is_set or self.multiplier_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier_low.get_name_leafdata())
                                if (self.threshold_high.is_set or self.threshold_high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_high.get_name_leafdata())
                                if (self.threshold_low.is_set or self.threshold_low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold_low.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multiplier-high" or name == "multiplier-low" or name == "threshold-high" or name == "threshold-low"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "multiplier-high"):
                                    self.multiplier_high = value
                                    self.multiplier_high.value_namespace = name_space
                                    self.multiplier_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "multiplier-low"):
                                    self.multiplier_low = value
                                    self.multiplier_low.value_namespace = name_space
                                    self.multiplier_low.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-high"):
                                    self.threshold_high = value
                                    self.threshold_high.value_namespace = name_space
                                    self.threshold_high.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold-low"):
                                    self.threshold_low = value
                                    self.threshold_low.value_namespace = name_space
                                    self.threshold_low.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.window.is_set or
                                (self.threshold is not None and self.threshold.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.window.yfilter != YFilter.not_set or
                                (self.threshold is not None and self.threshold.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "frame" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.window.is_set or self.window.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.window.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "threshold"):
                                if (self.threshold is None):
                                    self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold()
                                    self.threshold.parent = self
                                    self._children_name_map["threshold"] = "threshold"
                                return self.threshold

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "threshold" or name == "window"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "window"):
                                self.window = value
                                self.window.value_namespace = name_space
                                self.window.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.monitoring.is_set or
                            (self.frame is not None and self.frame.has_data()) or
                            (self.frame_period is not None and self.frame_period.has_data()) or
                            (self.frame_seconds is not None and self.frame_seconds.has_data()) or
                            (self.symbol_period is not None and self.symbol_period.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.monitoring.yfilter != YFilter.not_set or
                            (self.frame is not None and self.frame.has_operation()) or
                            (self.frame_period is not None and self.frame_period.has_operation()) or
                            (self.frame_seconds is not None and self.frame_seconds.has_operation()) or
                            (self.symbol_period is not None and self.symbol_period.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "link-monitoring" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.monitoring.is_set or self.monitoring.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.monitoring.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "frame"):
                            if (self.frame is None):
                                self.frame = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame()
                                self.frame.parent = self
                                self._children_name_map["frame"] = "frame"
                            return self.frame

                        if (child_yang_name == "frame-period"):
                            if (self.frame_period is None):
                                self.frame_period = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod()
                                self.frame_period.parent = self
                                self._children_name_map["frame_period"] = "frame-period"
                            return self.frame_period

                        if (child_yang_name == "frame-seconds"):
                            if (self.frame_seconds is None):
                                self.frame_seconds = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds()
                                self.frame_seconds.parent = self
                                self._children_name_map["frame_seconds"] = "frame-seconds"
                            return self.frame_seconds

                        if (child_yang_name == "symbol-period"):
                            if (self.symbol_period is None):
                                self.symbol_period = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod()
                                self.symbol_period.parent = self
                                self._children_name_map["symbol_period"] = "symbol-period"
                            return self.symbol_period

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "frame" or name == "frame-period" or name == "frame-seconds" or name == "symbol-period" or name == "monitoring"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "monitoring"):
                            self.monitoring = value
                            self.monitoring.value_namespace = name_space
                            self.monitoring.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.hello_interval.is_set or
                        self.mib_retrieval.is_set or
                        self.mode.is_set or
                        self.profile_name.is_set or
                        self.remote_loopback.is_set or
                        self.timeout.is_set or
                        self.udlf.is_set or
                        (self.action is not None and self.action.has_data()) or
                        (self.link_monitoring is not None and self.link_monitoring.has_data()) or
                        (self.require_remote is not None and self.require_remote.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.hello_interval.yfilter != YFilter.not_set or
                        self.mib_retrieval.yfilter != YFilter.not_set or
                        self.mode.yfilter != YFilter.not_set or
                        self.profile_name.yfilter != YFilter.not_set or
                        self.remote_loopback.yfilter != YFilter.not_set or
                        self.timeout.yfilter != YFilter.not_set or
                        self.udlf.yfilter != YFilter.not_set or
                        (self.action is not None and self.action.has_operation()) or
                        (self.link_monitoring is not None and self.link_monitoring.has_operation()) or
                        (self.require_remote is not None and self.require_remote.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-ethernet-link-oam-cfg:ether-link-oam" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                    if (self.mib_retrieval.is_set or self.mib_retrieval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mib_retrieval.get_name_leafdata())
                    if (self.mode.is_set or self.mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mode.get_name_leafdata())
                    if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.profile_name.get_name_leafdata())
                    if (self.remote_loopback.is_set or self.remote_loopback.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_loopback.get_name_leafdata())
                    if (self.timeout.is_set or self.timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.timeout.get_name_leafdata())
                    if (self.udlf.is_set or self.udlf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.udlf.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "action"):
                        if (self.action is None):
                            self.action = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action()
                            self.action.parent = self
                            self._children_name_map["action"] = "action"
                        return self.action

                    if (child_yang_name == "link-monitoring"):
                        if (self.link_monitoring is None):
                            self.link_monitoring = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring()
                            self.link_monitoring.parent = self
                            self._children_name_map["link_monitoring"] = "link-monitoring"
                        return self.link_monitoring

                    if (child_yang_name == "require-remote"):
                        if (self.require_remote is None):
                            self.require_remote = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote()
                            self.require_remote.parent = self
                            self._children_name_map["require_remote"] = "require-remote"
                        return self.require_remote

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "action" or name == "link-monitoring" or name == "require-remote" or name == "hello-interval" or name == "mib-retrieval" or name == "mode" or name == "profile-name" or name == "remote-loopback" or name == "timeout" or name == "udlf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "hello-interval"):
                        self.hello_interval = value
                        self.hello_interval.value_namespace = name_space
                        self.hello_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mib-retrieval"):
                        self.mib_retrieval = value
                        self.mib_retrieval.value_namespace = name_space
                        self.mib_retrieval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mode"):
                        self.mode = value
                        self.mode.value_namespace = name_space
                        self.mode.value_namespace_prefix = name_space_prefix
                    if(value_path == "profile-name"):
                        self.profile_name = value
                        self.profile_name.value_namespace = name_space
                        self.profile_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-loopback"):
                        self.remote_loopback = value
                        self.remote_loopback.value_namespace = name_space
                        self.remote_loopback.value_namespace_prefix = name_space_prefix
                    if(value_path == "timeout"):
                        self.timeout = value
                        self.timeout.value_namespace = name_space
                        self.timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "udlf"):
                        self.udlf = value
                        self.udlf.value_namespace = name_space
                        self.udlf.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.ether_link_oam_enable.is_set or
                    self.filtering.is_set or
                    (self.cfm is not None and self.cfm.has_data()) or
                    (self.ether_link_oam is not None and self.ether_link_oam.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.ether_link_oam_enable.yfilter != YFilter.not_set or
                    self.filtering.yfilter != YFilter.not_set or
                    (self.cfm is not None and self.cfm.has_operation()) or
                    (self.ether_link_oam is not None and self.ether_link_oam.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:ethernet-features" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.ether_link_oam_enable.is_set or self.ether_link_oam_enable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ether_link_oam_enable.get_name_leafdata())
                if (self.filtering.is_set or self.filtering.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.filtering.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "cfm"):
                    if (self.cfm is None):
                        self.cfm = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm()
                        self.cfm.parent = self
                        self._children_name_map["cfm"] = "cfm"
                    return self.cfm

                if (child_yang_name == "ether-link-oam"):
                    if (self.ether_link_oam is None):
                        self.ether_link_oam = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam()
                        self.ether_link_oam.parent = self
                        self._children_name_map["ether_link_oam"] = "ether-link-oam"
                    return self.ether_link_oam

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "cfm" or name == "ether-link-oam" or name == "ether-link-oam-enable" or name == "filtering"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "ether-link-oam-enable"):
                    self.ether_link_oam_enable = value
                    self.ether_link_oam_enable.value_namespace = name_space
                    self.ether_link_oam_enable.value_namespace_prefix = name_space_prefix
                if(value_path == "filtering"):
                    self.filtering = value
                    self.filtering.value_namespace = name_space
                    self.filtering.value_namespace_prefix = name_space_prefix


        class CarrierDelay(Entity):
            """
            Set the carrier transition delay on an interface
            in msecs
            
            .. attribute:: carrier_delay_down
            
            	Carrier Delay down in msecs, must be set to 0
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: carrier_delay_up
            
            	Carrier Delay (up) in msecs
            	**type**\:  int
            
            	**range:** 1..65535
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CarrierDelay, self).__init__()

                self.yang_name = "carrier-delay"
                self.yang_parent_name = "interface-configuration"

                self.carrier_delay_down = YLeaf(YType.uint32, "carrier-delay-down")

                self.carrier_delay_up = YLeaf(YType.uint32, "carrier-delay-up")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("carrier_delay_down",
                                "carrier_delay_up") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.CarrierDelay, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.CarrierDelay, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.carrier_delay_down.is_set or
                    self.carrier_delay_up.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.carrier_delay_down.yfilter != YFilter.not_set or
                    self.carrier_delay_up.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:carrier-delay" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.carrier_delay_down.is_set or self.carrier_delay_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.carrier_delay_down.get_name_leafdata())
                if (self.carrier_delay_up.is_set or self.carrier_delay_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.carrier_delay_up.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "carrier-delay-down" or name == "carrier-delay-up"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "carrier-delay-down"):
                    self.carrier_delay_down = value
                    self.carrier_delay_down.value_namespace = name_space
                    self.carrier_delay_down.value_namespace_prefix = name_space_prefix
                if(value_path == "carrier-delay-up"):
                    self.carrier_delay_up = value
                    self.carrier_delay_up.value_namespace = name_space
                    self.carrier_delay_up.value_namespace_prefix = name_space_prefix


        class VlanTrunkConfiguration(Entity):
            """
            IEEE 802.1Q VLAN trunk interface configuration
            
            .. attribute:: native_vlan_identifier
            
            	The Native VLAN identifier associated with this trunk interface
            	**type**\:   :py:class:`NativeVlanIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier>`
            
            	**presence node**\: True
            
            .. attribute:: tunneling_ethertype
            
            	The outer ethertype used in Q\-in\-Q frames. The default value is 0x8100
            	**type**\:   :py:class:`TunnelingEthertype <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.TunnelingEthertype>`
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration, self).__init__()

                self.yang_name = "vlan-trunk-configuration"
                self.yang_parent_name = "interface-configuration"

                self.tunneling_ethertype = YLeaf(YType.enumeration, "tunneling-ethertype")

                self.native_vlan_identifier = None
                self._children_name_map["native_vlan_identifier"] = "native-vlan-identifier"
                self._children_yang_names.add("native-vlan-identifier")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("tunneling_ethertype") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration, self).__setattr__(name, value)

            class TunnelingEthertype(Enum):
                """
                TunnelingEthertype

                The outer ethertype used in Q\-in\-Q frames. The

                default value is 0x8100

                .. data:: Y_0x9100 = 37120

                	0x9100

                .. data:: Y_0x9200 = 37376

                	0x9200

                """

                Y_0x9100 = Enum.YLeaf(37120, "0x9100")

                Y_0x9200 = Enum.YLeaf(37376, "0x9200")



            class NativeVlanIdentifier(Entity):
                """
                The Native VLAN identifier associated with this
                trunk interface
                
                .. attribute:: vlan_identifier
                
                	VLAN identifier
                	**type**\:  int
                
                	**range:** 1..4094
                
                	**mandatory**\: True
                
                .. attribute:: vlan_type
                
                	Whether this interface is dot1ad or dot1Q
                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Vlan>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier, self).__init__()

                    self.yang_name = "native-vlan-identifier"
                    self.yang_parent_name = "vlan-trunk-configuration"
                    self.is_presence_container = True

                    self.vlan_identifier = YLeaf(YType.uint32, "vlan-identifier")

                    self.vlan_type = YLeaf(YType.enumeration, "vlan-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vlan_identifier",
                                    "vlan_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.vlan_identifier.is_set or
                        self.vlan_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vlan_identifier.yfilter != YFilter.not_set or
                        self.vlan_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "native-vlan-identifier" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vlan_identifier.is_set or self.vlan_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_identifier.get_name_leafdata())
                    if (self.vlan_type.is_set or self.vlan_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vlan-identifier" or name == "vlan-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vlan-identifier"):
                        self.vlan_identifier = value
                        self.vlan_identifier.value_namespace = name_space
                        self.vlan_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "vlan-type"):
                        self.vlan_type = value
                        self.vlan_type.value_namespace = name_space
                        self.vlan_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.tunneling_ethertype.is_set or
                    (self.native_vlan_identifier is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.tunneling_ethertype.yfilter != YFilter.not_set or
                    (self.native_vlan_identifier is not None and self.native_vlan_identifier.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-l2-eth-infra-cfg:vlan-trunk-configuration" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.tunneling_ethertype.is_set or self.tunneling_ethertype.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tunneling_ethertype.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "native-vlan-identifier"):
                    if (self.native_vlan_identifier is None):
                        self.native_vlan_identifier = InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier()
                        self.native_vlan_identifier.parent = self
                        self._children_name_map["native_vlan_identifier"] = "native-vlan-identifier"
                    return self.native_vlan_identifier

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "native-vlan-identifier" or name == "tunneling-ethertype"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "tunneling-ethertype"):
                    self.tunneling_ethertype = value
                    self.tunneling_ethertype.value_namespace = name_space
                    self.tunneling_ethertype.value_namespace_prefix = name_space_prefix


        class NvSatelliteAccess(Entity):
            """
            nV Satellite Access Link Configuration
            
            .. attribute:: qos
            
            	Interface QOS configuration
            	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos>`
            
            

            """

            _prefix = 'icpe-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess, self).__init__()

                self.yang_name = "nv-satellite-access"
                self.yang_parent_name = "interface-configuration"

                self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos()
                self.qos.parent = self
                self._children_name_map["qos"] = "qos"
                self._children_yang_names.add("qos")


            class Qos(Entity):
                """
                Interface QOS configuration
                
                .. attribute:: input
                
                	Ingress service policy
                	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input>`
                
                .. attribute:: output
                
                	Egress service policy
                	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output>`
                
                

                """

                _prefix = 'qos-ma-sat-cfg'
                _revision = '2017-04-24'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos, self).__init__()

                    self.yang_name = "qos"
                    self.yang_parent_name = "nv-satellite-access"

                    self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"
                    self._children_yang_names.add("input")

                    self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._children_yang_names.add("output")


                class Output(Entity):
                    """
                    Egress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-04-24'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "qos"

                        self.service_policy = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output, self).__setattr__(name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-04-24'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "output"

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("service_policy_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy, self).__setattr__(name, value)

                        def has_data(self):
                            return self.service_policy_name.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.service_policy_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "service-policy-name"):
                                self.service_policy_name = value
                                self.service_policy_name.value_namespace = name_space
                                self.service_policy_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.service_policy:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.service_policy:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "output" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "service-policy"):
                            for c in self.service_policy:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.service_policy.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "service-policy"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Input(Entity):
                    """
                    Ingress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-04-24'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "qos"

                        self.service_policy = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input, self).__setattr__(name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-04-24'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "input"

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("service_policy_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy, self).__setattr__(name, value)

                        def has_data(self):
                            return self.service_policy_name.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.service_policy_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "service-policy-name"):
                                self.service_policy_name = value
                                self.service_policy_name.value_namespace = name_space
                                self.service_policy_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.service_policy:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.service_policy:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "input" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "service-policy"):
                            for c in self.service_policy:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.service_policy.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "service-policy"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.input is not None and self.input.has_data()) or
                        (self.output is not None and self.output.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.input is not None and self.input.has_operation()) or
                        (self.output is not None and self.output.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-qos-ma-sat-cfg:qos" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "input"):
                        if (self.input is None):
                            self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"
                        return self.input

                    if (child_yang_name == "output"):
                        if (self.output is None):
                            self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                        return self.output

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "input" or name == "output"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.qos is not None and self.qos.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.qos is not None and self.qos.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-icpe-infra-cfg:nv-satellite-access" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "qos"):
                    if (self.qos is None):
                        self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"
                    return self.qos

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "qos"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class NvSatelliteFabricLink(Entity):
            """
            nV Satellite Fabric Link Configuration
            
            .. attribute:: ethernet_features
            
            	Ethernet Satellite configuration
            	**type**\:   :py:class:`EthernetFeatures <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures>`
            
            .. attribute:: minimum_required_links
            
            	Mininum number of active links required
            	**type**\:  int
            
            	**range:** 1..64
            
            .. attribute:: qos
            
            	Interface QOS configuration
            	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos>`
            
            .. attribute:: redundancy
            
            	Redundancy submode
            	**type**\:   :py:class:`Redundancy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy>`
            
            .. attribute:: remote_ports
            
            	Remote Ports table
            	**type**\:   :py:class:`RemotePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts>`
            
            .. attribute:: satellite
            
            	Hub & Spoke connection to a single Satellite
            	**type**\:  int
            
            	**range:** 100..65534
            
            

            """

            _prefix = 'icpe-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink, self).__init__()

                self.yang_name = "nv-satellite-fabric-link"
                self.yang_parent_name = "interface-configuration"

                self.minimum_required_links = YLeaf(YType.uint32, "minimum-required-links")

                self.satellite = YLeaf(YType.uint32, "satellite")

                self.ethernet_features = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures()
                self.ethernet_features.parent = self
                self._children_name_map["ethernet_features"] = "ethernet-features"
                self._children_yang_names.add("ethernet-features")

                self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos()
                self.qos.parent = self
                self._children_name_map["qos"] = "qos"
                self._children_yang_names.add("qos")

                self.redundancy = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._children_yang_names.add("redundancy")

                self.remote_ports = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts()
                self.remote_ports.parent = self
                self._children_name_map["remote_ports"] = "remote-ports"
                self._children_yang_names.add("remote-ports")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("minimum_required_links",
                                "satellite") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink, self).__setattr__(name, value)


            class Redundancy(Entity):
                """
                Redundancy submode
                
                .. attribute:: iccp_group
                
                	Links the satellite fabric to the given ICCP group
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: minimum_preferred_links
                
                	Mininum number of active links preferred
                	**type**\:  int
                
                	**range:** 1..64
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "nv-satellite-fabric-link"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.minimum_preferred_links = YLeaf(YType.uint32, "minimum-preferred-links")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group",
                                    "minimum_preferred_links") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        self.minimum_preferred_links.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        self.minimum_preferred_links.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "redundancy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())
                    if (self.minimum_preferred_links.is_set or self.minimum_preferred_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_preferred_links.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group" or name == "minimum-preferred-links"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-preferred-links"):
                        self.minimum_preferred_links = value
                        self.minimum_preferred_links.value_namespace = name_space
                        self.minimum_preferred_links.value_namespace_prefix = name_space_prefix


            class RemotePorts(Entity):
                """
                Remote Ports table
                
                .. attribute:: remote_port
                
                	Remote Ports
                	**type**\: list of    :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort>`
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts, self).__init__()

                    self.yang_name = "remote-ports"
                    self.yang_parent_name = "nv-satellite-fabric-link"

                    self.remote_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts, self).__setattr__(name, value)


                class RemotePort(Entity):
                    """
                    Remote Ports
                    
                    .. attribute:: port_type  <key>
                    
                    	Port type
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: slot  <key>
                    
                    	Slot
                    	**type**\:  int
                    
                    	**range:** 0..8
                    
                    .. attribute:: sub_slot  <key>
                    
                    	Sub slot
                    	**type**\:  int
                    
                    	**range:** 0..8
                    
                    .. attribute:: port_range
                    
                    	Port range
                    	**type**\:  str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'icpe-infra-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort, self).__init__()

                        self.yang_name = "remote-port"
                        self.yang_parent_name = "remote-ports"

                        self.port_type = YLeaf(YType.str, "port-type")

                        self.slot = YLeaf(YType.uint32, "slot")

                        self.sub_slot = YLeaf(YType.uint32, "sub-slot")

                        self.port_range = YLeaf(YType.str, "port-range")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("port_type",
                                        "slot",
                                        "sub_slot",
                                        "port_range") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.port_type.is_set or
                            self.slot.is_set or
                            self.sub_slot.is_set or
                            self.port_range.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.port_type.yfilter != YFilter.not_set or
                            self.slot.yfilter != YFilter.not_set or
                            self.sub_slot.yfilter != YFilter.not_set or
                            self.port_range.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "remote-port" + "[port-type='" + self.port_type.get() + "']" + "[slot='" + self.slot.get() + "']" + "[sub-slot='" + self.sub_slot.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.port_type.is_set or self.port_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_type.get_name_leafdata())
                        if (self.slot.is_set or self.slot.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.slot.get_name_leafdata())
                        if (self.sub_slot.is_set or self.sub_slot.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sub_slot.get_name_leafdata())
                        if (self.port_range.is_set or self.port_range.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_range.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "port-type" or name == "slot" or name == "sub-slot" or name == "port-range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "port-type"):
                            self.port_type = value
                            self.port_type.value_namespace = name_space
                            self.port_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "slot"):
                            self.slot = value
                            self.slot.value_namespace = name_space
                            self.slot.value_namespace_prefix = name_space_prefix
                        if(value_path == "sub-slot"):
                            self.sub_slot = value
                            self.sub_slot.value_namespace = name_space
                            self.sub_slot.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-range"):
                            self.port_range = value
                            self.port_range.value_namespace = name_space
                            self.port_range.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.remote_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.remote_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "remote-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "remote-port"):
                        for c in self.remote_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.remote_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "remote-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EthernetFeatures(Entity):
                """
                Ethernet Satellite configuration
                
                .. attribute:: cfm
                
                	CFM Satellite configuration
                	**type**\:   :py:class:`Cfm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm>`
                
                

                """

                _prefix = 'ethernet-cfm-sat-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures, self).__init__()

                    self.yang_name = "ethernet-features"
                    self.yang_parent_name = "nv-satellite-fabric-link"

                    self.cfm = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm()
                    self.cfm.parent = self
                    self._children_name_map["cfm"] = "cfm"
                    self._children_yang_names.add("cfm")


                class Cfm(Entity):
                    """
                    CFM Satellite configuration
                    
                    .. attribute:: continuity_check_interval
                    
                    	Continuity\-Check Interval
                    	**type**\:   :py:class:`CfmCcmInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_cfm_datatypes.CfmCcmInterval>`
                    
                    .. attribute:: enable
                    
                    	Enable CFM on Satellite
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level
                    
                    	Maintenance Domain Level
                    	**type**\:  int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ethernet-cfm-sat-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm, self).__init__()

                        self.yang_name = "cfm"
                        self.yang_parent_name = "ethernet-features"

                        self.continuity_check_interval = YLeaf(YType.enumeration, "continuity-check-interval")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.level = YLeaf(YType.uint32, "level")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("continuity_check_interval",
                                        "enable",
                                        "level") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.continuity_check_interval.is_set or
                            self.enable.is_set or
                            self.level.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.continuity_check_interval.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.level.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "cfm" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.continuity_check_interval.is_set or self.continuity_check_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.continuity_check_interval.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.level.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "continuity-check-interval" or name == "enable" or name == "level"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "continuity-check-interval"):
                            self.continuity_check_interval = value
                            self.continuity_check_interval.value_namespace = name_space
                            self.continuity_check_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "level"):
                            self.level = value
                            self.level.value_namespace = name_space
                            self.level.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.cfm is not None and self.cfm.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.cfm is not None and self.cfm.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-ethernet-cfm-sat-cfg:ethernet-features" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "cfm"):
                        if (self.cfm is None):
                            self.cfm = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm()
                            self.cfm.parent = self
                            self._children_name_map["cfm"] = "cfm"
                        return self.cfm

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "cfm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Qos(Entity):
                """
                Interface QOS configuration
                
                .. attribute:: input
                
                	Ingress service policy
                	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input>`
                
                .. attribute:: output
                
                	Egress service policy
                	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output>`
                
                

                """

                _prefix = 'qos-ma-sat-cfg'
                _revision = '2017-04-24'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos, self).__init__()

                    self.yang_name = "qos"
                    self.yang_parent_name = "nv-satellite-fabric-link"

                    self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"
                    self._children_yang_names.add("input")

                    self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._children_yang_names.add("output")


                class Output(Entity):
                    """
                    Egress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-04-24'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "qos"

                        self.service_policy = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output, self).__setattr__(name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-04-24'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "output"

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("service_policy_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy, self).__setattr__(name, value)

                        def has_data(self):
                            return self.service_policy_name.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.service_policy_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "service-policy-name"):
                                self.service_policy_name = value
                                self.service_policy_name.value_namespace = name_space
                                self.service_policy_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.service_policy:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.service_policy:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "output" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "service-policy"):
                            for c in self.service_policy:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.service_policy.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "service-policy"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Input(Entity):
                    """
                    Ingress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-04-24'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "qos"

                        self.service_policy = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input, self).__setattr__(name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-04-24'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "input"

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("service_policy_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy, self).__setattr__(name, value)

                        def has_data(self):
                            return self.service_policy_name.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.service_policy_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "service-policy-name"):
                                self.service_policy_name = value
                                self.service_policy_name.value_namespace = name_space
                                self.service_policy_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.service_policy:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.service_policy:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "input" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "service-policy"):
                            for c in self.service_policy:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.service_policy.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "service-policy"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.input is not None and self.input.has_data()) or
                        (self.output is not None and self.output.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.input is not None and self.input.has_operation()) or
                        (self.output is not None and self.output.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "Cisco-IOS-XR-qos-ma-sat-cfg:qos" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "input"):
                        if (self.input is None):
                            self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"
                        return self.input

                    if (child_yang_name == "output"):
                        if (self.output is None):
                            self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                        return self.output

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "input" or name == "output"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.minimum_required_links.is_set or
                    self.satellite.is_set or
                    (self.ethernet_features is not None and self.ethernet_features.has_data()) or
                    (self.qos is not None and self.qos.has_data()) or
                    (self.redundancy is not None and self.redundancy.has_data()) or
                    (self.remote_ports is not None and self.remote_ports.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.minimum_required_links.yfilter != YFilter.not_set or
                    self.satellite.yfilter != YFilter.not_set or
                    (self.ethernet_features is not None and self.ethernet_features.has_operation()) or
                    (self.qos is not None and self.qos.has_operation()) or
                    (self.redundancy is not None and self.redundancy.has_operation()) or
                    (self.remote_ports is not None and self.remote_ports.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-icpe-infra-cfg:nv-satellite-fabric-link" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.minimum_required_links.is_set or self.minimum_required_links.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.minimum_required_links.get_name_leafdata())
                if (self.satellite.is_set or self.satellite.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.satellite.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ethernet-features"):
                    if (self.ethernet_features is None):
                        self.ethernet_features = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures()
                        self.ethernet_features.parent = self
                        self._children_name_map["ethernet_features"] = "ethernet-features"
                    return self.ethernet_features

                if (child_yang_name == "qos"):
                    if (self.qos is None):
                        self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos()
                        self.qos.parent = self
                        self._children_name_map["qos"] = "qos"
                    return self.qos

                if (child_yang_name == "redundancy"):
                    if (self.redundancy is None):
                        self.redundancy = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                    return self.redundancy

                if (child_yang_name == "remote-ports"):
                    if (self.remote_ports is None):
                        self.remote_ports = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts()
                        self.remote_ports.parent = self
                        self._children_name_map["remote_ports"] = "remote-ports"
                    return self.remote_ports

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ethernet-features" or name == "qos" or name == "redundancy" or name == "remote-ports" or name == "minimum-required-links" or name == "satellite"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "minimum-required-links"):
                    self.minimum_required_links = value
                    self.minimum_required_links.value_namespace = name_space
                    self.minimum_required_links.value_namespace_prefix = name_space_prefix
                if(value_path == "satellite"):
                    self.satellite = value
                    self.satellite.value_namespace = name_space
                    self.satellite.value_namespace_prefix = name_space_prefix


        class NvSatelliteFabricNetwork(Entity):
            """
            Complex Network connection to one or more
            Satellites
            
            .. attribute:: enable
            
            	Enable
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: redundancy
            
            	Redundancy submode
            	**type**\:   :py:class:`Redundancy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy>`
            
            .. attribute:: satellites
            
            	Connected Satellite table
            	**type**\:   :py:class:`Satellites <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites>`
            
            

            """

            _prefix = 'icpe-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork, self).__init__()

                self.yang_name = "nv-satellite-fabric-network"
                self.yang_parent_name = "interface-configuration"

                self.enable = YLeaf(YType.empty, "enable")

                self.redundancy = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._children_yang_names.add("redundancy")

                self.satellites = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites()
                self.satellites.parent = self
                self._children_name_map["satellites"] = "satellites"
                self._children_yang_names.add("satellites")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("enable") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork, self).__setattr__(name, value)


            class Satellites(Entity):
                """
                Connected Satellite table
                
                .. attribute:: qos
                
                	Interface QOS configuration
                	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos>`
                
                .. attribute:: satellite
                
                	Connected Satellite
                	**type**\: list of    :py:class:`Satellite <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite>`
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites, self).__init__()

                    self.yang_name = "satellites"
                    self.yang_parent_name = "nv-satellite-fabric-network"

                    self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._children_yang_names.add("qos")

                    self.satellite = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites, self).__setattr__(name, value)


                class Satellite(Entity):
                    """
                    Connected Satellite
                    
                    .. attribute:: satellite_id  <key>
                    
                    	Satellite ID
                    	**type**\:  int
                    
                    	**range:** 100..65534
                    
                    .. attribute:: enable
                    
                    	Enable
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: remote_ports
                    
                    	Remote Ports table
                    	**type**\:   :py:class:`RemotePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts>`
                    
                    

                    """

                    _prefix = 'icpe-infra-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite, self).__init__()

                        self.yang_name = "satellite"
                        self.yang_parent_name = "satellites"

                        self.satellite_id = YLeaf(YType.uint32, "satellite-id")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.remote_ports = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts()
                        self.remote_ports.parent = self
                        self._children_name_map["remote_ports"] = "remote-ports"
                        self._children_yang_names.add("remote-ports")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("satellite_id",
                                        "enable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite, self).__setattr__(name, value)


                    class RemotePorts(Entity):
                        """
                        Remote Ports table
                        
                        .. attribute:: remote_port
                        
                        	Remote Ports
                        	**type**\: list of    :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort>`
                        
                        

                        """

                        _prefix = 'icpe-infra-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts, self).__init__()

                            self.yang_name = "remote-ports"
                            self.yang_parent_name = "satellite"

                            self.remote_port = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts, self).__setattr__(name, value)


                        class RemotePort(Entity):
                            """
                            Remote Ports
                            
                            .. attribute:: port_type  <key>
                            
                            	Port type
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: slot  <key>
                            
                            	Slot
                            	**type**\:  int
                            
                            	**range:** 0..8
                            
                            .. attribute:: sub_slot  <key>
                            
                            	Sub slot
                            	**type**\:  int
                            
                            	**range:** 0..8
                            
                            .. attribute:: port_range
                            
                            	Port range
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'icpe-infra-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort, self).__init__()

                                self.yang_name = "remote-port"
                                self.yang_parent_name = "remote-ports"

                                self.port_type = YLeaf(YType.str, "port-type")

                                self.slot = YLeaf(YType.uint32, "slot")

                                self.sub_slot = YLeaf(YType.uint32, "sub-slot")

                                self.port_range = YLeaf(YType.str, "port-range")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port_type",
                                                "slot",
                                                "sub_slot",
                                                "port_range") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.port_type.is_set or
                                    self.slot.is_set or
                                    self.sub_slot.is_set or
                                    self.port_range.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port_type.yfilter != YFilter.not_set or
                                    self.slot.yfilter != YFilter.not_set or
                                    self.sub_slot.yfilter != YFilter.not_set or
                                    self.port_range.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-port" + "[port-type='" + self.port_type.get() + "']" + "[slot='" + self.slot.get() + "']" + "[sub-slot='" + self.sub_slot.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port_type.is_set or self.port_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_type.get_name_leafdata())
                                if (self.slot.is_set or self.slot.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.slot.get_name_leafdata())
                                if (self.sub_slot.is_set or self.sub_slot.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_slot.get_name_leafdata())
                                if (self.port_range.is_set or self.port_range.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_range.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-type" or name == "slot" or name == "sub-slot" or name == "port-range"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port-type"):
                                    self.port_type = value
                                    self.port_type.value_namespace = name_space
                                    self.port_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "slot"):
                                    self.slot = value
                                    self.slot.value_namespace = name_space
                                    self.slot.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-slot"):
                                    self.sub_slot = value
                                    self.sub_slot.value_namespace = name_space
                                    self.sub_slot.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-range"):
                                    self.port_range = value
                                    self.port_range.value_namespace = name_space
                                    self.port_range.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.remote_port:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.remote_port:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "remote-port"):
                                for c in self.remote_port:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.remote_port.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "remote-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.satellite_id.is_set or
                            self.enable.is_set or
                            (self.remote_ports is not None and self.remote_ports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.satellite_id.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            (self.remote_ports is not None and self.remote_ports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "satellite" + "[satellite-id='" + self.satellite_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.satellite_id.is_set or self.satellite_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.satellite_id.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "remote-ports"):
                            if (self.remote_ports is None):
                                self.remote_ports = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts()
                                self.remote_ports.parent = self
                                self._children_name_map["remote_ports"] = "remote-ports"
                            return self.remote_ports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "remote-ports" or name == "satellite-id" or name == "enable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "satellite-id"):
                            self.satellite_id = value
                            self.satellite_id.value_namespace = name_space
                            self.satellite_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix


                class Qos(Entity):
                    """
                    Interface QOS configuration
                    
                    .. attribute:: input
                    
                    	Ingress service policy
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input>`
                    
                    .. attribute:: output
                    
                    	Egress service policy
                    	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-04-24'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "satellites"

                        self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")

                        self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                        self._children_yang_names.add("output")


                    class Output(Entity):
                        """
                        Egress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy>`
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-04-24'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "qos"

                            self.service_policy = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output, self).__setattr__(name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            

                            """

                            _prefix = 'qos-ma-sat-cfg'
                            _revision = '2017-04-24'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "output"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy, self).__setattr__(name, value)

                            def has_data(self):
                                return self.service_policy_name.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "service-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.service_policy:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.service_policy:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "output" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "service-policy"):
                                for c in self.service_policy:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Input(Entity):
                        """
                        Ingress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy>`
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-04-24'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"

                            self.service_policy = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input, self).__setattr__(name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            

                            """

                            _prefix = 'qos-ma-sat-cfg'
                            _revision = '2017-04-24'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "input"

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("service_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy, self).__setattr__(name, value)

                            def has_data(self):
                                return self.service_policy_name.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.service_policy_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "service-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "service-policy-name"):
                                    self.service_policy_name = value
                                    self.service_policy_name.value_namespace = name_space
                                    self.service_policy_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.service_policy:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.service_policy:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "input" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "service-policy"):
                                for c in self.service_policy:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.service_policy.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "service-policy"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.input is not None and self.input.has_data()) or
                            (self.output is not None and self.output.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.input is not None and self.input.has_operation()) or
                            (self.output is not None and self.output.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "Cisco-IOS-XR-qos-ma-sat-cfg:qos" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "input"):
                            if (self.input is None):
                                self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input()
                                self.input.parent = self
                                self._children_name_map["input"] = "input"
                            return self.input

                        if (child_yang_name == "output"):
                            if (self.output is None):
                                self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output()
                                self.output.parent = self
                                self._children_name_map["output"] = "output"
                            return self.output

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "input" or name == "output"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    for c in self.satellite:
                        if (c.has_data()):
                            return True
                    return (self.qos is not None and self.qos.has_data())

                def has_operation(self):
                    for c in self.satellite:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.qos is not None and self.qos.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "satellites" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "qos"):
                        if (self.qos is None):
                            self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos()
                            self.qos.parent = self
                            self._children_name_map["qos"] = "qos"
                        return self.qos

                    if (child_yang_name == "satellite"):
                        for c in self.satellite:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.satellite.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "qos" or name == "satellite"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Redundancy(Entity):
                """
                Redundancy submode
                
                .. attribute:: iccp_group
                
                	Links the satellite fabric to the given ICCP group
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: minimum_preferred_links
                
                	Mininum number of active links preferred
                	**type**\:  int
                
                	**range:** 1..64
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "nv-satellite-fabric-network"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.minimum_preferred_links = YLeaf(YType.uint32, "minimum-preferred-links")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group",
                                    "minimum_preferred_links") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        self.minimum_preferred_links.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        self.minimum_preferred_links.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "redundancy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())
                    if (self.minimum_preferred_links.is_set or self.minimum_preferred_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_preferred_links.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group" or name == "minimum-preferred-links"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-preferred-links"):
                        self.minimum_preferred_links = value
                        self.minimum_preferred_links.value_namespace = name_space
                        self.minimum_preferred_links.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.enable.is_set or
                    (self.redundancy is not None and self.redundancy.has_data()) or
                    (self.satellites is not None and self.satellites.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.enable.yfilter != YFilter.not_set or
                    (self.redundancy is not None and self.redundancy.has_operation()) or
                    (self.satellites is not None and self.satellites.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-icpe-infra-cfg:nv-satellite-fabric-network" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.enable.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "redundancy"):
                    if (self.redundancy is None):
                        self.redundancy = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                    return self.redundancy

                if (child_yang_name == "satellites"):
                    if (self.satellites is None):
                        self.satellites = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites()
                        self.satellites.parent = self
                        self._children_name_map["satellites"] = "satellites"
                    return self.satellites

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "redundancy" or name == "satellites" or name == "enable"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "enable"):
                    self.enable = value
                    self.enable.value_namespace = name_space
                    self.enable.value_namespace_prefix = name_space_prefix


        class Lldp(Entity):
            """
            Disable LLDP TX or RX
            
            .. attribute:: lldp_intf_enter
            
            	enter LLDP interface submode
            	**type**\:  bool
            
            	**mandatory**\: True
            
            .. attribute:: receive
            
            	Disable LLDP RX
            	**type**\:   :py:class:`Receive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive>`
            
            .. attribute:: transmit
            
            	Disable LLDP TX
            	**type**\:   :py:class:`Transmit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ethernet-lldp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Lldp, self).__init__()

                self.yang_name = "lldp"
                self.yang_parent_name = "interface-configuration"
                self.is_presence_container = True

                self.lldp_intf_enter = YLeaf(YType.boolean, "lldp-intf-enter")

                self.receive = InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive()
                self.receive.parent = self
                self._children_name_map["receive"] = "receive"
                self._children_yang_names.add("receive")

                self.transmit = InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit()
                self.transmit.parent = self
                self._children_name_map["transmit"] = "transmit"
                self._children_yang_names.add("transmit")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("lldp_intf_enter") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Lldp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Lldp, self).__setattr__(name, value)


            class Transmit(Entity):
                """
                Disable LLDP TX
                
                .. attribute:: disable
                
                	disable LLDP TX
                	**type**\:  bool
                
                	**default value**\: false
                
                

                """

                _prefix = 'ethernet-lldp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit, self).__init__()

                    self.yang_name = "transmit"
                    self.yang_parent_name = "lldp"

                    self.disable = YLeaf(YType.boolean, "disable")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("disable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit, self).__setattr__(name, value)

                def has_data(self):
                    return self.disable.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.disable.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "transmit" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "disable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "disable"):
                        self.disable = value
                        self.disable.value_namespace = name_space
                        self.disable.value_namespace_prefix = name_space_prefix


            class Receive(Entity):
                """
                Disable LLDP RX
                
                .. attribute:: disable
                
                	disable LLDP RX
                	**type**\:  bool
                
                	**default value**\: false
                
                

                """

                _prefix = 'ethernet-lldp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive, self).__init__()

                    self.yang_name = "receive"
                    self.yang_parent_name = "lldp"

                    self.disable = YLeaf(YType.boolean, "disable")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("disable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive, self).__setattr__(name, value)

                def has_data(self):
                    return self.disable.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.disable.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "receive" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "disable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "disable"):
                        self.disable = value
                        self.disable.value_namespace = name_space
                        self.disable.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.lldp_intf_enter.is_set or
                    (self.receive is not None and self.receive.has_data()) or
                    (self.transmit is not None and self.transmit.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.lldp_intf_enter.yfilter != YFilter.not_set or
                    (self.receive is not None and self.receive.has_operation()) or
                    (self.transmit is not None and self.transmit.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ethernet-lldp-cfg:lldp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.lldp_intf_enter.is_set or self.lldp_intf_enter.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lldp_intf_enter.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "receive"):
                    if (self.receive is None):
                        self.receive = InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive()
                        self.receive.parent = self
                        self._children_name_map["receive"] = "receive"
                    return self.receive

                if (child_yang_name == "transmit"):
                    if (self.transmit is None):
                        self.transmit = InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit()
                        self.transmit.parent = self
                        self._children_name_map["transmit"] = "transmit"
                    return self.transmit

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "receive" or name == "transmit" or name == "lldp-intf-enter"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "lldp-intf-enter"):
                    self.lldp_intf_enter = value
                    self.lldp_intf_enter.value_namespace = name_space
                    self.lldp_intf_enter.value_namespace_prefix = name_space_prefix


        class SpanMonitorSessions(Entity):
            """
            Monitor Session container for this source
            interface
            
            .. attribute:: span_monitor_session
            
            	Configuration for a particular class of Monitor Session
            	**type**\: list of    :py:class:`SpanMonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession>`
            
            

            """

            _prefix = 'ethernet-span-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions, self).__init__()

                self.yang_name = "span-monitor-sessions"
                self.yang_parent_name = "interface-configuration"

                self.span_monitor_session = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions, self).__setattr__(name, value)


            class SpanMonitorSession(Entity):
                """
                Configuration for a particular class of Monitor
                Session
                
                .. attribute:: session_class  <key>
                
                	Session Class
                	**type**\:   :py:class:`SpanSessionClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_datatypes.SpanSessionClass>`
                
                .. attribute:: acl
                
                	Enable ACL matching for traffic mirroring
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: attachment
                
                	Attach the interface to a Monitor Session
                	**type**\:   :py:class:`Attachment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment>`
                
                	**presence node**\: True
                
                .. attribute:: mirror_first
                
                	Mirror a specified number of bytes from start of packet
                	**type**\:  int
                
                	**range:** 1..10000
                
                	**units**\: byte
                
                .. attribute:: mirror_interval
                
                	Specify the mirror interval
                	**type**\:   :py:class:`SpanMirrorInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanMirrorInterval>`
                
                

                """

                _prefix = 'ethernet-span-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession, self).__init__()

                    self.yang_name = "span-monitor-session"
                    self.yang_parent_name = "span-monitor-sessions"

                    self.session_class = YLeaf(YType.enumeration, "session-class")

                    self.acl = YLeaf(YType.empty, "acl")

                    self.mirror_first = YLeaf(YType.uint32, "mirror-first")

                    self.mirror_interval = YLeaf(YType.enumeration, "mirror-interval")

                    self.attachment = None
                    self._children_name_map["attachment"] = "attachment"
                    self._children_yang_names.add("attachment")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("session_class",
                                    "acl",
                                    "mirror_first",
                                    "mirror_interval") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession, self).__setattr__(name, value)


                class Attachment(Entity):
                    """
                    Attach the interface to a Monitor Session
                    
                    .. attribute:: direction
                    
                    	Specify the direction of traffic to replicate (optional)
                    	**type**\:   :py:class:`SpanTrafficDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanTrafficDirection>`
                    
                    .. attribute:: port_level_enable
                    
                    	Enable port level traffic mirroring
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: session_name
                    
                    	Session Name
                    	**type**\:  str
                    
                    	**length:** 1..79
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ethernet-span-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__init__()

                        self.yang_name = "attachment"
                        self.yang_parent_name = "span-monitor-session"
                        self.is_presence_container = True

                        self.direction = YLeaf(YType.enumeration, "direction")

                        self.port_level_enable = YLeaf(YType.empty, "port-level-enable")

                        self.session_name = YLeaf(YType.str, "session-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("direction",
                                        "port_level_enable",
                                        "session_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.direction.is_set or
                            self.port_level_enable.is_set or
                            self.session_name.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.direction.yfilter != YFilter.not_set or
                            self.port_level_enable.yfilter != YFilter.not_set or
                            self.session_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "attachment" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.direction.get_name_leafdata())
                        if (self.port_level_enable.is_set or self.port_level_enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_level_enable.get_name_leafdata())
                        if (self.session_name.is_set or self.session_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "direction" or name == "port-level-enable" or name == "session-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "direction"):
                            self.direction = value
                            self.direction.value_namespace = name_space
                            self.direction.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-level-enable"):
                            self.port_level_enable = value
                            self.port_level_enable.value_namespace = name_space
                            self.port_level_enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "session-name"):
                            self.session_name = value
                            self.session_name.value_namespace = name_space
                            self.session_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.session_class.is_set or
                        self.acl.is_set or
                        self.mirror_first.is_set or
                        self.mirror_interval.is_set or
                        (self.attachment is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.session_class.yfilter != YFilter.not_set or
                        self.acl.yfilter != YFilter.not_set or
                        self.mirror_first.yfilter != YFilter.not_set or
                        self.mirror_interval.yfilter != YFilter.not_set or
                        (self.attachment is not None and self.attachment.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "span-monitor-session" + "[session-class='" + self.session_class.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.session_class.is_set or self.session_class.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.session_class.get_name_leafdata())
                    if (self.acl.is_set or self.acl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.acl.get_name_leafdata())
                    if (self.mirror_first.is_set or self.mirror_first.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mirror_first.get_name_leafdata())
                    if (self.mirror_interval.is_set or self.mirror_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mirror_interval.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "attachment"):
                        if (self.attachment is None):
                            self.attachment = InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment()
                            self.attachment.parent = self
                            self._children_name_map["attachment"] = "attachment"
                        return self.attachment

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "attachment" or name == "session-class" or name == "acl" or name == "mirror-first" or name == "mirror-interval"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "session-class"):
                        self.session_class = value
                        self.session_class.value_namespace = name_space
                        self.session_class.value_namespace_prefix = name_space_prefix
                    if(value_path == "acl"):
                        self.acl = value
                        self.acl.value_namespace = name_space
                        self.acl.value_namespace_prefix = name_space_prefix
                    if(value_path == "mirror-first"):
                        self.mirror_first = value
                        self.mirror_first.value_namespace = name_space
                        self.mirror_first.value_namespace_prefix = name_space_prefix
                    if(value_path == "mirror-interval"):
                        self.mirror_interval = value
                        self.mirror_interval.value_namespace = name_space
                        self.mirror_interval.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.span_monitor_session:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.span_monitor_session:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-Ethernet-SPAN-cfg:span-monitor-sessions" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "span-monitor-session"):
                    for c in self.span_monitor_session:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.span_monitor_session.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "span-monitor-session"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class ServicePolicies(Entity):
            """
            Interface control subscriber policy
            configuration
            
            .. attribute:: service_policy
            
            	Service policy to be applied to access interface  for subscribers
            	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy>`
            
            

            """

            _prefix = 'iedge4710-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies, self).__init__()

                self.yang_name = "service-policies"
                self.yang_parent_name = "interface-configuration"

                self.service_policy = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies, self).__setattr__(name, value)


            class ServicePolicy(Entity):
                """
                Service policy to be applied to access
                interface  for subscribers
                
                .. attribute:: service_policy_name  <key>
                
                	Name of policy\-map
                	**type**\:  str
                
                	**length:** 1..63
                
                

                """

                _prefix = 'iedge4710-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "service-policies"

                    self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("service_policy_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy, self).__setattr__(name, value)

                def has_data(self):
                    return self.service_policy_name.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.service_policy_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "service-policy-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "service-policy-name"):
                        self.service_policy_name = value
                        self.service_policy_name.value_namespace = name_space
                        self.service_policy_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.service_policy:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.service_policy:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-iedge4710-cfg:service-policies" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "service-policy"):
                    for c in self.service_policy:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.service_policy.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "service-policy"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Afs(Entity):
            """
            Per\-address\-family and topology configuration
            
            .. attribute:: af
            
            	The presence of this object enables the givenaddress\-family and topology on the interface
            	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Afs.Af>`
            
            .. attribute:: af_topology_name
            
            	The presence of this object enables the givenaddress\-family and topology on the interface
            	**type**\: list of    :py:class:`AfTopologyName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName>`
            
            

            """

            _prefix = 'infra-rsi-cfg'
            _revision = '2016-12-19'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Afs, self).__init__()

                self.yang_name = "afs"
                self.yang_parent_name = "interface-configuration"

                self.af = YList(self)
                self.af_topology_name = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Afs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Afs, self).__setattr__(name, value)


            class Af(Entity):
                """
                The presence of this object enables the
                givenaddress\-family and topology on the
                interface.
                
                .. attribute:: af_name  <key>
                
                	Address\-family
                	**type**\:   :py:class:`VrfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfAddressFamily>`
                
                .. attribute:: saf_name  <key>
                
                	Sub\-address\-family
                	**type**\:   :py:class:`VrfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfSubAddressFamily>`
                
                

                """

                _prefix = 'infra-rsi-cfg'
                _revision = '2016-12-19'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Afs.Af, self).__init__()

                    self.yang_name = "af"
                    self.yang_parent_name = "afs"

                    self.af_name = YLeaf(YType.enumeration, "af-name")

                    self.saf_name = YLeaf(YType.enumeration, "saf-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("af_name",
                                    "saf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Afs.Af, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Afs.Af, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.af_name.is_set or
                        self.saf_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.af_name.yfilter != YFilter.not_set or
                        self.saf_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "af" + "[af-name='" + self.af_name.get() + "']" + "[saf-name='" + self.saf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.af_name.get_name_leafdata())
                    if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.saf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "af-name" or name == "saf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "af-name"):
                        self.af_name = value
                        self.af_name.value_namespace = name_space
                        self.af_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "saf-name"):
                        self.saf_name = value
                        self.saf_name.value_namespace = name_space
                        self.saf_name.value_namespace_prefix = name_space_prefix


            class AfTopologyName(Entity):
                """
                The presence of this object enables the
                givenaddress\-family and topology on the
                interface.
                
                .. attribute:: topology_name  <key>
                
                	Topology name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: af_name  <key>
                
                	Address\-family
                	**type**\:   :py:class:`VrfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfAddressFamily>`
                
                .. attribute:: saf_name  <key>
                
                	Sub\-address\-family
                	**type**\:   :py:class:`VrfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfSubAddressFamily>`
                
                

                """

                _prefix = 'infra-rsi-cfg'
                _revision = '2016-12-19'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName, self).__init__()

                    self.yang_name = "af-topology-name"
                    self.yang_parent_name = "afs"

                    self.topology_name = YLeaf(YType.str, "topology-name")

                    self.af_name = YLeaf(YType.enumeration, "af-name")

                    self.saf_name = YLeaf(YType.enumeration, "saf-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("topology_name",
                                    "af_name",
                                    "saf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.topology_name.is_set or
                        self.af_name.is_set or
                        self.saf_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.topology_name.yfilter != YFilter.not_set or
                        self.af_name.yfilter != YFilter.not_set or
                        self.saf_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "af-topology-name" + "[topology-name='" + self.topology_name.get() + "']" + "[af-name='" + self.af_name.get() + "']" + "[saf-name='" + self.saf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_name.get_name_leafdata())
                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.af_name.get_name_leafdata())
                    if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.saf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-name" or name == "af-name" or name == "saf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "topology-name"):
                        self.topology_name = value
                        self.topology_name.value_namespace = name_space
                        self.topology_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "af-name"):
                        self.af_name = value
                        self.af_name.value_namespace = name_space
                        self.af_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "saf-name"):
                        self.saf_name = value
                        self.saf_name.value_namespace = name_space
                        self.saf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.af:
                    if (c.has_data()):
                        return True
                for c in self.af_topology_name:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.af:
                    if (c.has_operation()):
                        return True
                for c in self.af_topology_name:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-infra-rsi-cfg:afs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "af"):
                    for c in self.af:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = InterfaceConfigurations.InterfaceConfiguration.Afs.Af()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.af.append(c)
                    return c

                if (child_yang_name == "af-topology-name"):
                    for c in self.af_topology_name:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.af_topology_name.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "af" or name == "af-topology-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Statistics(Entity):
            """
            Per\-interface statistics configuration
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\:  int
            
            	**range:** 0..600
            
            	**default value**\: 300
            
            

            """

            _prefix = 'infra-statsd-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Statistics, self).__init__()

                self.yang_name = "statistics"
                self.yang_parent_name = "interface-configuration"

                self.load_interval = YLeaf(YType.uint32, "load-interval")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("load_interval") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Statistics, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Statistics, self).__setattr__(name, value)

            def has_data(self):
                return self.load_interval.is_set

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.load_interval.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-infra-statsd-cfg:statistics" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.load_interval.is_set or self.load_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.load_interval.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "load-interval"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "load-interval"):
                    self.load_interval = value
                    self.load_interval.value_namespace = name_space
                    self.load_interval.value_namespace_prefix = name_space_prefix


        class Ipv6PacketFilter(Entity):
            """
            IPv6 Packet Filtering configuration for the
            interface
            
            .. attribute:: inbound
            
            	IPv6 Packet filter to be applied to inbound packets
            	**type**\:   :py:class:`Inbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound>`
            
            .. attribute:: outbound
            
            	IPv6 Packet filter to be applied to outbound packets
            	**type**\:   :py:class:`Outbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound>`
            
            

            """

            _prefix = 'ip-pfilter-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter, self).__init__()

                self.yang_name = "ipv6-packet-filter"
                self.yang_parent_name = "interface-configuration"

                self.inbound = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound()
                self.inbound.parent = self
                self._children_name_map["inbound"] = "inbound"
                self._children_yang_names.add("inbound")

                self.outbound = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound()
                self.outbound.parent = self
                self._children_name_map["outbound"] = "outbound"
                self._children_yang_names.add("outbound")


            class Inbound(Entity):
                """
                IPv6 Packet filter to be applied to inbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv6 Packet Filter Names to be applied to Inbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: common_acl_name
                
                	Reserved for backward compatibility. IPv6 Packet Filter Name to be applied to Inbound packets, ACL providing HW optimization when applied on multiple interfaces. NOTE\: This parameter is mandatory if 'Name' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them. NOTE\: InterfaceStatistics is allowed only if Name is specified
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv6 Packet Filter Name to be applied to Inbound  NOTE\: This parameter is mandatory if 'CommonACLName' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound, self).__init__()

                    self.yang_name = "inbound"
                    self.yang_parent_name = "ipv6-packet-filter"

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.common_acl_name = YLeaf(YType.str, "common-acl-name")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("acl_name_array",
                                    "common_acl_name",
                                    "compression_level",
                                    "interface_statistics",
                                    "is_common_array",
                                    "name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.common_acl_name.is_set or
                        self.compression_level.is_set or
                        self.interface_statistics.is_set or
                        self.name.is_set)

                def has_operation(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.acl_name_array.yfilter != YFilter.not_set or
                        self.common_acl_name.yfilter != YFilter.not_set or
                        self.compression_level.yfilter != YFilter.not_set or
                        self.interface_statistics.yfilter != YFilter.not_set or
                        self.is_common_array.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "inbound" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.common_acl_name.is_set or self.common_acl_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.common_acl_name.get_name_leafdata())
                    if (self.compression_level.is_set or self.compression_level.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.compression_level.get_name_leafdata())
                    if (self.interface_statistics.is_set or self.interface_statistics.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_statistics.get_name_leafdata())
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    leaf_name_data.extend(self.acl_name_array.get_name_leafdata())

                    leaf_name_data.extend(self.is_common_array.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "acl-name-array" or name == "common-acl-name" or name == "compression-level" or name == "interface-statistics" or name == "is-common-array" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "acl-name-array"):
                        self.acl_name_array.append(value)
                    if(value_path == "common-acl-name"):
                        self.common_acl_name = value
                        self.common_acl_name.value_namespace = name_space
                        self.common_acl_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "compression-level"):
                        self.compression_level = value
                        self.compression_level.value_namespace = name_space
                        self.compression_level.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-statistics"):
                        self.interface_statistics = value
                        self.interface_statistics.value_namespace = name_space
                        self.interface_statistics.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-common-array"):
                        self.is_common_array.append(value)
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix


            class Outbound(Entity):
                """
                IPv6 Packet filter to be applied to outbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv6 Packet Filter Names to be applied to Inbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: do_not_use
                
                	Reserved.  Error if specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv6 Packet Filter Name to be applied to Outbound  packets
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound, self).__init__()

                    self.yang_name = "outbound"
                    self.yang_parent_name = "ipv6-packet-filter"

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.do_not_use = YLeaf(YType.str, "do-not-use")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("acl_name_array",
                                    "compression_level",
                                    "do_not_use",
                                    "interface_statistics",
                                    "is_common_array",
                                    "name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.compression_level.is_set or
                        self.do_not_use.is_set or
                        self.interface_statistics.is_set or
                        self.name.is_set)

                def has_operation(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.acl_name_array.yfilter != YFilter.not_set or
                        self.compression_level.yfilter != YFilter.not_set or
                        self.do_not_use.yfilter != YFilter.not_set or
                        self.interface_statistics.yfilter != YFilter.not_set or
                        self.is_common_array.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "outbound" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.compression_level.is_set or self.compression_level.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.compression_level.get_name_leafdata())
                    if (self.do_not_use.is_set or self.do_not_use.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.do_not_use.get_name_leafdata())
                    if (self.interface_statistics.is_set or self.interface_statistics.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_statistics.get_name_leafdata())
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    leaf_name_data.extend(self.acl_name_array.get_name_leafdata())

                    leaf_name_data.extend(self.is_common_array.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "acl-name-array" or name == "compression-level" or name == "do-not-use" or name == "interface-statistics" or name == "is-common-array" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "acl-name-array"):
                        self.acl_name_array.append(value)
                    if(value_path == "compression-level"):
                        self.compression_level = value
                        self.compression_level.value_namespace = name_space
                        self.compression_level.value_namespace_prefix = name_space_prefix
                    if(value_path == "do-not-use"):
                        self.do_not_use = value
                        self.do_not_use.value_namespace = name_space
                        self.do_not_use.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-statistics"):
                        self.interface_statistics = value
                        self.interface_statistics.value_namespace = name_space
                        self.interface_statistics.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-common-array"):
                        self.is_common_array.append(value)
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.inbound is not None and self.inbound.has_data()) or
                    (self.outbound is not None and self.outbound.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.inbound is not None and self.inbound.has_operation()) or
                    (self.outbound is not None and self.outbound.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ip-pfilter-cfg:ipv6-packet-filter" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "inbound"):
                    if (self.inbound is None):
                        self.inbound = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound()
                        self.inbound.parent = self
                        self._children_name_map["inbound"] = "inbound"
                    return self.inbound

                if (child_yang_name == "outbound"):
                    if (self.outbound is None):
                        self.outbound = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound()
                        self.outbound.parent = self
                        self._children_name_map["outbound"] = "outbound"
                    return self.outbound

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "inbound" or name == "outbound"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EsPacketFilter(Entity):
            """
            ES Packet Filtering configuration for the
            interface
            
            .. attribute:: inbound
            
            	Name of filter to be applied to inbound packets
            	**type**\:  str
            
            	**length:** 1..65
            
            .. attribute:: outbound
            
            	Name of filter to be applied to outbound packets
            	**type**\:  str
            
            	**length:** 1..65
            
            

            """

            _prefix = 'ip-pfilter-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter, self).__init__()

                self.yang_name = "es-packet-filter"
                self.yang_parent_name = "interface-configuration"

                self.inbound = YLeaf(YType.str, "inbound")

                self.outbound = YLeaf(YType.str, "outbound")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("inbound",
                                "outbound") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.inbound.is_set or
                    self.outbound.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.inbound.yfilter != YFilter.not_set or
                    self.outbound.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ip-pfilter-cfg:es-packet-filter" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.inbound.is_set or self.inbound.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.inbound.get_name_leafdata())
                if (self.outbound.is_set or self.outbound.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outbound.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "inbound" or name == "outbound"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "inbound"):
                    self.inbound = value
                    self.inbound.value_namespace = name_space
                    self.inbound.value_namespace_prefix = name_space_prefix
                if(value_path == "outbound"):
                    self.outbound = value
                    self.outbound.value_namespace = name_space
                    self.outbound.value_namespace_prefix = name_space_prefix


        class Ipv4PacketFilter(Entity):
            """
            IPv4 Packet Filtering configuration for the
            interface
            
            .. attribute:: inbound
            
            	IPv4 Packet filter to be applied to inbound packets
            	**type**\:   :py:class:`Inbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound>`
            
            .. attribute:: outbound
            
            	IPv4 Packet filter to be applied to outbound packets
            	**type**\:   :py:class:`Outbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound>`
            
            

            """

            _prefix = 'ip-pfilter-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter, self).__init__()

                self.yang_name = "ipv4-packet-filter"
                self.yang_parent_name = "interface-configuration"

                self.inbound = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound()
                self.inbound.parent = self
                self._children_name_map["inbound"] = "inbound"
                self._children_yang_names.add("inbound")

                self.outbound = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound()
                self.outbound.parent = self
                self._children_name_map["outbound"] = "outbound"
                self._children_yang_names.add("outbound")


            class Outbound(Entity):
                """
                IPv4 Packet filter to be applied to outbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv4 Packet Filter Names to be applied to Outbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: do_not_use
                
                	Reserved.  Error if specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: hardware_count
                
                	True if packets hitting the ACL should be counted in the hardware.  The default is not to count them
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv4 Packet Filter Name to be applied to Outbound packets NOTE\: This parameter is mandatory if 'CommonACLName' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound, self).__init__()

                    self.yang_name = "outbound"
                    self.yang_parent_name = "ipv4-packet-filter"

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.do_not_use = YLeaf(YType.str, "do-not-use")

                    self.hardware_count = YLeaf(YType.empty, "hardware-count")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("acl_name_array",
                                    "compression_level",
                                    "do_not_use",
                                    "hardware_count",
                                    "interface_statistics",
                                    "is_common_array",
                                    "name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.compression_level.is_set or
                        self.do_not_use.is_set or
                        self.hardware_count.is_set or
                        self.interface_statistics.is_set or
                        self.name.is_set)

                def has_operation(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.acl_name_array.yfilter != YFilter.not_set or
                        self.compression_level.yfilter != YFilter.not_set or
                        self.do_not_use.yfilter != YFilter.not_set or
                        self.hardware_count.yfilter != YFilter.not_set or
                        self.interface_statistics.yfilter != YFilter.not_set or
                        self.is_common_array.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "outbound" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.compression_level.is_set or self.compression_level.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.compression_level.get_name_leafdata())
                    if (self.do_not_use.is_set or self.do_not_use.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.do_not_use.get_name_leafdata())
                    if (self.hardware_count.is_set or self.hardware_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hardware_count.get_name_leafdata())
                    if (self.interface_statistics.is_set or self.interface_statistics.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_statistics.get_name_leafdata())
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    leaf_name_data.extend(self.acl_name_array.get_name_leafdata())

                    leaf_name_data.extend(self.is_common_array.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "acl-name-array" or name == "compression-level" or name == "do-not-use" or name == "hardware-count" or name == "interface-statistics" or name == "is-common-array" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "acl-name-array"):
                        self.acl_name_array.append(value)
                    if(value_path == "compression-level"):
                        self.compression_level = value
                        self.compression_level.value_namespace = name_space
                        self.compression_level.value_namespace_prefix = name_space_prefix
                    if(value_path == "do-not-use"):
                        self.do_not_use = value
                        self.do_not_use.value_namespace = name_space
                        self.do_not_use.value_namespace_prefix = name_space_prefix
                    if(value_path == "hardware-count"):
                        self.hardware_count = value
                        self.hardware_count.value_namespace = name_space
                        self.hardware_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-statistics"):
                        self.interface_statistics = value
                        self.interface_statistics.value_namespace = name_space
                        self.interface_statistics.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-common-array"):
                        self.is_common_array.append(value)
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix


            class Inbound(Entity):
                """
                IPv4 Packet filter to be applied to inbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv4 Packet Filter Names to be applied to Inbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: common_acl_name
                
                	Reserved for backward compatibility. IPv4 Packet Filter Name to be applied to Inbound packets, ACL providing HW optimization when applied on multiple interfaces. NOTE\: This parameter is mandatory if 'Name' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: hardware_count
                
                	True if packets hitting the ACL should be counted in the hardware.  The default is not to count them. NOTE\: HardwareCount is allowed only if Name is specified
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them. NOTE\: InterfaceStatistics is allowed only if Name is specified
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv4 Packet Filter Name to be applied to Inbound packets NOTE\: This parameter is mandatory if 'CommonACLName' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound, self).__init__()

                    self.yang_name = "inbound"
                    self.yang_parent_name = "ipv4-packet-filter"

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.common_acl_name = YLeaf(YType.str, "common-acl-name")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.hardware_count = YLeaf(YType.empty, "hardware-count")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("acl_name_array",
                                    "common_acl_name",
                                    "compression_level",
                                    "hardware_count",
                                    "interface_statistics",
                                    "is_common_array",
                                    "name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.common_acl_name.is_set or
                        self.compression_level.is_set or
                        self.hardware_count.is_set or
                        self.interface_statistics.is_set or
                        self.name.is_set)

                def has_operation(self):
                    for leaf in self.acl_name_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.is_common_array.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.acl_name_array.yfilter != YFilter.not_set or
                        self.common_acl_name.yfilter != YFilter.not_set or
                        self.compression_level.yfilter != YFilter.not_set or
                        self.hardware_count.yfilter != YFilter.not_set or
                        self.interface_statistics.yfilter != YFilter.not_set or
                        self.is_common_array.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "inbound" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.common_acl_name.is_set or self.common_acl_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.common_acl_name.get_name_leafdata())
                    if (self.compression_level.is_set or self.compression_level.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.compression_level.get_name_leafdata())
                    if (self.hardware_count.is_set or self.hardware_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hardware_count.get_name_leafdata())
                    if (self.interface_statistics.is_set or self.interface_statistics.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_statistics.get_name_leafdata())
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    leaf_name_data.extend(self.acl_name_array.get_name_leafdata())

                    leaf_name_data.extend(self.is_common_array.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "acl-name-array" or name == "common-acl-name" or name == "compression-level" or name == "hardware-count" or name == "interface-statistics" or name == "is-common-array" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "acl-name-array"):
                        self.acl_name_array.append(value)
                    if(value_path == "common-acl-name"):
                        self.common_acl_name = value
                        self.common_acl_name.value_namespace = name_space
                        self.common_acl_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "compression-level"):
                        self.compression_level = value
                        self.compression_level.value_namespace = name_space
                        self.compression_level.value_namespace_prefix = name_space_prefix
                    if(value_path == "hardware-count"):
                        self.hardware_count = value
                        self.hardware_count.value_namespace = name_space
                        self.hardware_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-statistics"):
                        self.interface_statistics = value
                        self.interface_statistics.value_namespace = name_space
                        self.interface_statistics.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-common-array"):
                        self.is_common_array.append(value)
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.inbound is not None and self.inbound.has_data()) or
                    (self.outbound is not None and self.outbound.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.inbound is not None and self.inbound.has_operation()) or
                    (self.outbound is not None and self.outbound.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ip-pfilter-cfg:ipv4-packet-filter" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "inbound"):
                    if (self.inbound is None):
                        self.inbound = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound()
                        self.inbound.parent = self
                        self._children_name_map["inbound"] = "inbound"
                    return self.inbound

                if (child_yang_name == "outbound"):
                    if (self.outbound is None):
                        self.outbound = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound()
                        self.outbound.parent = self
                        self._children_name_map["outbound"] = "outbound"
                    return self.outbound

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "inbound" or name == "outbound"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Dagrs(Entity):
            """
            Direct\-Attached Gateway Redundancy configuration
            
            .. attribute:: dagr
            
            	The DAGR entry being configured
            	**type**\: list of    :py:class:`Dagr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr>`
            
            

            """

            _prefix = 'ipv4-arp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dagrs, self).__init__()

                self.yang_name = "dagrs"
                self.yang_parent_name = "interface-configuration"

                self.dagr = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Dagrs, self).__setattr__(name, value)


            class Dagr(Entity):
                """
                The DAGR entry being configured
                
                .. attribute:: ip_addr  <key>
                
                	DAGR Peer IPv4 address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: enter
                
                	DAGR Group Enter item
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sub
                
                	DAGR Submode configuration
                	**type**\:   :py:class:`Sub <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub>`
                
                

                """

                _prefix = 'ipv4-arp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr, self).__init__()

                    self.yang_name = "dagr"
                    self.yang_parent_name = "dagrs"

                    self.ip_addr = YLeaf(YType.str, "ip-addr")

                    self.enter = YLeaf(YType.empty, "enter")

                    self.sub = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub()
                    self.sub.parent = self
                    self._children_name_map["sub"] = "sub"
                    self._children_yang_names.add("sub")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_addr",
                                    "enter") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr, self).__setattr__(name, value)


                class Sub(Entity):
                    """
                    DAGR Submode configuration
                    
                    .. attribute:: distance
                    
                    	Set Route Distance
                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance>`
                    
                    .. attribute:: metric
                    
                    	Set Route Metric
                    	**type**\:   :py:class:`Metric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric>`
                    
                    .. attribute:: priority_timeout
                    
                    	Priority Timeout value
                    	**type**\:  int
                    
                    	**range:** 1..10000
                    
                    	**default value**\: 20
                    
                    .. attribute:: timers
                    
                    	Set Query Timers
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers>`
                    
                    

                    """

                    _prefix = 'ipv4-arp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub, self).__init__()

                        self.yang_name = "sub"
                        self.yang_parent_name = "dagr"

                        self.priority_timeout = YLeaf(YType.uint32, "priority-timeout")

                        self.distance = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"
                        self._children_yang_names.add("distance")

                        self.metric = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._children_yang_names.add("metric")

                        self.timers = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._children_yang_names.add("timers")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("priority_timeout") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub, self).__setattr__(name, value)


                    class Metric(Entity):
                        """
                        Set Route Metric
                        
                        .. attribute:: metric_norm
                        
                        	Normal Route Metric
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 100
                        
                        .. attribute:: metric_prio
                        
                        	Priority Route Metric
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 90
                        
                        

                        """

                        _prefix = 'ipv4-arp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "sub"

                            self.metric_norm = YLeaf(YType.uint32, "metric-norm")

                            self.metric_prio = YLeaf(YType.uint32, "metric-prio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("metric_norm",
                                            "metric_prio") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.metric_norm.is_set or
                                self.metric_prio.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.metric_norm.yfilter != YFilter.not_set or
                                self.metric_prio.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "metric" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.metric_norm.is_set or self.metric_norm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_norm.get_name_leafdata())
                            if (self.metric_prio.is_set or self.metric_prio.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_prio.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "metric-norm" or name == "metric-prio"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "metric-norm"):
                                self.metric_norm = value
                                self.metric_norm.value_namespace = name_space
                                self.metric_norm.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-prio"):
                                self.metric_prio = value
                                self.metric_prio.value_namespace = name_space
                                self.metric_prio.value_namespace_prefix = name_space_prefix


                    class Timers(Entity):
                        """
                        Set Query Timers
                        
                        .. attribute:: query_time
                        
                        	Query Timeout
                        	**type**\:  int
                        
                        	**range:** 1..10000
                        
                        	**default value**\: 1
                        
                        .. attribute:: sby_time
                        
                        	Standby Query Timeout
                        	**type**\:  int
                        
                        	**range:** 1..10000
                        
                        	**default value**\: 20
                        
                        

                        """

                        _prefix = 'ipv4-arp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "sub"

                            self.query_time = YLeaf(YType.uint32, "query-time")

                            self.sby_time = YLeaf(YType.uint32, "sby-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("query_time",
                                            "sby_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.query_time.is_set or
                                self.sby_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.query_time.yfilter != YFilter.not_set or
                                self.sby_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "timers" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.query_time.is_set or self.query_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_time.get_name_leafdata())
                            if (self.sby_time.is_set or self.sby_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sby_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "query-time" or name == "sby-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "query-time"):
                                self.query_time = value
                                self.query_time.value_namespace = name_space
                                self.query_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "sby-time"):
                                self.sby_time = value
                                self.sby_time.value_namespace = name_space
                                self.sby_time.value_namespace_prefix = name_space_prefix


                    class Distance(Entity):
                        """
                        Set Route Distance
                        
                        .. attribute:: dist_norm
                        
                        	Normal Route Distance
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 150
                        
                        .. attribute:: dist_prio
                        
                        	Priority Route Distance
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 5
                        
                        

                        """

                        _prefix = 'ipv4-arp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "sub"

                            self.dist_norm = YLeaf(YType.uint32, "dist-norm")

                            self.dist_prio = YLeaf(YType.uint32, "dist-prio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dist_norm",
                                            "dist_prio") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.dist_norm.is_set or
                                self.dist_prio.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dist_norm.yfilter != YFilter.not_set or
                                self.dist_prio.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "distance" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dist_norm.is_set or self.dist_norm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dist_norm.get_name_leafdata())
                            if (self.dist_prio.is_set or self.dist_prio.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dist_prio.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dist-norm" or name == "dist-prio"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dist-norm"):
                                self.dist_norm = value
                                self.dist_norm.value_namespace = name_space
                                self.dist_norm.value_namespace_prefix = name_space_prefix
                            if(value_path == "dist-prio"):
                                self.dist_prio = value
                                self.dist_prio.value_namespace = name_space
                                self.dist_prio.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.priority_timeout.is_set or
                            (self.distance is not None and self.distance.has_data()) or
                            (self.metric is not None and self.metric.has_data()) or
                            (self.timers is not None and self.timers.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.priority_timeout.yfilter != YFilter.not_set or
                            (self.distance is not None and self.distance.has_operation()) or
                            (self.metric is not None and self.metric.has_operation()) or
                            (self.timers is not None and self.timers.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sub" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.priority_timeout.is_set or self.priority_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.priority_timeout.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "distance"):
                            if (self.distance is None):
                                self.distance = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"
                            return self.distance

                        if (child_yang_name == "metric"):
                            if (self.metric is None):
                                self.metric = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                            return self.metric

                        if (child_yang_name == "timers"):
                            if (self.timers is None):
                                self.timers = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                            return self.timers

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "distance" or name == "metric" or name == "timers" or name == "priority-timeout"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "priority-timeout"):
                            self.priority_timeout = value
                            self.priority_timeout.value_namespace = name_space
                            self.priority_timeout.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.ip_addr.is_set or
                        self.enter.is_set or
                        (self.sub is not None and self.sub.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_addr.yfilter != YFilter.not_set or
                        self.enter.yfilter != YFilter.not_set or
                        (self.sub is not None and self.sub.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "dagr" + "[ip-addr='" + self.ip_addr.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_addr.is_set or self.ip_addr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_addr.get_name_leafdata())
                    if (self.enter.is_set or self.enter.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enter.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sub"):
                        if (self.sub is None):
                            self.sub = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub()
                            self.sub.parent = self
                            self._children_name_map["sub"] = "sub"
                        return self.sub

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sub" or name == "ip-addr" or name == "enter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-addr"):
                        self.ip_addr = value
                        self.ip_addr.value_namespace = name_space
                        self.ip_addr.value_namespace_prefix = name_space_prefix
                    if(value_path == "enter"):
                        self.enter = value
                        self.enter.value_namespace = name_space
                        self.enter.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.dagr:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.dagr:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ipv4-arp-cfg:dagrs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "dagr"):
                    for c in self.dagr:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.dagr.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "dagr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Ipv4Arp(Entity):
            """
            Configure Address Resolution Protocol
            
            .. attribute:: gratuitous_ignore
            
            	Ignore the receipt of Gratuitous ARP packets on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: learning_disable
            
            	Disable the dynamic learning of ARP entries on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: learning_local
            
            	Enable the dynamic learning of ARP entries(for local subnet) on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: local_proxy_arp
            
            	Local Proxy ARP configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: proxy_arp
            
            	Proxy ARP configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: purge_delay
            
            	Time to delay purging arp entries when the interface goes down
            	**type**\:  int
            
            	**range:** 1..65535
            
            .. attribute:: timeout
            
            	Number of seconds for ARP cache timeout
            	**type**\:  int
            
            	**range:** 30..2144448000
            
            	**units**\: second
            
            

            """

            _prefix = 'ipv4-arp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp, self).__init__()

                self.yang_name = "ipv4arp"
                self.yang_parent_name = "interface-configuration"

                self.gratuitous_ignore = YLeaf(YType.empty, "gratuitous-ignore")

                self.learning_disable = YLeaf(YType.empty, "learning-disable")

                self.learning_local = YLeaf(YType.empty, "learning-local")

                self.local_proxy_arp = YLeaf(YType.empty, "local-proxy-arp")

                self.proxy_arp = YLeaf(YType.empty, "proxy-arp")

                self.purge_delay = YLeaf(YType.uint32, "purge-delay")

                self.timeout = YLeaf(YType.uint32, "timeout")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("gratuitous_ignore",
                                "learning_disable",
                                "learning_local",
                                "local_proxy_arp",
                                "proxy_arp",
                                "purge_delay",
                                "timeout") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.gratuitous_ignore.is_set or
                    self.learning_disable.is_set or
                    self.learning_local.is_set or
                    self.local_proxy_arp.is_set or
                    self.proxy_arp.is_set or
                    self.purge_delay.is_set or
                    self.timeout.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.gratuitous_ignore.yfilter != YFilter.not_set or
                    self.learning_disable.yfilter != YFilter.not_set or
                    self.learning_local.yfilter != YFilter.not_set or
                    self.local_proxy_arp.yfilter != YFilter.not_set or
                    self.proxy_arp.yfilter != YFilter.not_set or
                    self.purge_delay.yfilter != YFilter.not_set or
                    self.timeout.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ipv4-arp-cfg:ipv4arp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.gratuitous_ignore.is_set or self.gratuitous_ignore.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.gratuitous_ignore.get_name_leafdata())
                if (self.learning_disable.is_set or self.learning_disable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.learning_disable.get_name_leafdata())
                if (self.learning_local.is_set or self.learning_local.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.learning_local.get_name_leafdata())
                if (self.local_proxy_arp.is_set or self.local_proxy_arp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.local_proxy_arp.get_name_leafdata())
                if (self.proxy_arp.is_set or self.proxy_arp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.proxy_arp.get_name_leafdata())
                if (self.purge_delay.is_set or self.purge_delay.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.purge_delay.get_name_leafdata())
                if (self.timeout.is_set or self.timeout.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.timeout.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "gratuitous-ignore" or name == "learning-disable" or name == "learning-local" or name == "local-proxy-arp" or name == "proxy-arp" or name == "purge-delay" or name == "timeout"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "gratuitous-ignore"):
                    self.gratuitous_ignore = value
                    self.gratuitous_ignore.value_namespace = name_space
                    self.gratuitous_ignore.value_namespace_prefix = name_space_prefix
                if(value_path == "learning-disable"):
                    self.learning_disable = value
                    self.learning_disable.value_namespace = name_space
                    self.learning_disable.value_namespace_prefix = name_space_prefix
                if(value_path == "learning-local"):
                    self.learning_local = value
                    self.learning_local.value_namespace = name_space
                    self.learning_local.value_namespace_prefix = name_space_prefix
                if(value_path == "local-proxy-arp"):
                    self.local_proxy_arp = value
                    self.local_proxy_arp.value_namespace = name_space
                    self.local_proxy_arp.value_namespace_prefix = name_space_prefix
                if(value_path == "proxy-arp"):
                    self.proxy_arp = value
                    self.proxy_arp.value_namespace = name_space
                    self.proxy_arp.value_namespace_prefix = name_space_prefix
                if(value_path == "purge-delay"):
                    self.purge_delay = value
                    self.purge_delay.value_namespace = name_space
                    self.purge_delay.value_namespace_prefix = name_space_prefix
                if(value_path == "timeout"):
                    self.timeout = value
                    self.timeout.value_namespace = name_space
                    self.timeout.value_namespace_prefix = name_space_prefix


        class Ipv4Network(Entity):
            """
            Interface IPv4 Network configuration data
            
            .. attribute:: addresses
            
            	Set the IP address of an interface
            	**type**\:   :py:class:`Addresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses>`
            
            .. attribute:: bgp
            
            	Interface ipv4 bgp configuration
            	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp>`
            
            .. attribute:: bgp_pa
            
            	Interface ipv4 bgp configuration
            	**type**\:   :py:class:`BgpPa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa>`
            
            .. attribute:: forwarding_enable
            
            	IPv4 forwarding to get enabled on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: helper_addresses
            
            	The set of IP destination addresses for UDP broadcasts
            	**type**\:   :py:class:`HelperAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses>`
            
            .. attribute:: icmp_mask_reply
            
            	The flag for enabling sending of ICMP mask reply messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: mtu
            
            	The IP Maximum Transmission Unit
            	**type**\:  int
            
            	**range:** 68..65535
            
            .. attribute:: point_to_point
            
            	Enable point\-to\-point handling for this interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: tcp_mss_adjust_enable
            
            	Enable TCP MSS Adjust on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ttl_propagate_disable
            
            	Disable TTL propagate on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: verify
            
            	Enable Verify handling for this interface
            	**type**\:   :py:class:`Verify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify>`
            
            

            """

            _prefix = 'ipv4-io-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network, self).__init__()

                self.yang_name = "ipv4-network"
                self.yang_parent_name = "interface-configuration"

                self.forwarding_enable = YLeaf(YType.empty, "forwarding-enable")

                self.icmp_mask_reply = YLeaf(YType.empty, "icmp-mask-reply")

                self.mtu = YLeaf(YType.uint32, "mtu")

                self.point_to_point = YLeaf(YType.empty, "point-to-point")

                self.tcp_mss_adjust_enable = YLeaf(YType.empty, "tcp-mss-adjust-enable")

                self.ttl_propagate_disable = YLeaf(YType.empty, "ttl-propagate-disable")

                self.addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses()
                self.addresses.parent = self
                self._children_name_map["addresses"] = "addresses"
                self._children_yang_names.add("addresses")

                self.bgp = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp()
                self.bgp.parent = self
                self._children_name_map["bgp"] = "bgp"
                self._children_yang_names.add("bgp")

                self.bgp_pa = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa()
                self.bgp_pa.parent = self
                self._children_name_map["bgp_pa"] = "bgp-pa"
                self._children_yang_names.add("bgp-pa")

                self.helper_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses()
                self.helper_addresses.parent = self
                self._children_name_map["helper_addresses"] = "helper-addresses"
                self._children_yang_names.add("helper-addresses")

                self.verify = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify()
                self.verify.parent = self
                self._children_name_map["verify"] = "verify"
                self._children_yang_names.add("verify")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("forwarding_enable",
                                "icmp_mask_reply",
                                "mtu",
                                "point_to_point",
                                "tcp_mss_adjust_enable",
                                "ttl_propagate_disable") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network, self).__setattr__(name, value)


            class BgpPa(Entity):
                """
                Interface ipv4 bgp configuration
                
                .. attribute:: input
                
                	Input
                	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input>`
                
                .. attribute:: output
                
                	Output
                	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa, self).__init__()

                    self.yang_name = "bgp-pa"
                    self.yang_parent_name = "ipv4-network"

                    self.input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"
                    self._children_yang_names.add("input")

                    self.output = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._children_yang_names.add("output")


                class Input(Entity):
                    """
                    Input
                    
                    .. attribute:: destination_accounting
                    
                    	BGP PA configuration on destination
                    	**type**\:  bool
                    
                    .. attribute:: source_accounting
                    
                    	BGP PA configuration on source
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "bgp-pa"

                        self.destination_accounting = YLeaf(YType.boolean, "destination-accounting")

                        self.source_accounting = YLeaf(YType.boolean, "source-accounting")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("destination_accounting",
                                        "source_accounting") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.destination_accounting.is_set or
                            self.source_accounting.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.destination_accounting.yfilter != YFilter.not_set or
                            self.source_accounting.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "input" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.destination_accounting.is_set or self.destination_accounting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_accounting.get_name_leafdata())
                        if (self.source_accounting.is_set or self.source_accounting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_accounting.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-accounting" or name == "source-accounting"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "destination-accounting"):
                            self.destination_accounting = value
                            self.destination_accounting.value_namespace = name_space
                            self.destination_accounting.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-accounting"):
                            self.source_accounting = value
                            self.source_accounting.value_namespace = name_space
                            self.source_accounting.value_namespace_prefix = name_space_prefix


                class Output(Entity):
                    """
                    Output
                    
                    .. attribute:: destination_accounting
                    
                    	BGP PA configuration on destination
                    	**type**\:  bool
                    
                    .. attribute:: source_accounting
                    
                    	BGP PA configuration on source
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "bgp-pa"

                        self.destination_accounting = YLeaf(YType.boolean, "destination-accounting")

                        self.source_accounting = YLeaf(YType.boolean, "source-accounting")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("destination_accounting",
                                        "source_accounting") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.destination_accounting.is_set or
                            self.source_accounting.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.destination_accounting.yfilter != YFilter.not_set or
                            self.source_accounting.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "output" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.destination_accounting.is_set or self.destination_accounting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_accounting.get_name_leafdata())
                        if (self.source_accounting.is_set or self.source_accounting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_accounting.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-accounting" or name == "source-accounting"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "destination-accounting"):
                            self.destination_accounting = value
                            self.destination_accounting.value_namespace = name_space
                            self.destination_accounting.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-accounting"):
                            self.source_accounting = value
                            self.source_accounting.value_namespace = name_space
                            self.source_accounting.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        (self.input is not None and self.input.has_data()) or
                        (self.output is not None and self.output.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.input is not None and self.input.has_operation()) or
                        (self.output is not None and self.output.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-pa" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "input"):
                        if (self.input is None):
                            self.input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input()
                            self.input.parent = self
                            self._children_name_map["input"] = "input"
                        return self.input

                    if (child_yang_name == "output"):
                        if (self.output is None):
                            self.output = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output()
                            self.output.parent = self
                            self._children_name_map["output"] = "output"
                        return self.output

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "input" or name == "output"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Verify(Entity):
                """
                Enable Verify handling for this interface
                
                .. attribute:: default_ping
                
                	Allow default route to match when checking source address
                	**type**\:   :py:class:`Ipv4DefaultPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4DefaultPing>`
                
                .. attribute:: reachable
                
                	Source is reachable via any interface or interface on which packet was received
                	**type**\:   :py:class:`Ipv4Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4Reachable>`
                
                .. attribute:: self_ping
                
                	Allow router to ping itself (opens vulnerability in verification)
                	**type**\:   :py:class:`Ipv4SelfPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4SelfPing>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify, self).__init__()

                    self.yang_name = "verify"
                    self.yang_parent_name = "ipv4-network"

                    self.default_ping = YLeaf(YType.enumeration, "default-ping")

                    self.reachable = YLeaf(YType.enumeration, "reachable")

                    self.self_ping = YLeaf(YType.enumeration, "self-ping")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("default_ping",
                                    "reachable",
                                    "self_ping") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.default_ping.is_set or
                        self.reachable.is_set or
                        self.self_ping.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.default_ping.yfilter != YFilter.not_set or
                        self.reachable.yfilter != YFilter.not_set or
                        self.self_ping.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "verify" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.default_ping.is_set or self.default_ping.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_ping.get_name_leafdata())
                    if (self.reachable.is_set or self.reachable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reachable.get_name_leafdata())
                    if (self.self_ping.is_set or self.self_ping.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.self_ping.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-ping" or name == "reachable" or name == "self-ping"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "default-ping"):
                        self.default_ping = value
                        self.default_ping.value_namespace = name_space
                        self.default_ping.value_namespace_prefix = name_space_prefix
                    if(value_path == "reachable"):
                        self.reachable = value
                        self.reachable.value_namespace = name_space
                        self.reachable.value_namespace_prefix = name_space_prefix
                    if(value_path == "self-ping"):
                        self.self_ping = value
                        self.self_ping.value_namespace = name_space
                        self.self_ping.value_namespace_prefix = name_space_prefix


            class Bgp(Entity):
                """
                Interface ipv4 bgp configuration
                
                .. attribute:: flow_tag
                
                	Interface ipv4 bgp policy propagation flow tag configuration
                	**type**\:   :py:class:`FlowTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag>`
                
                .. attribute:: qppb
                
                	Interface ipv4 bgp policy propagation configuration
                	**type**\:   :py:class:`Qppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp, self).__init__()

                    self.yang_name = "bgp"
                    self.yang_parent_name = "ipv4-network"

                    self.flow_tag = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag()
                    self.flow_tag.parent = self
                    self._children_name_map["flow_tag"] = "flow-tag"
                    self._children_yang_names.add("flow-tag")

                    self.qppb = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb()
                    self.qppb.parent = self
                    self._children_name_map["qppb"] = "qppb"
                    self._children_yang_names.add("qppb")


                class Qppb(Entity):
                    """
                    Interface ipv4 bgp policy propagation
                    configuration
                    
                    .. attribute:: input
                    
                    	Input
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input>`
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb, self).__init__()

                        self.yang_name = "qppb"
                        self.yang_parent_name = "bgp"

                        self.input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")


                    class Input(Entity):
                        """
                        Input
                        
                        .. attribute:: destination
                        
                        	QPPB configuration on destination
                        	**type**\:   :py:class:`Ipv4InterfaceQppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4InterfaceQppb>`
                        
                        .. attribute:: source
                        
                        	QPPB configuration on source
                        	**type**\:   :py:class:`Ipv4InterfaceQppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4InterfaceQppb>`
                        
                        

                        """

                        _prefix = 'ipv4-io-cfg'
                        _revision = '2015-07-30'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qppb"

                            self.destination = YLeaf(YType.enumeration, "destination")

                            self.source = YLeaf(YType.enumeration, "source")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination",
                                            "source") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination.is_set or
                                self.source.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination.yfilter != YFilter.not_set or
                                self.source.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "input" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination.get_name_leafdata())
                            if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination" or name == "source"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination"):
                                self.destination = value
                                self.destination.value_namespace = name_space
                                self.destination.value_namespace_prefix = name_space_prefix
                            if(value_path == "source"):
                                self.source = value
                                self.source.value_namespace = name_space
                                self.source.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.input is not None and self.input.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.input is not None and self.input.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "qppb" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "input"):
                            if (self.input is None):
                                self.input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input()
                                self.input.parent = self
                                self._children_name_map["input"] = "input"
                            return self.input

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "input"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class FlowTag(Entity):
                    """
                    Interface ipv4 bgp policy propagation flow tag
                    configuration
                    
                    .. attribute:: flow_tag_input
                    
                    	Input
                    	**type**\:   :py:class:`FlowTagInput <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput>`
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag, self).__init__()

                        self.yang_name = "flow-tag"
                        self.yang_parent_name = "bgp"

                        self.flow_tag_input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput()
                        self.flow_tag_input.parent = self
                        self._children_name_map["flow_tag_input"] = "flow-tag-input"
                        self._children_yang_names.add("flow-tag-input")


                    class FlowTagInput(Entity):
                        """
                        Input
                        
                        .. attribute:: destination
                        
                        	FlowTag configuration on destination
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	FlowTag configuration on source
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-io-cfg'
                        _revision = '2015-07-30'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput, self).__init__()

                            self.yang_name = "flow-tag-input"
                            self.yang_parent_name = "flow-tag"

                            self.destination = YLeaf(YType.boolean, "destination")

                            self.source = YLeaf(YType.boolean, "source")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination",
                                            "source") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination.is_set or
                                self.source.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination.yfilter != YFilter.not_set or
                                self.source.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flow-tag-input" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination.get_name_leafdata())
                            if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination" or name == "source"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination"):
                                self.destination = value
                                self.destination.value_namespace = name_space
                                self.destination.value_namespace_prefix = name_space_prefix
                            if(value_path == "source"):
                                self.source = value
                                self.source.value_namespace = name_space
                                self.source.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.flow_tag_input is not None and self.flow_tag_input.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.flow_tag_input is not None and self.flow_tag_input.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flow-tag" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flow-tag-input"):
                            if (self.flow_tag_input is None):
                                self.flow_tag_input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput()
                                self.flow_tag_input.parent = self
                                self._children_name_map["flow_tag_input"] = "flow-tag-input"
                            return self.flow_tag_input

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-tag-input"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.flow_tag is not None and self.flow_tag.has_data()) or
                        (self.qppb is not None and self.qppb.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.flow_tag is not None and self.flow_tag.has_operation()) or
                        (self.qppb is not None and self.qppb.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flow-tag"):
                        if (self.flow_tag is None):
                            self.flow_tag = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag()
                            self.flow_tag.parent = self
                            self._children_name_map["flow_tag"] = "flow-tag"
                        return self.flow_tag

                    if (child_yang_name == "qppb"):
                        if (self.qppb is None):
                            self.qppb = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb()
                            self.qppb.parent = self
                            self._children_name_map["qppb"] = "qppb"
                        return self.qppb

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-tag" or name == "qppb"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Addresses(Entity):
                """
                Set the IP address of an interface
                
                .. attribute:: dhcp
                
                	IPv4 address and Mask negotiated via DHCP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: primary
                
                	IP address and Mask
                	**type**\:   :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary>`
                
                	**presence node**\: True
                
                .. attribute:: secondaries
                
                	Specify a secondary address
                	**type**\:   :py:class:`Secondaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses, self).__init__()

                    self.yang_name = "addresses"
                    self.yang_parent_name = "ipv4-network"

                    self.dhcp = YLeaf(YType.empty, "dhcp")

                    self.unnumbered = YLeaf(YType.str, "unnumbered")

                    self.primary = None
                    self._children_name_map["primary"] = "primary"
                    self._children_yang_names.add("primary")

                    self.secondaries = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries()
                    self.secondaries.parent = self
                    self._children_name_map["secondaries"] = "secondaries"
                    self._children_yang_names.add("secondaries")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dhcp",
                                    "unnumbered") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses, self).__setattr__(name, value)


                class Secondaries(Entity):
                    """
                    Specify a secondary address
                    
                    .. attribute:: secondary
                    
                    	IP address and Mask
                    	**type**\: list of    :py:class:`Secondary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary>`
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries, self).__init__()

                        self.yang_name = "secondaries"
                        self.yang_parent_name = "addresses"

                        self.secondary = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries, self).__setattr__(name, value)


                    class Secondary(Entity):
                        """
                        IP address and Mask
                        
                        .. attribute:: address  <key>
                        
                        	Secondary IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: netmask
                        
                        	Netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: route_tag
                        
                        	RouteTag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-io-cfg'
                        _revision = '2015-07-30'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "secondaries"

                            self.address = YLeaf(YType.str, "address")

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.route_tag = YLeaf(YType.uint32, "route-tag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "netmask",
                                            "route_tag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.netmask.is_set or
                                self.route_tag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.netmask.yfilter != YFilter.not_set or
                                self.route_tag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "secondary" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.netmask.get_name_leafdata())
                            if (self.route_tag.is_set or self.route_tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_tag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "netmask" or name == "route-tag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "netmask"):
                                self.netmask = value
                                self.netmask.value_namespace = name_space
                                self.netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-tag"):
                                self.route_tag = value
                                self.route_tag.value_namespace = name_space
                                self.route_tag.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.secondary:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.secondary:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "secondaries" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "secondary"):
                            for c in self.secondary:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.secondary.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "secondary"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Primary(Entity):
                    """
                    IP address and Mask
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    .. attribute:: netmask
                    
                    	Netmask
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    .. attribute:: route_tag
                    
                    	RouteTag
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary, self).__init__()

                        self.yang_name = "primary"
                        self.yang_parent_name = "addresses"
                        self.is_presence_container = True

                        self.address = YLeaf(YType.str, "address")

                        self.netmask = YLeaf(YType.str, "netmask")

                        self.route_tag = YLeaf(YType.uint32, "route-tag")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "netmask",
                                        "route_tag") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.netmask.is_set or
                            self.route_tag.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.netmask.yfilter != YFilter.not_set or
                            self.route_tag.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "primary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.netmask.get_name_leafdata())
                        if (self.route_tag.is_set or self.route_tag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_tag.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "netmask" or name == "route-tag"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "netmask"):
                            self.netmask = value
                            self.netmask.value_namespace = name_space
                            self.netmask.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-tag"):
                            self.route_tag = value
                            self.route_tag.value_namespace = name_space
                            self.route_tag.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dhcp.is_set or
                        self.unnumbered.is_set or
                        (self.secondaries is not None and self.secondaries.has_data()) or
                        (self.primary is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dhcp.yfilter != YFilter.not_set or
                        self.unnumbered.yfilter != YFilter.not_set or
                        (self.primary is not None and self.primary.has_operation()) or
                        (self.secondaries is not None and self.secondaries.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "addresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dhcp.is_set or self.dhcp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dhcp.get_name_leafdata())
                    if (self.unnumbered.is_set or self.unnumbered.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unnumbered.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "primary"):
                        if (self.primary is None):
                            self.primary = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary()
                            self.primary.parent = self
                            self._children_name_map["primary"] = "primary"
                        return self.primary

                    if (child_yang_name == "secondaries"):
                        if (self.secondaries is None):
                            self.secondaries = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries()
                            self.secondaries.parent = self
                            self._children_name_map["secondaries"] = "secondaries"
                        return self.secondaries

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "primary" or name == "secondaries" or name == "dhcp" or name == "unnumbered"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dhcp"):
                        self.dhcp = value
                        self.dhcp.value_namespace = name_space
                        self.dhcp.value_namespace_prefix = name_space_prefix
                    if(value_path == "unnumbered"):
                        self.unnumbered = value
                        self.unnumbered.value_namespace = name_space
                        self.unnumbered.value_namespace_prefix = name_space_prefix


            class HelperAddresses(Entity):
                """
                The set of IP destination addresses for UDP
                broadcasts
                
                .. attribute:: helper_address
                
                	An IP destination addresses for UDP broadcasts
                	**type**\: list of    :py:class:`HelperAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses, self).__init__()

                    self.yang_name = "helper-addresses"
                    self.yang_parent_name = "ipv4-network"

                    self.helper_address = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses, self).__setattr__(name, value)


                class HelperAddress(Entity):
                    """
                    An IP destination addresses for UDP broadcasts
                    
                    .. attribute:: address  <key>
                    
                    	IP destination address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2015-07-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "helper-addresses"

                        self.address = YLeaf(YType.str, "address")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.vrf_name.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "helper-address" + "[address='" + self.address.get() + "']" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.helper_address:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.helper_address:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "helper-addresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "helper-address"):
                        for c in self.helper_address:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.helper_address.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "helper-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.forwarding_enable.is_set or
                    self.icmp_mask_reply.is_set or
                    self.mtu.is_set or
                    self.point_to_point.is_set or
                    self.tcp_mss_adjust_enable.is_set or
                    self.ttl_propagate_disable.is_set or
                    (self.addresses is not None and self.addresses.has_data()) or
                    (self.bgp is not None and self.bgp.has_data()) or
                    (self.bgp_pa is not None and self.bgp_pa.has_data()) or
                    (self.helper_addresses is not None and self.helper_addresses.has_data()) or
                    (self.verify is not None and self.verify.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.forwarding_enable.yfilter != YFilter.not_set or
                    self.icmp_mask_reply.yfilter != YFilter.not_set or
                    self.mtu.yfilter != YFilter.not_set or
                    self.point_to_point.yfilter != YFilter.not_set or
                    self.tcp_mss_adjust_enable.yfilter != YFilter.not_set or
                    self.ttl_propagate_disable.yfilter != YFilter.not_set or
                    (self.addresses is not None and self.addresses.has_operation()) or
                    (self.bgp is not None and self.bgp.has_operation()) or
                    (self.bgp_pa is not None and self.bgp_pa.has_operation()) or
                    (self.helper_addresses is not None and self.helper_addresses.has_operation()) or
                    (self.verify is not None and self.verify.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ipv4-io-cfg:ipv4-network" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.forwarding_enable.is_set or self.forwarding_enable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.forwarding_enable.get_name_leafdata())
                if (self.icmp_mask_reply.is_set or self.icmp_mask_reply.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.icmp_mask_reply.get_name_leafdata())
                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mtu.get_name_leafdata())
                if (self.point_to_point.is_set or self.point_to_point.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.point_to_point.get_name_leafdata())
                if (self.tcp_mss_adjust_enable.is_set or self.tcp_mss_adjust_enable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tcp_mss_adjust_enable.get_name_leafdata())
                if (self.ttl_propagate_disable.is_set or self.ttl_propagate_disable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ttl_propagate_disable.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "addresses"):
                    if (self.addresses is None):
                        self.addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses()
                        self.addresses.parent = self
                        self._children_name_map["addresses"] = "addresses"
                    return self.addresses

                if (child_yang_name == "bgp"):
                    if (self.bgp is None):
                        self.bgp = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp()
                        self.bgp.parent = self
                        self._children_name_map["bgp"] = "bgp"
                    return self.bgp

                if (child_yang_name == "bgp-pa"):
                    if (self.bgp_pa is None):
                        self.bgp_pa = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa()
                        self.bgp_pa.parent = self
                        self._children_name_map["bgp_pa"] = "bgp-pa"
                    return self.bgp_pa

                if (child_yang_name == "helper-addresses"):
                    if (self.helper_addresses is None):
                        self.helper_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses()
                        self.helper_addresses.parent = self
                        self._children_name_map["helper_addresses"] = "helper-addresses"
                    return self.helper_addresses

                if (child_yang_name == "verify"):
                    if (self.verify is None):
                        self.verify = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"
                    return self.verify

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "addresses" or name == "bgp" or name == "bgp-pa" or name == "helper-addresses" or name == "verify" or name == "forwarding-enable" or name == "icmp-mask-reply" or name == "mtu" or name == "point-to-point" or name == "tcp-mss-adjust-enable" or name == "ttl-propagate-disable"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "forwarding-enable"):
                    self.forwarding_enable = value
                    self.forwarding_enable.value_namespace = name_space
                    self.forwarding_enable.value_namespace_prefix = name_space_prefix
                if(value_path == "icmp-mask-reply"):
                    self.icmp_mask_reply = value
                    self.icmp_mask_reply.value_namespace = name_space
                    self.icmp_mask_reply.value_namespace_prefix = name_space_prefix
                if(value_path == "mtu"):
                    self.mtu = value
                    self.mtu.value_namespace = name_space
                    self.mtu.value_namespace_prefix = name_space_prefix
                if(value_path == "point-to-point"):
                    self.point_to_point = value
                    self.point_to_point.value_namespace = name_space
                    self.point_to_point.value_namespace_prefix = name_space_prefix
                if(value_path == "tcp-mss-adjust-enable"):
                    self.tcp_mss_adjust_enable = value
                    self.tcp_mss_adjust_enable.value_namespace = name_space
                    self.tcp_mss_adjust_enable.value_namespace_prefix = name_space_prefix
                if(value_path == "ttl-propagate-disable"):
                    self.ttl_propagate_disable = value
                    self.ttl_propagate_disable.value_namespace = name_space
                    self.ttl_propagate_disable.value_namespace_prefix = name_space_prefix


        class Ipv4NetworkForwarding(Entity):
            """
            Interface IPv4 Network configuration data also
            used for forwarding
            
            .. attribute:: directed_broadcast
            
            	Enable forwarding of directed broadcast
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: redirects
            
            	Enable sending ICMP Redirect messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: unreachables
            
            	Disable sending ICMP unreachables
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ipv4-io-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding, self).__init__()

                self.yang_name = "ipv4-network-forwarding"
                self.yang_parent_name = "interface-configuration"

                self.directed_broadcast = YLeaf(YType.empty, "directed-broadcast")

                self.redirects = YLeaf(YType.empty, "redirects")

                self.unreachables = YLeaf(YType.empty, "unreachables")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("directed_broadcast",
                                "redirects",
                                "unreachables") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.directed_broadcast.is_set or
                    self.redirects.is_set or
                    self.unreachables.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.directed_broadcast.yfilter != YFilter.not_set or
                    self.redirects.yfilter != YFilter.not_set or
                    self.unreachables.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ipv4-io-cfg:ipv4-network-forwarding" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.directed_broadcast.is_set or self.directed_broadcast.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.directed_broadcast.get_name_leafdata())
                if (self.redirects.is_set or self.redirects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.redirects.get_name_leafdata())
                if (self.unreachables.is_set or self.unreachables.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unreachables.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "directed-broadcast" or name == "redirects" or name == "unreachables"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "directed-broadcast"):
                    self.directed_broadcast = value
                    self.directed_broadcast.value_namespace = name_space
                    self.directed_broadcast.value_namespace_prefix = name_space_prefix
                if(value_path == "redirects"):
                    self.redirects = value
                    self.redirects.value_namespace = name_space
                    self.redirects.value_namespace_prefix = name_space_prefix
                if(value_path == "unreachables"):
                    self.unreachables = value
                    self.unreachables.value_namespace = name_space
                    self.unreachables.value_namespace_prefix = name_space_prefix


        class Ipv6Network(Entity):
            """
            Interface IPv6 Network configuration data
            
            .. attribute:: addresses
            
            	Set the IPv6 address of an interface
            	**type**\:   :py:class:`Addresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses>`
            
            .. attribute:: bgp_flow_tag_policy_table
            
            	Interface ipv6 bgp policy propagation flowtag configuration
            	**type**\:   :py:class:`BgpFlowTagPolicyTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable>`
            
            .. attribute:: bgp_policy_accountings
            
            	IPv6 BGP Policy Accounting
            	**type**\:   :py:class:`BgpPolicyAccountings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings>`
            
            .. attribute:: bgp_qos_policy_propagation
            
            	Configure BGP QoS policy propagation
            	**type**\:   :py:class:`BgpQosPolicyPropagation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation>`
            
            	**presence node**\: True
            
            .. attribute:: mtu
            
            	MTU Setting of Interface
            	**type**\:  int
            
            	**range:** 1280..65535
            
            .. attribute:: tcp_mss_adjust_enable
            
            	Enable TCP MSS adjust on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ttl_propagate_disable
            
            	Disabled TTL propagate on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: unnumbered
            
            	Enable IPv6 processing without an explicit address
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: unreachables
            
            	Override Sending of ICMP Unreachable Messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: verify
            
            	IPv6 Verify Unicast Souce Reachable
            	**type**\:   :py:class:`Verify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ipv6-ma-cfg'
            _revision = '2017-03-03'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network, self).__init__()

                self.yang_name = "ipv6-network"
                self.yang_parent_name = "interface-configuration"

                self.mtu = YLeaf(YType.uint32, "mtu")

                self.tcp_mss_adjust_enable = YLeaf(YType.empty, "tcp-mss-adjust-enable")

                self.ttl_propagate_disable = YLeaf(YType.empty, "ttl-propagate-disable")

                self.unnumbered = YLeaf(YType.str, "unnumbered")

                self.unreachables = YLeaf(YType.empty, "unreachables")

                self.addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses()
                self.addresses.parent = self
                self._children_name_map["addresses"] = "addresses"
                self._children_yang_names.add("addresses")

                self.bgp_flow_tag_policy_table = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable()
                self.bgp_flow_tag_policy_table.parent = self
                self._children_name_map["bgp_flow_tag_policy_table"] = "bgp-flow-tag-policy-table"
                self._children_yang_names.add("bgp-flow-tag-policy-table")

                self.bgp_policy_accountings = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings()
                self.bgp_policy_accountings.parent = self
                self._children_name_map["bgp_policy_accountings"] = "bgp-policy-accountings"
                self._children_yang_names.add("bgp-policy-accountings")

                self.bgp_qos_policy_propagation = None
                self._children_name_map["bgp_qos_policy_propagation"] = "bgp-qos-policy-propagation"
                self._children_yang_names.add("bgp-qos-policy-propagation")

                self.verify = None
                self._children_name_map["verify"] = "verify"
                self._children_yang_names.add("verify")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("mtu",
                                "tcp_mss_adjust_enable",
                                "ttl_propagate_disable",
                                "unnumbered",
                                "unreachables") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network, self).__setattr__(name, value)


            class BgpQosPolicyPropagation(Entity):
                """
                Configure BGP QoS policy propagation
                
                .. attribute:: destination
                
                	QPPB configuration on destination
                	**type**\:   :py:class:`Ipv6Qppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6Qppb>`
                
                	**mandatory**\: True
                
                .. attribute:: source
                
                	QPPB configuration on source
                	**type**\:   :py:class:`Ipv6Qppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6Qppb>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation, self).__init__()

                    self.yang_name = "bgp-qos-policy-propagation"
                    self.yang_parent_name = "ipv6-network"
                    self.is_presence_container = True

                    self.destination = YLeaf(YType.enumeration, "destination")

                    self.source = YLeaf(YType.enumeration, "source")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination",
                                    "source") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination.is_set or
                        self.source.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination.yfilter != YFilter.not_set or
                        self.source.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-qos-policy-propagation" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination.get_name_leafdata())
                    if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination" or name == "source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination"):
                        self.destination = value
                        self.destination.value_namespace = name_space
                        self.destination.value_namespace_prefix = name_space_prefix
                    if(value_path == "source"):
                        self.source = value
                        self.source.value_namespace = name_space
                        self.source.value_namespace_prefix = name_space_prefix


            class BgpPolicyAccountings(Entity):
                """
                IPv6 BGP Policy Accounting
                
                .. attribute:: bgp_policy_accounting
                
                	Accounting input or output
                	**type**\: list of    :py:class:`BgpPolicyAccounting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting>`
                
                

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings, self).__init__()

                    self.yang_name = "bgp-policy-accountings"
                    self.yang_parent_name = "ipv6-network"

                    self.bgp_policy_accounting = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings, self).__setattr__(name, value)


                class BgpPolicyAccounting(Entity):
                    """
                    Accounting input or output
                    
                    .. attribute:: direction  <key>
                    
                    	Accouting on input or output
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: destination_accounting
                    
                    	Accounting on Destination IP Address
                    	**type**\:  bool
                    
                    	**mandatory**\: True
                    
                    .. attribute:: source_accounting
                    
                    	Accounting on Source IP Address
                    	**type**\:  bool
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting, self).__init__()

                        self.yang_name = "bgp-policy-accounting"
                        self.yang_parent_name = "bgp-policy-accountings"

                        self.direction = YLeaf(YType.str, "direction")

                        self.destination_accounting = YLeaf(YType.boolean, "destination-accounting")

                        self.source_accounting = YLeaf(YType.boolean, "source-accounting")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("direction",
                                        "destination_accounting",
                                        "source_accounting") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.direction.is_set or
                            self.destination_accounting.is_set or
                            self.source_accounting.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.direction.yfilter != YFilter.not_set or
                            self.destination_accounting.yfilter != YFilter.not_set or
                            self.source_accounting.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-policy-accounting" + "[direction='" + self.direction.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.direction.get_name_leafdata())
                        if (self.destination_accounting.is_set or self.destination_accounting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_accounting.get_name_leafdata())
                        if (self.source_accounting.is_set or self.source_accounting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_accounting.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "direction" or name == "destination-accounting" or name == "source-accounting"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "direction"):
                            self.direction = value
                            self.direction.value_namespace = name_space
                            self.direction.value_namespace_prefix = name_space_prefix
                        if(value_path == "destination-accounting"):
                            self.destination_accounting = value
                            self.destination_accounting.value_namespace = name_space
                            self.destination_accounting.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-accounting"):
                            self.source_accounting = value
                            self.source_accounting.value_namespace = name_space
                            self.source_accounting.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bgp_policy_accounting:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bgp_policy_accounting:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-policy-accountings" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-policy-accounting"):
                        for c in self.bgp_policy_accounting:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bgp_policy_accounting.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-policy-accounting"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Verify(Entity):
                """
                IPv6 Verify Unicast Souce Reachable
                
                .. attribute:: default_ping
                
                	Allow Default Route
                	**type**\:   :py:class:`Ipv6DefaultPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6DefaultPing>`
                
                	**mandatory**\: True
                
                .. attribute:: reachable
                
                	Source Reachable Interface
                	**type**\:   :py:class:`Ipv6Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6Reachable>`
                
                	**mandatory**\: True
                
                .. attribute:: self_ping
                
                	Allow Self Ping
                	**type**\:   :py:class:`Ipv6SelfPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6SelfPing>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify, self).__init__()

                    self.yang_name = "verify"
                    self.yang_parent_name = "ipv6-network"
                    self.is_presence_container = True

                    self.default_ping = YLeaf(YType.enumeration, "default-ping")

                    self.reachable = YLeaf(YType.enumeration, "reachable")

                    self.self_ping = YLeaf(YType.enumeration, "self-ping")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("default_ping",
                                    "reachable",
                                    "self_ping") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.default_ping.is_set or
                        self.reachable.is_set or
                        self.self_ping.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.default_ping.yfilter != YFilter.not_set or
                        self.reachable.yfilter != YFilter.not_set or
                        self.self_ping.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "verify" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.default_ping.is_set or self.default_ping.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_ping.get_name_leafdata())
                    if (self.reachable.is_set or self.reachable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reachable.get_name_leafdata())
                    if (self.self_ping.is_set or self.self_ping.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.self_ping.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-ping" or name == "reachable" or name == "self-ping"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "default-ping"):
                        self.default_ping = value
                        self.default_ping.value_namespace = name_space
                        self.default_ping.value_namespace_prefix = name_space_prefix
                    if(value_path == "reachable"):
                        self.reachable = value
                        self.reachable.value_namespace = name_space
                        self.reachable.value_namespace_prefix = name_space_prefix
                    if(value_path == "self-ping"):
                        self.self_ping = value
                        self.self_ping.value_namespace = name_space
                        self.self_ping.value_namespace_prefix = name_space_prefix


            class Addresses(Entity):
                """
                Set the IPv6 address of an interface
                
                .. attribute:: auto_configuration
                
                	Auto IPv6 Interface Configuration
                	**type**\:   :py:class:`AutoConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration>`
                
                .. attribute:: eui64_addresses
                
                	EUI\-64 IPv6 address Table
                	**type**\:   :py:class:`Eui64Addresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses>`
                
                .. attribute:: link_local_address
                
                	Link local IPv6 address
                	**type**\:   :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress>`
                
                	**presence node**\: True
                
                .. attribute:: regular_addresses
                
                	Regular IPv6 address Table
                	**type**\:   :py:class:`RegularAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses>`
                
                .. attribute:: segment_routings
                
                	Segment Routing Table
                	**type**\:   :py:class:`SegmentRoutings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings>`
                
                

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses, self).__init__()

                    self.yang_name = "addresses"
                    self.yang_parent_name = "ipv6-network"

                    self.auto_configuration = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration()
                    self.auto_configuration.parent = self
                    self._children_name_map["auto_configuration"] = "auto-configuration"
                    self._children_yang_names.add("auto-configuration")

                    self.eui64_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses()
                    self.eui64_addresses.parent = self
                    self._children_name_map["eui64_addresses"] = "eui64-addresses"
                    self._children_yang_names.add("eui64-addresses")

                    self.link_local_address = None
                    self._children_name_map["link_local_address"] = "link-local-address"
                    self._children_yang_names.add("link-local-address")

                    self.regular_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses()
                    self.regular_addresses.parent = self
                    self._children_name_map["regular_addresses"] = "regular-addresses"
                    self._children_yang_names.add("regular-addresses")

                    self.segment_routings = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings()
                    self.segment_routings.parent = self
                    self._children_name_map["segment_routings"] = "segment-routings"
                    self._children_yang_names.add("segment-routings")


                class SegmentRoutings(Entity):
                    """
                    Segment Routing Table
                    
                    .. attribute:: segment_routing
                    
                    	Segment Routing Submode 
                    	**type**\: list of    :py:class:`SegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings, self).__init__()

                        self.yang_name = "segment-routings"
                        self.yang_parent_name = "addresses"

                        self.segment_routing = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings, self).__setattr__(name, value)


                    class SegmentRouting(Entity):
                        """
                        Segment Routing Submode 
                        
                        .. attribute:: address  <key>
                        
                        	IPv6 address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: enable
                        
                        	Segment Routing Submode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6_prefix_sid
                        
                        	Prefix\-Sid for Segment Routing
                        	**type**\:   :py:class:`Ipv6PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ipv6-ma-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting, self).__init__()

                            self.yang_name = "segment-routing"
                            self.yang_parent_name = "segment-routings"

                            self.address = YLeaf(YType.str, "address")

                            self.enable = YLeaf(YType.empty, "enable")

                            self.ipv6_prefix_sid = None
                            self._children_name_map["ipv6_prefix_sid"] = "ipv6-prefix-sid"
                            self._children_yang_names.add("ipv6-prefix-sid")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "enable") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting, self).__setattr__(name, value)


                        class Ipv6PrefixSid(Entity):
                            """
                            Prefix\-Sid for Segment Routing
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            	**mandatory**\: True
                            
                            .. attribute:: route_tag
                            
                            	RouteTag
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: zone
                            
                            	IPv6 address zone
                            	**type**\:  str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv6-ma-cfg'
                            _revision = '2017-03-03'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid, self).__init__()

                                self.yang_name = "ipv6-prefix-sid"
                                self.yang_parent_name = "segment-routing"
                                self.is_presence_container = True

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_tag = YLeaf(YType.uint32, "route-tag")

                                self.zone = YLeaf(YType.str, "zone")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix_length",
                                                "route_tag",
                                                "zone") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.prefix_length.is_set or
                                    self.route_tag.is_set or
                                    self.zone.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.route_tag.yfilter != YFilter.not_set or
                                    self.zone.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv6-prefix-sid" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.route_tag.is_set or self.route_tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_tag.get_name_leafdata())
                                if (self.zone.is_set or self.zone.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.zone.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix-length" or name == "route-tag" or name == "zone"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-tag"):
                                    self.route_tag = value
                                    self.route_tag.value_namespace = name_space
                                    self.route_tag.value_namespace_prefix = name_space_prefix
                                if(value_path == "zone"):
                                    self.zone = value
                                    self.zone.value_namespace = name_space
                                    self.zone.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.enable.is_set or
                                (self.ipv6_prefix_sid is not None))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.enable.yfilter != YFilter.not_set or
                                (self.ipv6_prefix_sid is not None and self.ipv6_prefix_sid.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment-routing" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enable.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv6-prefix-sid"):
                                if (self.ipv6_prefix_sid is None):
                                    self.ipv6_prefix_sid = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid()
                                    self.ipv6_prefix_sid.parent = self
                                    self._children_name_map["ipv6_prefix_sid"] = "ipv6-prefix-sid"
                                return self.ipv6_prefix_sid

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv6-prefix-sid" or name == "address" or name == "enable"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "enable"):
                                self.enable = value
                                self.enable.value_namespace = name_space
                                self.enable.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.segment_routing:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.segment_routing:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "segment-routings" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "segment-routing"):
                            for c in self.segment_routing:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.segment_routing.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "segment-routing"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class LinkLocalAddress(Entity):
                    """
                    Link local IPv6 address
                    
                    .. attribute:: address
                    
                    	IPv6 address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    
                    ----
                    .. attribute:: route_tag
                    
                    	RouteTag
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: zone
                    
                    	IPv6 address zone
                    	**type**\:  str
                    
                    	**default value**\: 0
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress, self).__init__()

                        self.yang_name = "link-local-address"
                        self.yang_parent_name = "addresses"
                        self.is_presence_container = True

                        self.address = YLeaf(YType.str, "address")

                        self.route_tag = YLeaf(YType.uint32, "route-tag")

                        self.zone = YLeaf(YType.str, "zone")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "route_tag",
                                        "zone") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.route_tag.is_set or
                            self.zone.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.route_tag.yfilter != YFilter.not_set or
                            self.zone.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "link-local-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.route_tag.is_set or self.route_tag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_tag.get_name_leafdata())
                        if (self.zone.is_set or self.zone.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.zone.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "route-tag" or name == "zone"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-tag"):
                            self.route_tag = value
                            self.route_tag.value_namespace = name_space
                            self.route_tag.value_namespace_prefix = name_space_prefix
                        if(value_path == "zone"):
                            self.zone = value
                            self.zone.value_namespace = name_space
                            self.zone.value_namespace_prefix = name_space_prefix


                class Eui64Addresses(Entity):
                    """
                    EUI\-64 IPv6 address Table
                    
                    .. attribute:: eui64_address
                    
                    	EUI\-64 IPv6 address
                    	**type**\: list of    :py:class:`Eui64Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses, self).__init__()

                        self.yang_name = "eui64-addresses"
                        self.yang_parent_name = "addresses"

                        self.eui64_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses, self).__setattr__(name, value)


                    class Eui64Address(Entity):
                        """
                        EUI\-64 IPv6 address
                        
                        .. attribute:: address  <key>
                        
                        	IPv6 address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        	**mandatory**\: True
                        
                        .. attribute:: route_tag
                        
                        	RouteTag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: zone
                        
                        	IPv6 address zone
                        	**type**\:  str
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'ipv6-ma-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address, self).__init__()

                            self.yang_name = "eui64-address"
                            self.yang_parent_name = "eui64-addresses"

                            self.address = YLeaf(YType.str, "address")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.route_tag = YLeaf(YType.uint32, "route-tag")

                            self.zone = YLeaf(YType.str, "zone")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "prefix_length",
                                            "route_tag",
                                            "zone") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.prefix_length.is_set or
                                self.route_tag.is_set or
                                self.zone.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.route_tag.yfilter != YFilter.not_set or
                                self.zone.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "eui64-address" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.route_tag.is_set or self.route_tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_tag.get_name_leafdata())
                            if (self.zone.is_set or self.zone.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.zone.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "prefix-length" or name == "route-tag" or name == "zone"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-tag"):
                                self.route_tag = value
                                self.route_tag.value_namespace = name_space
                                self.route_tag.value_namespace_prefix = name_space_prefix
                            if(value_path == "zone"):
                                self.zone = value
                                self.zone.value_namespace = name_space
                                self.zone.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.eui64_address:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.eui64_address:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "eui64-addresses" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "eui64-address"):
                            for c in self.eui64_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.eui64_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "eui64-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RegularAddresses(Entity):
                    """
                    Regular IPv6 address Table
                    
                    .. attribute:: regular_address
                    
                    	Regular IPv6 address
                    	**type**\: list of    :py:class:`RegularAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses, self).__init__()

                        self.yang_name = "regular-addresses"
                        self.yang_parent_name = "addresses"

                        self.regular_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses, self).__setattr__(name, value)


                    class RegularAddress(Entity):
                        """
                        Regular IPv6 address
                        
                        .. attribute:: address  <key>
                        
                        	IPv6 address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        	**mandatory**\: True
                        
                        .. attribute:: route_tag
                        
                        	RouteTag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: zone
                        
                        	IPv6 address zone
                        	**type**\:  str
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'ipv6-ma-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress, self).__init__()

                            self.yang_name = "regular-address"
                            self.yang_parent_name = "regular-addresses"

                            self.address = YLeaf(YType.str, "address")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.route_tag = YLeaf(YType.uint32, "route-tag")

                            self.zone = YLeaf(YType.str, "zone")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "prefix_length",
                                            "route_tag",
                                            "zone") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.prefix_length.is_set or
                                self.route_tag.is_set or
                                self.zone.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.route_tag.yfilter != YFilter.not_set or
                                self.zone.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "regular-address" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.route_tag.is_set or self.route_tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_tag.get_name_leafdata())
                            if (self.zone.is_set or self.zone.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.zone.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "prefix-length" or name == "route-tag" or name == "zone"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-tag"):
                                self.route_tag = value
                                self.route_tag.value_namespace = name_space
                                self.route_tag.value_namespace_prefix = name_space_prefix
                            if(value_path == "zone"):
                                self.zone = value
                                self.zone.value_namespace = name_space
                                self.zone.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.regular_address:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.regular_address:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "regular-addresses" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "regular-address"):
                            for c in self.regular_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.regular_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "regular-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AutoConfiguration(Entity):
                    """
                    Auto IPv6 Interface Configuration
                    
                    .. attribute:: enable
                    
                    	The flag to enable auto ipv6 interface configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration, self).__init__()

                        self.yang_name = "auto-configuration"
                        self.yang_parent_name = "addresses"

                        self.enable = YLeaf(YType.empty, "enable")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("enable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration, self).__setattr__(name, value)

                    def has_data(self):
                        return self.enable.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto-configuration" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "enable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        (self.auto_configuration is not None and self.auto_configuration.has_data()) or
                        (self.eui64_addresses is not None and self.eui64_addresses.has_data()) or
                        (self.regular_addresses is not None and self.regular_addresses.has_data()) or
                        (self.segment_routings is not None and self.segment_routings.has_data()) or
                        (self.link_local_address is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.auto_configuration is not None and self.auto_configuration.has_operation()) or
                        (self.eui64_addresses is not None and self.eui64_addresses.has_operation()) or
                        (self.link_local_address is not None and self.link_local_address.has_operation()) or
                        (self.regular_addresses is not None and self.regular_addresses.has_operation()) or
                        (self.segment_routings is not None and self.segment_routings.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "addresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto-configuration"):
                        if (self.auto_configuration is None):
                            self.auto_configuration = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration()
                            self.auto_configuration.parent = self
                            self._children_name_map["auto_configuration"] = "auto-configuration"
                        return self.auto_configuration

                    if (child_yang_name == "eui64-addresses"):
                        if (self.eui64_addresses is None):
                            self.eui64_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses()
                            self.eui64_addresses.parent = self
                            self._children_name_map["eui64_addresses"] = "eui64-addresses"
                        return self.eui64_addresses

                    if (child_yang_name == "link-local-address"):
                        if (self.link_local_address is None):
                            self.link_local_address = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress()
                            self.link_local_address.parent = self
                            self._children_name_map["link_local_address"] = "link-local-address"
                        return self.link_local_address

                    if (child_yang_name == "regular-addresses"):
                        if (self.regular_addresses is None):
                            self.regular_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses()
                            self.regular_addresses.parent = self
                            self._children_name_map["regular_addresses"] = "regular-addresses"
                        return self.regular_addresses

                    if (child_yang_name == "segment-routings"):
                        if (self.segment_routings is None):
                            self.segment_routings = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings()
                            self.segment_routings.parent = self
                            self._children_name_map["segment_routings"] = "segment-routings"
                        return self.segment_routings

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto-configuration" or name == "eui64-addresses" or name == "link-local-address" or name == "regular-addresses" or name == "segment-routings"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BgpFlowTagPolicyTable(Entity):
                """
                Interface ipv6 bgp policy propagation flowtag
                configuration
                
                .. attribute:: bgp_flow_tag_policy
                
                	Input
                	**type**\:   :py:class:`BgpFlowTagPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy>`
                
                

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable, self).__init__()

                    self.yang_name = "bgp-flow-tag-policy-table"
                    self.yang_parent_name = "ipv6-network"

                    self.bgp_flow_tag_policy = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy()
                    self.bgp_flow_tag_policy.parent = self
                    self._children_name_map["bgp_flow_tag_policy"] = "bgp-flow-tag-policy"
                    self._children_yang_names.add("bgp-flow-tag-policy")


                class BgpFlowTagPolicy(Entity):
                    """
                    Input
                    
                    .. attribute:: destination
                    
                    	Flow Tag configuration on destination
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	Flow Tag configuration on source
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy, self).__init__()

                        self.yang_name = "bgp-flow-tag-policy"
                        self.yang_parent_name = "bgp-flow-tag-policy-table"

                        self.destination = YLeaf(YType.boolean, "destination")

                        self.source = YLeaf(YType.boolean, "source")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("destination",
                                        "source") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.destination.is_set or
                            self.source.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.destination.yfilter != YFilter.not_set or
                            self.source.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-flow-tag-policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination.get_name_leafdata())
                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination" or name == "source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "destination"):
                            self.destination = value
                            self.destination.value_namespace = name_space
                            self.destination.value_namespace_prefix = name_space_prefix
                        if(value_path == "source"):
                            self.source = value
                            self.source.value_namespace = name_space
                            self.source.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.bgp_flow_tag_policy is not None and self.bgp_flow_tag_policy.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bgp_flow_tag_policy is not None and self.bgp_flow_tag_policy.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-flow-tag-policy-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-flow-tag-policy"):
                        if (self.bgp_flow_tag_policy is None):
                            self.bgp_flow_tag_policy = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy()
                            self.bgp_flow_tag_policy.parent = self
                            self._children_name_map["bgp_flow_tag_policy"] = "bgp-flow-tag-policy"
                        return self.bgp_flow_tag_policy

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-flow-tag-policy"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.mtu.is_set or
                    self.tcp_mss_adjust_enable.is_set or
                    self.ttl_propagate_disable.is_set or
                    self.unnumbered.is_set or
                    self.unreachables.is_set or
                    (self.addresses is not None and self.addresses.has_data()) or
                    (self.bgp_flow_tag_policy_table is not None and self.bgp_flow_tag_policy_table.has_data()) or
                    (self.bgp_policy_accountings is not None and self.bgp_policy_accountings.has_data()) or
                    (self.bgp_qos_policy_propagation is not None) or
                    (self.verify is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.mtu.yfilter != YFilter.not_set or
                    self.tcp_mss_adjust_enable.yfilter != YFilter.not_set or
                    self.ttl_propagate_disable.yfilter != YFilter.not_set or
                    self.unnumbered.yfilter != YFilter.not_set or
                    self.unreachables.yfilter != YFilter.not_set or
                    (self.addresses is not None and self.addresses.has_operation()) or
                    (self.bgp_flow_tag_policy_table is not None and self.bgp_flow_tag_policy_table.has_operation()) or
                    (self.bgp_policy_accountings is not None and self.bgp_policy_accountings.has_operation()) or
                    (self.bgp_qos_policy_propagation is not None and self.bgp_qos_policy_propagation.has_operation()) or
                    (self.verify is not None and self.verify.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ipv6-ma-cfg:ipv6-network" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mtu.get_name_leafdata())
                if (self.tcp_mss_adjust_enable.is_set or self.tcp_mss_adjust_enable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tcp_mss_adjust_enable.get_name_leafdata())
                if (self.ttl_propagate_disable.is_set or self.ttl_propagate_disable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ttl_propagate_disable.get_name_leafdata())
                if (self.unnumbered.is_set or self.unnumbered.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unnumbered.get_name_leafdata())
                if (self.unreachables.is_set or self.unreachables.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unreachables.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "addresses"):
                    if (self.addresses is None):
                        self.addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses()
                        self.addresses.parent = self
                        self._children_name_map["addresses"] = "addresses"
                    return self.addresses

                if (child_yang_name == "bgp-flow-tag-policy-table"):
                    if (self.bgp_flow_tag_policy_table is None):
                        self.bgp_flow_tag_policy_table = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable()
                        self.bgp_flow_tag_policy_table.parent = self
                        self._children_name_map["bgp_flow_tag_policy_table"] = "bgp-flow-tag-policy-table"
                    return self.bgp_flow_tag_policy_table

                if (child_yang_name == "bgp-policy-accountings"):
                    if (self.bgp_policy_accountings is None):
                        self.bgp_policy_accountings = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings()
                        self.bgp_policy_accountings.parent = self
                        self._children_name_map["bgp_policy_accountings"] = "bgp-policy-accountings"
                    return self.bgp_policy_accountings

                if (child_yang_name == "bgp-qos-policy-propagation"):
                    if (self.bgp_qos_policy_propagation is None):
                        self.bgp_qos_policy_propagation = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation()
                        self.bgp_qos_policy_propagation.parent = self
                        self._children_name_map["bgp_qos_policy_propagation"] = "bgp-qos-policy-propagation"
                    return self.bgp_qos_policy_propagation

                if (child_yang_name == "verify"):
                    if (self.verify is None):
                        self.verify = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify()
                        self.verify.parent = self
                        self._children_name_map["verify"] = "verify"
                    return self.verify

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "addresses" or name == "bgp-flow-tag-policy-table" or name == "bgp-policy-accountings" or name == "bgp-qos-policy-propagation" or name == "verify" or name == "mtu" or name == "tcp-mss-adjust-enable" or name == "ttl-propagate-disable" or name == "unnumbered" or name == "unreachables"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "mtu"):
                    self.mtu = value
                    self.mtu.value_namespace = name_space
                    self.mtu.value_namespace_prefix = name_space_prefix
                if(value_path == "tcp-mss-adjust-enable"):
                    self.tcp_mss_adjust_enable = value
                    self.tcp_mss_adjust_enable.value_namespace = name_space
                    self.tcp_mss_adjust_enable.value_namespace_prefix = name_space_prefix
                if(value_path == "ttl-propagate-disable"):
                    self.ttl_propagate_disable = value
                    self.ttl_propagate_disable.value_namespace = name_space
                    self.ttl_propagate_disable.value_namespace_prefix = name_space_prefix
                if(value_path == "unnumbered"):
                    self.unnumbered = value
                    self.unnumbered.value_namespace = name_space
                    self.unnumbered.value_namespace_prefix = name_space_prefix
                if(value_path == "unreachables"):
                    self.unreachables = value
                    self.unreachables.value_namespace = name_space
                    self.unreachables.value_namespace_prefix = name_space_prefix


        class Ipv6Neighbor(Entity):
            """
            IPv6 interface neighbor or neighbor discovery
            configuration
            
            .. attribute:: cache_limit
            
            	Set the cache limit for neighbor entries
            	**type**\:  int
            
            	**range:** 0..128000
            
            .. attribute:: dad_attempts
            
            	Set IPv6 duplicate address detection transmits
            	**type**\:  int
            
            	**range:** 0..600
            
            .. attribute:: ipv6_prefixes
            
            	Prefixes 
            	**type**\:   :py:class:`Ipv6Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes>`
            
            .. attribute:: managed_config
            
            	Host to use stateful protocol for address configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ns_interval
            
            	Set advertised NS retransmission interval in milliseconds
            	**type**\:  int
            
            	**range:** 1000..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: other_config
            
            	Host to use stateful protocol for non\-address configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ra_interval
            
            	Set IPv6 Router Advertisement (RA) interval in seconds
            	**type**\:   :py:class:`RaInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval>`
            
            	**presence node**\: True
            
            .. attribute:: ra_lifetime
            
            	Set IPv6 Router Advertisement (RA) lifetime in seconds
            	**type**\:  int
            
            	**range:** 0..9000
            
            	**units**\: second
            
            .. attribute:: ra_suppress
            
            	Enable suppress IPv6 router advertisement
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ra_unicast
            
            	Enable unicast IPv6 router advertisement
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ra_unspecify_hoplimit
            
            	Unspecify IPv6 Router Advertisement (RA) hop\-limit
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: radns_searches
            
            	IPv6 Router Advertisement (RA) DNS Search List
            	**type**\:   :py:class:`RadnsSearches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches>`
            
            .. attribute:: radns_servers
            
            	IPv6 Router Advertisement (RA) DNS Servre
            	**type**\:   :py:class:`RadnsServers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers>`
            
            .. attribute:: ramtu_suppress
            
            	Enable suppress MTU in IPv6 router advertisement
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: raspecific_route_s
            
            	IPv6 Router Advertisement (RA) Specific Route
            	**type**\:   :py:class:`RaspecificRouteS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS>`
            
            .. attribute:: reachable_time
            
            	Set advertised reachability time in milliseconds
            	**type**\:  int
            
            	**range:** 0..3600000
            
            	**units**\: millisecond
            
            .. attribute:: redirect
            
            	Enable sending of ICMP Redirect messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: router_preference
            
            	RA Router Preference
            	**type**\:   :py:class:`Ipv6NdRouterPref <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6NdRouterPref>`
            
            .. attribute:: srp_multicast_encapsulation
            
            	Set SRP multicast prefer encapsulation
            	**type**\:   :py:class:`Ipv6SrpEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6SrpEncapsulation>`
            
            .. attribute:: srp_unicast_encapsulation
            
            	Set SRP unicast prefer encapsulation
            	**type**\:   :py:class:`Ipv6SrpEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6SrpEncapsulation>`
            
            

            """

            _prefix = 'ipv6-nd-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor, self).__init__()

                self.yang_name = "ipv6-neighbor"
                self.yang_parent_name = "interface-configuration"

                self.cache_limit = YLeaf(YType.uint32, "cache-limit")

                self.dad_attempts = YLeaf(YType.uint32, "dad-attempts")

                self.managed_config = YLeaf(YType.empty, "managed-config")

                self.ns_interval = YLeaf(YType.uint32, "ns-interval")

                self.other_config = YLeaf(YType.empty, "other-config")

                self.ra_lifetime = YLeaf(YType.uint32, "ra-lifetime")

                self.ra_suppress = YLeaf(YType.empty, "ra-suppress")

                self.ra_unicast = YLeaf(YType.empty, "ra-unicast")

                self.ra_unspecify_hoplimit = YLeaf(YType.empty, "ra-unspecify-hoplimit")

                self.ramtu_suppress = YLeaf(YType.empty, "ramtu-suppress")

                self.reachable_time = YLeaf(YType.uint32, "reachable-time")

                self.redirect = YLeaf(YType.empty, "redirect")

                self.router_preference = YLeaf(YType.enumeration, "router-preference")

                self.srp_multicast_encapsulation = YLeaf(YType.enumeration, "srp-multicast-encapsulation")

                self.srp_unicast_encapsulation = YLeaf(YType.enumeration, "srp-unicast-encapsulation")

                self.ipv6_prefixes = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes()
                self.ipv6_prefixes.parent = self
                self._children_name_map["ipv6_prefixes"] = "ipv6-prefixes"
                self._children_yang_names.add("ipv6-prefixes")

                self.ra_interval = None
                self._children_name_map["ra_interval"] = "ra-interval"
                self._children_yang_names.add("ra-interval")

                self.radns_searches = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches()
                self.radns_searches.parent = self
                self._children_name_map["radns_searches"] = "radns-searches"
                self._children_yang_names.add("radns-searches")

                self.radns_servers = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers()
                self.radns_servers.parent = self
                self._children_name_map["radns_servers"] = "radns-servers"
                self._children_yang_names.add("radns-servers")

                self.raspecific_route_s = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS()
                self.raspecific_route_s.parent = self
                self._children_name_map["raspecific_route_s"] = "raspecific-route-s"
                self._children_yang_names.add("raspecific-route-s")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("cache_limit",
                                "dad_attempts",
                                "managed_config",
                                "ns_interval",
                                "other_config",
                                "ra_lifetime",
                                "ra_suppress",
                                "ra_unicast",
                                "ra_unspecify_hoplimit",
                                "ramtu_suppress",
                                "reachable_time",
                                "redirect",
                                "router_preference",
                                "srp_multicast_encapsulation",
                                "srp_unicast_encapsulation") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor, self).__setattr__(name, value)


            class RaspecificRouteS(Entity):
                """
                IPv6 Router Advertisement (RA) Specific Route
                
                .. attribute:: raspecific_route
                
                	IPv6 Router Advertisement (RA) Specific Route
                	**type**\: list of    :py:class:`RaspecificRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS, self).__init__()

                    self.yang_name = "raspecific-route-s"
                    self.yang_parent_name = "ipv6-neighbor"

                    self.raspecific_route = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS, self).__setattr__(name, value)


                class RaspecificRoute(Entity):
                    """
                    IPv6 Router Advertisement (RA) Specific Route
                    
                    .. attribute:: specific_route  <key>
                    
                    	IPv6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: lifetime
                    
                    	Lifetime (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: preference
                    
                    	Preference
                    	**type**\:   :py:class:`Ipv6NdRouterPref <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6NdRouterPref>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix mask length
                    	**type**\:  int
                    
                    	**range:** 0..128
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute, self).__init__()

                        self.yang_name = "raspecific-route"
                        self.yang_parent_name = "raspecific-route-s"

                        self.specific_route = YLeaf(YType.str, "specific-route")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")

                        self.preference = YLeaf(YType.enumeration, "preference")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("specific_route",
                                        "lifetime",
                                        "preference",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.specific_route.is_set or
                            self.lifetime.is_set or
                            self.preference.is_set or
                            self.prefix_length.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.specific_route.yfilter != YFilter.not_set or
                            self.lifetime.yfilter != YFilter.not_set or
                            self.preference.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "raspecific-route" + "[specific-route='" + self.specific_route.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.specific_route.is_set or self.specific_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.specific_route.get_name_leafdata())
                        if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lifetime.get_name_leafdata())
                        if (self.preference.is_set or self.preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preference.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "specific-route" or name == "lifetime" or name == "preference" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "specific-route"):
                            self.specific_route = value
                            self.specific_route.value_namespace = name_space
                            self.specific_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "lifetime"):
                            self.lifetime = value
                            self.lifetime.value_namespace = name_space
                            self.lifetime.value_namespace_prefix = name_space_prefix
                        if(value_path == "preference"):
                            self.preference = value
                            self.preference.value_namespace = name_space
                            self.preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.raspecific_route:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.raspecific_route:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "raspecific-route-s" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "raspecific-route"):
                        for c in self.raspecific_route:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.raspecific_route.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "raspecific-route"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RadnsSearches(Entity):
                """
                IPv6 Router Advertisement (RA) DNS Search List
                
                .. attribute:: radns_search
                
                	IPv6 Router Advertisement (RA) DNS Search List
                	**type**\: list of    :py:class:`RadnsSearch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches, self).__init__()

                    self.yang_name = "radns-searches"
                    self.yang_parent_name = "ipv6-neighbor"

                    self.radns_search = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches, self).__setattr__(name, value)


                class RadnsSearch(Entity):
                    """
                    IPv6 Router Advertisement (RA) DNS Search List
                    
                    .. attribute:: dns_search_list  <key>
                    
                    	Search List
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: lifetime
                    
                    	Lifetime value in seconds
                    	**type**\:  int
                    
                    	**range:** 4..3600
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch, self).__init__()

                        self.yang_name = "radns-search"
                        self.yang_parent_name = "radns-searches"

                        self.dns_search_list = YLeaf(YType.str, "dns-search-list")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dns_search_list",
                                        "lifetime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.dns_search_list.is_set or
                            self.lifetime.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dns_search_list.yfilter != YFilter.not_set or
                            self.lifetime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "radns-search" + "[dns-search-list='" + self.dns_search_list.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dns_search_list.is_set or self.dns_search_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dns_search_list.get_name_leafdata())
                        if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lifetime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dns-search-list" or name == "lifetime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dns-search-list"):
                            self.dns_search_list = value
                            self.dns_search_list.value_namespace = name_space
                            self.dns_search_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "lifetime"):
                            self.lifetime = value
                            self.lifetime.value_namespace = name_space
                            self.lifetime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.radns_search:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.radns_search:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "radns-searches" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "radns-search"):
                        for c in self.radns_search:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.radns_search.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "radns-search"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RadnsServers(Entity):
                """
                IPv6 Router Advertisement (RA) DNS Servre
                
                .. attribute:: radns_server
                
                	IPv6 Router Advertisement (RA) DNS Servre
                	**type**\: list of    :py:class:`RadnsServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers, self).__init__()

                    self.yang_name = "radns-servers"
                    self.yang_parent_name = "ipv6-neighbor"

                    self.radns_server = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers, self).__setattr__(name, value)


                class RadnsServer(Entity):
                    """
                    IPv6 Router Advertisement (RA) DNS Servre
                    
                    .. attribute:: dns_server  <key>
                    
                    	IPv6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: lifetime
                    
                    	Lifetime value in seconds
                    	**type**\:  int
                    
                    	**range:** 4..3600
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer, self).__init__()

                        self.yang_name = "radns-server"
                        self.yang_parent_name = "radns-servers"

                        self.dns_server = YLeaf(YType.str, "dns-server")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dns_server",
                                        "lifetime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.dns_server.is_set or
                            self.lifetime.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dns_server.yfilter != YFilter.not_set or
                            self.lifetime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "radns-server" + "[dns-server='" + self.dns_server.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dns_server.is_set or self.dns_server.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dns_server.get_name_leafdata())
                        if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lifetime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dns-server" or name == "lifetime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dns-server"):
                            self.dns_server = value
                            self.dns_server.value_namespace = name_space
                            self.dns_server.value_namespace_prefix = name_space_prefix
                        if(value_path == "lifetime"):
                            self.lifetime = value
                            self.lifetime.value_namespace = name_space
                            self.lifetime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.radns_server:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.radns_server:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "radns-servers" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "radns-server"):
                        for c in self.radns_server:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.radns_server.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "radns-server"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RaInterval(Entity):
                """
                Set IPv6 Router Advertisement (RA) interval in
                seconds
                
                .. attribute:: maximum
                
                	Maximum RA interval in seconds
                	**type**\:  int
                
                	**range:** 4..1800
                
                	**mandatory**\: True
                
                .. attribute:: minimum
                
                	Minimum RA interval in seconds. Must be less than 0.75 \* maximum interval
                	**type**\:  int
                
                	**range:** 3..1800
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval, self).__init__()

                    self.yang_name = "ra-interval"
                    self.yang_parent_name = "ipv6-neighbor"
                    self.is_presence_container = True

                    self.maximum = YLeaf(YType.uint32, "maximum")

                    self.minimum = YLeaf(YType.uint32, "minimum")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("maximum",
                                    "minimum") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.maximum.is_set or
                        self.minimum.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.maximum.yfilter != YFilter.not_set or
                        self.minimum.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ra-interval" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum.get_name_leafdata())
                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "maximum" or name == "minimum"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "maximum"):
                        self.maximum = value
                        self.maximum.value_namespace = name_space
                        self.maximum.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum"):
                        self.minimum = value
                        self.minimum.value_namespace = name_space
                        self.minimum.value_namespace_prefix = name_space_prefix


            class Ipv6Prefixes(Entity):
                """
                Prefixes 
                
                .. attribute:: ipv6_prefix
                
                	Configure prefix with paramemters
                	**type**\: list of    :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes, self).__init__()

                    self.yang_name = "ipv6-prefixes"
                    self.yang_parent_name = "ipv6-neighbor"

                    self.ipv6_prefix = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes, self).__setattr__(name, value)


                class Ipv6Prefix(Entity):
                    """
                    Configure prefix with paramemters
                    
                    .. attribute:: prefix  <key>
                    
                    	IPv6 prefix
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: expiry_date
                    
                    	Date to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 1..31
                    
                    .. attribute:: expiry_hour
                    
                    	Hour to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 0..23
                    
                    .. attribute:: expiry_minute
                    
                    	Minute to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 0..59
                    
                    .. attribute:: expiry_month
                    
                    	Month to expire valid lifetime
                    	**type**\:   :py:class:`Ipv6NdMonth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6NdMonth>`
                    
                    .. attribute:: expiry_year
                    
                    	Year to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 2003..2035
                    
                    .. attribute:: no_advertize
                    
                    	If set, prefix will not be advertized
                    	**type**\:  bool
                    
                    .. attribute:: no_auto_config
                    
                    	If set, prefix will not be used for auto configuration
                    	**type**\:  bool
                    
                    .. attribute:: off_link
                    
                    	If set, prefix will not be used for onlink determination
                    	**type**\:  bool
                    
                    .. attribute:: pref_expiry_date
                    
                    	Date to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 1..31
                    
                    .. attribute:: pref_expiry_hour
                    
                    	Hour to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 0..23
                    
                    .. attribute:: pref_expiry_minute
                    
                    	Minute to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 0..59
                    
                    .. attribute:: pref_expiry_month
                    
                    	Month to expire preferred lifetime
                    	**type**\:   :py:class:`Ipv6NdMonth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6NdMonth>`
                    
                    .. attribute:: pref_expiry_year
                    
                    	Year to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 2003..2035
                    
                    .. attribute:: preferred_lifetime
                    
                    	Preferred Lifetime (seconds) must be <= Valid Lifetime
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix_length
                    
                    	Prefix mask length
                    	**type**\:  int
                    
                    	**range:** 0..128
                    
                    	**mandatory**\: True
                    
                    .. attribute:: prefix_zone
                    
                    	Prefix zone
                    	**type**\:  str
                    
                    	**length:** 1..9
                    
                    .. attribute:: valid_lifetime
                    
                    	Valid Lifetime (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix, self).__init__()

                        self.yang_name = "ipv6-prefix"
                        self.yang_parent_name = "ipv6-prefixes"

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.expiry_date = YLeaf(YType.uint32, "expiry-date")

                        self.expiry_hour = YLeaf(YType.uint32, "expiry-hour")

                        self.expiry_minute = YLeaf(YType.uint32, "expiry-minute")

                        self.expiry_month = YLeaf(YType.enumeration, "expiry-month")

                        self.expiry_year = YLeaf(YType.uint32, "expiry-year")

                        self.no_advertize = YLeaf(YType.boolean, "no-advertize")

                        self.no_auto_config = YLeaf(YType.boolean, "no-auto-config")

                        self.off_link = YLeaf(YType.boolean, "off-link")

                        self.pref_expiry_date = YLeaf(YType.uint32, "pref-expiry-date")

                        self.pref_expiry_hour = YLeaf(YType.uint32, "pref-expiry-hour")

                        self.pref_expiry_minute = YLeaf(YType.uint32, "pref-expiry-minute")

                        self.pref_expiry_month = YLeaf(YType.enumeration, "pref-expiry-month")

                        self.pref_expiry_year = YLeaf(YType.uint32, "pref-expiry-year")

                        self.preferred_lifetime = YLeaf(YType.uint32, "preferred-lifetime")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix_zone = YLeaf(YType.str, "prefix-zone")

                        self.valid_lifetime = YLeaf(YType.uint32, "valid-lifetime")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("prefix",
                                        "expiry_date",
                                        "expiry_hour",
                                        "expiry_minute",
                                        "expiry_month",
                                        "expiry_year",
                                        "no_advertize",
                                        "no_auto_config",
                                        "off_link",
                                        "pref_expiry_date",
                                        "pref_expiry_hour",
                                        "pref_expiry_minute",
                                        "pref_expiry_month",
                                        "pref_expiry_year",
                                        "preferred_lifetime",
                                        "prefix_length",
                                        "prefix_zone",
                                        "valid_lifetime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.prefix.is_set or
                            self.expiry_date.is_set or
                            self.expiry_hour.is_set or
                            self.expiry_minute.is_set or
                            self.expiry_month.is_set or
                            self.expiry_year.is_set or
                            self.no_advertize.is_set or
                            self.no_auto_config.is_set or
                            self.off_link.is_set or
                            self.pref_expiry_date.is_set or
                            self.pref_expiry_hour.is_set or
                            self.pref_expiry_minute.is_set or
                            self.pref_expiry_month.is_set or
                            self.pref_expiry_year.is_set or
                            self.preferred_lifetime.is_set or
                            self.prefix_length.is_set or
                            self.prefix_zone.is_set or
                            self.valid_lifetime.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.expiry_date.yfilter != YFilter.not_set or
                            self.expiry_hour.yfilter != YFilter.not_set or
                            self.expiry_minute.yfilter != YFilter.not_set or
                            self.expiry_month.yfilter != YFilter.not_set or
                            self.expiry_year.yfilter != YFilter.not_set or
                            self.no_advertize.yfilter != YFilter.not_set or
                            self.no_auto_config.yfilter != YFilter.not_set or
                            self.off_link.yfilter != YFilter.not_set or
                            self.pref_expiry_date.yfilter != YFilter.not_set or
                            self.pref_expiry_hour.yfilter != YFilter.not_set or
                            self.pref_expiry_minute.yfilter != YFilter.not_set or
                            self.pref_expiry_month.yfilter != YFilter.not_set or
                            self.pref_expiry_year.yfilter != YFilter.not_set or
                            self.preferred_lifetime.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.prefix_zone.yfilter != YFilter.not_set or
                            self.valid_lifetime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv6-prefix" + "[prefix='" + self.prefix.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.expiry_date.is_set or self.expiry_date.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_date.get_name_leafdata())
                        if (self.expiry_hour.is_set or self.expiry_hour.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_hour.get_name_leafdata())
                        if (self.expiry_minute.is_set or self.expiry_minute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_minute.get_name_leafdata())
                        if (self.expiry_month.is_set or self.expiry_month.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_month.get_name_leafdata())
                        if (self.expiry_year.is_set or self.expiry_year.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_year.get_name_leafdata())
                        if (self.no_advertize.is_set or self.no_advertize.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_advertize.get_name_leafdata())
                        if (self.no_auto_config.is_set or self.no_auto_config.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_auto_config.get_name_leafdata())
                        if (self.off_link.is_set or self.off_link.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.off_link.get_name_leafdata())
                        if (self.pref_expiry_date.is_set or self.pref_expiry_date.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_expiry_date.get_name_leafdata())
                        if (self.pref_expiry_hour.is_set or self.pref_expiry_hour.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_expiry_hour.get_name_leafdata())
                        if (self.pref_expiry_minute.is_set or self.pref_expiry_minute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_expiry_minute.get_name_leafdata())
                        if (self.pref_expiry_month.is_set or self.pref_expiry_month.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_expiry_month.get_name_leafdata())
                        if (self.pref_expiry_year.is_set or self.pref_expiry_year.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_expiry_year.get_name_leafdata())
                        if (self.preferred_lifetime.is_set or self.preferred_lifetime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_lifetime.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.prefix_zone.is_set or self.prefix_zone.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_zone.get_name_leafdata())
                        if (self.valid_lifetime.is_set or self.valid_lifetime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.valid_lifetime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "prefix" or name == "expiry-date" or name == "expiry-hour" or name == "expiry-minute" or name == "expiry-month" or name == "expiry-year" or name == "no-advertize" or name == "no-auto-config" or name == "off-link" or name == "pref-expiry-date" or name == "pref-expiry-hour" or name == "pref-expiry-minute" or name == "pref-expiry-month" or name == "pref-expiry-year" or name == "preferred-lifetime" or name == "prefix-length" or name == "prefix-zone" or name == "valid-lifetime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-date"):
                            self.expiry_date = value
                            self.expiry_date.value_namespace = name_space
                            self.expiry_date.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-hour"):
                            self.expiry_hour = value
                            self.expiry_hour.value_namespace = name_space
                            self.expiry_hour.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-minute"):
                            self.expiry_minute = value
                            self.expiry_minute.value_namespace = name_space
                            self.expiry_minute.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-month"):
                            self.expiry_month = value
                            self.expiry_month.value_namespace = name_space
                            self.expiry_month.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-year"):
                            self.expiry_year = value
                            self.expiry_year.value_namespace = name_space
                            self.expiry_year.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-advertize"):
                            self.no_advertize = value
                            self.no_advertize.value_namespace = name_space
                            self.no_advertize.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-auto-config"):
                            self.no_auto_config = value
                            self.no_auto_config.value_namespace = name_space
                            self.no_auto_config.value_namespace_prefix = name_space_prefix
                        if(value_path == "off-link"):
                            self.off_link = value
                            self.off_link.value_namespace = name_space
                            self.off_link.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-expiry-date"):
                            self.pref_expiry_date = value
                            self.pref_expiry_date.value_namespace = name_space
                            self.pref_expiry_date.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-expiry-hour"):
                            self.pref_expiry_hour = value
                            self.pref_expiry_hour.value_namespace = name_space
                            self.pref_expiry_hour.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-expiry-minute"):
                            self.pref_expiry_minute = value
                            self.pref_expiry_minute.value_namespace = name_space
                            self.pref_expiry_minute.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-expiry-month"):
                            self.pref_expiry_month = value
                            self.pref_expiry_month.value_namespace = name_space
                            self.pref_expiry_month.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-expiry-year"):
                            self.pref_expiry_year = value
                            self.pref_expiry_year.value_namespace = name_space
                            self.pref_expiry_year.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-lifetime"):
                            self.preferred_lifetime = value
                            self.preferred_lifetime.value_namespace = name_space
                            self.preferred_lifetime.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-zone"):
                            self.prefix_zone = value
                            self.prefix_zone.value_namespace = name_space
                            self.prefix_zone.value_namespace_prefix = name_space_prefix
                        if(value_path == "valid-lifetime"):
                            self.valid_lifetime = value
                            self.valid_lifetime.value_namespace = name_space
                            self.valid_lifetime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ipv6_prefix:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ipv6_prefix:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ipv6-prefixes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv6-prefix"):
                        for c in self.ipv6_prefix:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ipv6_prefix.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv6-prefix"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.cache_limit.is_set or
                    self.dad_attempts.is_set or
                    self.managed_config.is_set or
                    self.ns_interval.is_set or
                    self.other_config.is_set or
                    self.ra_lifetime.is_set or
                    self.ra_suppress.is_set or
                    self.ra_unicast.is_set or
                    self.ra_unspecify_hoplimit.is_set or
                    self.ramtu_suppress.is_set or
                    self.reachable_time.is_set or
                    self.redirect.is_set or
                    self.router_preference.is_set or
                    self.srp_multicast_encapsulation.is_set or
                    self.srp_unicast_encapsulation.is_set or
                    (self.ipv6_prefixes is not None and self.ipv6_prefixes.has_data()) or
                    (self.radns_searches is not None and self.radns_searches.has_data()) or
                    (self.radns_servers is not None and self.radns_servers.has_data()) or
                    (self.raspecific_route_s is not None and self.raspecific_route_s.has_data()) or
                    (self.ra_interval is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.cache_limit.yfilter != YFilter.not_set or
                    self.dad_attempts.yfilter != YFilter.not_set or
                    self.managed_config.yfilter != YFilter.not_set or
                    self.ns_interval.yfilter != YFilter.not_set or
                    self.other_config.yfilter != YFilter.not_set or
                    self.ra_lifetime.yfilter != YFilter.not_set or
                    self.ra_suppress.yfilter != YFilter.not_set or
                    self.ra_unicast.yfilter != YFilter.not_set or
                    self.ra_unspecify_hoplimit.yfilter != YFilter.not_set or
                    self.ramtu_suppress.yfilter != YFilter.not_set or
                    self.reachable_time.yfilter != YFilter.not_set or
                    self.redirect.yfilter != YFilter.not_set or
                    self.router_preference.yfilter != YFilter.not_set or
                    self.srp_multicast_encapsulation.yfilter != YFilter.not_set or
                    self.srp_unicast_encapsulation.yfilter != YFilter.not_set or
                    (self.ipv6_prefixes is not None and self.ipv6_prefixes.has_operation()) or
                    (self.ra_interval is not None and self.ra_interval.has_operation()) or
                    (self.radns_searches is not None and self.radns_searches.has_operation()) or
                    (self.radns_servers is not None and self.radns_servers.has_operation()) or
                    (self.raspecific_route_s is not None and self.raspecific_route_s.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ipv6-nd-cfg:ipv6-neighbor" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.cache_limit.is_set or self.cache_limit.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.cache_limit.get_name_leafdata())
                if (self.dad_attempts.is_set or self.dad_attempts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.dad_attempts.get_name_leafdata())
                if (self.managed_config.is_set or self.managed_config.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.managed_config.get_name_leafdata())
                if (self.ns_interval.is_set or self.ns_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ns_interval.get_name_leafdata())
                if (self.other_config.is_set or self.other_config.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.other_config.get_name_leafdata())
                if (self.ra_lifetime.is_set or self.ra_lifetime.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ra_lifetime.get_name_leafdata())
                if (self.ra_suppress.is_set or self.ra_suppress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ra_suppress.get_name_leafdata())
                if (self.ra_unicast.is_set or self.ra_unicast.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ra_unicast.get_name_leafdata())
                if (self.ra_unspecify_hoplimit.is_set or self.ra_unspecify_hoplimit.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ra_unspecify_hoplimit.get_name_leafdata())
                if (self.ramtu_suppress.is_set or self.ramtu_suppress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ramtu_suppress.get_name_leafdata())
                if (self.reachable_time.is_set or self.reachable_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reachable_time.get_name_leafdata())
                if (self.redirect.is_set or self.redirect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.redirect.get_name_leafdata())
                if (self.router_preference.is_set or self.router_preference.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.router_preference.get_name_leafdata())
                if (self.srp_multicast_encapsulation.is_set or self.srp_multicast_encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.srp_multicast_encapsulation.get_name_leafdata())
                if (self.srp_unicast_encapsulation.is_set or self.srp_unicast_encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.srp_unicast_encapsulation.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ipv6-prefixes"):
                    if (self.ipv6_prefixes is None):
                        self.ipv6_prefixes = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes()
                        self.ipv6_prefixes.parent = self
                        self._children_name_map["ipv6_prefixes"] = "ipv6-prefixes"
                    return self.ipv6_prefixes

                if (child_yang_name == "ra-interval"):
                    if (self.ra_interval is None):
                        self.ra_interval = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval()
                        self.ra_interval.parent = self
                        self._children_name_map["ra_interval"] = "ra-interval"
                    return self.ra_interval

                if (child_yang_name == "radns-searches"):
                    if (self.radns_searches is None):
                        self.radns_searches = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches()
                        self.radns_searches.parent = self
                        self._children_name_map["radns_searches"] = "radns-searches"
                    return self.radns_searches

                if (child_yang_name == "radns-servers"):
                    if (self.radns_servers is None):
                        self.radns_servers = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers()
                        self.radns_servers.parent = self
                        self._children_name_map["radns_servers"] = "radns-servers"
                    return self.radns_servers

                if (child_yang_name == "raspecific-route-s"):
                    if (self.raspecific_route_s is None):
                        self.raspecific_route_s = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS()
                        self.raspecific_route_s.parent = self
                        self._children_name_map["raspecific_route_s"] = "raspecific-route-s"
                    return self.raspecific_route_s

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ipv6-prefixes" or name == "ra-interval" or name == "radns-searches" or name == "radns-servers" or name == "raspecific-route-s" or name == "cache-limit" or name == "dad-attempts" or name == "managed-config" or name == "ns-interval" or name == "other-config" or name == "ra-lifetime" or name == "ra-suppress" or name == "ra-unicast" or name == "ra-unspecify-hoplimit" or name == "ramtu-suppress" or name == "reachable-time" or name == "redirect" or name == "router-preference" or name == "srp-multicast-encapsulation" or name == "srp-unicast-encapsulation"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "cache-limit"):
                    self.cache_limit = value
                    self.cache_limit.value_namespace = name_space
                    self.cache_limit.value_namespace_prefix = name_space_prefix
                if(value_path == "dad-attempts"):
                    self.dad_attempts = value
                    self.dad_attempts.value_namespace = name_space
                    self.dad_attempts.value_namespace_prefix = name_space_prefix
                if(value_path == "managed-config"):
                    self.managed_config = value
                    self.managed_config.value_namespace = name_space
                    self.managed_config.value_namespace_prefix = name_space_prefix
                if(value_path == "ns-interval"):
                    self.ns_interval = value
                    self.ns_interval.value_namespace = name_space
                    self.ns_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "other-config"):
                    self.other_config = value
                    self.other_config.value_namespace = name_space
                    self.other_config.value_namespace_prefix = name_space_prefix
                if(value_path == "ra-lifetime"):
                    self.ra_lifetime = value
                    self.ra_lifetime.value_namespace = name_space
                    self.ra_lifetime.value_namespace_prefix = name_space_prefix
                if(value_path == "ra-suppress"):
                    self.ra_suppress = value
                    self.ra_suppress.value_namespace = name_space
                    self.ra_suppress.value_namespace_prefix = name_space_prefix
                if(value_path == "ra-unicast"):
                    self.ra_unicast = value
                    self.ra_unicast.value_namespace = name_space
                    self.ra_unicast.value_namespace_prefix = name_space_prefix
                if(value_path == "ra-unspecify-hoplimit"):
                    self.ra_unspecify_hoplimit = value
                    self.ra_unspecify_hoplimit.value_namespace = name_space
                    self.ra_unspecify_hoplimit.value_namespace_prefix = name_space_prefix
                if(value_path == "ramtu-suppress"):
                    self.ramtu_suppress = value
                    self.ramtu_suppress.value_namespace = name_space
                    self.ramtu_suppress.value_namespace_prefix = name_space_prefix
                if(value_path == "reachable-time"):
                    self.reachable_time = value
                    self.reachable_time.value_namespace = name_space
                    self.reachable_time.value_namespace_prefix = name_space_prefix
                if(value_path == "redirect"):
                    self.redirect = value
                    self.redirect.value_namespace = name_space
                    self.redirect.value_namespace_prefix = name_space_prefix
                if(value_path == "router-preference"):
                    self.router_preference = value
                    self.router_preference.value_namespace = name_space
                    self.router_preference.value_namespace_prefix = name_space_prefix
                if(value_path == "srp-multicast-encapsulation"):
                    self.srp_multicast_encapsulation = value
                    self.srp_multicast_encapsulation.value_namespace = name_space
                    self.srp_multicast_encapsulation.value_namespace_prefix = name_space_prefix
                if(value_path == "srp-unicast-encapsulation"):
                    self.srp_unicast_encapsulation = value
                    self.srp_unicast_encapsulation.value_namespace = name_space
                    self.srp_unicast_encapsulation.value_namespace_prefix = name_space_prefix


        class TunnelTeAttributes(Entity):
            """
            MPLS tunnel attributes
            
            .. attribute:: admin_mode
            
            	Performs admin operations on the optical tunnel interface
            	**type**\:   :py:class:`AdminMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode>`
            
            .. attribute:: affinity_mask
            
            	Set the affinity flags and mask
            	**type**\:   :py:class:`AffinityMask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask>`
            
            	**presence node**\: True
            
            .. attribute:: auto_bandwidth
            
            	Tunnel Interface Auto\-bandwidth configuration data
            	**type**\:   :py:class:`AutoBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth>`
            
            .. attribute:: autoroute
            
            	Parameters for IGP routing over tunnel
            	**type**\:   :py:class:`Autoroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute>`
            
            .. attribute:: backup_bandwidth
            
            	Tunnel backup bandwidth requirement
            	**type**\:   :py:class:`BackupBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth>`
            
            .. attribute:: bandwidth
            
            	Tunnel bandwidth requirement
            	**type**\:   :py:class:`Bandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth>`
            
            	**presence node**\: True
            
            .. attribute:: bfd_over_lsp
            
            	BFD over TE LSP
            	**type**\:   :py:class:`BfdOverLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp>`
            
            .. attribute:: bidirectional
            
            	Tunnel Interface Bidirectional configuration data
            	**type**\:   :py:class:`Bidirectional <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional>`
            
            .. attribute:: binding_segment_id_mpls
            
            	Allocate MPLS binding segment ID
            	**type**\:   :py:class:`BindingSegmentIdMpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls>`
            
            .. attribute:: destination
            
            	Set the destination of the tunnel
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fast_reroute
            
            	Specify MPLS tunnel can be fast\-rerouted
            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute>`
            
            	**presence node**\: True
            
            .. attribute:: forward_class
            
            	Forward class value
            	**type**\:  int
            
            	**range:** 1..7
            
            .. attribute:: forwarding_adjacency
            
            	Forwarding adjacency announcement to IGP
            	**type**\:   :py:class:`ForwardingAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency>`
            
            .. attribute:: load_share
            
            	Tunnel loadsharing metric
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: logging
            
            	Log tunnel LSP messages
            	**type**\:   :py:class:`Logging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging>`
            
            .. attribute:: new_style_affinity_affinity_types
            
            	Tunnel new style affinity attributes table
            	**type**\:   :py:class:`NewStyleAffinityAffinityTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes>`
            
            .. attribute:: path_option_protects
            
            	Tunnel path protection state
            	**type**\:   :py:class:`PathOptionProtects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects>`
            
            .. attribute:: path_protection
            
            	Specify MPLS tunnel to be path protected
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: path_selection_metric
            
            	Path selection metric to use in path calculation
            	**type**\:   :py:class:`MplsTePathSelectionMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathSelectionMetric>`
            
            .. attribute:: pce
            
            	PCE config
            	**type**\:   :py:class:`Pce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce>`
            
            .. attribute:: policy_classes
            
            	Policy classes for PBTS
            	**type**\:   :py:class:`PolicyClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses>`
            
            .. attribute:: priority
            
            	Tunnel Setup and Hold Priorities
            	**type**\:   :py:class:`Priority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority>`
            
            	**presence node**\: True
            
            .. attribute:: record_route
            
            	Record the route used by the tunnel
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: signalled_name
            
            	The name of the tunnel to be included in signalling messages
            	**type**\:  str
            
            	**length:** 1..254
            
            .. attribute:: soft_preemption
            
            	Enable the soft\-preemption feature on the tunnel
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: switching
            
            	Specify tunnel LSPs switching capability descriptor
            	**type**\:   :py:class:`Switching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching>`
            
            .. attribute:: tunnel_path_selection
            
            	Configure path selection properties
            	**type**\:   :py:class:`TunnelPathSelection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection>`
            
            

            """

            _prefix = 'mpls-te-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes, self).__init__()

                self.yang_name = "tunnel-te-attributes"
                self.yang_parent_name = "interface-configuration"

                self.destination = YLeaf(YType.str, "destination")

                self.forward_class = YLeaf(YType.uint32, "forward-class")

                self.load_share = YLeaf(YType.uint32, "load-share")

                self.path_protection = YLeaf(YType.empty, "path-protection")

                self.path_selection_metric = YLeaf(YType.enumeration, "path-selection-metric")

                self.record_route = YLeaf(YType.empty, "record-route")

                self.signalled_name = YLeaf(YType.str, "signalled-name")

                self.soft_preemption = YLeaf(YType.empty, "soft-preemption")

                self.admin_mode = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode()
                self.admin_mode.parent = self
                self._children_name_map["admin_mode"] = "admin-mode"
                self._children_yang_names.add("admin-mode")

                self.affinity_mask = None
                self._children_name_map["affinity_mask"] = "affinity-mask"
                self._children_yang_names.add("affinity-mask")

                self.auto_bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth()
                self.auto_bandwidth.parent = self
                self._children_name_map["auto_bandwidth"] = "auto-bandwidth"
                self._children_yang_names.add("auto-bandwidth")

                self.autoroute = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute()
                self.autoroute.parent = self
                self._children_name_map["autoroute"] = "autoroute"
                self._children_yang_names.add("autoroute")

                self.backup_bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth()
                self.backup_bandwidth.parent = self
                self._children_name_map["backup_bandwidth"] = "backup-bandwidth"
                self._children_yang_names.add("backup-bandwidth")

                self.bandwidth = None
                self._children_name_map["bandwidth"] = "bandwidth"
                self._children_yang_names.add("bandwidth")

                self.bfd_over_lsp = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp()
                self.bfd_over_lsp.parent = self
                self._children_name_map["bfd_over_lsp"] = "bfd-over-lsp"
                self._children_yang_names.add("bfd-over-lsp")

                self.bidirectional = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional()
                self.bidirectional.parent = self
                self._children_name_map["bidirectional"] = "bidirectional"
                self._children_yang_names.add("bidirectional")

                self.binding_segment_id_mpls = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls()
                self.binding_segment_id_mpls.parent = self
                self._children_name_map["binding_segment_id_mpls"] = "binding-segment-id-mpls"
                self._children_yang_names.add("binding-segment-id-mpls")

                self.fast_reroute = None
                self._children_name_map["fast_reroute"] = "fast-reroute"
                self._children_yang_names.add("fast-reroute")

                self.forwarding_adjacency = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency()
                self.forwarding_adjacency.parent = self
                self._children_name_map["forwarding_adjacency"] = "forwarding-adjacency"
                self._children_yang_names.add("forwarding-adjacency")

                self.logging = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"
                self._children_yang_names.add("logging")

                self.new_style_affinity_affinity_types = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes()
                self.new_style_affinity_affinity_types.parent = self
                self._children_name_map["new_style_affinity_affinity_types"] = "new-style-affinity-affinity-types"
                self._children_yang_names.add("new-style-affinity-affinity-types")

                self.path_option_protects = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects()
                self.path_option_protects.parent = self
                self._children_name_map["path_option_protects"] = "path-option-protects"
                self._children_yang_names.add("path-option-protects")

                self.pce = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce()
                self.pce.parent = self
                self._children_name_map["pce"] = "pce"
                self._children_yang_names.add("pce")

                self.policy_classes = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses()
                self.policy_classes.parent = self
                self._children_name_map["policy_classes"] = "policy-classes"
                self._children_yang_names.add("policy-classes")

                self.priority = None
                self._children_name_map["priority"] = "priority"
                self._children_yang_names.add("priority")

                self.switching = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching()
                self.switching.parent = self
                self._children_name_map["switching"] = "switching"
                self._children_yang_names.add("switching")

                self.tunnel_path_selection = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection()
                self.tunnel_path_selection.parent = self
                self._children_name_map["tunnel_path_selection"] = "tunnel-path-selection"
                self._children_yang_names.add("tunnel-path-selection")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination",
                                "forward_class",
                                "load_share",
                                "path_protection",
                                "path_selection_metric",
                                "record_route",
                                "signalled_name",
                                "soft_preemption") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes, self).__setattr__(name, value)


            class BackupBandwidth(Entity):
                """
                Tunnel backup bandwidth requirement
                
                .. attribute:: backup_bandwidth
                
                	Backup bandwidth requested by this tunnel in kbps. Ignored if bandwidth limit type is unlimited
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: class_type
                
                	Backup bandwidth class type, relevant only if DSTEType is StandardDSTE
                	**type**\:   :py:class:`MplsTeBackupBandwidthClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBackupBandwidthClass>`
                
                .. attribute:: dste_type
                
                	DSTE\-standard flag
                	**type**\:   :py:class:`MplsTeBandwidthDste <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthDste>`
                
                .. attribute:: limit_type
                
                	Backup bandwidth limit type
                	**type**\:   :py:class:`MplsTeBandwidthLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthLimit>`
                
                .. attribute:: pool_type
                
                	Backup bandwidth pool type, relevant only if DSTEType is PreStandardDSTE
                	**type**\:   :py:class:`MplsTeBackupBandwidthPool <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBackupBandwidthPool>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth, self).__init__()

                    self.yang_name = "backup-bandwidth"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.backup_bandwidth = YLeaf(YType.uint32, "backup-bandwidth")

                    self.class_type = YLeaf(YType.enumeration, "class-type")

                    self.dste_type = YLeaf(YType.enumeration, "dste-type")

                    self.limit_type = YLeaf(YType.enumeration, "limit-type")

                    self.pool_type = YLeaf(YType.enumeration, "pool-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("backup_bandwidth",
                                    "class_type",
                                    "dste_type",
                                    "limit_type",
                                    "pool_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.backup_bandwidth.is_set or
                        self.class_type.is_set or
                        self.dste_type.is_set or
                        self.limit_type.is_set or
                        self.pool_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.backup_bandwidth.yfilter != YFilter.not_set or
                        self.class_type.yfilter != YFilter.not_set or
                        self.dste_type.yfilter != YFilter.not_set or
                        self.limit_type.yfilter != YFilter.not_set or
                        self.pool_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "backup-bandwidth" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.backup_bandwidth.is_set or self.backup_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.backup_bandwidth.get_name_leafdata())
                    if (self.class_type.is_set or self.class_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.class_type.get_name_leafdata())
                    if (self.dste_type.is_set or self.dste_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_type.get_name_leafdata())
                    if (self.limit_type.is_set or self.limit_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.limit_type.get_name_leafdata())
                    if (self.pool_type.is_set or self.pool_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "backup-bandwidth" or name == "class-type" or name == "dste-type" or name == "limit-type" or name == "pool-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "backup-bandwidth"):
                        self.backup_bandwidth = value
                        self.backup_bandwidth.value_namespace = name_space
                        self.backup_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "class-type"):
                        self.class_type = value
                        self.class_type.value_namespace = name_space
                        self.class_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "dste-type"):
                        self.dste_type = value
                        self.dste_type.value_namespace = name_space
                        self.dste_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "limit-type"):
                        self.limit_type = value
                        self.limit_type.value_namespace = name_space
                        self.limit_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "pool-type"):
                        self.pool_type = value
                        self.pool_type.value_namespace = name_space
                        self.pool_type.value_namespace_prefix = name_space_prefix


            class BfdOverLsp(Entity):
                """
                BFD over TE LSP
                
                .. attribute:: bringup_timeout
                
                	Wait for session to come up in seconds (default 60)
                	**type**\:  int
                
                	**range:** 10..3600
                
                .. attribute:: dampening_initial_wait
                
                	Initial delay in milliseconds (default 16000)
                	**type**\:  int
                
                	**range:** 1..518400000
                
                .. attribute:: dampening_maximum_wait
                
                	Maximum delay in milliseconds (default 600000)
                	**type**\:  int
                
                	**range:** 1..518400000
                
                .. attribute:: dampening_secondary_wait
                
                	Secondary delay in milliseconds (default 20000)
                	**type**\:  int
                
                	**range:** 1..518400000
                
                .. attribute:: enable
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: encap_mode
                
                	Specify BFD Encap Mode on the tunnel
                	**type**\:  int
                
                	**range:** 0..1
                
                .. attribute:: fast_detect
                
                	Enable BFD Fast Detect On the tunnel
                	**type**\:   :py:class:`MplsTebfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTebfdSession>`
                
                .. attribute:: minimum_interval
                
                	Specify the minimum interval for BFD failure detection
                	**type**\:  int
                
                	**range:** 3..30000
                
                .. attribute:: multiplier
                
                	Specify the multiplier for BFD failure detection
                	**type**\:  int
                
                	**range:** 3..10
                
                .. attribute:: periodic_ping_disable
                
                	Disable Periodic LSP Ping for BFD over LSP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: periodic_ping_interval
                
                	Periodic LSP Ping Interval in seconds (default 120)
                	**type**\:  int
                
                	**range:** 60..3600
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp, self).__init__()

                    self.yang_name = "bfd-over-lsp"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.bringup_timeout = YLeaf(YType.uint32, "bringup-timeout")

                    self.dampening_initial_wait = YLeaf(YType.uint32, "dampening-initial-wait")

                    self.dampening_maximum_wait = YLeaf(YType.uint32, "dampening-maximum-wait")

                    self.dampening_secondary_wait = YLeaf(YType.uint32, "dampening-secondary-wait")

                    self.enable = YLeaf(YType.empty, "enable")

                    self.encap_mode = YLeaf(YType.uint32, "encap-mode")

                    self.fast_detect = YLeaf(YType.enumeration, "fast-detect")

                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                    self.multiplier = YLeaf(YType.uint32, "multiplier")

                    self.periodic_ping_disable = YLeaf(YType.empty, "periodic-ping-disable")

                    self.periodic_ping_interval = YLeaf(YType.uint32, "periodic-ping-interval")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bringup_timeout",
                                    "dampening_initial_wait",
                                    "dampening_maximum_wait",
                                    "dampening_secondary_wait",
                                    "enable",
                                    "encap_mode",
                                    "fast_detect",
                                    "minimum_interval",
                                    "multiplier",
                                    "periodic_ping_disable",
                                    "periodic_ping_interval") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bringup_timeout.is_set or
                        self.dampening_initial_wait.is_set or
                        self.dampening_maximum_wait.is_set or
                        self.dampening_secondary_wait.is_set or
                        self.enable.is_set or
                        self.encap_mode.is_set or
                        self.fast_detect.is_set or
                        self.minimum_interval.is_set or
                        self.multiplier.is_set or
                        self.periodic_ping_disable.is_set or
                        self.periodic_ping_interval.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bringup_timeout.yfilter != YFilter.not_set or
                        self.dampening_initial_wait.yfilter != YFilter.not_set or
                        self.dampening_maximum_wait.yfilter != YFilter.not_set or
                        self.dampening_secondary_wait.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        self.encap_mode.yfilter != YFilter.not_set or
                        self.fast_detect.yfilter != YFilter.not_set or
                        self.minimum_interval.yfilter != YFilter.not_set or
                        self.multiplier.yfilter != YFilter.not_set or
                        self.periodic_ping_disable.yfilter != YFilter.not_set or
                        self.periodic_ping_interval.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bfd-over-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bringup_timeout.is_set or self.bringup_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bringup_timeout.get_name_leafdata())
                    if (self.dampening_initial_wait.is_set or self.dampening_initial_wait.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dampening_initial_wait.get_name_leafdata())
                    if (self.dampening_maximum_wait.is_set or self.dampening_maximum_wait.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dampening_maximum_wait.get_name_leafdata())
                    if (self.dampening_secondary_wait.is_set or self.dampening_secondary_wait.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dampening_secondary_wait.get_name_leafdata())
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())
                    if (self.encap_mode.is_set or self.encap_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.encap_mode.get_name_leafdata())
                    if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.fast_detect.get_name_leafdata())
                    if (self.minimum_interval.is_set or self.minimum_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_interval.get_name_leafdata())
                    if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multiplier.get_name_leafdata())
                    if (self.periodic_ping_disable.is_set or self.periodic_ping_disable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.periodic_ping_disable.get_name_leafdata())
                    if (self.periodic_ping_interval.is_set or self.periodic_ping_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.periodic_ping_interval.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bringup-timeout" or name == "dampening-initial-wait" or name == "dampening-maximum-wait" or name == "dampening-secondary-wait" or name == "enable" or name == "encap-mode" or name == "fast-detect" or name == "minimum-interval" or name == "multiplier" or name == "periodic-ping-disable" or name == "periodic-ping-interval"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bringup-timeout"):
                        self.bringup_timeout = value
                        self.bringup_timeout.value_namespace = name_space
                        self.bringup_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "dampening-initial-wait"):
                        self.dampening_initial_wait = value
                        self.dampening_initial_wait.value_namespace = name_space
                        self.dampening_initial_wait.value_namespace_prefix = name_space_prefix
                    if(value_path == "dampening-maximum-wait"):
                        self.dampening_maximum_wait = value
                        self.dampening_maximum_wait.value_namespace = name_space
                        self.dampening_maximum_wait.value_namespace_prefix = name_space_prefix
                    if(value_path == "dampening-secondary-wait"):
                        self.dampening_secondary_wait = value
                        self.dampening_secondary_wait.value_namespace = name_space
                        self.dampening_secondary_wait.value_namespace_prefix = name_space_prefix
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix
                    if(value_path == "encap-mode"):
                        self.encap_mode = value
                        self.encap_mode.value_namespace = name_space
                        self.encap_mode.value_namespace_prefix = name_space_prefix
                    if(value_path == "fast-detect"):
                        self.fast_detect = value
                        self.fast_detect.value_namespace = name_space
                        self.fast_detect.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-interval"):
                        self.minimum_interval = value
                        self.minimum_interval.value_namespace = name_space
                        self.minimum_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "multiplier"):
                        self.multiplier = value
                        self.multiplier.value_namespace = name_space
                        self.multiplier.value_namespace_prefix = name_space_prefix
                    if(value_path == "periodic-ping-disable"):
                        self.periodic_ping_disable = value
                        self.periodic_ping_disable.value_namespace = name_space
                        self.periodic_ping_disable.value_namespace_prefix = name_space_prefix
                    if(value_path == "periodic-ping-interval"):
                        self.periodic_ping_interval = value
                        self.periodic_ping_interval.value_namespace = name_space
                        self.periodic_ping_interval.value_namespace_prefix = name_space_prefix


            class BindingSegmentIdMpls(Entity):
                """
                Allocate MPLS binding segment ID
                
                .. attribute:: label_value
                
                	MPLS label
                	**type**\:  int
                
                	**range:** 16..4015
                
                .. attribute:: segment_id_type
                
                	MPLS label value type
                	**type**\:   :py:class:`BindingSegmentId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.BindingSegmentId>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls, self).__init__()

                    self.yang_name = "binding-segment-id-mpls"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.label_value = YLeaf(YType.uint32, "label-value")

                    self.segment_id_type = YLeaf(YType.enumeration, "segment-id-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("label_value",
                                    "segment_id_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.label_value.is_set or
                        self.segment_id_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.label_value.yfilter != YFilter.not_set or
                        self.segment_id_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "binding-segment-id-mpls" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.label_value.is_set or self.label_value.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.label_value.get_name_leafdata())
                    if (self.segment_id_type.is_set or self.segment_id_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.segment_id_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "label-value" or name == "segment-id-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "label-value"):
                        self.label_value = value
                        self.label_value.value_namespace = name_space
                        self.label_value.value_namespace_prefix = name_space_prefix
                    if(value_path == "segment-id-type"):
                        self.segment_id_type = value
                        self.segment_id_type.value_namespace = name_space
                        self.segment_id_type.value_namespace_prefix = name_space_prefix


            class ForwardingAdjacency(Entity):
                """
                Forwarding adjacency announcement to IGP
                
                .. attribute:: enable
                
                	Enable forwarding adjacency
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hold_time
                
                	Specify the holdtime for the tunnel as forwarding adjacency
                	**type**\:  int
                
                	**range:** 0..20000
                
                .. attribute:: include_ipv6
                
                	Specify that the tunnel should be an IPv6 forwarding adjacency also
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency, self).__init__()

                    self.yang_name = "forwarding-adjacency"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.enable = YLeaf(YType.empty, "enable")

                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                    self.include_ipv6 = YLeaf(YType.empty, "include-ipv6")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("enable",
                                    "hold_time",
                                    "include_ipv6") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.enable.is_set or
                        self.hold_time.is_set or
                        self.include_ipv6.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        self.hold_time.yfilter != YFilter.not_set or
                        self.include_ipv6.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "forwarding-adjacency" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())
                    if (self.hold_time.is_set or self.hold_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hold_time.get_name_leafdata())
                    if (self.include_ipv6.is_set or self.include_ipv6.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.include_ipv6.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "enable" or name == "hold-time" or name == "include-ipv6"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix
                    if(value_path == "hold-time"):
                        self.hold_time = value
                        self.hold_time.value_namespace = name_space
                        self.hold_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "include-ipv6"):
                        self.include_ipv6 = value
                        self.include_ipv6.value_namespace = name_space
                        self.include_ipv6.value_namespace_prefix = name_space_prefix


            class PathOptionProtects(Entity):
                """
                Tunnel path protection state
                
                .. attribute:: path_option_protect
                
                	Tunnel path protection
                	**type**\: list of    :py:class:`PathOptionProtect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects, self).__init__()

                    self.yang_name = "path-option-protects"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.path_option_protect = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects, self).__setattr__(name, value)


                class PathOptionProtect(Entity):
                    """
                    Tunnel path protection
                    
                    .. attribute:: protection  <key>
                    
                    	Protection type for this path
                    	**type**\:   :py:class:`MplsTePathOptionProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProtection>`
                    
                    .. attribute:: path_options
                    
                    	Tunnel path options
                    	**type**\:   :py:class:`PathOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect, self).__init__()

                        self.yang_name = "path-option-protect"
                        self.yang_parent_name = "path-option-protects"

                        self.protection = YLeaf(YType.enumeration, "protection")

                        self.path_options = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions()
                        self.path_options.parent = self
                        self._children_name_map["path_options"] = "path-options"
                        self._children_yang_names.add("path-options")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("protection") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect, self).__setattr__(name, value)


                    class PathOptions(Entity):
                        """
                        Tunnel path options
                        
                        .. attribute:: path_option
                        
                        	A tunnel path option
                        	**type**\: list of    :py:class:`PathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions, self).__init__()

                            self.yang_name = "path-options"
                            self.yang_parent_name = "path-option-protect"

                            self.path_option = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions, self).__setattr__(name, value)


                        class PathOption(Entity):
                            """
                            A tunnel path option
                            
                            .. attribute:: preference_level  <key>
                            
                            	Preference level for this path option
                            	**type**\:  int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: destination
                            
                            	Deprecated
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: igp_area
                            
                            	IGP area ID in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: igp_area_ip_address_id
                            
                            	IGP area ID in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: igp_instance
                            
                            	IGP instance name
                            	**type**\:  str
                            
                            	**length:** 1..40
                            
                            .. attribute:: igp_type
                            
                            	IGP type
                            	**type**\:   :py:class:`MplsTeIgpProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeIgpProtocol>`
                            
                            	**default value**\: none
                            
                            .. attribute:: interface
                            
                            	Deprecated
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: lockdown
                            
                            	Lockdown properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            .. attribute:: output_label
                            
                            	Deprecated
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: path_id
                            
                            	The ID of the IP explicit path associated with this option
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**default value**\: 1
                            
                            .. attribute:: path_name
                            
                            	The name of the IP explicit path associated with this option
                            	**type**\:  str
                            
                            .. attribute:: path_option_attribute_set_name
                            
                            	Path option attribute set name
                            	**type**\:  str
                            
                            .. attribute:: path_property
                            
                            	Deprecated
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: path_type
                            
                            	The type of the path option
                            	**type**\:   :py:class:`MplsTePathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOption>`
                            
                            	**mandatory**\: True
                            
                            .. attribute:: pce
                            
                            	PCE properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            .. attribute:: pce_address
                            
                            	PCE address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: protected_by_preference_level
                            
                            	Preference level of the protecting explicit path. Leave unset in order to not use an explicit protecting path
                            	**type**\:  int
                            
                            	**range:** 1..1000
                            
                            	**default value**\: 1
                            
                            .. attribute:: segment_routing
                            
                            	SegmentRouting properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            .. attribute:: verbatim
                            
                            	Verbatim properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            

                            """

                            _prefix = 'mpls-te-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "path-options"

                                self.preference_level = YLeaf(YType.uint32, "preference-level")

                                self.destination = YLeaf(YType.str, "destination")

                                self.igp_area = YLeaf(YType.int32, "igp-area")

                                self.igp_area_ip_address_id = YLeaf(YType.str, "igp-area-ip-address-id")

                                self.igp_instance = YLeaf(YType.str, "igp-instance")

                                self.igp_type = YLeaf(YType.enumeration, "igp-type")

                                self.interface = YLeaf(YType.str, "interface")

                                self.lockdown = YLeaf(YType.enumeration, "lockdown")

                                self.output_label = YLeaf(YType.int32, "output-label")

                                self.path_id = YLeaf(YType.uint32, "path-id")

                                self.path_name = YLeaf(YType.str, "path-name")

                                self.path_option_attribute_set_name = YLeaf(YType.str, "path-option-attribute-set-name")

                                self.path_property = YLeaf(YType.int32, "path-property")

                                self.path_type = YLeaf(YType.enumeration, "path-type")

                                self.pce = YLeaf(YType.enumeration, "pce")

                                self.pce_address = YLeaf(YType.str, "pce-address")

                                self.protected_by_preference_level = YLeaf(YType.uint32, "protected-by-preference-level")

                                self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                                self.verbatim = YLeaf(YType.enumeration, "verbatim")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("preference_level",
                                                "destination",
                                                "igp_area",
                                                "igp_area_ip_address_id",
                                                "igp_instance",
                                                "igp_type",
                                                "interface",
                                                "lockdown",
                                                "output_label",
                                                "path_id",
                                                "path_name",
                                                "path_option_attribute_set_name",
                                                "path_property",
                                                "path_type",
                                                "pce",
                                                "pce_address",
                                                "protected_by_preference_level",
                                                "segment_routing",
                                                "verbatim") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.preference_level.is_set or
                                    self.destination.is_set or
                                    self.igp_area.is_set or
                                    self.igp_area_ip_address_id.is_set or
                                    self.igp_instance.is_set or
                                    self.igp_type.is_set or
                                    self.interface.is_set or
                                    self.lockdown.is_set or
                                    self.output_label.is_set or
                                    self.path_id.is_set or
                                    self.path_name.is_set or
                                    self.path_option_attribute_set_name.is_set or
                                    self.path_property.is_set or
                                    self.path_type.is_set or
                                    self.pce.is_set or
                                    self.pce_address.is_set or
                                    self.protected_by_preference_level.is_set or
                                    self.segment_routing.is_set or
                                    self.verbatim.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.preference_level.yfilter != YFilter.not_set or
                                    self.destination.yfilter != YFilter.not_set or
                                    self.igp_area.yfilter != YFilter.not_set or
                                    self.igp_area_ip_address_id.yfilter != YFilter.not_set or
                                    self.igp_instance.yfilter != YFilter.not_set or
                                    self.igp_type.yfilter != YFilter.not_set or
                                    self.interface.yfilter != YFilter.not_set or
                                    self.lockdown.yfilter != YFilter.not_set or
                                    self.output_label.yfilter != YFilter.not_set or
                                    self.path_id.yfilter != YFilter.not_set or
                                    self.path_name.yfilter != YFilter.not_set or
                                    self.path_option_attribute_set_name.yfilter != YFilter.not_set or
                                    self.path_property.yfilter != YFilter.not_set or
                                    self.path_type.yfilter != YFilter.not_set or
                                    self.pce.yfilter != YFilter.not_set or
                                    self.pce_address.yfilter != YFilter.not_set or
                                    self.protected_by_preference_level.yfilter != YFilter.not_set or
                                    self.segment_routing.yfilter != YFilter.not_set or
                                    self.verbatim.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "path-option" + "[preference-level='" + self.preference_level.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.preference_level.is_set or self.preference_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preference_level.get_name_leafdata())
                                if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination.get_name_leafdata())
                                if (self.igp_area.is_set or self.igp_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igp_area.get_name_leafdata())
                                if (self.igp_area_ip_address_id.is_set or self.igp_area_ip_address_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igp_area_ip_address_id.get_name_leafdata())
                                if (self.igp_instance.is_set or self.igp_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igp_instance.get_name_leafdata())
                                if (self.igp_type.is_set or self.igp_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igp_type.get_name_leafdata())
                                if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface.get_name_leafdata())
                                if (self.lockdown.is_set or self.lockdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lockdown.get_name_leafdata())
                                if (self.output_label.is_set or self.output_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.output_label.get_name_leafdata())
                                if (self.path_id.is_set or self.path_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_id.get_name_leafdata())
                                if (self.path_name.is_set or self.path_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_name.get_name_leafdata())
                                if (self.path_option_attribute_set_name.is_set or self.path_option_attribute_set_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_option_attribute_set_name.get_name_leafdata())
                                if (self.path_property.is_set or self.path_property.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_property.get_name_leafdata())
                                if (self.path_type.is_set or self.path_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_type.get_name_leafdata())
                                if (self.pce.is_set or self.pce.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce.get_name_leafdata())
                                if (self.pce_address.is_set or self.pce_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pce_address.get_name_leafdata())
                                if (self.protected_by_preference_level.is_set or self.protected_by_preference_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_by_preference_level.get_name_leafdata())
                                if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_routing.get_name_leafdata())
                                if (self.verbatim.is_set or self.verbatim.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.verbatim.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "preference-level" or name == "destination" or name == "igp-area" or name == "igp-area-ip-address-id" or name == "igp-instance" or name == "igp-type" or name == "interface" or name == "lockdown" or name == "output-label" or name == "path-id" or name == "path-name" or name == "path-option-attribute-set-name" or name == "path-property" or name == "path-type" or name == "pce" or name == "pce-address" or name == "protected-by-preference-level" or name == "segment-routing" or name == "verbatim"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "preference-level"):
                                    self.preference_level = value
                                    self.preference_level.value_namespace = name_space
                                    self.preference_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination"):
                                    self.destination = value
                                    self.destination.value_namespace = name_space
                                    self.destination.value_namespace_prefix = name_space_prefix
                                if(value_path == "igp-area"):
                                    self.igp_area = value
                                    self.igp_area.value_namespace = name_space
                                    self.igp_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "igp-area-ip-address-id"):
                                    self.igp_area_ip_address_id = value
                                    self.igp_area_ip_address_id.value_namespace = name_space
                                    self.igp_area_ip_address_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "igp-instance"):
                                    self.igp_instance = value
                                    self.igp_instance.value_namespace = name_space
                                    self.igp_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "igp-type"):
                                    self.igp_type = value
                                    self.igp_type.value_namespace = name_space
                                    self.igp_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface"):
                                    self.interface = value
                                    self.interface.value_namespace = name_space
                                    self.interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "lockdown"):
                                    self.lockdown = value
                                    self.lockdown.value_namespace = name_space
                                    self.lockdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "output-label"):
                                    self.output_label = value
                                    self.output_label.value_namespace = name_space
                                    self.output_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-id"):
                                    self.path_id = value
                                    self.path_id.value_namespace = name_space
                                    self.path_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-name"):
                                    self.path_name = value
                                    self.path_name.value_namespace = name_space
                                    self.path_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-option-attribute-set-name"):
                                    self.path_option_attribute_set_name = value
                                    self.path_option_attribute_set_name.value_namespace = name_space
                                    self.path_option_attribute_set_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-property"):
                                    self.path_property = value
                                    self.path_property.value_namespace = name_space
                                    self.path_property.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-type"):
                                    self.path_type = value
                                    self.path_type.value_namespace = name_space
                                    self.path_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce"):
                                    self.pce = value
                                    self.pce.value_namespace = name_space
                                    self.pce.value_namespace_prefix = name_space_prefix
                                if(value_path == "pce-address"):
                                    self.pce_address = value
                                    self.pce_address.value_namespace = name_space
                                    self.pce_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-by-preference-level"):
                                    self.protected_by_preference_level = value
                                    self.protected_by_preference_level.value_namespace = name_space
                                    self.protected_by_preference_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-routing"):
                                    self.segment_routing = value
                                    self.segment_routing.value_namespace = name_space
                                    self.segment_routing.value_namespace_prefix = name_space_prefix
                                if(value_path == "verbatim"):
                                    self.verbatim = value
                                    self.verbatim.value_namespace = name_space
                                    self.verbatim.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.path_option:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.path_option:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "path-options" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "path-option"):
                                for c in self.path_option:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.path_option.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path-option"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.protection.is_set or
                            (self.path_options is not None and self.path_options.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.protection.yfilter != YFilter.not_set or
                            (self.path_options is not None and self.path_options.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "path-option-protect" + "[protection='" + self.protection.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.protection.is_set or self.protection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protection.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "path-options"):
                            if (self.path_options is None):
                                self.path_options = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions()
                                self.path_options.parent = self
                                self._children_name_map["path_options"] = "path-options"
                            return self.path_options

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "path-options" or name == "protection"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "protection"):
                            self.protection = value
                            self.protection.value_namespace = name_space
                            self.protection.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.path_option_protect:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.path_option_protect:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "path-option-protects" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "path-option-protect"):
                        for c in self.path_option_protect:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.path_option_protect.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "path-option-protect"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bidirectional(Entity):
                """
                Tunnel Interface Bidirectional configuration
                data
                
                .. attribute:: association_corouted_type
                
                	Association Corouted Type
                	**type**\:   :py:class:`AssociationCoroutedType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType>`
                
                .. attribute:: association_parameters
                
                	Association ID, Source IP Address, and Global ID
                	**type**\:   :py:class:`AssociationParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters>`
                
                	**presence node**\: True
                
                .. attribute:: enabled
                
                	This object is only valid for tunnel interfaces and it controls whether that interface has bidirectional enabled on it or not
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional, self).__init__()

                    self.yang_name = "bidirectional"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.enabled = YLeaf(YType.empty, "enabled")

                    self.association_corouted_type = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType()
                    self.association_corouted_type.parent = self
                    self._children_name_map["association_corouted_type"] = "association-corouted-type"
                    self._children_yang_names.add("association-corouted-type")

                    self.association_parameters = None
                    self._children_name_map["association_parameters"] = "association-parameters"
                    self._children_yang_names.add("association-parameters")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional, self).__setattr__(name, value)


                class AssociationCoroutedType(Entity):
                    """
                    Association Corouted Type
                    
                    .. attribute:: enable
                    
                    	Controls whether association type is co\-routed
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fault_oam
                    
                    	Tunnel Fault OAM
                    	**type**\:   :py:class:`FaultOam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam>`
                    
                    .. attribute:: wrap_protection_enable
                    
                    	This object is only valid for bidirectional tunnel interfaces and it controls whether that interface has LSP Wrap protectionenabled on it or not
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType, self).__init__()

                        self.yang_name = "association-corouted-type"
                        self.yang_parent_name = "bidirectional"

                        self.enable = YLeaf(YType.empty, "enable")

                        self.wrap_protection_enable = YLeaf(YType.empty, "wrap-protection-enable")

                        self.fault_oam = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam()
                        self.fault_oam.parent = self
                        self._children_name_map["fault_oam"] = "fault-oam"
                        self._children_yang_names.add("fault-oam")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("enable",
                                        "wrap_protection_enable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType, self).__setattr__(name, value)


                    class FaultOam(Entity):
                        """
                        Tunnel Fault OAM
                        
                        .. attribute:: enable
                        
                        	This object is only valid for bidirectional tunnel interfaces and it controls whether that interface has fault OAM enabled on it or not
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam, self).__init__()

                            self.yang_name = "fault-oam"
                            self.yang_parent_name = "association-corouted-type"

                            self.enable = YLeaf(YType.empty, "enable")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("enable") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam, self).__setattr__(name, value)

                        def has_data(self):
                            return self.enable.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.enable.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "fault-oam" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enable.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "enable"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "enable"):
                                self.enable = value
                                self.enable.value_namespace = name_space
                                self.enable.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.enable.is_set or
                            self.wrap_protection_enable.is_set or
                            (self.fault_oam is not None and self.fault_oam.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.wrap_protection_enable.yfilter != YFilter.not_set or
                            (self.fault_oam is not None and self.fault_oam.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "association-corouted-type" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.wrap_protection_enable.is_set or self.wrap_protection_enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wrap_protection_enable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "fault-oam"):
                            if (self.fault_oam is None):
                                self.fault_oam = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam()
                                self.fault_oam.parent = self
                                self._children_name_map["fault_oam"] = "fault-oam"
                            return self.fault_oam

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "fault-oam" or name == "enable" or name == "wrap-protection-enable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "wrap-protection-enable"):
                            self.wrap_protection_enable = value
                            self.wrap_protection_enable.value_namespace = name_space
                            self.wrap_protection_enable.value_namespace_prefix = name_space_prefix


                class AssociationParameters(Entity):
                    """
                    Association ID, Source IP Address, and Global
                    ID
                    
                    .. attribute:: association_global_id
                    
                    	Association Global ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: association_id
                    
                    	Association ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**mandatory**\: True
                    
                    .. attribute:: association_is_global_id_configured
                    
                    	Is Association Global ID Configured
                    	**type**\:  bool
                    
                    .. attribute:: association_source_address
                    
                    	Association Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters, self).__init__()

                        self.yang_name = "association-parameters"
                        self.yang_parent_name = "bidirectional"
                        self.is_presence_container = True

                        self.association_global_id = YLeaf(YType.uint32, "association-global-id")

                        self.association_id = YLeaf(YType.uint32, "association-id")

                        self.association_is_global_id_configured = YLeaf(YType.boolean, "association-is-global-id-configured")

                        self.association_source_address = YLeaf(YType.str, "association-source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("association_global_id",
                                        "association_id",
                                        "association_is_global_id_configured",
                                        "association_source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.association_global_id.is_set or
                            self.association_id.is_set or
                            self.association_is_global_id_configured.is_set or
                            self.association_source_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.association_global_id.yfilter != YFilter.not_set or
                            self.association_id.yfilter != YFilter.not_set or
                            self.association_is_global_id_configured.yfilter != YFilter.not_set or
                            self.association_source_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "association-parameters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.association_global_id.is_set or self.association_global_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.association_global_id.get_name_leafdata())
                        if (self.association_id.is_set or self.association_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.association_id.get_name_leafdata())
                        if (self.association_is_global_id_configured.is_set or self.association_is_global_id_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.association_is_global_id_configured.get_name_leafdata())
                        if (self.association_source_address.is_set or self.association_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.association_source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "association-global-id" or name == "association-id" or name == "association-is-global-id-configured" or name == "association-source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "association-global-id"):
                            self.association_global_id = value
                            self.association_global_id.value_namespace = name_space
                            self.association_global_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "association-id"):
                            self.association_id = value
                            self.association_id.value_namespace = name_space
                            self.association_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "association-is-global-id-configured"):
                            self.association_is_global_id_configured = value
                            self.association_is_global_id_configured.value_namespace = name_space
                            self.association_is_global_id_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "association-source-address"):
                            self.association_source_address = value
                            self.association_source_address.value_namespace = name_space
                            self.association_source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.enabled.is_set or
                        (self.association_corouted_type is not None and self.association_corouted_type.has_data()) or
                        (self.association_parameters is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.enabled.yfilter != YFilter.not_set or
                        (self.association_corouted_type is not None and self.association_corouted_type.has_operation()) or
                        (self.association_parameters is not None and self.association_parameters.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidirectional" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.enabled.is_set or self.enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "association-corouted-type"):
                        if (self.association_corouted_type is None):
                            self.association_corouted_type = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType()
                            self.association_corouted_type.parent = self
                            self._children_name_map["association_corouted_type"] = "association-corouted-type"
                        return self.association_corouted_type

                    if (child_yang_name == "association-parameters"):
                        if (self.association_parameters is None):
                            self.association_parameters = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters()
                            self.association_parameters.parent = self
                            self._children_name_map["association_parameters"] = "association-parameters"
                        return self.association_parameters

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "association-corouted-type" or name == "association-parameters" or name == "enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "enabled"):
                        self.enabled = value
                        self.enabled.value_namespace = name_space
                        self.enabled.value_namespace_prefix = name_space_prefix


            class AdminMode(Entity):
                """
                Performs admin operations on the optical tunnel
                interface
                
                .. attribute:: deactivate_tunnel
                
                	Performs signalling operation to deactivate optical tunnel
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode, self).__init__()

                    self.yang_name = "admin-mode"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.deactivate_tunnel = YLeaf(YType.empty, "deactivate-tunnel")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("deactivate_tunnel") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode, self).__setattr__(name, value)

                def has_data(self):
                    return self.deactivate_tunnel.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.deactivate_tunnel.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "admin-mode" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.deactivate_tunnel.is_set or self.deactivate_tunnel.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.deactivate_tunnel.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "deactivate-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "deactivate-tunnel"):
                        self.deactivate_tunnel = value
                        self.deactivate_tunnel.value_namespace = name_space
                        self.deactivate_tunnel.value_namespace_prefix = name_space_prefix


            class Switching(Entity):
                """
                Specify tunnel LSPs switching capability
                descriptor
                
                .. attribute:: endpoint
                
                	Specify end point switching descriptor parameters
                	**type**\:   :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint>`
                
                	**presence node**\: True
                
                .. attribute:: transit
                
                	Specify transit switching descriptor parameters
                	**type**\:   :py:class:`Transit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching, self).__init__()

                    self.yang_name = "switching"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.endpoint = None
                    self._children_name_map["endpoint"] = "endpoint"
                    self._children_yang_names.add("endpoint")

                    self.transit = None
                    self._children_name_map["transit"] = "transit"
                    self._children_yang_names.add("transit")


                class Transit(Entity):
                    """
                    Specify transit switching descriptor
                    parameters
                    
                    .. attribute:: capability
                    
                    	Switching capability
                    	**type**\:   :py:class:`MplsTeSwitchingCap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingCap>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: encoding
                    
                    	LSP encoding
                    	**type**\:   :py:class:`MplsTeSwitchingEncode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingEncode>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit, self).__init__()

                        self.yang_name = "transit"
                        self.yang_parent_name = "switching"
                        self.is_presence_container = True

                        self.capability = YLeaf(YType.enumeration, "capability")

                        self.encoding = YLeaf(YType.enumeration, "encoding")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("capability",
                                        "encoding") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.capability.is_set or
                            self.encoding.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.capability.yfilter != YFilter.not_set or
                            self.encoding.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "transit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.capability.is_set or self.capability.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.capability.get_name_leafdata())
                        if (self.encoding.is_set or self.encoding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encoding.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "capability" or name == "encoding"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "capability"):
                            self.capability = value
                            self.capability.value_namespace = name_space
                            self.capability.value_namespace_prefix = name_space_prefix
                        if(value_path == "encoding"):
                            self.encoding = value
                            self.encoding.value_namespace = name_space
                            self.encoding.value_namespace_prefix = name_space_prefix


                class Endpoint(Entity):
                    """
                    Specify end point switching descriptor
                    parameters
                    
                    .. attribute:: capability
                    
                    	Switching capability
                    	**type**\:   :py:class:`MplsTeSwitchingCap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingCap>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: encoding
                    
                    	LSP encoding
                    	**type**\:   :py:class:`MplsTeSwitchingEncode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingEncode>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint, self).__init__()

                        self.yang_name = "endpoint"
                        self.yang_parent_name = "switching"
                        self.is_presence_container = True

                        self.capability = YLeaf(YType.enumeration, "capability")

                        self.encoding = YLeaf(YType.enumeration, "encoding")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("capability",
                                        "encoding") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.capability.is_set or
                            self.encoding.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.capability.yfilter != YFilter.not_set or
                            self.encoding.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "endpoint" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.capability.is_set or self.capability.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.capability.get_name_leafdata())
                        if (self.encoding.is_set or self.encoding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encoding.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "capability" or name == "encoding"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "capability"):
                            self.capability = value
                            self.capability.value_namespace = name_space
                            self.capability.value_namespace_prefix = name_space_prefix
                        if(value_path == "encoding"):
                            self.encoding = value
                            self.encoding.value_namespace = name_space
                            self.encoding.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        (self.endpoint is not None) or
                        (self.transit is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.endpoint is not None and self.endpoint.has_operation()) or
                        (self.transit is not None and self.transit.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "switching" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "endpoint"):
                        if (self.endpoint is None):
                            self.endpoint = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint()
                            self.endpoint.parent = self
                            self._children_name_map["endpoint"] = "endpoint"
                        return self.endpoint

                    if (child_yang_name == "transit"):
                        if (self.transit is None):
                            self.transit = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit()
                            self.transit.parent = self
                            self._children_name_map["transit"] = "transit"
                        return self.transit

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "endpoint" or name == "transit"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Pce(Entity):
                """
                PCE config
                
                .. attribute:: delegation
                
                	Enable PCE Delegation
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enable
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce, self).__init__()

                    self.yang_name = "pce"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.delegation = YLeaf(YType.empty, "delegation")

                    self.enable = YLeaf(YType.empty, "enable")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("delegation",
                                    "enable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.delegation.is_set or
                        self.enable.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.delegation.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pce" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.delegation.is_set or self.delegation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.delegation.get_name_leafdata())
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "delegation" or name == "enable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "delegation"):
                        self.delegation = value
                        self.delegation.value_namespace = name_space
                        self.delegation.value_namespace_prefix = name_space_prefix
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix


            class TunnelPathSelection(Entity):
                """
                Configure path selection properties
                
                .. attribute:: invalidation
                
                	Path invalidation configuration for this specific tunnel
                	**type**\:   :py:class:`Invalidation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation>`
                
                	**presence node**\: True
                
                .. attribute:: path_selection_cost_limit
                
                	Path selection cost limit configuration for this specific tunnel
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: path_selection_hop_limit
                
                	Path selection hop limit configuration for this specific tunnel
                	**type**\:  int
                
                	**range:** 1..255
                
                .. attribute:: tiebreaker
                
                	CSPF tiebreaker to use in path calculation
                	**type**\:   :py:class:`MplsTePathSelectionTiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathSelectionTiebreaker>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection, self).__init__()

                    self.yang_name = "tunnel-path-selection"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.path_selection_cost_limit = YLeaf(YType.uint32, "path-selection-cost-limit")

                    self.path_selection_hop_limit = YLeaf(YType.uint32, "path-selection-hop-limit")

                    self.tiebreaker = YLeaf(YType.enumeration, "tiebreaker")

                    self.invalidation = None
                    self._children_name_map["invalidation"] = "invalidation"
                    self._children_yang_names.add("invalidation")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("path_selection_cost_limit",
                                    "path_selection_hop_limit",
                                    "tiebreaker") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection, self).__setattr__(name, value)


                class Invalidation(Entity):
                    """
                    Path invalidation configuration for this
                    specific tunnel
                    
                    .. attribute:: path_invalidation_action
                    
                    	Path Invalidation Action
                    	**type**\:   :py:class:`PathInvalidationAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.PathInvalidationAction>`
                    
                    .. attribute:: path_invalidation_timeout
                    
                    	Path Invalidation Timeout
                    	**type**\:  int
                    
                    	**range:** 0..60000
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation, self).__init__()

                        self.yang_name = "invalidation"
                        self.yang_parent_name = "tunnel-path-selection"
                        self.is_presence_container = True

                        self.path_invalidation_action = YLeaf(YType.enumeration, "path-invalidation-action")

                        self.path_invalidation_timeout = YLeaf(YType.uint32, "path-invalidation-timeout")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("path_invalidation_action",
                                        "path_invalidation_timeout") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.path_invalidation_action.is_set or
                            self.path_invalidation_timeout.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.path_invalidation_action.yfilter != YFilter.not_set or
                            self.path_invalidation_timeout.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "invalidation" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.path_invalidation_action.is_set or self.path_invalidation_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_invalidation_action.get_name_leafdata())
                        if (self.path_invalidation_timeout.is_set or self.path_invalidation_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_invalidation_timeout.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "path-invalidation-action" or name == "path-invalidation-timeout"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "path-invalidation-action"):
                            self.path_invalidation_action = value
                            self.path_invalidation_action.value_namespace = name_space
                            self.path_invalidation_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-invalidation-timeout"):
                            self.path_invalidation_timeout = value
                            self.path_invalidation_timeout.value_namespace = name_space
                            self.path_invalidation_timeout.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.path_selection_cost_limit.is_set or
                        self.path_selection_hop_limit.is_set or
                        self.tiebreaker.is_set or
                        (self.invalidation is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.path_selection_cost_limit.yfilter != YFilter.not_set or
                        self.path_selection_hop_limit.yfilter != YFilter.not_set or
                        self.tiebreaker.yfilter != YFilter.not_set or
                        (self.invalidation is not None and self.invalidation.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "tunnel-path-selection" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.path_selection_cost_limit.is_set or self.path_selection_cost_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_selection_cost_limit.get_name_leafdata())
                    if (self.path_selection_hop_limit.is_set or self.path_selection_hop_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_selection_hop_limit.get_name_leafdata())
                    if (self.tiebreaker.is_set or self.tiebreaker.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tiebreaker.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "invalidation"):
                        if (self.invalidation is None):
                            self.invalidation = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation()
                            self.invalidation.parent = self
                            self._children_name_map["invalidation"] = "invalidation"
                        return self.invalidation

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "invalidation" or name == "path-selection-cost-limit" or name == "path-selection-hop-limit" or name == "tiebreaker"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "path-selection-cost-limit"):
                        self.path_selection_cost_limit = value
                        self.path_selection_cost_limit.value_namespace = name_space
                        self.path_selection_cost_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-selection-hop-limit"):
                        self.path_selection_hop_limit = value
                        self.path_selection_hop_limit.value_namespace = name_space
                        self.path_selection_hop_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "tiebreaker"):
                        self.tiebreaker = value
                        self.tiebreaker.value_namespace = name_space
                        self.tiebreaker.value_namespace_prefix = name_space_prefix


            class AutoBandwidth(Entity):
                """
                Tunnel Interface Auto\-bandwidth configuration
                data
                
                .. attribute:: adjustment_threshold
                
                	Set the bandwidth change threshold to trigger adjustment
                	**type**\:   :py:class:`AdjustmentThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold>`
                
                	**presence node**\: True
                
                .. attribute:: application_frequency
                
                	Set the tunnel auto\-bw application frequency in minutes
                	**type**\:  int
                
                	**range:** 5..10080
                
                	**units**\: minute
                
                .. attribute:: bandwidth_limits
                
                	Set min/max bandwidth auto\-bw can apply on a tunnel
                	**type**\:   :py:class:`BandwidthLimits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits>`
                
                	**presence node**\: True
                
                .. attribute:: collection_only
                
                	Enable bandwidth collection only, no auto\-bw adjustment
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enabled
                
                	This object is only valid for tunnel interfaces and it controls whether that interface has auto\-bw enabled on it or not.The object must be set before any other auto\-bw configuration is supplied for the interface, and must be the last auto\-bw configuration object to be removed 
                	**type**\:  bool
                
                .. attribute:: overflow
                
                	Configuring the tunnel overflow detection
                	**type**\:   :py:class:`Overflow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow>`
                
                	**presence node**\: True
                
                .. attribute:: overflow_enable
                
                	Enable auto bandwidth overflow detection
                	**type**\:  bool
                
                .. attribute:: underflow
                
                	Configuring the tunnel underflow detection
                	**type**\:   :py:class:`Underflow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow>`
                
                	**presence node**\: True
                
                .. attribute:: underflow_enable
                
                	Enable auto bandwidth underflow detection
                	**type**\:  bool
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth, self).__init__()

                    self.yang_name = "auto-bandwidth"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.application_frequency = YLeaf(YType.uint32, "application-frequency")

                    self.collection_only = YLeaf(YType.empty, "collection-only")

                    self.enabled = YLeaf(YType.boolean, "enabled")

                    self.overflow_enable = YLeaf(YType.boolean, "overflow-enable")

                    self.underflow_enable = YLeaf(YType.boolean, "underflow-enable")

                    self.adjustment_threshold = None
                    self._children_name_map["adjustment_threshold"] = "adjustment-threshold"
                    self._children_yang_names.add("adjustment-threshold")

                    self.bandwidth_limits = None
                    self._children_name_map["bandwidth_limits"] = "bandwidth-limits"
                    self._children_yang_names.add("bandwidth-limits")

                    self.overflow = None
                    self._children_name_map["overflow"] = "overflow"
                    self._children_yang_names.add("overflow")

                    self.underflow = None
                    self._children_name_map["underflow"] = "underflow"
                    self._children_yang_names.add("underflow")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("application_frequency",
                                    "collection_only",
                                    "enabled",
                                    "overflow_enable",
                                    "underflow_enable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth, self).__setattr__(name, value)


                class Underflow(Entity):
                    """
                    Configuring the tunnel underflow detection
                    
                    .. attribute:: underflow_threshold_limit
                    
                    	Number of consecutive collections exceeding threshold
                    	**type**\:  int
                    
                    	**range:** 1..10
                    
                    	**mandatory**\: True
                    
                    .. attribute:: underflow_threshold_percent
                    
                    	Bandwidth change percent to trigger an underflow
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    	**mandatory**\: True
                    
                    	**units**\: percentage
                    
                    .. attribute:: underflow_threshold_value
                    
                    	Bandwidth change value to trigger an underflow (kbps)
                    	**type**\:  int
                    
                    	**range:** 10..4294967295
                    
                    	**mandatory**\: True
                    
                    	**units**\: kbit/s
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow, self).__init__()

                        self.yang_name = "underflow"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_presence_container = True

                        self.underflow_threshold_limit = YLeaf(YType.uint32, "underflow-threshold-limit")

                        self.underflow_threshold_percent = YLeaf(YType.uint32, "underflow-threshold-percent")

                        self.underflow_threshold_value = YLeaf(YType.uint32, "underflow-threshold-value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("underflow_threshold_limit",
                                        "underflow_threshold_percent",
                                        "underflow_threshold_value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.underflow_threshold_limit.is_set or
                            self.underflow_threshold_percent.is_set or
                            self.underflow_threshold_value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.underflow_threshold_limit.yfilter != YFilter.not_set or
                            self.underflow_threshold_percent.yfilter != YFilter.not_set or
                            self.underflow_threshold_value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "underflow" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.underflow_threshold_limit.is_set or self.underflow_threshold_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.underflow_threshold_limit.get_name_leafdata())
                        if (self.underflow_threshold_percent.is_set or self.underflow_threshold_percent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.underflow_threshold_percent.get_name_leafdata())
                        if (self.underflow_threshold_value.is_set or self.underflow_threshold_value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.underflow_threshold_value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "underflow-threshold-limit" or name == "underflow-threshold-percent" or name == "underflow-threshold-value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "underflow-threshold-limit"):
                            self.underflow_threshold_limit = value
                            self.underflow_threshold_limit.value_namespace = name_space
                            self.underflow_threshold_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "underflow-threshold-percent"):
                            self.underflow_threshold_percent = value
                            self.underflow_threshold_percent.value_namespace = name_space
                            self.underflow_threshold_percent.value_namespace_prefix = name_space_prefix
                        if(value_path == "underflow-threshold-value"):
                            self.underflow_threshold_value = value
                            self.underflow_threshold_value.value_namespace = name_space
                            self.underflow_threshold_value.value_namespace_prefix = name_space_prefix


                class Overflow(Entity):
                    """
                    Configuring the tunnel overflow detection
                    
                    .. attribute:: overflow_threshold_limit
                    
                    	Number of consecutive collections exceeding threshold
                    	**type**\:  int
                    
                    	**range:** 1..10
                    
                    	**mandatory**\: True
                    
                    .. attribute:: overflow_threshold_percent
                    
                    	Bandwidth change percent to trigger an overflow
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    	**mandatory**\: True
                    
                    	**units**\: percentage
                    
                    .. attribute:: overflow_threshold_value
                    
                    	Bandwidth change value to trigger an overflow (kbps)
                    	**type**\:  int
                    
                    	**range:** 10..4294967295
                    
                    	**mandatory**\: True
                    
                    	**units**\: kbit/s
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow, self).__init__()

                        self.yang_name = "overflow"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_presence_container = True

                        self.overflow_threshold_limit = YLeaf(YType.uint32, "overflow-threshold-limit")

                        self.overflow_threshold_percent = YLeaf(YType.uint32, "overflow-threshold-percent")

                        self.overflow_threshold_value = YLeaf(YType.uint32, "overflow-threshold-value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("overflow_threshold_limit",
                                        "overflow_threshold_percent",
                                        "overflow_threshold_value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.overflow_threshold_limit.is_set or
                            self.overflow_threshold_percent.is_set or
                            self.overflow_threshold_value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.overflow_threshold_limit.yfilter != YFilter.not_set or
                            self.overflow_threshold_percent.yfilter != YFilter.not_set or
                            self.overflow_threshold_value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "overflow" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.overflow_threshold_limit.is_set or self.overflow_threshold_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.overflow_threshold_limit.get_name_leafdata())
                        if (self.overflow_threshold_percent.is_set or self.overflow_threshold_percent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.overflow_threshold_percent.get_name_leafdata())
                        if (self.overflow_threshold_value.is_set or self.overflow_threshold_value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.overflow_threshold_value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "overflow-threshold-limit" or name == "overflow-threshold-percent" or name == "overflow-threshold-value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "overflow-threshold-limit"):
                            self.overflow_threshold_limit = value
                            self.overflow_threshold_limit.value_namespace = name_space
                            self.overflow_threshold_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "overflow-threshold-percent"):
                            self.overflow_threshold_percent = value
                            self.overflow_threshold_percent.value_namespace = name_space
                            self.overflow_threshold_percent.value_namespace_prefix = name_space_prefix
                        if(value_path == "overflow-threshold-value"):
                            self.overflow_threshold_value = value
                            self.overflow_threshold_value.value_namespace = name_space
                            self.overflow_threshold_value.value_namespace_prefix = name_space_prefix


                class BandwidthLimits(Entity):
                    """
                    Set min/max bandwidth auto\-bw can apply on a
                    tunnel
                    
                    .. attribute:: bandwidth_max_limit
                    
                    	Set maximum bandwidth auto\-bw can apply on a tunnel
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**mandatory**\: True
                    
                    .. attribute:: bandwidth_min_limit
                    
                    	Set minimum bandwidth auto\-bw can apply on a tunnel
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits, self).__init__()

                        self.yang_name = "bandwidth-limits"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_presence_container = True

                        self.bandwidth_max_limit = YLeaf(YType.uint32, "bandwidth-max-limit")

                        self.bandwidth_min_limit = YLeaf(YType.uint32, "bandwidth-min-limit")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bandwidth_max_limit",
                                        "bandwidth_min_limit") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bandwidth_max_limit.is_set or
                            self.bandwidth_min_limit.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bandwidth_max_limit.yfilter != YFilter.not_set or
                            self.bandwidth_min_limit.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bandwidth-limits" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bandwidth_max_limit.is_set or self.bandwidth_max_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth_max_limit.get_name_leafdata())
                        if (self.bandwidth_min_limit.is_set or self.bandwidth_min_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth_min_limit.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bandwidth-max-limit" or name == "bandwidth-min-limit"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bandwidth-max-limit"):
                            self.bandwidth_max_limit = value
                            self.bandwidth_max_limit.value_namespace = name_space
                            self.bandwidth_max_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bandwidth-min-limit"):
                            self.bandwidth_min_limit = value
                            self.bandwidth_min_limit.value_namespace = name_space
                            self.bandwidth_min_limit.value_namespace_prefix = name_space_prefix


                class AdjustmentThreshold(Entity):
                    """
                    Set the bandwidth change threshold to trigger
                    adjustment
                    
                    .. attribute:: adjustment_threshold_percent
                    
                    	Bandwidth change percent to trigger adjustment
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    	**mandatory**\: True
                    
                    	**units**\: percentage
                    
                    .. attribute:: adjustment_threshold_value
                    
                    	Bandwidth change value to trigger adjustment (kbps)
                    	**type**\:  int
                    
                    	**range:** 10..4294967295
                    
                    	**mandatory**\: True
                    
                    	**units**\: kbit/s
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold, self).__init__()

                        self.yang_name = "adjustment-threshold"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_presence_container = True

                        self.adjustment_threshold_percent = YLeaf(YType.uint32, "adjustment-threshold-percent")

                        self.adjustment_threshold_value = YLeaf(YType.uint32, "adjustment-threshold-value")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("adjustment_threshold_percent",
                                        "adjustment_threshold_value") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.adjustment_threshold_percent.is_set or
                            self.adjustment_threshold_value.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.adjustment_threshold_percent.yfilter != YFilter.not_set or
                            self.adjustment_threshold_value.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "adjustment-threshold" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.adjustment_threshold_percent.is_set or self.adjustment_threshold_percent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.adjustment_threshold_percent.get_name_leafdata())
                        if (self.adjustment_threshold_value.is_set or self.adjustment_threshold_value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.adjustment_threshold_value.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "adjustment-threshold-percent" or name == "adjustment-threshold-value"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "adjustment-threshold-percent"):
                            self.adjustment_threshold_percent = value
                            self.adjustment_threshold_percent.value_namespace = name_space
                            self.adjustment_threshold_percent.value_namespace_prefix = name_space_prefix
                        if(value_path == "adjustment-threshold-value"):
                            self.adjustment_threshold_value = value
                            self.adjustment_threshold_value.value_namespace = name_space
                            self.adjustment_threshold_value.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.application_frequency.is_set or
                        self.collection_only.is_set or
                        self.enabled.is_set or
                        self.overflow_enable.is_set or
                        self.underflow_enable.is_set or
                        (self.adjustment_threshold is not None) or
                        (self.bandwidth_limits is not None) or
                        (self.overflow is not None) or
                        (self.underflow is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.application_frequency.yfilter != YFilter.not_set or
                        self.collection_only.yfilter != YFilter.not_set or
                        self.enabled.yfilter != YFilter.not_set or
                        self.overflow_enable.yfilter != YFilter.not_set or
                        self.underflow_enable.yfilter != YFilter.not_set or
                        (self.adjustment_threshold is not None and self.adjustment_threshold.has_operation()) or
                        (self.bandwidth_limits is not None and self.bandwidth_limits.has_operation()) or
                        (self.overflow is not None and self.overflow.has_operation()) or
                        (self.underflow is not None and self.underflow.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auto-bandwidth" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.application_frequency.is_set or self.application_frequency.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.application_frequency.get_name_leafdata())
                    if (self.collection_only.is_set or self.collection_only.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collection_only.get_name_leafdata())
                    if (self.enabled.is_set or self.enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enabled.get_name_leafdata())
                    if (self.overflow_enable.is_set or self.overflow_enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.overflow_enable.get_name_leafdata())
                    if (self.underflow_enable.is_set or self.underflow_enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.underflow_enable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "adjustment-threshold"):
                        if (self.adjustment_threshold is None):
                            self.adjustment_threshold = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold()
                            self.adjustment_threshold.parent = self
                            self._children_name_map["adjustment_threshold"] = "adjustment-threshold"
                        return self.adjustment_threshold

                    if (child_yang_name == "bandwidth-limits"):
                        if (self.bandwidth_limits is None):
                            self.bandwidth_limits = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits()
                            self.bandwidth_limits.parent = self
                            self._children_name_map["bandwidth_limits"] = "bandwidth-limits"
                        return self.bandwidth_limits

                    if (child_yang_name == "overflow"):
                        if (self.overflow is None):
                            self.overflow = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow()
                            self.overflow.parent = self
                            self._children_name_map["overflow"] = "overflow"
                        return self.overflow

                    if (child_yang_name == "underflow"):
                        if (self.underflow is None):
                            self.underflow = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow()
                            self.underflow.parent = self
                            self._children_name_map["underflow"] = "underflow"
                        return self.underflow

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "adjustment-threshold" or name == "bandwidth-limits" or name == "overflow" or name == "underflow" or name == "application-frequency" or name == "collection-only" or name == "enabled" or name == "overflow-enable" or name == "underflow-enable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "application-frequency"):
                        self.application_frequency = value
                        self.application_frequency.value_namespace = name_space
                        self.application_frequency.value_namespace_prefix = name_space_prefix
                    if(value_path == "collection-only"):
                        self.collection_only = value
                        self.collection_only.value_namespace = name_space
                        self.collection_only.value_namespace_prefix = name_space_prefix
                    if(value_path == "enabled"):
                        self.enabled = value
                        self.enabled.value_namespace = name_space
                        self.enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "overflow-enable"):
                        self.overflow_enable = value
                        self.overflow_enable.value_namespace = name_space
                        self.overflow_enable.value_namespace_prefix = name_space_prefix
                    if(value_path == "underflow-enable"):
                        self.underflow_enable = value
                        self.underflow_enable.value_namespace = name_space
                        self.underflow_enable.value_namespace_prefix = name_space_prefix


            class Priority(Entity):
                """
                Tunnel Setup and Hold Priorities
                
                .. attribute:: hold_priority
                
                	Hold Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                	**mandatory**\: True
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority, self).__init__()

                    self.yang_name = "priority"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_presence_container = True

                    self.hold_priority = YLeaf(YType.uint32, "hold-priority")

                    self.setup_priority = YLeaf(YType.uint32, "setup-priority")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("hold_priority",
                                    "setup_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.hold_priority.is_set or
                        self.setup_priority.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.hold_priority.yfilter != YFilter.not_set or
                        self.setup_priority.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "priority" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.hold_priority.is_set or self.hold_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hold_priority.get_name_leafdata())
                    if (self.setup_priority.is_set or self.setup_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.setup_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hold-priority" or name == "setup-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "hold-priority"):
                        self.hold_priority = value
                        self.hold_priority.value_namespace = name_space
                        self.hold_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "setup-priority"):
                        self.setup_priority = value
                        self.setup_priority.value_namespace = name_space
                        self.setup_priority.value_namespace_prefix = name_space_prefix


            class AffinityMask(Entity):
                """
                Set the affinity flags and mask
                
                .. attribute:: affinity
                
                	Affinity flags
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                	**mandatory**\: True
                
                .. attribute:: mask
                
                	Affinity mask
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask, self).__init__()

                    self.yang_name = "affinity-mask"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_presence_container = True

                    self.affinity = YLeaf(YType.str, "affinity")

                    self.mask = YLeaf(YType.str, "mask")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("affinity",
                                    "mask") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.affinity.is_set or
                        self.mask.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.affinity.yfilter != YFilter.not_set or
                        self.mask.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "affinity-mask" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.affinity.get_name_leafdata())
                    if (self.mask.is_set or self.mask.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mask.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "affinity" or name == "mask"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "affinity"):
                        self.affinity = value
                        self.affinity.value_namespace = name_space
                        self.affinity.value_namespace_prefix = name_space_prefix
                    if(value_path == "mask"):
                        self.mask = value
                        self.mask.value_namespace = name_space
                        self.mask.value_namespace_prefix = name_space_prefix


            class Logging(Entity):
                """
                Log tunnel LSP messages
                
                .. attribute:: all
                
                	Log all events for a tunnel
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bandwidth_change_message
                
                	Log tunnel messages for bandwidth change
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bfd_state_message
                
                	Enable BFD session state change alarm
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: insufficient_bw_message
                
                	Log tunnel messages for insufficient bandwidth
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: lsp_switch_over_change_message
                
                	Log tunnel messages for bandwidth change
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pcalc_failure_message
                
                	Enable logging for path\-calculation failures
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: record_route_messsage
                
                	Log tunnel record\-route messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimize_attempts_message
                
                	Log tunnel reoptimization attempts messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimized_message
                
                	Log tunnel reoptimized messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reroute_messsage
                
                	Log tunnel rereoute messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: state_message
                
                	Log tunnel state messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.all = YLeaf(YType.empty, "all")

                    self.bandwidth_change_message = YLeaf(YType.empty, "bandwidth-change-message")

                    self.bfd_state_message = YLeaf(YType.empty, "bfd-state-message")

                    self.insufficient_bw_message = YLeaf(YType.empty, "insufficient-bw-message")

                    self.lsp_switch_over_change_message = YLeaf(YType.empty, "lsp-switch-over-change-message")

                    self.pcalc_failure_message = YLeaf(YType.empty, "pcalc-failure-message")

                    self.record_route_messsage = YLeaf(YType.empty, "record-route-messsage")

                    self.reoptimize_attempts_message = YLeaf(YType.empty, "reoptimize-attempts-message")

                    self.reoptimized_message = YLeaf(YType.empty, "reoptimized-message")

                    self.reroute_messsage = YLeaf(YType.empty, "reroute-messsage")

                    self.state_message = YLeaf(YType.empty, "state-message")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("all",
                                    "bandwidth_change_message",
                                    "bfd_state_message",
                                    "insufficient_bw_message",
                                    "lsp_switch_over_change_message",
                                    "pcalc_failure_message",
                                    "record_route_messsage",
                                    "reoptimize_attempts_message",
                                    "reoptimized_message",
                                    "reroute_messsage",
                                    "state_message") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.all.is_set or
                        self.bandwidth_change_message.is_set or
                        self.bfd_state_message.is_set or
                        self.insufficient_bw_message.is_set or
                        self.lsp_switch_over_change_message.is_set or
                        self.pcalc_failure_message.is_set or
                        self.record_route_messsage.is_set or
                        self.reoptimize_attempts_message.is_set or
                        self.reoptimized_message.is_set or
                        self.reroute_messsage.is_set or
                        self.state_message.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.all.yfilter != YFilter.not_set or
                        self.bandwidth_change_message.yfilter != YFilter.not_set or
                        self.bfd_state_message.yfilter != YFilter.not_set or
                        self.insufficient_bw_message.yfilter != YFilter.not_set or
                        self.lsp_switch_over_change_message.yfilter != YFilter.not_set or
                        self.pcalc_failure_message.yfilter != YFilter.not_set or
                        self.record_route_messsage.yfilter != YFilter.not_set or
                        self.reoptimize_attempts_message.yfilter != YFilter.not_set or
                        self.reoptimized_message.yfilter != YFilter.not_set or
                        self.reroute_messsage.yfilter != YFilter.not_set or
                        self.state_message.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "logging" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.all.is_set or self.all.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.all.get_name_leafdata())
                    if (self.bandwidth_change_message.is_set or self.bandwidth_change_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth_change_message.get_name_leafdata())
                    if (self.bfd_state_message.is_set or self.bfd_state_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bfd_state_message.get_name_leafdata())
                    if (self.insufficient_bw_message.is_set or self.insufficient_bw_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.insufficient_bw_message.get_name_leafdata())
                    if (self.lsp_switch_over_change_message.is_set or self.lsp_switch_over_change_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_switch_over_change_message.get_name_leafdata())
                    if (self.pcalc_failure_message.is_set or self.pcalc_failure_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pcalc_failure_message.get_name_leafdata())
                    if (self.record_route_messsage.is_set or self.record_route_messsage.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.record_route_messsage.get_name_leafdata())
                    if (self.reoptimize_attempts_message.is_set or self.reoptimize_attempts_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reoptimize_attempts_message.get_name_leafdata())
                    if (self.reoptimized_message.is_set or self.reoptimized_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reoptimized_message.get_name_leafdata())
                    if (self.reroute_messsage.is_set or self.reroute_messsage.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reroute_messsage.get_name_leafdata())
                    if (self.state_message.is_set or self.state_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state_message.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "all" or name == "bandwidth-change-message" or name == "bfd-state-message" or name == "insufficient-bw-message" or name == "lsp-switch-over-change-message" or name == "pcalc-failure-message" or name == "record-route-messsage" or name == "reoptimize-attempts-message" or name == "reoptimized-message" or name == "reroute-messsage" or name == "state-message"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "all"):
                        self.all = value
                        self.all.value_namespace = name_space
                        self.all.value_namespace_prefix = name_space_prefix
                    if(value_path == "bandwidth-change-message"):
                        self.bandwidth_change_message = value
                        self.bandwidth_change_message.value_namespace = name_space
                        self.bandwidth_change_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "bfd-state-message"):
                        self.bfd_state_message = value
                        self.bfd_state_message.value_namespace = name_space
                        self.bfd_state_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "insufficient-bw-message"):
                        self.insufficient_bw_message = value
                        self.insufficient_bw_message.value_namespace = name_space
                        self.insufficient_bw_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-switch-over-change-message"):
                        self.lsp_switch_over_change_message = value
                        self.lsp_switch_over_change_message.value_namespace = name_space
                        self.lsp_switch_over_change_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "pcalc-failure-message"):
                        self.pcalc_failure_message = value
                        self.pcalc_failure_message.value_namespace = name_space
                        self.pcalc_failure_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "record-route-messsage"):
                        self.record_route_messsage = value
                        self.record_route_messsage.value_namespace = name_space
                        self.record_route_messsage.value_namespace_prefix = name_space_prefix
                    if(value_path == "reoptimize-attempts-message"):
                        self.reoptimize_attempts_message = value
                        self.reoptimize_attempts_message.value_namespace = name_space
                        self.reoptimize_attempts_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "reoptimized-message"):
                        self.reoptimized_message = value
                        self.reoptimized_message.value_namespace = name_space
                        self.reoptimized_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "reroute-messsage"):
                        self.reroute_messsage = value
                        self.reroute_messsage.value_namespace = name_space
                        self.reroute_messsage.value_namespace_prefix = name_space_prefix
                    if(value_path == "state-message"):
                        self.state_message = value
                        self.state_message.value_namespace = name_space
                        self.state_message.value_namespace_prefix = name_space_prefix


            class Bandwidth(Entity):
                """
                Tunnel bandwidth requirement
                
                .. attribute:: bandwidth
                
                	The value of the bandwidth reserved by this tunnel in kbps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**mandatory**\: True
                
                	**units**\: kbit/s
                
                .. attribute:: class_or_pool_type
                
                	Class type for the bandwidth allocation
                	**type**\:  int
                
                	**range:** 0..1
                
                	**mandatory**\: True
                
                .. attribute:: dste_type
                
                	DSTE\-standard flag
                	**type**\:   :py:class:`MplsTeBandwidthDste <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthDste>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_presence_container = True

                    self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                    self.class_or_pool_type = YLeaf(YType.uint32, "class-or-pool-type")

                    self.dste_type = YLeaf(YType.enumeration, "dste-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bandwidth",
                                    "class_or_pool_type",
                                    "dste_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bandwidth.is_set or
                        self.class_or_pool_type.is_set or
                        self.dste_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bandwidth.yfilter != YFilter.not_set or
                        self.class_or_pool_type.yfilter != YFilter.not_set or
                        self.dste_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth.get_name_leafdata())
                    if (self.class_or_pool_type.is_set or self.class_or_pool_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.class_or_pool_type.get_name_leafdata())
                    if (self.dste_type.is_set or self.dste_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bandwidth" or name == "class-or-pool-type" or name == "dste-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bandwidth"):
                        self.bandwidth = value
                        self.bandwidth.value_namespace = name_space
                        self.bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "class-or-pool-type"):
                        self.class_or_pool_type = value
                        self.class_or_pool_type.value_namespace = name_space
                        self.class_or_pool_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "dste-type"):
                        self.dste_type = value
                        self.dste_type.value_namespace = name_space
                        self.dste_type.value_namespace_prefix = name_space_prefix


            class Autoroute(Entity):
                """
                Parameters for IGP routing over tunnel
                
                .. attribute:: autoroute_announce
                
                	Announce tunnel to IGP
                	**type**\:   :py:class:`AutorouteAnnounce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce>`
                
                .. attribute:: destination
                
                	Deprecated\: do NOT use
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: destination_xr
                
                	Tunnel Autoroute Destination(s)
                	**type**\:   :py:class:`DestinationXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute, self).__init__()

                    self.yang_name = "autoroute"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.destination = YLeaf(YType.empty, "destination")

                    self.autoroute_announce = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce()
                    self.autoroute_announce.parent = self
                    self._children_name_map["autoroute_announce"] = "autoroute-announce"
                    self._children_yang_names.add("autoroute-announce")

                    self.destination_xr = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr()
                    self.destination_xr.parent = self
                    self._children_name_map["destination_xr"] = "destination-xr"
                    self._children_yang_names.add("destination-xr")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute, self).__setattr__(name, value)


                class AutorouteAnnounce(Entity):
                    """
                    Announce tunnel to IGP
                    
                    .. attribute:: enable
                    
                    	Enable autoroute announce
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: exclude_traffic
                    
                    	Exclude traffic on autorouted tunnel
                    	**type**\:   :py:class:`ExcludeTraffic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic>`
                    
                    .. attribute:: include_ipv6
                    
                    	Specify that the tunnel should be an IPv6 autoroute announce also
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	Specify MPLS tunnel metric
                    	**type**\:   :py:class:`Metric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce, self).__init__()

                        self.yang_name = "autoroute-announce"
                        self.yang_parent_name = "autoroute"

                        self.enable = YLeaf(YType.empty, "enable")

                        self.include_ipv6 = YLeaf(YType.empty, "include-ipv6")

                        self.exclude_traffic = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic()
                        self.exclude_traffic.parent = self
                        self._children_name_map["exclude_traffic"] = "exclude-traffic"
                        self._children_yang_names.add("exclude-traffic")

                        self.metric = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._children_yang_names.add("metric")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("enable",
                                        "include_ipv6") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce, self).__setattr__(name, value)


                    class ExcludeTraffic(Entity):
                        """
                        Exclude traffic on autorouted tunnel
                        
                        .. attribute:: segment_routing
                        
                        	Exclude tunnel in IGP for SR prefixes
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic, self).__init__()

                            self.yang_name = "exclude-traffic"
                            self.yang_parent_name = "autoroute-announce"

                            self.segment_routing = YLeaf(YType.empty, "segment-routing")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("segment_routing") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic, self).__setattr__(name, value)

                        def has_data(self):
                            return self.segment_routing.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.segment_routing.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "exclude-traffic" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_routing.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "segment-routing"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "segment-routing"):
                                self.segment_routing = value
                                self.segment_routing.value_namespace = name_space
                                self.segment_routing.value_namespace_prefix = name_space_prefix


                    class Metric(Entity):
                        """
                        Specify MPLS tunnel metric
                        
                        .. attribute:: absolute_metric
                        
                        	The absolute metric value
                        	**type**\:  int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: constant_metric
                        
                        	The constant metric value
                        	**type**\:  int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: metric_type
                        
                        	Autoroute tunnel metric type
                        	**type**\:   :py:class:`MplsTeAutorouteMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeAutorouteMetric>`
                        
                        .. attribute:: relative_metric
                        
                        	The value of the adjustment
                        	**type**\:  int
                        
                        	**range:** \-10..10
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "autoroute-announce"

                            self.absolute_metric = YLeaf(YType.uint32, "absolute-metric")

                            self.constant_metric = YLeaf(YType.uint32, "constant-metric")

                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                            self.relative_metric = YLeaf(YType.int32, "relative-metric")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("absolute_metric",
                                            "constant_metric",
                                            "metric_type",
                                            "relative_metric") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.absolute_metric.is_set or
                                self.constant_metric.is_set or
                                self.metric_type.is_set or
                                self.relative_metric.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.absolute_metric.yfilter != YFilter.not_set or
                                self.constant_metric.yfilter != YFilter.not_set or
                                self.metric_type.yfilter != YFilter.not_set or
                                self.relative_metric.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "metric" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.absolute_metric.is_set or self.absolute_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.absolute_metric.get_name_leafdata())
                            if (self.constant_metric.is_set or self.constant_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.constant_metric.get_name_leafdata())
                            if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_type.get_name_leafdata())
                            if (self.relative_metric.is_set or self.relative_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.relative_metric.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "absolute-metric" or name == "constant-metric" or name == "metric-type" or name == "relative-metric"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "absolute-metric"):
                                self.absolute_metric = value
                                self.absolute_metric.value_namespace = name_space
                                self.absolute_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "constant-metric"):
                                self.constant_metric = value
                                self.constant_metric.value_namespace = name_space
                                self.constant_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-type"):
                                self.metric_type = value
                                self.metric_type.value_namespace = name_space
                                self.metric_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "relative-metric"):
                                self.relative_metric = value
                                self.relative_metric.value_namespace = name_space
                                self.relative_metric.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.enable.is_set or
                            self.include_ipv6.is_set or
                            (self.exclude_traffic is not None and self.exclude_traffic.has_data()) or
                            (self.metric is not None and self.metric.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.include_ipv6.yfilter != YFilter.not_set or
                            (self.exclude_traffic is not None and self.exclude_traffic.has_operation()) or
                            (self.metric is not None and self.metric.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "autoroute-announce" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.include_ipv6.is_set or self.include_ipv6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.include_ipv6.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "exclude-traffic"):
                            if (self.exclude_traffic is None):
                                self.exclude_traffic = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic()
                                self.exclude_traffic.parent = self
                                self._children_name_map["exclude_traffic"] = "exclude-traffic"
                            return self.exclude_traffic

                        if (child_yang_name == "metric"):
                            if (self.metric is None):
                                self.metric = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric()
                                self.metric.parent = self
                                self._children_name_map["metric"] = "metric"
                            return self.metric

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "exclude-traffic" or name == "metric" or name == "enable" or name == "include-ipv6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "include-ipv6"):
                            self.include_ipv6 = value
                            self.include_ipv6.value_namespace = name_space
                            self.include_ipv6.value_namespace_prefix = name_space_prefix


                class DestinationXr(Entity):
                    """
                    Tunnel Autoroute Destination(s)
                    
                    .. attribute:: destination
                    
                    	Destination address to add in RIB
                    	**type**\: list of    :py:class:`Destination <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr.Destination>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr, self).__init__()

                        self.yang_name = "destination-xr"
                        self.yang_parent_name = "autoroute"

                        self.destination = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr, self).__setattr__(name, value)


                    class Destination(Entity):
                        """
                        Destination address to add in RIB
                        
                        .. attribute:: destination_address  <key>
                        
                        	IP address of destination
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "destination-xr"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr.Destination, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr.Destination, self).__setattr__(name, value)

                        def has_data(self):
                            return self.destination_address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.destination:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.destination:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "destination-xr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "destination"):
                            for c in self.destination:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr.Destination()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.destination.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.destination.is_set or
                        (self.autoroute_announce is not None and self.autoroute_announce.has_data()) or
                        (self.destination_xr is not None and self.destination_xr.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination.yfilter != YFilter.not_set or
                        (self.autoroute_announce is not None and self.autoroute_announce.has_operation()) or
                        (self.destination_xr is not None and self.destination_xr.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "autoroute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "autoroute-announce"):
                        if (self.autoroute_announce is None):
                            self.autoroute_announce = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce()
                            self.autoroute_announce.parent = self
                            self._children_name_map["autoroute_announce"] = "autoroute-announce"
                        return self.autoroute_announce

                    if (child_yang_name == "destination-xr"):
                        if (self.destination_xr is None):
                            self.destination_xr = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.DestinationXr()
                            self.destination_xr.parent = self
                            self._children_name_map["destination_xr"] = "destination-xr"
                        return self.destination_xr

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "autoroute-announce" or name == "destination-xr" or name == "destination"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination"):
                        self.destination = value
                        self.destination.value_namespace = name_space
                        self.destination.value_namespace_prefix = name_space_prefix


            class PolicyClasses(Entity):
                """
                Policy classes for PBTS
                
                .. attribute:: policy_class
                
                	Array of Policy class
                	**type**\:  list of int
                
                	**range:** 1..8
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses, self).__init__()

                    self.yang_name = "policy-classes"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.policy_class = YLeafList(YType.uint32, "policy-class")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("policy_class") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.policy_class.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return False

                def has_operation(self):
                    for leaf in self.policy_class.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.policy_class.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-classes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    leaf_name_data.extend(self.policy_class.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "policy-class"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "policy-class"):
                        self.policy_class.append(value)


            class NewStyleAffinityAffinityTypes(Entity):
                """
                Tunnel new style affinity attributes table
                
                .. attribute:: new_style_affinity_affinity_type
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes, self).__init__()

                    self.yang_name = "new-style-affinity-affinity-types"
                    self.yang_parent_name = "tunnel-te-attributes"

                    self.new_style_affinity_affinity_type = YList(self)
                    self.new_style_affinity_affinity_type_affinity1 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10 = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes, self).__setattr__(name, value)


                class NewStyleAffinityAffinityType(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType, self).__setattr__(name, value)

                    def has_data(self):
                        return self.affinity_type.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type" + "[affinity-type='" + self.affinity_type.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5",
                                        "affinity6") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set or
                            self.affinity6.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set or
                            self.affinity6.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())
                        if (self.affinity6.is_set or self.affinity6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity6.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5" or name == "affinity6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity6"):
                            self.affinity6 = value
                            self.affinity6.value_namespace = name_space
                            self.affinity6.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5",
                                        "affinity6",
                                        "affinity7") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set or
                            self.affinity6.is_set or
                            self.affinity7.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set or
                            self.affinity6.yfilter != YFilter.not_set or
                            self.affinity7.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())
                        if (self.affinity6.is_set or self.affinity6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity6.get_name_leafdata())
                        if (self.affinity7.is_set or self.affinity7.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity7.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5" or name == "affinity6" or name == "affinity7"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity6"):
                            self.affinity6 = value
                            self.affinity6.value_namespace = name_space
                            self.affinity6.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity7"):
                            self.affinity7 = value
                            self.affinity7.value_namespace = name_space
                            self.affinity7.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5",
                                        "affinity6",
                                        "affinity7",
                                        "affinity8") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set or
                            self.affinity6.is_set or
                            self.affinity7.is_set or
                            self.affinity8.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set or
                            self.affinity6.yfilter != YFilter.not_set or
                            self.affinity7.yfilter != YFilter.not_set or
                            self.affinity8.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())
                        if (self.affinity6.is_set or self.affinity6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity6.get_name_leafdata())
                        if (self.affinity7.is_set or self.affinity7.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity7.get_name_leafdata())
                        if (self.affinity8.is_set or self.affinity8.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity8.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5" or name == "affinity6" or name == "affinity7" or name == "affinity8"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity6"):
                            self.affinity6 = value
                            self.affinity6.value_namespace = name_space
                            self.affinity6.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity7"):
                            self.affinity7 = value
                            self.affinity7.value_namespace = name_space
                            self.affinity7.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity8"):
                            self.affinity8 = value
                            self.affinity8.value_namespace = name_space
                            self.affinity8.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity9  <key>
                    
                    	The name of the nineth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                        self.affinity9 = YLeaf(YType.str, "affinity9")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5",
                                        "affinity6",
                                        "affinity7",
                                        "affinity8",
                                        "affinity9") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set or
                            self.affinity6.is_set or
                            self.affinity7.is_set or
                            self.affinity8.is_set or
                            self.affinity9.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set or
                            self.affinity6.yfilter != YFilter.not_set or
                            self.affinity7.yfilter != YFilter.not_set or
                            self.affinity8.yfilter != YFilter.not_set or
                            self.affinity9.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + "[affinity9='" + self.affinity9.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())
                        if (self.affinity6.is_set or self.affinity6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity6.get_name_leafdata())
                        if (self.affinity7.is_set or self.affinity7.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity7.get_name_leafdata())
                        if (self.affinity8.is_set or self.affinity8.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity8.get_name_leafdata())
                        if (self.affinity9.is_set or self.affinity9.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity9.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5" or name == "affinity6" or name == "affinity7" or name == "affinity8" or name == "affinity9"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity6"):
                            self.affinity6 = value
                            self.affinity6.value_namespace = name_space
                            self.affinity6.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity7"):
                            self.affinity7 = value
                            self.affinity7.value_namespace = name_space
                            self.affinity7.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity8"):
                            self.affinity8 = value
                            self.affinity8.value_namespace = name_space
                            self.affinity8.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity9"):
                            self.affinity9 = value
                            self.affinity9.value_namespace = name_space
                            self.affinity9.value_namespace_prefix = name_space_prefix


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity9  <key>
                    
                    	The name of the nineth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity10  <key>
                    
                    	The name of the tenth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10"
                        self.yang_parent_name = "new-style-affinity-affinity-types"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                        self.affinity9 = YLeaf(YType.str, "affinity9")

                        self.affinity10 = YLeaf(YType.str, "affinity10")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5",
                                        "affinity6",
                                        "affinity7",
                                        "affinity8",
                                        "affinity9",
                                        "affinity10") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set or
                            self.affinity6.is_set or
                            self.affinity7.is_set or
                            self.affinity8.is_set or
                            self.affinity9.is_set or
                            self.affinity10.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set or
                            self.affinity6.yfilter != YFilter.not_set or
                            self.affinity7.yfilter != YFilter.not_set or
                            self.affinity8.yfilter != YFilter.not_set or
                            self.affinity9.yfilter != YFilter.not_set or
                            self.affinity10.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + "[affinity9='" + self.affinity9.get() + "']" + "[affinity10='" + self.affinity10.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())
                        if (self.affinity6.is_set or self.affinity6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity6.get_name_leafdata())
                        if (self.affinity7.is_set or self.affinity7.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity7.get_name_leafdata())
                        if (self.affinity8.is_set or self.affinity8.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity8.get_name_leafdata())
                        if (self.affinity9.is_set or self.affinity9.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity9.get_name_leafdata())
                        if (self.affinity10.is_set or self.affinity10.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity10.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5" or name == "affinity6" or name == "affinity7" or name == "affinity8" or name == "affinity9" or name == "affinity10"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity6"):
                            self.affinity6 = value
                            self.affinity6.value_namespace = name_space
                            self.affinity6.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity7"):
                            self.affinity7 = value
                            self.affinity7.value_namespace = name_space
                            self.affinity7.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity8"):
                            self.affinity8 = value
                            self.affinity8.value_namespace = name_space
                            self.affinity8.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity9"):
                            self.affinity9 = value
                            self.affinity9.value_namespace = name_space
                            self.affinity9.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity10"):
                            self.affinity10 = value
                            self.affinity10.value_namespace = name_space
                            self.affinity10.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.new_style_affinity_affinity_type:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9:
                        if (c.has_data()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.new_style_affinity_affinity_type:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9:
                        if (c.has_operation()):
                            return True
                    for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "new-style-affinity-affinity-types" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "new-style-affinity-affinity-type"):
                        for c in self.new_style_affinity_affinity_type:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1"):
                        for c in self.new_style_affinity_affinity_type_affinity1:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9.append(c)
                        return c

                    if (child_yang_name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10"):
                        for c in self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "new-style-affinity-affinity-type" or name == "new-style-affinity-affinity-type-affinity1" or name == "new-style-affinity-affinity-type-affinity1-affinity2" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9" or name == "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class FastReroute(Entity):
                """
                Specify MPLS tunnel can be fast\-rerouted
                
                .. attribute:: bandwidth_protection
                
                	Bandwidth Protection
                	**type**\:  int
                
                	**range:** 0..1
                
                	**mandatory**\: True
                
                .. attribute:: node_protection
                
                	Node Protection
                	**type**\:  int
                
                	**range:** 0..1
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute, self).__init__()

                    self.yang_name = "fast-reroute"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_presence_container = True

                    self.bandwidth_protection = YLeaf(YType.uint32, "bandwidth-protection")

                    self.node_protection = YLeaf(YType.uint32, "node-protection")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bandwidth_protection",
                                    "node_protection") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bandwidth_protection.is_set or
                        self.node_protection.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bandwidth_protection.yfilter != YFilter.not_set or
                        self.node_protection.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "fast-reroute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bandwidth_protection.is_set or self.bandwidth_protection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth_protection.get_name_leafdata())
                    if (self.node_protection.is_set or self.node_protection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node_protection.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bandwidth-protection" or name == "node-protection"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bandwidth-protection"):
                        self.bandwidth_protection = value
                        self.bandwidth_protection.value_namespace = name_space
                        self.bandwidth_protection.value_namespace_prefix = name_space_prefix
                    if(value_path == "node-protection"):
                        self.node_protection = value
                        self.node_protection.value_namespace = name_space
                        self.node_protection.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination.is_set or
                    self.forward_class.is_set or
                    self.load_share.is_set or
                    self.path_protection.is_set or
                    self.path_selection_metric.is_set or
                    self.record_route.is_set or
                    self.signalled_name.is_set or
                    self.soft_preemption.is_set or
                    (self.admin_mode is not None and self.admin_mode.has_data()) or
                    (self.auto_bandwidth is not None and self.auto_bandwidth.has_data()) or
                    (self.autoroute is not None and self.autoroute.has_data()) or
                    (self.backup_bandwidth is not None and self.backup_bandwidth.has_data()) or
                    (self.bfd_over_lsp is not None and self.bfd_over_lsp.has_data()) or
                    (self.bidirectional is not None and self.bidirectional.has_data()) or
                    (self.binding_segment_id_mpls is not None and self.binding_segment_id_mpls.has_data()) or
                    (self.forwarding_adjacency is not None and self.forwarding_adjacency.has_data()) or
                    (self.logging is not None and self.logging.has_data()) or
                    (self.new_style_affinity_affinity_types is not None and self.new_style_affinity_affinity_types.has_data()) or
                    (self.path_option_protects is not None and self.path_option_protects.has_data()) or
                    (self.pce is not None and self.pce.has_data()) or
                    (self.policy_classes is not None and self.policy_classes.has_data()) or
                    (self.switching is not None and self.switching.has_data()) or
                    (self.tunnel_path_selection is not None and self.tunnel_path_selection.has_data()) or
                    (self.affinity_mask is not None) or
                    (self.bandwidth is not None) or
                    (self.fast_reroute is not None) or
                    (self.priority is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination.yfilter != YFilter.not_set or
                    self.forward_class.yfilter != YFilter.not_set or
                    self.load_share.yfilter != YFilter.not_set or
                    self.path_protection.yfilter != YFilter.not_set or
                    self.path_selection_metric.yfilter != YFilter.not_set or
                    self.record_route.yfilter != YFilter.not_set or
                    self.signalled_name.yfilter != YFilter.not_set or
                    self.soft_preemption.yfilter != YFilter.not_set or
                    (self.admin_mode is not None and self.admin_mode.has_operation()) or
                    (self.affinity_mask is not None and self.affinity_mask.has_operation()) or
                    (self.auto_bandwidth is not None and self.auto_bandwidth.has_operation()) or
                    (self.autoroute is not None and self.autoroute.has_operation()) or
                    (self.backup_bandwidth is not None and self.backup_bandwidth.has_operation()) or
                    (self.bandwidth is not None and self.bandwidth.has_operation()) or
                    (self.bfd_over_lsp is not None and self.bfd_over_lsp.has_operation()) or
                    (self.bidirectional is not None and self.bidirectional.has_operation()) or
                    (self.binding_segment_id_mpls is not None and self.binding_segment_id_mpls.has_operation()) or
                    (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                    (self.forwarding_adjacency is not None and self.forwarding_adjacency.has_operation()) or
                    (self.logging is not None and self.logging.has_operation()) or
                    (self.new_style_affinity_affinity_types is not None and self.new_style_affinity_affinity_types.has_operation()) or
                    (self.path_option_protects is not None and self.path_option_protects.has_operation()) or
                    (self.pce is not None and self.pce.has_operation()) or
                    (self.policy_classes is not None and self.policy_classes.has_operation()) or
                    (self.priority is not None and self.priority.has_operation()) or
                    (self.switching is not None and self.switching.has_operation()) or
                    (self.tunnel_path_selection is not None and self.tunnel_path_selection.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-mpls-te-cfg:tunnel-te-attributes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination.get_name_leafdata())
                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                if (self.load_share.is_set or self.load_share.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.load_share.get_name_leafdata())
                if (self.path_protection.is_set or self.path_protection.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_protection.get_name_leafdata())
                if (self.path_selection_metric.is_set or self.path_selection_metric.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_selection_metric.get_name_leafdata())
                if (self.record_route.is_set or self.record_route.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.record_route.get_name_leafdata())
                if (self.signalled_name.is_set or self.signalled_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalled_name.get_name_leafdata())
                if (self.soft_preemption.is_set or self.soft_preemption.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.soft_preemption.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "admin-mode"):
                    if (self.admin_mode is None):
                        self.admin_mode = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode()
                        self.admin_mode.parent = self
                        self._children_name_map["admin_mode"] = "admin-mode"
                    return self.admin_mode

                if (child_yang_name == "affinity-mask"):
                    if (self.affinity_mask is None):
                        self.affinity_mask = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask()
                        self.affinity_mask.parent = self
                        self._children_name_map["affinity_mask"] = "affinity-mask"
                    return self.affinity_mask

                if (child_yang_name == "auto-bandwidth"):
                    if (self.auto_bandwidth is None):
                        self.auto_bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth()
                        self.auto_bandwidth.parent = self
                        self._children_name_map["auto_bandwidth"] = "auto-bandwidth"
                    return self.auto_bandwidth

                if (child_yang_name == "autoroute"):
                    if (self.autoroute is None):
                        self.autoroute = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute()
                        self.autoroute.parent = self
                        self._children_name_map["autoroute"] = "autoroute"
                    return self.autoroute

                if (child_yang_name == "backup-bandwidth"):
                    if (self.backup_bandwidth is None):
                        self.backup_bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth()
                        self.backup_bandwidth.parent = self
                        self._children_name_map["backup_bandwidth"] = "backup-bandwidth"
                    return self.backup_bandwidth

                if (child_yang_name == "bandwidth"):
                    if (self.bandwidth is None):
                        self.bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth()
                        self.bandwidth.parent = self
                        self._children_name_map["bandwidth"] = "bandwidth"
                    return self.bandwidth

                if (child_yang_name == "bfd-over-lsp"):
                    if (self.bfd_over_lsp is None):
                        self.bfd_over_lsp = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp()
                        self.bfd_over_lsp.parent = self
                        self._children_name_map["bfd_over_lsp"] = "bfd-over-lsp"
                    return self.bfd_over_lsp

                if (child_yang_name == "bidirectional"):
                    if (self.bidirectional is None):
                        self.bidirectional = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional()
                        self.bidirectional.parent = self
                        self._children_name_map["bidirectional"] = "bidirectional"
                    return self.bidirectional

                if (child_yang_name == "binding-segment-id-mpls"):
                    if (self.binding_segment_id_mpls is None):
                        self.binding_segment_id_mpls = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls()
                        self.binding_segment_id_mpls.parent = self
                        self._children_name_map["binding_segment_id_mpls"] = "binding-segment-id-mpls"
                    return self.binding_segment_id_mpls

                if (child_yang_name == "fast-reroute"):
                    if (self.fast_reroute is None):
                        self.fast_reroute = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                    return self.fast_reroute

                if (child_yang_name == "forwarding-adjacency"):
                    if (self.forwarding_adjacency is None):
                        self.forwarding_adjacency = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency()
                        self.forwarding_adjacency.parent = self
                        self._children_name_map["forwarding_adjacency"] = "forwarding-adjacency"
                    return self.forwarding_adjacency

                if (child_yang_name == "logging"):
                    if (self.logging is None):
                        self.logging = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging()
                        self.logging.parent = self
                        self._children_name_map["logging"] = "logging"
                    return self.logging

                if (child_yang_name == "new-style-affinity-affinity-types"):
                    if (self.new_style_affinity_affinity_types is None):
                        self.new_style_affinity_affinity_types = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes()
                        self.new_style_affinity_affinity_types.parent = self
                        self._children_name_map["new_style_affinity_affinity_types"] = "new-style-affinity-affinity-types"
                    return self.new_style_affinity_affinity_types

                if (child_yang_name == "path-option-protects"):
                    if (self.path_option_protects is None):
                        self.path_option_protects = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects()
                        self.path_option_protects.parent = self
                        self._children_name_map["path_option_protects"] = "path-option-protects"
                    return self.path_option_protects

                if (child_yang_name == "pce"):
                    if (self.pce is None):
                        self.pce = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce()
                        self.pce.parent = self
                        self._children_name_map["pce"] = "pce"
                    return self.pce

                if (child_yang_name == "policy-classes"):
                    if (self.policy_classes is None):
                        self.policy_classes = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses()
                        self.policy_classes.parent = self
                        self._children_name_map["policy_classes"] = "policy-classes"
                    return self.policy_classes

                if (child_yang_name == "priority"):
                    if (self.priority is None):
                        self.priority = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                    return self.priority

                if (child_yang_name == "switching"):
                    if (self.switching is None):
                        self.switching = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching()
                        self.switching.parent = self
                        self._children_name_map["switching"] = "switching"
                    return self.switching

                if (child_yang_name == "tunnel-path-selection"):
                    if (self.tunnel_path_selection is None):
                        self.tunnel_path_selection = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection()
                        self.tunnel_path_selection.parent = self
                        self._children_name_map["tunnel_path_selection"] = "tunnel-path-selection"
                    return self.tunnel_path_selection

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "admin-mode" or name == "affinity-mask" or name == "auto-bandwidth" or name == "autoroute" or name == "backup-bandwidth" or name == "bandwidth" or name == "bfd-over-lsp" or name == "bidirectional" or name == "binding-segment-id-mpls" or name == "fast-reroute" or name == "forwarding-adjacency" or name == "logging" or name == "new-style-affinity-affinity-types" or name == "path-option-protects" or name == "pce" or name == "policy-classes" or name == "priority" or name == "switching" or name == "tunnel-path-selection" or name == "destination" or name == "forward-class" or name == "load-share" or name == "path-protection" or name == "path-selection-metric" or name == "record-route" or name == "signalled-name" or name == "soft-preemption"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination"):
                    self.destination = value
                    self.destination.value_namespace = name_space
                    self.destination.value_namespace_prefix = name_space_prefix
                if(value_path == "forward-class"):
                    self.forward_class = value
                    self.forward_class.value_namespace = name_space
                    self.forward_class.value_namespace_prefix = name_space_prefix
                if(value_path == "load-share"):
                    self.load_share = value
                    self.load_share.value_namespace = name_space
                    self.load_share.value_namespace_prefix = name_space_prefix
                if(value_path == "path-protection"):
                    self.path_protection = value
                    self.path_protection.value_namespace = name_space
                    self.path_protection.value_namespace_prefix = name_space_prefix
                if(value_path == "path-selection-metric"):
                    self.path_selection_metric = value
                    self.path_selection_metric.value_namespace = name_space
                    self.path_selection_metric.value_namespace_prefix = name_space_prefix
                if(value_path == "record-route"):
                    self.record_route = value
                    self.record_route.value_namespace = name_space
                    self.record_route.value_namespace_prefix = name_space_prefix
                if(value_path == "signalled-name"):
                    self.signalled_name = value
                    self.signalled_name.value_namespace = name_space
                    self.signalled_name.value_namespace_prefix = name_space_prefix
                if(value_path == "soft-preemption"):
                    self.soft_preemption = value
                    self.soft_preemption.value_namespace = name_space
                    self.soft_preemption.value_namespace_prefix = name_space_prefix


        class TransportProfileTunnel(Entity):
            """
            MPLS\-TP tunnel attributes
            
            .. attribute:: bfd
            
            	Configure BFD parameters
            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd>`
            
            .. attribute:: destination
            
            	Node identifier and optional global identifier and tunnel identifier at destination
            	**type**\:   :py:class:`Destination <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination>`
            
            .. attribute:: fault
            
            	Fault management
            	**type**\:   :py:class:`Fault <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault>`
            
            .. attribute:: protect_lsp
            
            	Protect LSP
            	**type**\:   :py:class:`ProtectLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp>`
            
            .. attribute:: source
            
            	Transport profile node identifier in IPv4 address format
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: working_lsp
            
            	Working LSP
            	**type**\:   :py:class:`WorkingLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp>`
            
            

            """

            _prefix = 'mpls-te-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel, self).__init__()

                self.yang_name = "transport-profile-tunnel"
                self.yang_parent_name = "interface-configuration"

                self.source = YLeaf(YType.str, "source")

                self.bfd = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"
                self._children_yang_names.add("bfd")

                self.destination = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"
                self._children_yang_names.add("destination")

                self.fault = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault()
                self.fault.parent = self
                self._children_name_map["fault"] = "fault"
                self._children_yang_names.add("fault")

                self.protect_lsp = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp()
                self.protect_lsp.parent = self
                self._children_name_map["protect_lsp"] = "protect-lsp"
                self._children_yang_names.add("protect-lsp")

                self.working_lsp = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp()
                self.working_lsp.parent = self
                self._children_name_map["working_lsp"] = "working-lsp"
                self._children_yang_names.add("working-lsp")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel, self).__setattr__(name, value)


            class Bfd(Entity):
                """
                Configure BFD parameters
                
                .. attribute:: detection_multiplier
                
                	Detect multiplier
                	**type**\:  int
                
                	**range:** 2..10
                
                .. attribute:: enable
                
                	Configure BFD parameters
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: min_interval
                
                	Hello interval, either in milli\-seconds or in micro\-seconds
                	**type**\:   :py:class:`MinInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval>`
                
                .. attribute:: min_interval_standby
                
                	Hello interval for standby transport profile LSP, either in milli\-seconds or in micro\-seconds
                	**type**\:   :py:class:`MinIntervalStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby>`
                
                .. attribute:: multiplier_standby
                
                	Detect multiplier for standby transport profile LSP
                	**type**\:  int
                
                	**range:** 2..10
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "transport-profile-tunnel"

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.enable = YLeaf(YType.empty, "enable")

                    self.multiplier_standby = YLeaf(YType.uint32, "multiplier-standby")

                    self.min_interval = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval()
                    self.min_interval.parent = self
                    self._children_name_map["min_interval"] = "min-interval"
                    self._children_yang_names.add("min-interval")

                    self.min_interval_standby = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby()
                    self.min_interval_standby.parent = self
                    self._children_name_map["min_interval_standby"] = "min-interval-standby"
                    self._children_yang_names.add("min-interval-standby")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("detection_multiplier",
                                    "enable",
                                    "multiplier_standby") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd, self).__setattr__(name, value)


                class MinInterval(Entity):
                    """
                    Hello interval, either in milli\-seconds or in
                    micro\-seconds
                    
                    .. attribute:: interval_ms
                    
                    	Hello interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 3..5000
                    
                    .. attribute:: interval_us
                    
                    	Hello interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 3000..5000000
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval, self).__init__()

                        self.yang_name = "min-interval"
                        self.yang_parent_name = "bfd"

                        self.interval_ms = YLeaf(YType.uint32, "interval-ms")

                        self.interval_us = YLeaf(YType.uint32, "interval-us")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interval_ms",
                                        "interval_us") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interval_ms.is_set or
                            self.interval_us.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interval_ms.yfilter != YFilter.not_set or
                            self.interval_us.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "min-interval" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interval_ms.is_set or self.interval_ms.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interval_ms.get_name_leafdata())
                        if (self.interval_us.is_set or self.interval_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interval_us.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interval-ms" or name == "interval-us"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interval-ms"):
                            self.interval_ms = value
                            self.interval_ms.value_namespace = name_space
                            self.interval_ms.value_namespace_prefix = name_space_prefix
                        if(value_path == "interval-us"):
                            self.interval_us = value
                            self.interval_us.value_namespace = name_space
                            self.interval_us.value_namespace_prefix = name_space_prefix


                class MinIntervalStandby(Entity):
                    """
                    Hello interval for standby transport profile
                    LSP, either in milli\-seconds or in
                    micro\-seconds
                    
                    .. attribute:: interval_standby_ms
                    
                    	Hello interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 3..5000
                    
                    .. attribute:: interval_standby_us
                    
                    	Hello interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 3000..5000000
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby, self).__init__()

                        self.yang_name = "min-interval-standby"
                        self.yang_parent_name = "bfd"

                        self.interval_standby_ms = YLeaf(YType.uint32, "interval-standby-ms")

                        self.interval_standby_us = YLeaf(YType.uint32, "interval-standby-us")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interval_standby_ms",
                                        "interval_standby_us") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interval_standby_ms.is_set or
                            self.interval_standby_us.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interval_standby_ms.yfilter != YFilter.not_set or
                            self.interval_standby_us.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "min-interval-standby" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interval_standby_ms.is_set or self.interval_standby_ms.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interval_standby_ms.get_name_leafdata())
                        if (self.interval_standby_us.is_set or self.interval_standby_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interval_standby_us.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interval-standby-ms" or name == "interval-standby-us"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interval-standby-ms"):
                            self.interval_standby_ms = value
                            self.interval_standby_ms.value_namespace = name_space
                            self.interval_standby_ms.value_namespace_prefix = name_space_prefix
                        if(value_path == "interval-standby-us"):
                            self.interval_standby_us = value
                            self.interval_standby_us.value_namespace = name_space
                            self.interval_standby_us.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.detection_multiplier.is_set or
                        self.enable.is_set or
                        self.multiplier_standby.is_set or
                        (self.min_interval is not None and self.min_interval.has_data()) or
                        (self.min_interval_standby is not None and self.min_interval_standby.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.detection_multiplier.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        self.multiplier_standby.yfilter != YFilter.not_set or
                        (self.min_interval is not None and self.min_interval.has_operation()) or
                        (self.min_interval_standby is not None and self.min_interval_standby.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bfd" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())
                    if (self.multiplier_standby.is_set or self.multiplier_standby.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multiplier_standby.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "min-interval"):
                        if (self.min_interval is None):
                            self.min_interval = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval()
                            self.min_interval.parent = self
                            self._children_name_map["min_interval"] = "min-interval"
                        return self.min_interval

                    if (child_yang_name == "min-interval-standby"):
                        if (self.min_interval_standby is None):
                            self.min_interval_standby = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby()
                            self.min_interval_standby.parent = self
                            self._children_name_map["min_interval_standby"] = "min-interval-standby"
                        return self.min_interval_standby

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "min-interval" or name == "min-interval-standby" or name == "detection-multiplier" or name == "enable" or name == "multiplier-standby"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "detection-multiplier"):
                        self.detection_multiplier = value
                        self.detection_multiplier.value_namespace = name_space
                        self.detection_multiplier.value_namespace_prefix = name_space_prefix
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix
                    if(value_path == "multiplier-standby"):
                        self.multiplier_standby = value
                        self.multiplier_standby.value_namespace = name_space
                        self.multiplier_standby.value_namespace_prefix = name_space_prefix


            class WorkingLsp(Entity):
                """
                Working LSP
                
                .. attribute:: in_label
                
                	Incoming MPLS label of the working LSP
                	**type**\:  int
                
                	**range:** 16..4015
                
                .. attribute:: lockout
                
                	Enable lockout of working LSP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: lsp_id
                
                	LSP Identifier of the working LSP
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**default value**\: 0
                
                .. attribute:: out_label
                
                	Outgoing MPLS label of the working LSP
                	**type**\:   :py:class:`OutLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp, self).__init__()

                    self.yang_name = "working-lsp"
                    self.yang_parent_name = "transport-profile-tunnel"

                    self.in_label = YLeaf(YType.uint32, "in-label")

                    self.lockout = YLeaf(YType.empty, "lockout")

                    self.lsp_id = YLeaf(YType.uint32, "lsp-id")

                    self.out_label = None
                    self._children_name_map["out_label"] = "out-label"
                    self._children_yang_names.add("out-label")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("in_label",
                                    "lockout",
                                    "lsp_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp, self).__setattr__(name, value)


                class OutLabel(Entity):
                    """
                    Outgoing MPLS label of the working LSP
                    
                    .. attribute:: label
                    
                    	MPLS label
                    	**type**\:  int
                    
                    	**range:** 16..1048575
                    
                    .. attribute:: link
                    
                    	Transport profile identifier of outgoing link
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel, self).__init__()

                        self.yang_name = "out-label"
                        self.yang_parent_name = "working-lsp"
                        self.is_presence_container = True

                        self.label = YLeaf(YType.uint32, "label")

                        self.link = YLeaf(YType.uint32, "link")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("label",
                                        "link") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.label.is_set or
                            self.link.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.label.yfilter != YFilter.not_set or
                            self.link.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "out-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.label.get_name_leafdata())
                        if (self.link.is_set or self.link.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "label" or name == "link"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "label"):
                            self.label = value
                            self.label.value_namespace = name_space
                            self.label.value_namespace_prefix = name_space_prefix
                        if(value_path == "link"):
                            self.link = value
                            self.link.value_namespace = name_space
                            self.link.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.in_label.is_set or
                        self.lockout.is_set or
                        self.lsp_id.is_set or
                        (self.out_label is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.in_label.yfilter != YFilter.not_set or
                        self.lockout.yfilter != YFilter.not_set or
                        self.lsp_id.yfilter != YFilter.not_set or
                        (self.out_label is not None and self.out_label.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "working-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.in_label.is_set or self.in_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_label.get_name_leafdata())
                    if (self.lockout.is_set or self.lockout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lockout.get_name_leafdata())
                    if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "out-label"):
                        if (self.out_label is None):
                            self.out_label = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel()
                            self.out_label.parent = self
                            self._children_name_map["out_label"] = "out-label"
                        return self.out_label

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "out-label" or name == "in-label" or name == "lockout" or name == "lsp-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "in-label"):
                        self.in_label = value
                        self.in_label.value_namespace = name_space
                        self.in_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "lockout"):
                        self.lockout = value
                        self.lockout.value_namespace = name_space
                        self.lockout.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-id"):
                        self.lsp_id = value
                        self.lsp_id.value_namespace = name_space
                        self.lsp_id.value_namespace_prefix = name_space_prefix


            class Destination(Entity):
                """
                Node identifier and optional global identifier
                and tunnel identifier at destination
                
                .. attribute:: global_id
                
                	Numeric global identifier
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: node_id
                
                	Node identifier in IPv4 address format
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tunnel_id
                
                	Numeric tunnel identifier
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "transport-profile-tunnel"

                    self.global_id = YLeaf(YType.uint32, "global-id")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("global_id",
                                    "node_id",
                                    "tunnel_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.global_id.is_set or
                        self.node_id.is_set or
                        self.tunnel_id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.global_id.yfilter != YFilter.not_set or
                        self.node_id.yfilter != YFilter.not_set or
                        self.tunnel_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "destination" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_id.get_name_leafdata())
                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node_id.get_name_leafdata())
                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "global-id" or name == "node-id" or name == "tunnel-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "global-id"):
                        self.global_id = value
                        self.global_id.value_namespace = name_space
                        self.global_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "node-id"):
                        self.node_id = value
                        self.node_id.value_namespace = name_space
                        self.node_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-id"):
                        self.tunnel_id = value
                        self.tunnel_id.value_namespace = name_space
                        self.tunnel_id.value_namespace_prefix = name_space_prefix


            class Fault(Entity):
                """
                Fault management
                
                .. attribute:: enable
                
                	Enter transport profile tunnel fault configuration
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: protection_trigger
                
                	OAM events that trigger protection switching
                	**type**\:   :py:class:`ProtectionTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault, self).__init__()

                    self.yang_name = "fault"
                    self.yang_parent_name = "transport-profile-tunnel"

                    self.enable = YLeaf(YType.empty, "enable")

                    self.protection_trigger = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger()
                    self.protection_trigger.parent = self
                    self._children_name_map["protection_trigger"] = "protection-trigger"
                    self._children_yang_names.add("protection-trigger")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("enable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault, self).__setattr__(name, value)


                class ProtectionTrigger(Entity):
                    """
                    OAM events that trigger protection switching
                    
                    .. attribute:: ais
                    
                    	Enable protection switching due to AIS event
                    	**type**\:  bool
                    
                    .. attribute:: ldi
                    
                    	Enable protection switching due to LDI event
                    	**type**\:  bool
                    
                    .. attribute:: lkr
                    
                    	Enable protection switching due to LKR event
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger, self).__init__()

                        self.yang_name = "protection-trigger"
                        self.yang_parent_name = "fault"

                        self.ais = YLeaf(YType.boolean, "ais")

                        self.ldi = YLeaf(YType.boolean, "ldi")

                        self.lkr = YLeaf(YType.boolean, "lkr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ais",
                                        "ldi",
                                        "lkr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ais.is_set or
                            self.ldi.is_set or
                            self.lkr.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ais.yfilter != YFilter.not_set or
                            self.ldi.yfilter != YFilter.not_set or
                            self.lkr.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "protection-trigger" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ais.is_set or self.ais.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ais.get_name_leafdata())
                        if (self.ldi.is_set or self.ldi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldi.get_name_leafdata())
                        if (self.lkr.is_set or self.lkr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lkr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ais" or name == "ldi" or name == "lkr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ais"):
                            self.ais = value
                            self.ais.value_namespace = name_space
                            self.ais.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldi"):
                            self.ldi = value
                            self.ldi.value_namespace = name_space
                            self.ldi.value_namespace_prefix = name_space_prefix
                        if(value_path == "lkr"):
                            self.lkr = value
                            self.lkr.value_namespace = name_space
                            self.lkr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.enable.is_set or
                        (self.protection_trigger is not None and self.protection_trigger.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        (self.protection_trigger is not None and self.protection_trigger.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "fault" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "protection-trigger"):
                        if (self.protection_trigger is None):
                            self.protection_trigger = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger()
                            self.protection_trigger.parent = self
                            self._children_name_map["protection_trigger"] = "protection-trigger"
                        return self.protection_trigger

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "protection-trigger" or name == "enable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix


            class ProtectLsp(Entity):
                """
                Protect LSP
                
                .. attribute:: in_label
                
                	Incoming MPLS label of the protect LSP
                	**type**\:  int
                
                	**range:** 16..4015
                
                .. attribute:: lockout
                
                	Enable lockout of protect LSP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: lsp_id
                
                	LSP Identifier of the protect LSP
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**default value**\: 1
                
                .. attribute:: out_label
                
                	Outgoing MPLS label of the protect LSP
                	**type**\:   :py:class:`OutLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp, self).__init__()

                    self.yang_name = "protect-lsp"
                    self.yang_parent_name = "transport-profile-tunnel"

                    self.in_label = YLeaf(YType.uint32, "in-label")

                    self.lockout = YLeaf(YType.empty, "lockout")

                    self.lsp_id = YLeaf(YType.uint32, "lsp-id")

                    self.out_label = None
                    self._children_name_map["out_label"] = "out-label"
                    self._children_yang_names.add("out-label")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("in_label",
                                    "lockout",
                                    "lsp_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp, self).__setattr__(name, value)


                class OutLabel(Entity):
                    """
                    Outgoing MPLS label of the protect LSP
                    
                    .. attribute:: label
                    
                    	MPLS label
                    	**type**\:  int
                    
                    	**range:** 16..1048575
                    
                    .. attribute:: link
                    
                    	Transport profile identifier of outgoing link
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel, self).__init__()

                        self.yang_name = "out-label"
                        self.yang_parent_name = "protect-lsp"
                        self.is_presence_container = True

                        self.label = YLeaf(YType.uint32, "label")

                        self.link = YLeaf(YType.uint32, "link")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("label",
                                        "link") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.label.is_set or
                            self.link.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.label.yfilter != YFilter.not_set or
                            self.link.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "out-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.label.get_name_leafdata())
                        if (self.link.is_set or self.link.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "label" or name == "link"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "label"):
                            self.label = value
                            self.label.value_namespace = name_space
                            self.label.value_namespace_prefix = name_space_prefix
                        if(value_path == "link"):
                            self.link = value
                            self.link.value_namespace = name_space
                            self.link.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.in_label.is_set or
                        self.lockout.is_set or
                        self.lsp_id.is_set or
                        (self.out_label is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.in_label.yfilter != YFilter.not_set or
                        self.lockout.yfilter != YFilter.not_set or
                        self.lsp_id.yfilter != YFilter.not_set or
                        (self.out_label is not None and self.out_label.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "protect-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.in_label.is_set or self.in_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_label.get_name_leafdata())
                    if (self.lockout.is_set or self.lockout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lockout.get_name_leafdata())
                    if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "out-label"):
                        if (self.out_label is None):
                            self.out_label = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel()
                            self.out_label.parent = self
                            self._children_name_map["out_label"] = "out-label"
                        return self.out_label

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "out-label" or name == "in-label" or name == "lockout" or name == "lsp-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "in-label"):
                        self.in_label = value
                        self.in_label.value_namespace = name_space
                        self.in_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "lockout"):
                        self.lockout = value
                        self.lockout.value_namespace = name_space
                        self.lockout.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-id"):
                        self.lsp_id = value
                        self.lsp_id.value_namespace = name_space
                        self.lsp_id.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source.is_set or
                    (self.bfd is not None and self.bfd.has_data()) or
                    (self.destination is not None and self.destination.has_data()) or
                    (self.fault is not None and self.fault.has_data()) or
                    (self.protect_lsp is not None and self.protect_lsp.has_data()) or
                    (self.working_lsp is not None and self.working_lsp.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source.yfilter != YFilter.not_set or
                    (self.bfd is not None and self.bfd.has_operation()) or
                    (self.destination is not None and self.destination.has_operation()) or
                    (self.fault is not None and self.fault.has_operation()) or
                    (self.protect_lsp is not None and self.protect_lsp.has_operation()) or
                    (self.working_lsp is not None and self.working_lsp.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-mpls-te-cfg:transport-profile-tunnel" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bfd"):
                    if (self.bfd is None):
                        self.bfd = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd()
                        self.bfd.parent = self
                        self._children_name_map["bfd"] = "bfd"
                    return self.bfd

                if (child_yang_name == "destination"):
                    if (self.destination is None):
                        self.destination = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"
                    return self.destination

                if (child_yang_name == "fault"):
                    if (self.fault is None):
                        self.fault = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault()
                        self.fault.parent = self
                        self._children_name_map["fault"] = "fault"
                    return self.fault

                if (child_yang_name == "protect-lsp"):
                    if (self.protect_lsp is None):
                        self.protect_lsp = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp()
                        self.protect_lsp.parent = self
                        self._children_name_map["protect_lsp"] = "protect-lsp"
                    return self.protect_lsp

                if (child_yang_name == "working-lsp"):
                    if (self.working_lsp is None):
                        self.working_lsp = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp()
                        self.working_lsp.parent = self
                        self._children_name_map["working_lsp"] = "working-lsp"
                    return self.working_lsp

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bfd" or name == "destination" or name == "fault" or name == "protect-lsp" or name == "working-lsp" or name == "source"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source"):
                    self.source = value
                    self.source.value_namespace = name_space
                    self.source.value_namespace_prefix = name_space_prefix


        class MteTunnelAttributes(Entity):
            """
            MPLS P2MP tunnel attributes
            
            .. attribute:: affinity_mask
            
            	P2MP tunnel affinity and mask
            	**type**\:   :py:class:`AffinityMask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask>`
            
            .. attribute:: bandwidth
            
            	P2MP tunnel bandwidth requirement
            	**type**\:   :py:class:`Bandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth>`
            
            .. attribute:: destination_leafs
            
            	P2MP destination table
            	**type**\:   :py:class:`DestinationLeafs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs>`
            
            .. attribute:: fast_reroute
            
            	Specify P2MP tunnel can be fast\-rerouted
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: impose_explicit_null
            
            	Impose an explicit null bellow the TE label
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: logging
            
            	Log tunnel LSP messages
            	**type**\:   :py:class:`Logging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging>`
            
            .. attribute:: new_style_affinities
            
            	P2MP tunnel new style affinity attributes table
            	**type**\:   :py:class:`NewStyleAffinities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities>`
            
            .. attribute:: path_selection_metric
            
            	Path selection configuration for this specific tunnel
            	**type**\:   :py:class:`MplsTePathSelectionMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathSelectionMetric>`
            
            .. attribute:: priority
            
            	P2MP tunnel setup and hold priorities
            	**type**\:   :py:class:`Priority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority>`
            
            .. attribute:: record_route
            
            	Record route used by individual P2MP S2L(s)
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: signalled_name
            
            	The name of the P2MP tunnel to be included in signalling messages
            	**type**\:  str
            
            	**length:** 1..254
            
            .. attribute:: signalled_payload
            
            	P2MP tunnel ipv6 signalled payload
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            

            """

            _prefix = 'mpls-te-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes, self).__init__()

                self.yang_name = "mte-tunnel-attributes"
                self.yang_parent_name = "interface-configuration"

                self.fast_reroute = YLeaf(YType.empty, "fast-reroute")

                self.impose_explicit_null = YLeaf(YType.empty, "impose-explicit-null")

                self.path_selection_metric = YLeaf(YType.enumeration, "path-selection-metric")

                self.record_route = YLeaf(YType.empty, "record-route")

                self.signalled_name = YLeaf(YType.str, "signalled-name")

                self.signalled_payload = YLeaf(YType.str, "signalled-payload")

                self.affinity_mask = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask()
                self.affinity_mask.parent = self
                self._children_name_map["affinity_mask"] = "affinity-mask"
                self._children_yang_names.add("affinity-mask")

                self.bandwidth = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"
                self._children_yang_names.add("bandwidth")

                self.destination_leafs = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs()
                self.destination_leafs.parent = self
                self._children_name_map["destination_leafs"] = "destination-leafs"
                self._children_yang_names.add("destination-leafs")

                self.logging = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"
                self._children_yang_names.add("logging")

                self.new_style_affinities = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities()
                self.new_style_affinities.parent = self
                self._children_name_map["new_style_affinities"] = "new-style-affinities"
                self._children_yang_names.add("new-style-affinities")

                self.priority = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority()
                self.priority.parent = self
                self._children_name_map["priority"] = "priority"
                self._children_yang_names.add("priority")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("fast_reroute",
                                "impose_explicit_null",
                                "path_selection_metric",
                                "record_route",
                                "signalled_name",
                                "signalled_payload") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes, self).__setattr__(name, value)


            class DestinationLeafs(Entity):
                """
                P2MP destination table
                
                .. attribute:: destination_leaf
                
                	P2MP destination leaf
                	**type**\: list of    :py:class:`DestinationLeaf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs, self).__init__()

                    self.yang_name = "destination-leafs"
                    self.yang_parent_name = "mte-tunnel-attributes"

                    self.destination_leaf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs, self).__setattr__(name, value)


                class DestinationLeaf(Entity):
                    """
                    P2MP destination leaf
                    
                    .. attribute:: address  <key>
                    
                    	Address of P2MP destination
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: destination
                    
                    	Always set to true
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: destination_disable
                    
                    	Disables P2MP destination
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: path_options
                    
                    	P2MP destination path\-options attributes table
                    	**type**\:   :py:class:`PathOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions>`
                    
                    .. attribute:: s2l_logging
                    
                    	Log tunnel destination s2l messages
                    	**type**\:   :py:class:`S2LLogging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf, self).__init__()

                        self.yang_name = "destination-leaf"
                        self.yang_parent_name = "destination-leafs"

                        self.address = YLeaf(YType.str, "address")

                        self.destination = YLeaf(YType.empty, "destination")

                        self.destination_disable = YLeaf(YType.empty, "destination-disable")

                        self.path_options = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions()
                        self.path_options.parent = self
                        self._children_name_map["path_options"] = "path-options"
                        self._children_yang_names.add("path-options")

                        self.s2l_logging = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging()
                        self.s2l_logging.parent = self
                        self._children_name_map["s2l_logging"] = "s2l-logging"
                        self._children_yang_names.add("s2l-logging")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "destination",
                                        "destination_disable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf, self).__setattr__(name, value)


                    class S2LLogging(Entity):
                        """
                        Log tunnel destination s2l messages
                        
                        .. attribute:: s2l_insufficient_bw_messsage
                        
                        	Log tunnel destination s2l insufficient BW messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s2l_pcalc_failure_message
                        
                        	Enable logging for destination s2l path\-calculation failures
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s2l_reroute_messsage
                        
                        	Log tunnel destination s2l rereoute messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s2l_state_message
                        
                        	Log tunnel destination s2l state messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging, self).__init__()

                            self.yang_name = "s2l-logging"
                            self.yang_parent_name = "destination-leaf"

                            self.s2l_insufficient_bw_messsage = YLeaf(YType.empty, "s2l-insufficient-bw-messsage")

                            self.s2l_pcalc_failure_message = YLeaf(YType.empty, "s2l-pcalc-failure-message")

                            self.s2l_reroute_messsage = YLeaf(YType.empty, "s2l-reroute-messsage")

                            self.s2l_state_message = YLeaf(YType.empty, "s2l-state-message")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("s2l_insufficient_bw_messsage",
                                            "s2l_pcalc_failure_message",
                                            "s2l_reroute_messsage",
                                            "s2l_state_message") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.s2l_insufficient_bw_messsage.is_set or
                                self.s2l_pcalc_failure_message.is_set or
                                self.s2l_reroute_messsage.is_set or
                                self.s2l_state_message.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.s2l_insufficient_bw_messsage.yfilter != YFilter.not_set or
                                self.s2l_pcalc_failure_message.yfilter != YFilter.not_set or
                                self.s2l_reroute_messsage.yfilter != YFilter.not_set or
                                self.s2l_state_message.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "s2l-logging" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.s2l_insufficient_bw_messsage.is_set or self.s2l_insufficient_bw_messsage.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.s2l_insufficient_bw_messsage.get_name_leafdata())
                            if (self.s2l_pcalc_failure_message.is_set or self.s2l_pcalc_failure_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.s2l_pcalc_failure_message.get_name_leafdata())
                            if (self.s2l_reroute_messsage.is_set or self.s2l_reroute_messsage.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.s2l_reroute_messsage.get_name_leafdata())
                            if (self.s2l_state_message.is_set or self.s2l_state_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.s2l_state_message.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "s2l-insufficient-bw-messsage" or name == "s2l-pcalc-failure-message" or name == "s2l-reroute-messsage" or name == "s2l-state-message"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "s2l-insufficient-bw-messsage"):
                                self.s2l_insufficient_bw_messsage = value
                                self.s2l_insufficient_bw_messsage.value_namespace = name_space
                                self.s2l_insufficient_bw_messsage.value_namespace_prefix = name_space_prefix
                            if(value_path == "s2l-pcalc-failure-message"):
                                self.s2l_pcalc_failure_message = value
                                self.s2l_pcalc_failure_message.value_namespace = name_space
                                self.s2l_pcalc_failure_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "s2l-reroute-messsage"):
                                self.s2l_reroute_messsage = value
                                self.s2l_reroute_messsage.value_namespace = name_space
                                self.s2l_reroute_messsage.value_namespace_prefix = name_space_prefix
                            if(value_path == "s2l-state-message"):
                                self.s2l_state_message = value
                                self.s2l_state_message.value_namespace = name_space
                                self.s2l_state_message.value_namespace_prefix = name_space_prefix


                    class PathOptions(Entity):
                        """
                        P2MP destination path\-options attributes
                        table
                        
                        .. attribute:: path_option
                        
                        	P2MP destination path option
                        	**type**\: list of    :py:class:`PathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions, self).__init__()

                            self.yang_name = "path-options"
                            self.yang_parent_name = "destination-leaf"

                            self.path_option = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions, self).__setattr__(name, value)


                        class PathOption(Entity):
                            """
                            P2MP destination path option
                            
                            .. attribute:: preference_level  <key>
                            
                            	Preference level for this path option
                            	**type**\:  int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: lockdown
                            
                            	Path option properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            .. attribute:: path_id
                            
                            	The ID of the IP explicit path associated with this option
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: path_name
                            
                            	The name of the IP explicit path associated with this option
                            	**type**\:  str
                            
                            .. attribute:: path_type
                            
                            	The type of the path option
                            	**type**\:   :py:class:`MplsTePathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOption>`
                            
                            .. attribute:: verbatim
                            
                            	Path option properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            

                            """

                            _prefix = 'mpls-te-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "path-options"

                                self.preference_level = YLeaf(YType.uint32, "preference-level")

                                self.lockdown = YLeaf(YType.enumeration, "lockdown")

                                self.path_id = YLeaf(YType.uint32, "path-id")

                                self.path_name = YLeaf(YType.str, "path-name")

                                self.path_type = YLeaf(YType.enumeration, "path-type")

                                self.verbatim = YLeaf(YType.enumeration, "verbatim")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("preference_level",
                                                "lockdown",
                                                "path_id",
                                                "path_name",
                                                "path_type",
                                                "verbatim") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.preference_level.is_set or
                                    self.lockdown.is_set or
                                    self.path_id.is_set or
                                    self.path_name.is_set or
                                    self.path_type.is_set or
                                    self.verbatim.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.preference_level.yfilter != YFilter.not_set or
                                    self.lockdown.yfilter != YFilter.not_set or
                                    self.path_id.yfilter != YFilter.not_set or
                                    self.path_name.yfilter != YFilter.not_set or
                                    self.path_type.yfilter != YFilter.not_set or
                                    self.verbatim.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "path-option" + "[preference-level='" + self.preference_level.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.preference_level.is_set or self.preference_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preference_level.get_name_leafdata())
                                if (self.lockdown.is_set or self.lockdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lockdown.get_name_leafdata())
                                if (self.path_id.is_set or self.path_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_id.get_name_leafdata())
                                if (self.path_name.is_set or self.path_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_name.get_name_leafdata())
                                if (self.path_type.is_set or self.path_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_type.get_name_leafdata())
                                if (self.verbatim.is_set or self.verbatim.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.verbatim.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "preference-level" or name == "lockdown" or name == "path-id" or name == "path-name" or name == "path-type" or name == "verbatim"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "preference-level"):
                                    self.preference_level = value
                                    self.preference_level.value_namespace = name_space
                                    self.preference_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "lockdown"):
                                    self.lockdown = value
                                    self.lockdown.value_namespace = name_space
                                    self.lockdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-id"):
                                    self.path_id = value
                                    self.path_id.value_namespace = name_space
                                    self.path_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-name"):
                                    self.path_name = value
                                    self.path_name.value_namespace = name_space
                                    self.path_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-type"):
                                    self.path_type = value
                                    self.path_type.value_namespace = name_space
                                    self.path_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "verbatim"):
                                    self.verbatim = value
                                    self.verbatim.value_namespace = name_space
                                    self.verbatim.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.path_option:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.path_option:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "path-options" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "path-option"):
                                for c in self.path_option:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.path_option.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path-option"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.destination.is_set or
                            self.destination_disable.is_set or
                            (self.path_options is not None and self.path_options.has_data()) or
                            (self.s2l_logging is not None and self.s2l_logging.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.destination.yfilter != YFilter.not_set or
                            self.destination_disable.yfilter != YFilter.not_set or
                            (self.path_options is not None and self.path_options.has_operation()) or
                            (self.s2l_logging is not None and self.s2l_logging.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "destination-leaf" + "[address='" + self.address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.destination.is_set or self.destination.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination.get_name_leafdata())
                        if (self.destination_disable.is_set or self.destination_disable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_disable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "path-options"):
                            if (self.path_options is None):
                                self.path_options = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions()
                                self.path_options.parent = self
                                self._children_name_map["path_options"] = "path-options"
                            return self.path_options

                        if (child_yang_name == "s2l-logging"):
                            if (self.s2l_logging is None):
                                self.s2l_logging = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging()
                                self.s2l_logging.parent = self
                                self._children_name_map["s2l_logging"] = "s2l-logging"
                            return self.s2l_logging

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "path-options" or name == "s2l-logging" or name == "address" or name == "destination" or name == "destination-disable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "destination"):
                            self.destination = value
                            self.destination.value_namespace = name_space
                            self.destination.value_namespace_prefix = name_space_prefix
                        if(value_path == "destination-disable"):
                            self.destination_disable = value
                            self.destination_disable.value_namespace = name_space
                            self.destination_disable.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.destination_leaf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.destination_leaf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "destination-leafs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "destination-leaf"):
                        for c in self.destination_leaf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.destination_leaf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-leaf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Priority(Entity):
                """
                P2MP tunnel setup and hold priorities
                
                .. attribute:: hold_priority
                
                	Hold Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority, self).__init__()

                    self.yang_name = "priority"
                    self.yang_parent_name = "mte-tunnel-attributes"

                    self.hold_priority = YLeaf(YType.uint32, "hold-priority")

                    self.setup_priority = YLeaf(YType.uint32, "setup-priority")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("hold_priority",
                                    "setup_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.hold_priority.is_set or
                        self.setup_priority.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.hold_priority.yfilter != YFilter.not_set or
                        self.setup_priority.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "priority" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.hold_priority.is_set or self.hold_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hold_priority.get_name_leafdata())
                    if (self.setup_priority.is_set or self.setup_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.setup_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hold-priority" or name == "setup-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "hold-priority"):
                        self.hold_priority = value
                        self.hold_priority.value_namespace = name_space
                        self.hold_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "setup-priority"):
                        self.setup_priority = value
                        self.setup_priority.value_namespace = name_space
                        self.setup_priority.value_namespace_prefix = name_space_prefix


            class NewStyleAffinities(Entity):
                """
                P2MP tunnel new style affinity attributes table
                
                .. attribute:: new_style_affinity
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities, self).__init__()

                    self.yang_name = "new-style-affinities"
                    self.yang_parent_name = "mte-tunnel-attributes"

                    self.new_style_affinity = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities, self).__setattr__(name, value)


                class NewStyleAffinity(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity9  <key>
                    
                    	The name of the nineth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity10  <key>
                    
                    	The name of the tenth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity, self).__init__()

                        self.yang_name = "new-style-affinity"
                        self.yang_parent_name = "new-style-affinities"

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                        self.affinity9 = YLeaf(YType.str, "affinity9")

                        self.affinity10 = YLeaf(YType.str, "affinity10")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("affinity_type",
                                        "affinity1",
                                        "affinity2",
                                        "affinity3",
                                        "affinity4",
                                        "affinity5",
                                        "affinity6",
                                        "affinity7",
                                        "affinity8",
                                        "affinity9",
                                        "affinity10") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.affinity_type.is_set or
                            self.affinity1.is_set or
                            self.affinity2.is_set or
                            self.affinity3.is_set or
                            self.affinity4.is_set or
                            self.affinity5.is_set or
                            self.affinity6.is_set or
                            self.affinity7.is_set or
                            self.affinity8.is_set or
                            self.affinity9.is_set or
                            self.affinity10.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.affinity_type.yfilter != YFilter.not_set or
                            self.affinity1.yfilter != YFilter.not_set or
                            self.affinity2.yfilter != YFilter.not_set or
                            self.affinity3.yfilter != YFilter.not_set or
                            self.affinity4.yfilter != YFilter.not_set or
                            self.affinity5.yfilter != YFilter.not_set or
                            self.affinity6.yfilter != YFilter.not_set or
                            self.affinity7.yfilter != YFilter.not_set or
                            self.affinity8.yfilter != YFilter.not_set or
                            self.affinity9.yfilter != YFilter.not_set or
                            self.affinity10.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "new-style-affinity" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + "[affinity9='" + self.affinity9.get() + "']" + "[affinity10='" + self.affinity10.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.affinity_type.is_set or self.affinity_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity_type.get_name_leafdata())
                        if (self.affinity1.is_set or self.affinity1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity1.get_name_leafdata())
                        if (self.affinity2.is_set or self.affinity2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity2.get_name_leafdata())
                        if (self.affinity3.is_set or self.affinity3.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity3.get_name_leafdata())
                        if (self.affinity4.is_set or self.affinity4.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity4.get_name_leafdata())
                        if (self.affinity5.is_set or self.affinity5.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity5.get_name_leafdata())
                        if (self.affinity6.is_set or self.affinity6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity6.get_name_leafdata())
                        if (self.affinity7.is_set or self.affinity7.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity7.get_name_leafdata())
                        if (self.affinity8.is_set or self.affinity8.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity8.get_name_leafdata())
                        if (self.affinity9.is_set or self.affinity9.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity9.get_name_leafdata())
                        if (self.affinity10.is_set or self.affinity10.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.affinity10.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "affinity-type" or name == "affinity1" or name == "affinity2" or name == "affinity3" or name == "affinity4" or name == "affinity5" or name == "affinity6" or name == "affinity7" or name == "affinity8" or name == "affinity9" or name == "affinity10"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "affinity-type"):
                            self.affinity_type = value
                            self.affinity_type.value_namespace = name_space
                            self.affinity_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity1"):
                            self.affinity1 = value
                            self.affinity1.value_namespace = name_space
                            self.affinity1.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity2"):
                            self.affinity2 = value
                            self.affinity2.value_namespace = name_space
                            self.affinity2.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity3"):
                            self.affinity3 = value
                            self.affinity3.value_namespace = name_space
                            self.affinity3.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity4"):
                            self.affinity4 = value
                            self.affinity4.value_namespace = name_space
                            self.affinity4.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity5"):
                            self.affinity5 = value
                            self.affinity5.value_namespace = name_space
                            self.affinity5.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity6"):
                            self.affinity6 = value
                            self.affinity6.value_namespace = name_space
                            self.affinity6.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity7"):
                            self.affinity7 = value
                            self.affinity7.value_namespace = name_space
                            self.affinity7.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity8"):
                            self.affinity8 = value
                            self.affinity8.value_namespace = name_space
                            self.affinity8.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity9"):
                            self.affinity9 = value
                            self.affinity9.value_namespace = name_space
                            self.affinity9.value_namespace_prefix = name_space_prefix
                        if(value_path == "affinity10"):
                            self.affinity10 = value
                            self.affinity10.value_namespace = name_space
                            self.affinity10.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.new_style_affinity:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.new_style_affinity:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "new-style-affinities" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "new-style-affinity"):
                        for c in self.new_style_affinity:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.new_style_affinity.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "new-style-affinity"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bandwidth(Entity):
                """
                P2MP tunnel bandwidth requirement
                
                .. attribute:: bandwidth
                
                	The value of the bandwidth reserved by this tunnel in kbps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: class_or_pool_type
                
                	Class type for the bandwidth allocation
                	**type**\:  int
                
                	**range:** 0..1
                
                .. attribute:: dste_type
                
                	DSTE\-standard flag
                	**type**\:   :py:class:`MplsTeBandwidthDste <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthDste>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "mte-tunnel-attributes"

                    self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                    self.class_or_pool_type = YLeaf(YType.uint32, "class-or-pool-type")

                    self.dste_type = YLeaf(YType.enumeration, "dste-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bandwidth",
                                    "class_or_pool_type",
                                    "dste_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bandwidth.is_set or
                        self.class_or_pool_type.is_set or
                        self.dste_type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bandwidth.yfilter != YFilter.not_set or
                        self.class_or_pool_type.yfilter != YFilter.not_set or
                        self.dste_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth.get_name_leafdata())
                    if (self.class_or_pool_type.is_set or self.class_or_pool_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.class_or_pool_type.get_name_leafdata())
                    if (self.dste_type.is_set or self.dste_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bandwidth" or name == "class-or-pool-type" or name == "dste-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bandwidth"):
                        self.bandwidth = value
                        self.bandwidth.value_namespace = name_space
                        self.bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "class-or-pool-type"):
                        self.class_or_pool_type = value
                        self.class_or_pool_type.value_namespace = name_space
                        self.class_or_pool_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "dste-type"):
                        self.dste_type = value
                        self.dste_type.value_namespace = name_space
                        self.dste_type.value_namespace_prefix = name_space_prefix


            class AffinityMask(Entity):
                """
                P2MP tunnel affinity and mask
                
                .. attribute:: affinity
                
                	Affinity flags
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: mask
                
                	Affinity mask
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask, self).__init__()

                    self.yang_name = "affinity-mask"
                    self.yang_parent_name = "mte-tunnel-attributes"

                    self.affinity = YLeaf(YType.str, "affinity")

                    self.mask = YLeaf(YType.str, "mask")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("affinity",
                                    "mask") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.affinity.is_set or
                        self.mask.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.affinity.yfilter != YFilter.not_set or
                        self.mask.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "affinity-mask" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.affinity.is_set or self.affinity.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.affinity.get_name_leafdata())
                    if (self.mask.is_set or self.mask.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mask.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "affinity" or name == "mask"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "affinity"):
                        self.affinity = value
                        self.affinity.value_namespace = name_space
                        self.affinity.value_namespace_prefix = name_space_prefix
                    if(value_path == "mask"):
                        self.mask = value
                        self.mask.value_namespace = name_space
                        self.mask.value_namespace_prefix = name_space_prefix


            class Logging(Entity):
                """
                Log tunnel LSP messages
                
                .. attribute:: all
                
                	Log all events for a tunnel
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bandwidth_change_message
                
                	Log tunnel bandwidth change messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: insufficient_bw_message
                
                	Log tunnel messages for insufficient bandwidth
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pcalc_failure_message
                
                	Enable logging for path\-calculation failures
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimize_attempts_message
                
                	Log tunnel reoptimization attempts messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimized_message
                
                	Log tunnel reoptimized messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reroute_messsage
                
                	Log tunnel rereoute messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: state_message
                
                	Log tunnel state messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sub_lsp_state_message
                
                	Log all tunnel sub\-LSP state messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "mte-tunnel-attributes"

                    self.all = YLeaf(YType.empty, "all")

                    self.bandwidth_change_message = YLeaf(YType.empty, "bandwidth-change-message")

                    self.insufficient_bw_message = YLeaf(YType.empty, "insufficient-bw-message")

                    self.pcalc_failure_message = YLeaf(YType.empty, "pcalc-failure-message")

                    self.reoptimize_attempts_message = YLeaf(YType.empty, "reoptimize-attempts-message")

                    self.reoptimized_message = YLeaf(YType.empty, "reoptimized-message")

                    self.reroute_messsage = YLeaf(YType.empty, "reroute-messsage")

                    self.state_message = YLeaf(YType.empty, "state-message")

                    self.sub_lsp_state_message = YLeaf(YType.empty, "sub-lsp-state-message")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("all",
                                    "bandwidth_change_message",
                                    "insufficient_bw_message",
                                    "pcalc_failure_message",
                                    "reoptimize_attempts_message",
                                    "reoptimized_message",
                                    "reroute_messsage",
                                    "state_message",
                                    "sub_lsp_state_message") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.all.is_set or
                        self.bandwidth_change_message.is_set or
                        self.insufficient_bw_message.is_set or
                        self.pcalc_failure_message.is_set or
                        self.reoptimize_attempts_message.is_set or
                        self.reoptimized_message.is_set or
                        self.reroute_messsage.is_set or
                        self.state_message.is_set or
                        self.sub_lsp_state_message.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.all.yfilter != YFilter.not_set or
                        self.bandwidth_change_message.yfilter != YFilter.not_set or
                        self.insufficient_bw_message.yfilter != YFilter.not_set or
                        self.pcalc_failure_message.yfilter != YFilter.not_set or
                        self.reoptimize_attempts_message.yfilter != YFilter.not_set or
                        self.reoptimized_message.yfilter != YFilter.not_set or
                        self.reroute_messsage.yfilter != YFilter.not_set or
                        self.state_message.yfilter != YFilter.not_set or
                        self.sub_lsp_state_message.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "logging" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.all.is_set or self.all.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.all.get_name_leafdata())
                    if (self.bandwidth_change_message.is_set or self.bandwidth_change_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth_change_message.get_name_leafdata())
                    if (self.insufficient_bw_message.is_set or self.insufficient_bw_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.insufficient_bw_message.get_name_leafdata())
                    if (self.pcalc_failure_message.is_set or self.pcalc_failure_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pcalc_failure_message.get_name_leafdata())
                    if (self.reoptimize_attempts_message.is_set or self.reoptimize_attempts_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reoptimize_attempts_message.get_name_leafdata())
                    if (self.reoptimized_message.is_set or self.reoptimized_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reoptimized_message.get_name_leafdata())
                    if (self.reroute_messsage.is_set or self.reroute_messsage.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reroute_messsage.get_name_leafdata())
                    if (self.state_message.is_set or self.state_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state_message.get_name_leafdata())
                    if (self.sub_lsp_state_message.is_set or self.sub_lsp_state_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sub_lsp_state_message.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "all" or name == "bandwidth-change-message" or name == "insufficient-bw-message" or name == "pcalc-failure-message" or name == "reoptimize-attempts-message" or name == "reoptimized-message" or name == "reroute-messsage" or name == "state-message" or name == "sub-lsp-state-message"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "all"):
                        self.all = value
                        self.all.value_namespace = name_space
                        self.all.value_namespace_prefix = name_space_prefix
                    if(value_path == "bandwidth-change-message"):
                        self.bandwidth_change_message = value
                        self.bandwidth_change_message.value_namespace = name_space
                        self.bandwidth_change_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "insufficient-bw-message"):
                        self.insufficient_bw_message = value
                        self.insufficient_bw_message.value_namespace = name_space
                        self.insufficient_bw_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "pcalc-failure-message"):
                        self.pcalc_failure_message = value
                        self.pcalc_failure_message.value_namespace = name_space
                        self.pcalc_failure_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "reoptimize-attempts-message"):
                        self.reoptimize_attempts_message = value
                        self.reoptimize_attempts_message.value_namespace = name_space
                        self.reoptimize_attempts_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "reoptimized-message"):
                        self.reoptimized_message = value
                        self.reoptimized_message.value_namespace = name_space
                        self.reoptimized_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "reroute-messsage"):
                        self.reroute_messsage = value
                        self.reroute_messsage.value_namespace = name_space
                        self.reroute_messsage.value_namespace_prefix = name_space_prefix
                    if(value_path == "state-message"):
                        self.state_message = value
                        self.state_message.value_namespace = name_space
                        self.state_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "sub-lsp-state-message"):
                        self.sub_lsp_state_message = value
                        self.sub_lsp_state_message.value_namespace = name_space
                        self.sub_lsp_state_message.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.fast_reroute.is_set or
                    self.impose_explicit_null.is_set or
                    self.path_selection_metric.is_set or
                    self.record_route.is_set or
                    self.signalled_name.is_set or
                    self.signalled_payload.is_set or
                    (self.affinity_mask is not None and self.affinity_mask.has_data()) or
                    (self.bandwidth is not None and self.bandwidth.has_data()) or
                    (self.destination_leafs is not None and self.destination_leafs.has_data()) or
                    (self.logging is not None and self.logging.has_data()) or
                    (self.new_style_affinities is not None and self.new_style_affinities.has_data()) or
                    (self.priority is not None and self.priority.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.fast_reroute.yfilter != YFilter.not_set or
                    self.impose_explicit_null.yfilter != YFilter.not_set or
                    self.path_selection_metric.yfilter != YFilter.not_set or
                    self.record_route.yfilter != YFilter.not_set or
                    self.signalled_name.yfilter != YFilter.not_set or
                    self.signalled_payload.yfilter != YFilter.not_set or
                    (self.affinity_mask is not None and self.affinity_mask.has_operation()) or
                    (self.bandwidth is not None and self.bandwidth.has_operation()) or
                    (self.destination_leafs is not None and self.destination_leafs.has_operation()) or
                    (self.logging is not None and self.logging.has_operation()) or
                    (self.new_style_affinities is not None and self.new_style_affinities.has_operation()) or
                    (self.priority is not None and self.priority.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-mpls-te-cfg:mte-tunnel-attributes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.fast_reroute.is_set or self.fast_reroute.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.fast_reroute.get_name_leafdata())
                if (self.impose_explicit_null.is_set or self.impose_explicit_null.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.impose_explicit_null.get_name_leafdata())
                if (self.path_selection_metric.is_set or self.path_selection_metric.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_selection_metric.get_name_leafdata())
                if (self.record_route.is_set or self.record_route.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.record_route.get_name_leafdata())
                if (self.signalled_name.is_set or self.signalled_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalled_name.get_name_leafdata())
                if (self.signalled_payload.is_set or self.signalled_payload.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalled_payload.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "affinity-mask"):
                    if (self.affinity_mask is None):
                        self.affinity_mask = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask()
                        self.affinity_mask.parent = self
                        self._children_name_map["affinity_mask"] = "affinity-mask"
                    return self.affinity_mask

                if (child_yang_name == "bandwidth"):
                    if (self.bandwidth is None):
                        self.bandwidth = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth()
                        self.bandwidth.parent = self
                        self._children_name_map["bandwidth"] = "bandwidth"
                    return self.bandwidth

                if (child_yang_name == "destination-leafs"):
                    if (self.destination_leafs is None):
                        self.destination_leafs = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs()
                        self.destination_leafs.parent = self
                        self._children_name_map["destination_leafs"] = "destination-leafs"
                    return self.destination_leafs

                if (child_yang_name == "logging"):
                    if (self.logging is None):
                        self.logging = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging()
                        self.logging.parent = self
                        self._children_name_map["logging"] = "logging"
                    return self.logging

                if (child_yang_name == "new-style-affinities"):
                    if (self.new_style_affinities is None):
                        self.new_style_affinities = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities()
                        self.new_style_affinities.parent = self
                        self._children_name_map["new_style_affinities"] = "new-style-affinities"
                    return self.new_style_affinities

                if (child_yang_name == "priority"):
                    if (self.priority is None):
                        self.priority = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority()
                        self.priority.parent = self
                        self._children_name_map["priority"] = "priority"
                    return self.priority

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "affinity-mask" or name == "bandwidth" or name == "destination-leafs" or name == "logging" or name == "new-style-affinities" or name == "priority" or name == "fast-reroute" or name == "impose-explicit-null" or name == "path-selection-metric" or name == "record-route" or name == "signalled-name" or name == "signalled-payload"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "fast-reroute"):
                    self.fast_reroute = value
                    self.fast_reroute.value_namespace = name_space
                    self.fast_reroute.value_namespace_prefix = name_space_prefix
                if(value_path == "impose-explicit-null"):
                    self.impose_explicit_null = value
                    self.impose_explicit_null.value_namespace = name_space
                    self.impose_explicit_null.value_namespace_prefix = name_space_prefix
                if(value_path == "path-selection-metric"):
                    self.path_selection_metric = value
                    self.path_selection_metric.value_namespace = name_space
                    self.path_selection_metric.value_namespace_prefix = name_space_prefix
                if(value_path == "record-route"):
                    self.record_route = value
                    self.record_route.value_namespace = name_space
                    self.record_route.value_namespace_prefix = name_space_prefix
                if(value_path == "signalled-name"):
                    self.signalled_name = value
                    self.signalled_name.value_namespace = name_space
                    self.signalled_name.value_namespace_prefix = name_space_prefix
                if(value_path == "signalled-payload"):
                    self.signalled_payload = value
                    self.signalled_payload.value_namespace = name_space
                    self.signalled_payload.value_namespace_prefix = name_space_prefix


        class Portmode(Entity):
            """
            Configure through port\-mode
            
            .. attribute:: diff_sel
            
            	Select Diff
            	**type**\:   :py:class:`DiffSel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs5500_coherent_portmode_cfg.DiffSel>`
            
            .. attribute:: fec_sel
            
            	Select Fec
            	**type**\:   :py:class:`FecSel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs5500_coherent_portmode_cfg.FecSel>`
            
            .. attribute:: speed_sel
            
            	Select speed
            	**type**\:   :py:class:`SpeedSel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs5500_coherent_portmode_cfg.SpeedSel>`
            
            

            """

            _prefix = 'ncs5500-coherent-portmode-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Portmode, self).__init__()

                self.yang_name = "portmode"
                self.yang_parent_name = "interface-configuration"

                self.diff_sel = YLeaf(YType.enumeration, "diff-sel")

                self.fec_sel = YLeaf(YType.enumeration, "fec-sel")

                self.speed_sel = YLeaf(YType.enumeration, "speed-sel")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("diff_sel",
                                "fec_sel",
                                "speed_sel") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Portmode, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Portmode, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.diff_sel.is_set or
                    self.fec_sel.is_set or
                    self.speed_sel.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.diff_sel.yfilter != YFilter.not_set or
                    self.fec_sel.yfilter != YFilter.not_set or
                    self.speed_sel.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ncs5500-coherent-portmode-cfg:portmode" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.diff_sel.is_set or self.diff_sel.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.diff_sel.get_name_leafdata())
                if (self.fec_sel.is_set or self.fec_sel.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.fec_sel.get_name_leafdata())
                if (self.speed_sel.is_set or self.speed_sel.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.speed_sel.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "diff-sel" or name == "fec-sel" or name == "speed-sel"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "diff-sel"):
                    self.diff_sel = value
                    self.diff_sel.value_namespace = name_space
                    self.diff_sel.value_namespace_prefix = name_space_prefix
                if(value_path == "fec-sel"):
                    self.fec_sel = value
                    self.fec_sel.value_namespace = name_space
                    self.fec_sel.value_namespace_prefix = name_space_prefix
                if(value_path == "speed-sel"):
                    self.speed_sel = value
                    self.speed_sel.value_namespace = name_space
                    self.speed_sel.value_namespace_prefix = name_space_prefix


        class ClientPort(Entity):
            """
            Mxp optics for client ports
            
            .. attribute:: channels
            
            	Client Port Lane
            	**type**\:   :py:class:`Channels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels>`
            
            .. attribute:: logical_channel_assignments
            
            	Client port logical channel assignment
            	**type**\:   :py:class:`LogicalChannelAssignments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments>`
            
            

            """

            _prefix = 'openconfig-optical-client-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.ClientPort, self).__init__()

                self.yang_name = "client-port"
                self.yang_parent_name = "interface-configuration"

                self.channels = InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels()
                self.channels.parent = self
                self._children_name_map["channels"] = "channels"
                self._children_yang_names.add("channels")

                self.logical_channel_assignments = InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments()
                self.logical_channel_assignments.parent = self
                self._children_name_map["logical_channel_assignments"] = "logical-channel-assignments"
                self._children_yang_names.add("logical-channel-assignments")


            class LogicalChannelAssignments(Entity):
                """
                Client port logical channel assignment
                
                .. attribute:: logical_channel_assignment
                
                	Logical channel assignment id
                	**type**\: list of    :py:class:`LogicalChannelAssignment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments.LogicalChannelAssignment>`
                
                

                """

                _prefix = 'openconfig-optical-client-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments, self).__init__()

                    self.yang_name = "logical-channel-assignments"
                    self.yang_parent_name = "client-port"

                    self.logical_channel_assignment = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments, self).__setattr__(name, value)


                class LogicalChannelAssignment(Entity):
                    """
                    Logical channel assignment id
                    
                    .. attribute:: assignment_index  <key>
                    
                    	Logical channel assignment id
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: allocation
                    
                    	Configure Allocation for this assignment(10, 40 or 100G)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: description
                    
                    	Configure description for this assignment
                    	**type**\:  str
                    
                    	**length:** 1..255
                    
                    .. attribute:: logical_channel_id
                    
                    	Configure Logical channel for this assignment
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'openconfig-optical-client-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments.LogicalChannelAssignment, self).__init__()

                        self.yang_name = "logical-channel-assignment"
                        self.yang_parent_name = "logical-channel-assignments"

                        self.assignment_index = YLeaf(YType.int32, "assignment-index")

                        self.allocation = YLeaf(YType.int32, "allocation")

                        self.description = YLeaf(YType.str, "description")

                        self.logical_channel_id = YLeaf(YType.int32, "logical-channel-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("assignment_index",
                                        "allocation",
                                        "description",
                                        "logical_channel_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments.LogicalChannelAssignment, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments.LogicalChannelAssignment, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.assignment_index.is_set or
                            self.allocation.is_set or
                            self.description.is_set or
                            self.logical_channel_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.assignment_index.yfilter != YFilter.not_set or
                            self.allocation.yfilter != YFilter.not_set or
                            self.description.yfilter != YFilter.not_set or
                            self.logical_channel_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "logical-channel-assignment" + "[assignment-index='" + self.assignment_index.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.assignment_index.is_set or self.assignment_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assignment_index.get_name_leafdata())
                        if (self.allocation.is_set or self.allocation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocation.get_name_leafdata())
                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.description.get_name_leafdata())
                        if (self.logical_channel_id.is_set or self.logical_channel_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.logical_channel_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "assignment-index" or name == "allocation" or name == "description" or name == "logical-channel-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "assignment-index"):
                            self.assignment_index = value
                            self.assignment_index.value_namespace = name_space
                            self.assignment_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "allocation"):
                            self.allocation = value
                            self.allocation.value_namespace = name_space
                            self.allocation.value_namespace_prefix = name_space_prefix
                        if(value_path == "description"):
                            self.description = value
                            self.description.value_namespace = name_space
                            self.description.value_namespace_prefix = name_space_prefix
                        if(value_path == "logical-channel-id"):
                            self.logical_channel_id = value
                            self.logical_channel_id.value_namespace = name_space
                            self.logical_channel_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.logical_channel_assignment:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.logical_channel_assignment:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "logical-channel-assignments" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "logical-channel-assignment"):
                        for c in self.logical_channel_assignment:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments.LogicalChannelAssignment()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.logical_channel_assignment.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "logical-channel-assignment"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Channels(Entity):
                """
                Client Port Lane
                
                .. attribute:: channel
                
                	Lane
                	**type**\: list of    :py:class:`Channel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels.Channel>`
                
                

                """

                _prefix = 'openconfig-optical-client-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels, self).__init__()

                    self.yang_name = "channels"
                    self.yang_parent_name = "client-port"

                    self.channel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels, self).__setattr__(name, value)


                class Channel(Entity):
                    """
                    Lane
                    
                    .. attribute:: index  <key>
                    
                    	Channel Number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: channel_description
                    
                    	Configure description for this Lane
                    	**type**\:  str
                    
                    	**length:** 1..255
                    
                    

                    """

                    _prefix = 'openconfig-optical-client-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels.Channel, self).__init__()

                        self.yang_name = "channel"
                        self.yang_parent_name = "channels"

                        self.index = YLeaf(YType.int32, "index")

                        self.channel_description = YLeaf(YType.str, "channel-description")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("index",
                                        "channel_description") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels.Channel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels.Channel, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.index.is_set or
                            self.channel_description.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.index.yfilter != YFilter.not_set or
                            self.channel_description.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "channel" + "[index='" + self.index.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.index.get_name_leafdata())
                        if (self.channel_description.is_set or self.channel_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.channel_description.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "index" or name == "channel-description"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "index"):
                            self.index = value
                            self.index.value_namespace = name_space
                            self.index.value_namespace_prefix = name_space_prefix
                        if(value_path == "channel-description"):
                            self.channel_description = value
                            self.channel_description.value_namespace = name_space
                            self.channel_description.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.channel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.channel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "channels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "channel"):
                        for c in self.channel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels.Channel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.channel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "channel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.channels is not None and self.channels.has_data()) or
                    (self.logical_channel_assignments is not None and self.logical_channel_assignments.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.channels is not None and self.channels.has_operation()) or
                    (self.logical_channel_assignments is not None and self.logical_channel_assignments.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-openconfig-optical-client-cfg:client-port" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "channels"):
                    if (self.channels is None):
                        self.channels = InterfaceConfigurations.InterfaceConfiguration.ClientPort.Channels()
                        self.channels.parent = self
                        self._children_name_map["channels"] = "channels"
                    return self.channels

                if (child_yang_name == "logical-channel-assignments"):
                    if (self.logical_channel_assignments is None):
                        self.logical_channel_assignments = InterfaceConfigurations.InterfaceConfiguration.ClientPort.LogicalChannelAssignments()
                        self.logical_channel_assignments.parent = self
                        self._children_name_map["logical_channel_assignments"] = "logical-channel-assignments"
                    return self.logical_channel_assignments

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "channels" or name == "logical-channel-assignments"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Pbr(Entity):
            """
            Interface PBR configuration
            
            .. attribute:: service_policy
            
            	PBR service policy configuration
            	**type**\:   :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy>`
            
            .. attribute:: service_policy_in
            
            	Class for subscriber ingress policy
            	**type**\:  str
            
            

            """

            _prefix = 'pbr-cfg'
            _revision = '2016-03-08'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Pbr, self).__init__()

                self.yang_name = "pbr"
                self.yang_parent_name = "interface-configuration"

                self.service_policy_in = YLeaf(YType.str, "service-policy-in")

                self.service_policy = InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"
                self._children_yang_names.add("service-policy")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("service_policy_in") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Pbr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Pbr, self).__setattr__(name, value)


            class ServicePolicy(Entity):
                """
                PBR service policy configuration
                
                .. attribute:: input
                
                	Ingress service policy
                	**type**\:  str
                
                

                """

                _prefix = 'pbr-cfg'
                _revision = '2016-03-08'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "pbr"

                    self.input = YLeaf(YType.str, "input")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("input") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy, self).__setattr__(name, value)

                def has_data(self):
                    return self.input.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.input.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "service-policy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.input.is_set or self.input.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "input"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "input"):
                        self.input = value
                        self.input.value_namespace = name_space
                        self.input.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.service_policy_in.is_set or
                    (self.service_policy is not None and self.service_policy.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.service_policy_in.yfilter != YFilter.not_set or
                    (self.service_policy is not None and self.service_policy.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-pbr-cfg:pbr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.service_policy_in.is_set or self.service_policy_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.service_policy_in.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "service-policy"):
                    if (self.service_policy is None):
                        self.service_policy = InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy()
                        self.service_policy.parent = self
                        self._children_name_map["service_policy"] = "service-policy"
                    return self.service_policy

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "service-policy" or name == "service-policy-in"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "service-policy-in"):
                    self.service_policy_in = value
                    self.service_policy_in.value_namespace = name_space
                    self.service_policy_in.value_namespace_prefix = name_space_prefix


        class PerformanceManagement(Entity):
            """
            Configure pm parameters
            
            .. attribute:: ethernet_hour24
            
            	Configure pm parameters of 24 hour interval
            	**type**\:   :py:class:`EthernetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24>`
            
            .. attribute:: ethernet_minute15
            
            	set opr min threshold
            	**type**\:   :py:class:`EthernetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15>`
            
            .. attribute:: ethernet_second30
            
            	Configure ethernet performance monitoring for 30 sec
            	**type**\:   :py:class:`EthernetSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30>`
            
            .. attribute:: ho_vc_hour24
            
            	set HO\_VC threshold
            	**type**\:   :py:class:`HoVcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24>`
            
            .. attribute:: ho_vc_minute15
            
            	set HO\_VC threshold
            	**type**\:   :py:class:`HoVcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15>`
            
            .. attribute:: hour24
            
            	Configure pm parameters of 24 hour interval
            	**type**\:   :py:class:`Hour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24>`
            
            .. attribute:: hour24_gfp
            
            	Configure pm parameters of gfp 24 hour interval
            	**type**\:   :py:class:`Hour24Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp>`
            
            .. attribute:: hour24_path
            
            	Configure pm parameters of pathmonitor 24 hour interval
            	**type**\:   :py:class:`Hour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path>`
            
            .. attribute:: hour24otn_tcms
            
            	Configure pm parameters of tcm's 24 hour interval
            	**type**\:   :py:class:`Hour24OtnTcms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms>`
            
            .. attribute:: minute15
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15>`
            
            .. attribute:: minute15_gfp
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp>`
            
            .. attribute:: minute15_path
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path>`
            
            .. attribute:: minute15otn_tcms
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15OtnTcms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms>`
            
            .. attribute:: oc_hour24
            
            	set Oc threshold
            	**type**\:   :py:class:`OcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24>`
            
            .. attribute:: oc_minute15
            
            	set OC threshold
            	**type**\:   :py:class:`OcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15>`
            
            .. attribute:: second30
            
            	Configure optics performance monitoring for 30 sec
            	**type**\:   :py:class:`Second30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30>`
            
            .. attribute:: sonet_hour24
            
            	set Sonet threshold
            	**type**\:   :py:class:`SonetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24>`
            
            .. attribute:: sonet_minute15
            
            	set Sonet threshold
            	**type**\:   :py:class:`SonetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15>`
            
            .. attribute:: stm_hour24
            
            	set STM threshold
            	**type**\:   :py:class:`StmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24>`
            
            .. attribute:: stm_minute15
            
            	set STM threshold
            	**type**\:   :py:class:`StmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15>`
            
            .. attribute:: sts_hour24
            
            	set STS threshold
            	**type**\:   :py:class:`StsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24>`
            
            .. attribute:: sts_minute15
            
            	set STS threshold
            	**type**\:   :py:class:`StsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15>`
            
            

            """

            _prefix = 'pmengine-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement, self).__init__()

                self.yang_name = "performance-management"
                self.yang_parent_name = "interface-configuration"

                self.ethernet_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24()
                self.ethernet_hour24.parent = self
                self._children_name_map["ethernet_hour24"] = "ethernet-hour24"
                self._children_yang_names.add("ethernet-hour24")

                self.ethernet_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15()
                self.ethernet_minute15.parent = self
                self._children_name_map["ethernet_minute15"] = "ethernet-minute15"
                self._children_yang_names.add("ethernet-minute15")

                self.ethernet_second30 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30()
                self.ethernet_second30.parent = self
                self._children_name_map["ethernet_second30"] = "ethernet-second30"
                self._children_yang_names.add("ethernet-second30")

                self.ho_vc_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24()
                self.ho_vc_hour24.parent = self
                self._children_name_map["ho_vc_hour24"] = "ho-vc-hour24"
                self._children_yang_names.add("ho-vc-hour24")

                self.ho_vc_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15()
                self.ho_vc_minute15.parent = self
                self._children_name_map["ho_vc_minute15"] = "ho-vc-minute15"
                self._children_yang_names.add("ho-vc-minute15")

                self.hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24()
                self.hour24.parent = self
                self._children_name_map["hour24"] = "hour24"
                self._children_yang_names.add("hour24")

                self.hour24_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp()
                self.hour24_gfp.parent = self
                self._children_name_map["hour24_gfp"] = "hour24-gfp"
                self._children_yang_names.add("hour24-gfp")

                self.hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path()
                self.hour24_path.parent = self
                self._children_name_map["hour24_path"] = "hour24-path"
                self._children_yang_names.add("hour24-path")

                self.hour24otn_tcms = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms()
                self.hour24otn_tcms.parent = self
                self._children_name_map["hour24otn_tcms"] = "hour24otn-tcms"
                self._children_yang_names.add("hour24otn-tcms")

                self.minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15()
                self.minute15.parent = self
                self._children_name_map["minute15"] = "minute15"
                self._children_yang_names.add("minute15")

                self.minute15_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp()
                self.minute15_gfp.parent = self
                self._children_name_map["minute15_gfp"] = "minute15-gfp"
                self._children_yang_names.add("minute15-gfp")

                self.minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path()
                self.minute15_path.parent = self
                self._children_name_map["minute15_path"] = "minute15-path"
                self._children_yang_names.add("minute15-path")

                self.minute15otn_tcms = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms()
                self.minute15otn_tcms.parent = self
                self._children_name_map["minute15otn_tcms"] = "minute15otn-tcms"
                self._children_yang_names.add("minute15otn-tcms")

                self.oc_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24()
                self.oc_hour24.parent = self
                self._children_name_map["oc_hour24"] = "oc-hour24"
                self._children_yang_names.add("oc-hour24")

                self.oc_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15()
                self.oc_minute15.parent = self
                self._children_name_map["oc_minute15"] = "oc-minute15"
                self._children_yang_names.add("oc-minute15")

                self.second30 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30()
                self.second30.parent = self
                self._children_name_map["second30"] = "second30"
                self._children_yang_names.add("second30")

                self.sonet_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24()
                self.sonet_hour24.parent = self
                self._children_name_map["sonet_hour24"] = "sonet-hour24"
                self._children_yang_names.add("sonet-hour24")

                self.sonet_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15()
                self.sonet_minute15.parent = self
                self._children_name_map["sonet_minute15"] = "sonet-minute15"
                self._children_yang_names.add("sonet-minute15")

                self.stm_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24()
                self.stm_hour24.parent = self
                self._children_name_map["stm_hour24"] = "stm-hour24"
                self._children_yang_names.add("stm-hour24")

                self.stm_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15()
                self.stm_minute15.parent = self
                self._children_name_map["stm_minute15"] = "stm-minute15"
                self._children_yang_names.add("stm-minute15")

                self.sts_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24()
                self.sts_hour24.parent = self
                self._children_name_map["sts_hour24"] = "sts-hour24"
                self._children_yang_names.add("sts-hour24")

                self.sts_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15()
                self.sts_minute15.parent = self
                self._children_name_map["sts_minute15"] = "sts-minute15"
                self._children_yang_names.add("sts-minute15")


            class StmHour24(Entity):
                """
                set STM threshold
                
                .. attribute:: stm_hour24_stm
                
                	Configure stm performance monitoring
                	**type**\:   :py:class:`StmHour24Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24, self).__init__()

                    self.yang_name = "stm-hour24"
                    self.yang_parent_name = "performance-management"

                    self.stm_hour24_stm = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm()
                    self.stm_hour24_stm.parent = self
                    self._children_name_map["stm_hour24_stm"] = "stm-hour24-stm"
                    self._children_yang_names.add("stm-hour24-stm")


                class StmHour24Stm(Entity):
                    """
                    Configure stm performance monitoring
                    
                    .. attribute:: stm_hour24_stm_reports
                    
                    	set stm TCA reporting status
                    	**type**\:   :py:class:`StmHour24StmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports>`
                    
                    .. attribute:: stm_hour24_stm_thresholds
                    
                    	Configure threshold on stm parameters
                    	**type**\:   :py:class:`StmHour24StmThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm, self).__init__()

                        self.yang_name = "stm-hour24-stm"
                        self.yang_parent_name = "stm-hour24"

                        self.stm_hour24_stm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports()
                        self.stm_hour24_stm_reports.parent = self
                        self._children_name_map["stm_hour24_stm_reports"] = "stm-hour24-stm-reports"
                        self._children_yang_names.add("stm-hour24-stm-reports")

                        self.stm_hour24_stm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds()
                        self.stm_hour24_stm_thresholds.parent = self
                        self._children_name_map["stm_hour24_stm_thresholds"] = "stm-hour24-stm-thresholds"
                        self._children_yang_names.add("stm-hour24-stm-thresholds")


                    class StmHour24StmReports(Entity):
                        """
                        set stm TCA reporting status
                        
                        .. attribute:: stm_hour24_stm_report
                        
                        	none
                        	**type**\: list of    :py:class:`StmHour24StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports, self).__init__()

                            self.yang_name = "stm-hour24-stm-reports"
                            self.yang_parent_name = "stm-hour24-stm"

                            self.stm_hour24_stm_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports, self).__setattr__(name, value)


                        class StmHour24StmReport(Entity):
                            """
                            none
                            
                            .. attribute:: stm_report  <key>
                            
                            	Stm Report Type
                            	**type**\:   :py:class:`StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmReport>`
                            
                            .. attribute:: enable
                            
                            	Stm Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport, self).__init__()

                                self.yang_name = "stm-hour24-stm-report"
                                self.yang_parent_name = "stm-hour24-stm-reports"

                                self.stm_report = YLeaf(YType.enumeration, "stm-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("stm_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.stm_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.stm_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-hour24-stm-report" + "[stm-report='" + self.stm_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.stm_report.is_set or self.stm_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stm_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "stm-report"):
                                    self.stm_report = value
                                    self.stm_report.value_namespace = name_space
                                    self.stm_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.stm_hour24_stm_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.stm_hour24_stm_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-hour24-stm-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-hour24-stm-report"):
                                for c in self.stm_hour24_stm_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.stm_hour24_stm_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-hour24-stm-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StmHour24StmThresholds(Entity):
                        """
                        Configure threshold on stm parameters
                        
                        .. attribute:: stm_hour24_stm_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StmHour24StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds, self).__init__()

                            self.yang_name = "stm-hour24-stm-thresholds"
                            self.yang_parent_name = "stm-hour24-stm"

                            self.stm_hour24_stm_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds, self).__setattr__(name, value)


                        class StmHour24StmThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: stm_threshold  <key>
                            
                            	Stm Threshold Type
                            	**type**\:   :py:class:`StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmThreshold>`
                            
                            .. attribute:: stm_threshold_value
                            
                            	Stm Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold, self).__init__()

                                self.yang_name = "stm-hour24-stm-threshold"
                                self.yang_parent_name = "stm-hour24-stm-thresholds"

                                self.stm_threshold = YLeaf(YType.enumeration, "stm-threshold")

                                self.stm_threshold_value = YLeaf(YType.int32, "stm-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("stm_threshold",
                                                "stm_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.stm_threshold.is_set or
                                    self.stm_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.stm_threshold.yfilter != YFilter.not_set or
                                    self.stm_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-hour24-stm-threshold" + "[stm-threshold='" + self.stm_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.stm_threshold.is_set or self.stm_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stm_threshold.get_name_leafdata())
                                if (self.stm_threshold_value.is_set or self.stm_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stm_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-threshold" or name == "stm-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "stm-threshold"):
                                    self.stm_threshold = value
                                    self.stm_threshold.value_namespace = name_space
                                    self.stm_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "stm-threshold-value"):
                                    self.stm_threshold_value = value
                                    self.stm_threshold_value.value_namespace = name_space
                                    self.stm_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.stm_hour24_stm_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.stm_hour24_stm_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-hour24-stm-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-hour24-stm-threshold"):
                                for c in self.stm_hour24_stm_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.stm_hour24_stm_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-hour24-stm-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.stm_hour24_stm_reports is not None and self.stm_hour24_stm_reports.has_data()) or
                            (self.stm_hour24_stm_thresholds is not None and self.stm_hour24_stm_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.stm_hour24_stm_reports is not None and self.stm_hour24_stm_reports.has_operation()) or
                            (self.stm_hour24_stm_thresholds is not None and self.stm_hour24_stm_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "stm-hour24-stm" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "stm-hour24-stm-reports"):
                            if (self.stm_hour24_stm_reports is None):
                                self.stm_hour24_stm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports()
                                self.stm_hour24_stm_reports.parent = self
                                self._children_name_map["stm_hour24_stm_reports"] = "stm-hour24-stm-reports"
                            return self.stm_hour24_stm_reports

                        if (child_yang_name == "stm-hour24-stm-thresholds"):
                            if (self.stm_hour24_stm_thresholds is None):
                                self.stm_hour24_stm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds()
                                self.stm_hour24_stm_thresholds.parent = self
                                self._children_name_map["stm_hour24_stm_thresholds"] = "stm-hour24-stm-thresholds"
                            return self.stm_hour24_stm_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "stm-hour24-stm-reports" or name == "stm-hour24-stm-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.stm_hour24_stm is not None and self.stm_hour24_stm.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.stm_hour24_stm is not None and self.stm_hour24_stm.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "stm-hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "stm-hour24-stm"):
                        if (self.stm_hour24_stm is None):
                            self.stm_hour24_stm = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm()
                            self.stm_hour24_stm.parent = self
                            self._children_name_map["stm_hour24_stm"] = "stm-hour24-stm"
                        return self.stm_hour24_stm

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "stm-hour24-stm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Minute15Gfp(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15_gfp
                
                	Configure gfp performance monitoring
                	**type**\:   :py:class:`Minute15Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp, self).__init__()

                    self.yang_name = "minute15-gfp"
                    self.yang_parent_name = "performance-management"

                    self.minute15_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp()
                    self.minute15_gfp.parent = self
                    self._children_name_map["minute15_gfp"] = "minute15-gfp"
                    self._children_yang_names.add("minute15-gfp")


                class Minute15Gfp(Entity):
                    """
                    Configure gfp performance monitoring
                    
                    .. attribute:: minute15_gfp_reports
                    
                    	set gfp TCA reporting status
                    	**type**\:   :py:class:`Minute15GfpReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports>`
                    
                    .. attribute:: minute15_gfp_thresholds
                    
                    	Configure threshold on gfp parameters
                    	**type**\:   :py:class:`Minute15GfpThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp, self).__init__()

                        self.yang_name = "minute15-gfp"
                        self.yang_parent_name = "minute15-gfp"

                        self.minute15_gfp_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports()
                        self.minute15_gfp_reports.parent = self
                        self._children_name_map["minute15_gfp_reports"] = "minute15-gfp-reports"
                        self._children_yang_names.add("minute15-gfp-reports")

                        self.minute15_gfp_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds()
                        self.minute15_gfp_thresholds.parent = self
                        self._children_name_map["minute15_gfp_thresholds"] = "minute15-gfp-thresholds"
                        self._children_yang_names.add("minute15-gfp-thresholds")


                    class Minute15GfpReports(Entity):
                        """
                        set gfp TCA reporting status
                        
                        .. attribute:: minute15_gfp_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports, self).__init__()

                            self.yang_name = "minute15-gfp-reports"
                            self.yang_parent_name = "minute15-gfp"

                            self.minute15_gfp_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports, self).__setattr__(name, value)


                        class Minute15GfpReport(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_report  <key>
                            
                            	Gfp Report Type
                            	**type**\:   :py:class:`GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport, self).__init__()

                                self.yang_name = "minute15-gfp-report"
                                self.yang_parent_name = "minute15-gfp-reports"

                                self.gfp_report = YLeaf(YType.enumeration, "gfp-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("gfp_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.gfp_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.gfp_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-gfp-report" + "[gfp-report='" + self.gfp_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.gfp_report.is_set or self.gfp_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gfp_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gfp-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "gfp-report"):
                                    self.gfp_report = value
                                    self.gfp_report.value_namespace = name_space
                                    self.gfp_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15_gfp_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15_gfp_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15-gfp-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-gfp-report"):
                                for c in self.minute15_gfp_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15_gfp_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-gfp-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15GfpThresholds(Entity):
                        """
                        Configure threshold on gfp parameters
                        
                        .. attribute:: minute15_gfp_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds, self).__init__()

                            self.yang_name = "minute15-gfp-thresholds"
                            self.yang_parent_name = "minute15-gfp"

                            self.minute15_gfp_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds, self).__setattr__(name, value)


                        class Minute15GfpThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_threshold  <key>
                            
                            	Gfp Threshold Type
                            	**type**\:   :py:class:`GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpThreshold>`
                            
                            .. attribute:: gfp_threshold_value
                            
                            	Gfp Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold, self).__init__()

                                self.yang_name = "minute15-gfp-threshold"
                                self.yang_parent_name = "minute15-gfp-thresholds"

                                self.gfp_threshold = YLeaf(YType.enumeration, "gfp-threshold")

                                self.gfp_threshold_value = YLeaf(YType.int32, "gfp-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("gfp_threshold",
                                                "gfp_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.gfp_threshold.is_set or
                                    self.gfp_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.gfp_threshold.yfilter != YFilter.not_set or
                                    self.gfp_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-gfp-threshold" + "[gfp-threshold='" + self.gfp_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.gfp_threshold.is_set or self.gfp_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gfp_threshold.get_name_leafdata())
                                if (self.gfp_threshold_value.is_set or self.gfp_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gfp_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gfp-threshold" or name == "gfp-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "gfp-threshold"):
                                    self.gfp_threshold = value
                                    self.gfp_threshold.value_namespace = name_space
                                    self.gfp_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "gfp-threshold-value"):
                                    self.gfp_threshold_value = value
                                    self.gfp_threshold_value.value_namespace = name_space
                                    self.gfp_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15_gfp_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15_gfp_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15-gfp-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-gfp-threshold"):
                                for c in self.minute15_gfp_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15_gfp_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-gfp-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.minute15_gfp_reports is not None and self.minute15_gfp_reports.has_data()) or
                            (self.minute15_gfp_thresholds is not None and self.minute15_gfp_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.minute15_gfp_reports is not None and self.minute15_gfp_reports.has_operation()) or
                            (self.minute15_gfp_thresholds is not None and self.minute15_gfp_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15-gfp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "minute15-gfp-reports"):
                            if (self.minute15_gfp_reports is None):
                                self.minute15_gfp_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports()
                                self.minute15_gfp_reports.parent = self
                                self._children_name_map["minute15_gfp_reports"] = "minute15-gfp-reports"
                            return self.minute15_gfp_reports

                        if (child_yang_name == "minute15-gfp-thresholds"):
                            if (self.minute15_gfp_thresholds is None):
                                self.minute15_gfp_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds()
                                self.minute15_gfp_thresholds.parent = self
                                self._children_name_map["minute15_gfp_thresholds"] = "minute15-gfp-thresholds"
                            return self.minute15_gfp_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "minute15-gfp-reports" or name == "minute15-gfp-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.minute15_gfp is not None and self.minute15_gfp.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.minute15_gfp is not None and self.minute15_gfp.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "minute15-gfp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "minute15-gfp"):
                        if (self.minute15_gfp is None):
                            self.minute15_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp()
                            self.minute15_gfp.parent = self
                            self._children_name_map["minute15_gfp"] = "minute15-gfp"
                        return self.minute15_gfp

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "minute15-gfp"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SonetMinute15(Entity):
                """
                set Sonet threshold
                
                .. attribute:: sonet_minute15_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`SonetMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn>`
                
                .. attribute:: sonet_minute15_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`SonetMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15, self).__init__()

                    self.yang_name = "sonet-minute15"
                    self.yang_parent_name = "performance-management"

                    self.sonet_minute15_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn()
                    self.sonet_minute15_ocn.parent = self
                    self._children_name_map["sonet_minute15_ocn"] = "sonet-minute15-ocn"
                    self._children_yang_names.add("sonet-minute15-ocn")

                    self.sonet_minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path()
                    self.sonet_minute15_path.parent = self
                    self._children_name_map["sonet_minute15_path"] = "sonet-minute15-path"
                    self._children_yang_names.add("sonet-minute15-path")


                class SonetMinute15Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sonet_minute15_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`SonetMinute15PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports>`
                    
                    .. attribute:: sonet_minute15_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`SonetMinute15PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path, self).__init__()

                        self.yang_name = "sonet-minute15-path"
                        self.yang_parent_name = "sonet-minute15"

                        self.sonet_minute15_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports()
                        self.sonet_minute15_path_reports.parent = self
                        self._children_name_map["sonet_minute15_path_reports"] = "sonet-minute15-path-reports"
                        self._children_yang_names.add("sonet-minute15-path-reports")

                        self.sonet_minute15_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds()
                        self.sonet_minute15_path_thresholds.parent = self
                        self._children_name_map["sonet_minute15_path_thresholds"] = "sonet-minute15-path-thresholds"
                        self._children_yang_names.add("sonet-minute15-path-thresholds")


                    class SonetMinute15PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sonet_minute15_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports, self).__init__()

                            self.yang_name = "sonet-minute15-path-reports"
                            self.yang_parent_name = "sonet-minute15-path"

                            self.sonet_minute15_path_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports, self).__setattr__(name, value)


                        class SonetMinute15PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport, self).__init__()

                                self.yang_name = "sonet-minute15-path-report"
                                self.yang_parent_name = "sonet-minute15-path-reports"

                                self.path_report = YLeaf(YType.enumeration, "path-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.path_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15-path-report" + "[path-report='" + self.path_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_report.is_set or self.path_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-report"):
                                    self.path_report = value
                                    self.path_report.value_namespace = name_space
                                    self.path_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_minute15_path_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_minute15_path_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-minute15-path-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-minute15-path-report"):
                                for c in self.sonet_minute15_path_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_minute15_path_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-minute15-path-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SonetMinute15PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sonet_minute15_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds, self).__init__()

                            self.yang_name = "sonet-minute15-path-thresholds"
                            self.yang_parent_name = "sonet-minute15-path"

                            self.sonet_minute15_path_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds, self).__setattr__(name, value)


                        class SonetMinute15PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold, self).__init__()

                                self.yang_name = "sonet-minute15-path-threshold"
                                self.yang_parent_name = "sonet-minute15-path-thresholds"

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_threshold",
                                                "path_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path_threshold.is_set or
                                    self.path_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_threshold.yfilter != YFilter.not_set or
                                    self.path_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_threshold.is_set or self.path_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold.get_name_leafdata())
                                if (self.path_threshold_value.is_set or self.path_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-threshold" or name == "path-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-threshold"):
                                    self.path_threshold = value
                                    self.path_threshold.value_namespace = name_space
                                    self.path_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-threshold-value"):
                                    self.path_threshold_value = value
                                    self.path_threshold_value.value_namespace = name_space
                                    self.path_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_minute15_path_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_minute15_path_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-minute15-path-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-minute15-path-threshold"):
                                for c in self.sonet_minute15_path_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_minute15_path_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-minute15-path-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sonet_minute15_path_reports is not None and self.sonet_minute15_path_reports.has_data()) or
                            (self.sonet_minute15_path_thresholds is not None and self.sonet_minute15_path_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sonet_minute15_path_reports is not None and self.sonet_minute15_path_reports.has_operation()) or
                            (self.sonet_minute15_path_thresholds is not None and self.sonet_minute15_path_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sonet-minute15-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sonet-minute15-path-reports"):
                            if (self.sonet_minute15_path_reports is None):
                                self.sonet_minute15_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports()
                                self.sonet_minute15_path_reports.parent = self
                                self._children_name_map["sonet_minute15_path_reports"] = "sonet-minute15-path-reports"
                            return self.sonet_minute15_path_reports

                        if (child_yang_name == "sonet-minute15-path-thresholds"):
                            if (self.sonet_minute15_path_thresholds is None):
                                self.sonet_minute15_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds()
                                self.sonet_minute15_path_thresholds.parent = self
                                self._children_name_map["sonet_minute15_path_thresholds"] = "sonet-minute15-path-thresholds"
                            return self.sonet_minute15_path_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sonet-minute15-path-reports" or name == "sonet-minute15-path-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SonetMinute15Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: sonet_minute15_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`SonetMinute15OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports>`
                    
                    .. attribute:: sonet_minute15_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`SonetMinute15OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn, self).__init__()

                        self.yang_name = "sonet-minute15-ocn"
                        self.yang_parent_name = "sonet-minute15"

                        self.sonet_minute15_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports()
                        self.sonet_minute15_ocn_reports.parent = self
                        self._children_name_map["sonet_minute15_ocn_reports"] = "sonet-minute15-ocn-reports"
                        self._children_yang_names.add("sonet-minute15-ocn-reports")

                        self.sonet_minute15_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds()
                        self.sonet_minute15_ocn_thresholds.parent = self
                        self._children_name_map["sonet_minute15_ocn_thresholds"] = "sonet-minute15-ocn-thresholds"
                        self._children_yang_names.add("sonet-minute15-ocn-thresholds")


                    class SonetMinute15OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: sonet_minute15_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports, self).__init__()

                            self.yang_name = "sonet-minute15-ocn-reports"
                            self.yang_parent_name = "sonet-minute15-ocn"

                            self.sonet_minute15_ocn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports, self).__setattr__(name, value)


                        class SonetMinute15OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport, self).__init__()

                                self.yang_name = "sonet-minute15-ocn-report"
                                self.yang_parent_name = "sonet-minute15-ocn-reports"

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.ocn_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_report.is_set or self.ocn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-report"):
                                    self.ocn_report = value
                                    self.ocn_report.value_namespace = name_space
                                    self.ocn_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_minute15_ocn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_minute15_ocn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-minute15-ocn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-minute15-ocn-report"):
                                for c in self.sonet_minute15_ocn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_minute15_ocn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-minute15-ocn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SonetMinute15OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: sonet_minute15_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds, self).__init__()

                            self.yang_name = "sonet-minute15-ocn-thresholds"
                            self.yang_parent_name = "sonet-minute15-ocn"

                            self.sonet_minute15_ocn_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds, self).__setattr__(name, value)


                        class SonetMinute15OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold, self).__init__()

                                self.yang_name = "sonet-minute15-ocn-threshold"
                                self.yang_parent_name = "sonet-minute15-ocn-thresholds"

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_threshold",
                                                "ocn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ocn_threshold.is_set or
                                    self.ocn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_threshold.yfilter != YFilter.not_set or
                                    self.ocn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_threshold.is_set or self.ocn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold.get_name_leafdata())
                                if (self.ocn_threshold_value.is_set or self.ocn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-threshold" or name == "ocn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-threshold"):
                                    self.ocn_threshold = value
                                    self.ocn_threshold.value_namespace = name_space
                                    self.ocn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ocn-threshold-value"):
                                    self.ocn_threshold_value = value
                                    self.ocn_threshold_value.value_namespace = name_space
                                    self.ocn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_minute15_ocn_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_minute15_ocn_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-minute15-ocn-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-minute15-ocn-threshold"):
                                for c in self.sonet_minute15_ocn_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_minute15_ocn_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-minute15-ocn-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sonet_minute15_ocn_reports is not None and self.sonet_minute15_ocn_reports.has_data()) or
                            (self.sonet_minute15_ocn_thresholds is not None and self.sonet_minute15_ocn_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sonet_minute15_ocn_reports is not None and self.sonet_minute15_ocn_reports.has_operation()) or
                            (self.sonet_minute15_ocn_thresholds is not None and self.sonet_minute15_ocn_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sonet-minute15-ocn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sonet-minute15-ocn-reports"):
                            if (self.sonet_minute15_ocn_reports is None):
                                self.sonet_minute15_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports()
                                self.sonet_minute15_ocn_reports.parent = self
                                self._children_name_map["sonet_minute15_ocn_reports"] = "sonet-minute15-ocn-reports"
                            return self.sonet_minute15_ocn_reports

                        if (child_yang_name == "sonet-minute15-ocn-thresholds"):
                            if (self.sonet_minute15_ocn_thresholds is None):
                                self.sonet_minute15_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds()
                                self.sonet_minute15_ocn_thresholds.parent = self
                                self._children_name_map["sonet_minute15_ocn_thresholds"] = "sonet-minute15-ocn-thresholds"
                            return self.sonet_minute15_ocn_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sonet-minute15-ocn-reports" or name == "sonet-minute15-ocn-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.sonet_minute15_ocn is not None and self.sonet_minute15_ocn.has_data()) or
                        (self.sonet_minute15_path is not None and self.sonet_minute15_path.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.sonet_minute15_ocn is not None and self.sonet_minute15_ocn.has_operation()) or
                        (self.sonet_minute15_path is not None and self.sonet_minute15_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sonet-minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sonet-minute15-ocn"):
                        if (self.sonet_minute15_ocn is None):
                            self.sonet_minute15_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn()
                            self.sonet_minute15_ocn.parent = self
                            self._children_name_map["sonet_minute15_ocn"] = "sonet-minute15-ocn"
                        return self.sonet_minute15_ocn

                    if (child_yang_name == "sonet-minute15-path"):
                        if (self.sonet_minute15_path is None):
                            self.sonet_minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path()
                            self.sonet_minute15_path.parent = self
                            self._children_name_map["sonet_minute15_path"] = "sonet-minute15-path"
                        return self.sonet_minute15_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sonet-minute15-ocn" or name == "sonet-minute15-path"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Hour24Gfp(Entity):
                """
                Configure pm parameters of gfp 24 hour interval
                
                .. attribute:: hour24_gfp
                
                	Configure gfp performance monitoring
                	**type**\:   :py:class:`Hour24Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp, self).__init__()

                    self.yang_name = "hour24-gfp"
                    self.yang_parent_name = "performance-management"

                    self.hour24_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp()
                    self.hour24_gfp.parent = self
                    self._children_name_map["hour24_gfp"] = "hour24-gfp"
                    self._children_yang_names.add("hour24-gfp")


                class Hour24Gfp(Entity):
                    """
                    Configure gfp performance monitoring
                    
                    .. attribute:: hour24_gfp_reports
                    
                    	set gfp TCA reporting status
                    	**type**\:   :py:class:`Hour24GfpReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports>`
                    
                    .. attribute:: hour24_gfp_thresholds
                    
                    	Configure threshold on gfp parameters
                    	**type**\:   :py:class:`Hour24GfpThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp, self).__init__()

                        self.yang_name = "hour24-gfp"
                        self.yang_parent_name = "hour24-gfp"

                        self.hour24_gfp_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports()
                        self.hour24_gfp_reports.parent = self
                        self._children_name_map["hour24_gfp_reports"] = "hour24-gfp-reports"
                        self._children_yang_names.add("hour24-gfp-reports")

                        self.hour24_gfp_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds()
                        self.hour24_gfp_thresholds.parent = self
                        self._children_name_map["hour24_gfp_thresholds"] = "hour24-gfp-thresholds"
                        self._children_yang_names.add("hour24-gfp-thresholds")


                    class Hour24GfpReports(Entity):
                        """
                        set gfp TCA reporting status
                        
                        .. attribute:: hour24_gfp_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports, self).__init__()

                            self.yang_name = "hour24-gfp-reports"
                            self.yang_parent_name = "hour24-gfp"

                            self.hour24_gfp_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports, self).__setattr__(name, value)


                        class Hour24GfpReport(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_report  <key>
                            
                            	Gfp Report Type
                            	**type**\:   :py:class:`GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport, self).__init__()

                                self.yang_name = "hour24-gfp-report"
                                self.yang_parent_name = "hour24-gfp-reports"

                                self.gfp_report = YLeaf(YType.enumeration, "gfp-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("gfp_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.gfp_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.gfp_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24-gfp-report" + "[gfp-report='" + self.gfp_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.gfp_report.is_set or self.gfp_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gfp_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gfp-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "gfp-report"):
                                    self.gfp_report = value
                                    self.gfp_report.value_namespace = name_space
                                    self.gfp_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24_gfp_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24_gfp_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24-gfp-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24-gfp-report"):
                                for c in self.hour24_gfp_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24_gfp_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24-gfp-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24GfpThresholds(Entity):
                        """
                        Configure threshold on gfp parameters
                        
                        .. attribute:: hour24_gfp_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds, self).__init__()

                            self.yang_name = "hour24-gfp-thresholds"
                            self.yang_parent_name = "hour24-gfp"

                            self.hour24_gfp_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds, self).__setattr__(name, value)


                        class Hour24GfpThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_threshold  <key>
                            
                            	Gfp Threshold Type
                            	**type**\:   :py:class:`GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpThreshold>`
                            
                            .. attribute:: gfp_threshold_value
                            
                            	Gfp Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold, self).__init__()

                                self.yang_name = "hour24-gfp-threshold"
                                self.yang_parent_name = "hour24-gfp-thresholds"

                                self.gfp_threshold = YLeaf(YType.enumeration, "gfp-threshold")

                                self.gfp_threshold_value = YLeaf(YType.int32, "gfp-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("gfp_threshold",
                                                "gfp_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.gfp_threshold.is_set or
                                    self.gfp_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.gfp_threshold.yfilter != YFilter.not_set or
                                    self.gfp_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24-gfp-threshold" + "[gfp-threshold='" + self.gfp_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.gfp_threshold.is_set or self.gfp_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gfp_threshold.get_name_leafdata())
                                if (self.gfp_threshold_value.is_set or self.gfp_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gfp_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gfp-threshold" or name == "gfp-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "gfp-threshold"):
                                    self.gfp_threshold = value
                                    self.gfp_threshold.value_namespace = name_space
                                    self.gfp_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "gfp-threshold-value"):
                                    self.gfp_threshold_value = value
                                    self.gfp_threshold_value.value_namespace = name_space
                                    self.gfp_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24_gfp_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24_gfp_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24-gfp-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24-gfp-threshold"):
                                for c in self.hour24_gfp_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24_gfp_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24-gfp-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.hour24_gfp_reports is not None and self.hour24_gfp_reports.has_data()) or
                            (self.hour24_gfp_thresholds is not None and self.hour24_gfp_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.hour24_gfp_reports is not None and self.hour24_gfp_reports.has_operation()) or
                            (self.hour24_gfp_thresholds is not None and self.hour24_gfp_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24-gfp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24-gfp-reports"):
                            if (self.hour24_gfp_reports is None):
                                self.hour24_gfp_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports()
                                self.hour24_gfp_reports.parent = self
                                self._children_name_map["hour24_gfp_reports"] = "hour24-gfp-reports"
                            return self.hour24_gfp_reports

                        if (child_yang_name == "hour24-gfp-thresholds"):
                            if (self.hour24_gfp_thresholds is None):
                                self.hour24_gfp_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds()
                                self.hour24_gfp_thresholds.parent = self
                                self._children_name_map["hour24_gfp_thresholds"] = "hour24-gfp-thresholds"
                            return self.hour24_gfp_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24-gfp-reports" or name == "hour24-gfp-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.hour24_gfp is not None and self.hour24_gfp.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.hour24_gfp is not None and self.hour24_gfp.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hour24-gfp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "hour24-gfp"):
                        if (self.hour24_gfp is None):
                            self.hour24_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp()
                            self.hour24_gfp.parent = self
                            self._children_name_map["hour24_gfp"] = "hour24-gfp"
                        return self.hour24_gfp

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hour24-gfp"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EthernetHour24(Entity):
                """
                Configure pm parameters of 24 hour interval
                
                .. attribute:: hour24_ether
                
                	Configure ether performance monitoring
                	**type**\:   :py:class:`Hour24Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24, self).__init__()

                    self.yang_name = "ethernet-hour24"
                    self.yang_parent_name = "performance-management"

                    self.hour24_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether()
                    self.hour24_ether.parent = self
                    self._children_name_map["hour24_ether"] = "hour24-ether"
                    self._children_yang_names.add("hour24-ether")


                class Hour24Ether(Entity):
                    """
                    Configure ether performance monitoring
                    
                    .. attribute:: hour24_ether_reports
                    
                    	set ether TCA reporting status
                    	**type**\:   :py:class:`Hour24EtherReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports>`
                    
                    .. attribute:: hour24_ether_thresholds
                    
                    	Configure threshold on ether parameters
                    	**type**\:   :py:class:`Hour24EtherThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether, self).__init__()

                        self.yang_name = "hour24-ether"
                        self.yang_parent_name = "ethernet-hour24"

                        self.hour24_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports()
                        self.hour24_ether_reports.parent = self
                        self._children_name_map["hour24_ether_reports"] = "hour24-ether-reports"
                        self._children_yang_names.add("hour24-ether-reports")

                        self.hour24_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds()
                        self.hour24_ether_thresholds.parent = self
                        self._children_name_map["hour24_ether_thresholds"] = "hour24-ether-thresholds"
                        self._children_yang_names.add("hour24-ether-thresholds")


                    class Hour24EtherThresholds(Entity):
                        """
                        Configure threshold on ether parameters
                        
                        .. attribute:: hour24_ether_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds, self).__init__()

                            self.yang_name = "hour24-ether-thresholds"
                            self.yang_parent_name = "hour24-ether"

                            self.hour24_ether_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds, self).__setattr__(name, value)


                        class Hour24EtherThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ether_threshold  <key>
                            
                            	Ether Threshold Type
                            	**type**\:   :py:class:`EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherThreshold>`
                            
                            .. attribute:: ether_threshold_value
                            
                            	Ether Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold, self).__init__()

                                self.yang_name = "hour24-ether-threshold"
                                self.yang_parent_name = "hour24-ether-thresholds"

                                self.ether_threshold = YLeaf(YType.enumeration, "ether-threshold")

                                self.ether_threshold_value = YLeaf(YType.int32, "ether-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ether_threshold",
                                                "ether_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ether_threshold.is_set or
                                    self.ether_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ether_threshold.yfilter != YFilter.not_set or
                                    self.ether_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24-ether-threshold" + "[ether-threshold='" + self.ether_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ether_threshold.is_set or self.ether_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_threshold.get_name_leafdata())
                                if (self.ether_threshold_value.is_set or self.ether_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ether-threshold" or name == "ether-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ether-threshold"):
                                    self.ether_threshold = value
                                    self.ether_threshold.value_namespace = name_space
                                    self.ether_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ether-threshold-value"):
                                    self.ether_threshold_value = value
                                    self.ether_threshold_value.value_namespace = name_space
                                    self.ether_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24_ether_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24_ether_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24-ether-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24-ether-threshold"):
                                for c in self.hour24_ether_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24_ether_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24-ether-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24EtherReports(Entity):
                        """
                        set ether TCA reporting status
                        
                        .. attribute:: hour24_ether_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports, self).__init__()

                            self.yang_name = "hour24-ether-reports"
                            self.yang_parent_name = "hour24-ether"

                            self.hour24_ether_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports, self).__setattr__(name, value)


                        class Hour24EtherReport(Entity):
                            """
                            none
                            
                            .. attribute:: ether_report  <key>
                            
                            	Ether Report Type
                            	**type**\:   :py:class:`EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport, self).__init__()

                                self.yang_name = "hour24-ether-report"
                                self.yang_parent_name = "hour24-ether-reports"

                                self.ether_report = YLeaf(YType.enumeration, "ether-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ether_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.ether_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ether_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24-ether-report" + "[ether-report='" + self.ether_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ether_report.is_set or self.ether_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ether-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ether-report"):
                                    self.ether_report = value
                                    self.ether_report.value_namespace = name_space
                                    self.ether_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24_ether_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24_ether_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24-ether-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24-ether-report"):
                                for c in self.hour24_ether_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24_ether_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24-ether-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.hour24_ether_reports is not None and self.hour24_ether_reports.has_data()) or
                            (self.hour24_ether_thresholds is not None and self.hour24_ether_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.hour24_ether_reports is not None and self.hour24_ether_reports.has_operation()) or
                            (self.hour24_ether_thresholds is not None and self.hour24_ether_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24-ether" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24-ether-reports"):
                            if (self.hour24_ether_reports is None):
                                self.hour24_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports()
                                self.hour24_ether_reports.parent = self
                                self._children_name_map["hour24_ether_reports"] = "hour24-ether-reports"
                            return self.hour24_ether_reports

                        if (child_yang_name == "hour24-ether-thresholds"):
                            if (self.hour24_ether_thresholds is None):
                                self.hour24_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds()
                                self.hour24_ether_thresholds.parent = self
                                self._children_name_map["hour24_ether_thresholds"] = "hour24-ether-thresholds"
                            return self.hour24_ether_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24-ether-reports" or name == "hour24-ether-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.hour24_ether is not None and self.hour24_ether.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.hour24_ether is not None and self.hour24_ether.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ethernet-hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "hour24-ether"):
                        if (self.hour24_ether is None):
                            self.hour24_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether()
                            self.hour24_ether.parent = self
                            self._children_name_map["hour24_ether"] = "hour24-ether"
                        return self.hour24_ether

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hour24-ether"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Minute15OtnTcms(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15otn_tcm
                
                	configure otn g709 tcm's performance monitoring
                	**type**\: list of    :py:class:`Minute15OtnTcm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms, self).__init__()

                    self.yang_name = "minute15otn-tcms"
                    self.yang_parent_name = "performance-management"

                    self.minute15otn_tcm = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms, self).__setattr__(name, value)


                class Minute15OtnTcm(Entity):
                    """
                    configure otn g709 tcm's performance
                    monitoring
                    
                    .. attribute:: tcm_number  <key>
                    
                    	TCM number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: min15_otn_tcm_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Min15OtnTcmThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes>`
                    
                    .. attribute:: minute15otn_tcm_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Minute15OtnTcmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm, self).__init__()

                        self.yang_name = "minute15otn-tcm"
                        self.yang_parent_name = "minute15otn-tcms"

                        self.tcm_number = YLeaf(YType.int32, "tcm-number")

                        self.min15_otn_tcm_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes()
                        self.min15_otn_tcm_threshes.parent = self
                        self._children_name_map["min15_otn_tcm_threshes"] = "min15-otn-tcm-threshes"
                        self._children_yang_names.add("min15-otn-tcm-threshes")

                        self.minute15otn_tcm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports()
                        self.minute15otn_tcm_reports.parent = self
                        self._children_name_map["minute15otn_tcm_reports"] = "minute15otn-tcm-reports"
                        self._children_yang_names.add("minute15otn-tcm-reports")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tcm_number") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm, self).__setattr__(name, value)


                    class Min15OtnTcmThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: min15_otn_tcm_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Min15OtnTcmThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes, self).__init__()

                            self.yang_name = "min15-otn-tcm-threshes"
                            self.yang_parent_name = "minute15otn-tcm"

                            self.min15_otn_tcm_thresh = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes, self).__setattr__(name, value)


                        class Min15OtnTcmThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnTcmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh, self).__init__()

                                self.yang_name = "min15-otn-tcm-thresh"
                                self.yang_parent_name = "min15-otn-tcm-threshes"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "min15-otn-tcm-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.min15_otn_tcm_thresh:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.min15_otn_tcm_thresh:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "min15-otn-tcm-threshes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "min15-otn-tcm-thresh"):
                                for c in self.min15_otn_tcm_thresh:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.min15_otn_tcm_thresh.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "min15-otn-tcm-thresh"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15OtnTcmReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: minute15otn_tcm_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports, self).__init__()

                            self.yang_name = "minute15otn-tcm-reports"
                            self.yang_parent_name = "minute15otn-tcm"

                            self.minute15otn_tcm_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports, self).__setattr__(name, value)


                        class Minute15OtnTcmReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport, self).__init__()

                                self.yang_name = "minute15otn-tcm-report"
                                self.yang_parent_name = "minute15otn-tcm-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15otn-tcm-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15otn_tcm_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15otn_tcm_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15otn-tcm-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15otn-tcm-report"):
                                for c in self.minute15otn_tcm_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15otn_tcm_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15otn-tcm-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.tcm_number.is_set or
                            (self.min15_otn_tcm_threshes is not None and self.min15_otn_tcm_threshes.has_data()) or
                            (self.minute15otn_tcm_reports is not None and self.minute15otn_tcm_reports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tcm_number.yfilter != YFilter.not_set or
                            (self.min15_otn_tcm_threshes is not None and self.min15_otn_tcm_threshes.has_operation()) or
                            (self.minute15otn_tcm_reports is not None and self.minute15otn_tcm_reports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15otn-tcm" + "[tcm-number='" + self.tcm_number.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tcm_number.is_set or self.tcm_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tcm_number.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "min15-otn-tcm-threshes"):
                            if (self.min15_otn_tcm_threshes is None):
                                self.min15_otn_tcm_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes()
                                self.min15_otn_tcm_threshes.parent = self
                                self._children_name_map["min15_otn_tcm_threshes"] = "min15-otn-tcm-threshes"
                            return self.min15_otn_tcm_threshes

                        if (child_yang_name == "minute15otn-tcm-reports"):
                            if (self.minute15otn_tcm_reports is None):
                                self.minute15otn_tcm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports()
                                self.minute15otn_tcm_reports.parent = self
                                self._children_name_map["minute15otn_tcm_reports"] = "minute15otn-tcm-reports"
                            return self.minute15otn_tcm_reports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "min15-otn-tcm-threshes" or name == "minute15otn-tcm-reports" or name == "tcm-number"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tcm-number"):
                            self.tcm_number = value
                            self.tcm_number.value_namespace = name_space
                            self.tcm_number.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.minute15otn_tcm:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.minute15otn_tcm:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "minute15otn-tcms" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "minute15otn-tcm"):
                        for c in self.minute15otn_tcm:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.minute15otn_tcm.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "minute15otn-tcm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OcHour24(Entity):
                """
                set Oc threshold
                
                .. attribute:: oc_hour24_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`OcHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24, self).__init__()

                    self.yang_name = "oc-hour24"
                    self.yang_parent_name = "performance-management"

                    self.oc_hour24_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn()
                    self.oc_hour24_ocn.parent = self
                    self._children_name_map["oc_hour24_ocn"] = "oc-hour24-ocn"
                    self._children_yang_names.add("oc-hour24-ocn")


                class OcHour24Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: oc_hour24_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`OcHour24OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports>`
                    
                    .. attribute:: oc_hour24_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`OcHour24OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn, self).__init__()

                        self.yang_name = "oc-hour24-ocn"
                        self.yang_parent_name = "oc-hour24"

                        self.oc_hour24_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports()
                        self.oc_hour24_ocn_reports.parent = self
                        self._children_name_map["oc_hour24_ocn_reports"] = "oc-hour24-ocn-reports"
                        self._children_yang_names.add("oc-hour24-ocn-reports")

                        self.oc_hour24_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds()
                        self.oc_hour24_ocn_thresholds.parent = self
                        self._children_name_map["oc_hour24_ocn_thresholds"] = "oc-hour24-ocn-thresholds"
                        self._children_yang_names.add("oc-hour24-ocn-thresholds")


                    class OcHour24OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: oc_hour24_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`OcHour24OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports, self).__init__()

                            self.yang_name = "oc-hour24-ocn-reports"
                            self.yang_parent_name = "oc-hour24-ocn"

                            self.oc_hour24_ocn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports, self).__setattr__(name, value)


                        class OcHour24OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            .. attribute:: enable
                            
                            	Ocn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport, self).__init__()

                                self.yang_name = "oc-hour24-ocn-report"
                                self.yang_parent_name = "oc-hour24-ocn-reports"

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ocn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-hour24-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_report.is_set or self.ocn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-report"):
                                    self.ocn_report = value
                                    self.ocn_report.value_namespace = name_space
                                    self.ocn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.oc_hour24_ocn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.oc_hour24_ocn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-hour24-ocn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-hour24-ocn-report"):
                                for c in self.oc_hour24_ocn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.oc_hour24_ocn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-hour24-ocn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OcHour24OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: oc_hour24_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OcHour24OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds, self).__init__()

                            self.yang_name = "oc-hour24-ocn-thresholds"
                            self.yang_parent_name = "oc-hour24-ocn"

                            self.oc_hour24_ocn_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds, self).__setattr__(name, value)


                        class OcHour24OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold, self).__init__()

                                self.yang_name = "oc-hour24-ocn-threshold"
                                self.yang_parent_name = "oc-hour24-ocn-thresholds"

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_threshold",
                                                "ocn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ocn_threshold.is_set or
                                    self.ocn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_threshold.yfilter != YFilter.not_set or
                                    self.ocn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-hour24-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_threshold.is_set or self.ocn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold.get_name_leafdata())
                                if (self.ocn_threshold_value.is_set or self.ocn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-threshold" or name == "ocn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-threshold"):
                                    self.ocn_threshold = value
                                    self.ocn_threshold.value_namespace = name_space
                                    self.ocn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ocn-threshold-value"):
                                    self.ocn_threshold_value = value
                                    self.ocn_threshold_value.value_namespace = name_space
                                    self.ocn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.oc_hour24_ocn_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.oc_hour24_ocn_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-hour24-ocn-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-hour24-ocn-threshold"):
                                for c in self.oc_hour24_ocn_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.oc_hour24_ocn_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-hour24-ocn-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.oc_hour24_ocn_reports is not None and self.oc_hour24_ocn_reports.has_data()) or
                            (self.oc_hour24_ocn_thresholds is not None and self.oc_hour24_ocn_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.oc_hour24_ocn_reports is not None and self.oc_hour24_ocn_reports.has_operation()) or
                            (self.oc_hour24_ocn_thresholds is not None and self.oc_hour24_ocn_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "oc-hour24-ocn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "oc-hour24-ocn-reports"):
                            if (self.oc_hour24_ocn_reports is None):
                                self.oc_hour24_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports()
                                self.oc_hour24_ocn_reports.parent = self
                                self._children_name_map["oc_hour24_ocn_reports"] = "oc-hour24-ocn-reports"
                            return self.oc_hour24_ocn_reports

                        if (child_yang_name == "oc-hour24-ocn-thresholds"):
                            if (self.oc_hour24_ocn_thresholds is None):
                                self.oc_hour24_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds()
                                self.oc_hour24_ocn_thresholds.parent = self
                                self._children_name_map["oc_hour24_ocn_thresholds"] = "oc-hour24-ocn-thresholds"
                            return self.oc_hour24_ocn_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "oc-hour24-ocn-reports" or name == "oc-hour24-ocn-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.oc_hour24_ocn is not None and self.oc_hour24_ocn.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.oc_hour24_ocn is not None and self.oc_hour24_ocn.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "oc-hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "oc-hour24-ocn"):
                        if (self.oc_hour24_ocn is None):
                            self.oc_hour24_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn()
                            self.oc_hour24_ocn.parent = self
                            self._children_name_map["oc_hour24_ocn"] = "oc-hour24-ocn"
                        return self.oc_hour24_ocn

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "oc-hour24-ocn"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EthernetMinute15(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15_ether
                
                	Configure ether performance monitoring
                	**type**\:   :py:class:`Minute15Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15, self).__init__()

                    self.yang_name = "ethernet-minute15"
                    self.yang_parent_name = "performance-management"

                    self.minute15_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether()
                    self.minute15_ether.parent = self
                    self._children_name_map["minute15_ether"] = "minute15-ether"
                    self._children_yang_names.add("minute15-ether")


                class Minute15Ether(Entity):
                    """
                    Configure ether performance monitoring
                    
                    .. attribute:: minute15_ether_reports
                    
                    	set ether TCA reporting status
                    	**type**\:   :py:class:`Minute15EtherReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports>`
                    
                    .. attribute:: minute15_ether_thresholds
                    
                    	Configure threshold on ether parameters
                    	**type**\:   :py:class:`Minute15EtherThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether, self).__init__()

                        self.yang_name = "minute15-ether"
                        self.yang_parent_name = "ethernet-minute15"

                        self.minute15_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports()
                        self.minute15_ether_reports.parent = self
                        self._children_name_map["minute15_ether_reports"] = "minute15-ether-reports"
                        self._children_yang_names.add("minute15-ether-reports")

                        self.minute15_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds()
                        self.minute15_ether_thresholds.parent = self
                        self._children_name_map["minute15_ether_thresholds"] = "minute15-ether-thresholds"
                        self._children_yang_names.add("minute15-ether-thresholds")


                    class Minute15EtherThresholds(Entity):
                        """
                        Configure threshold on ether parameters
                        
                        .. attribute:: minute15_ether_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds, self).__init__()

                            self.yang_name = "minute15-ether-thresholds"
                            self.yang_parent_name = "minute15-ether"

                            self.minute15_ether_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds, self).__setattr__(name, value)


                        class Minute15EtherThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ether_threshold  <key>
                            
                            	Ether Threshold Type
                            	**type**\:   :py:class:`EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherThreshold>`
                            
                            .. attribute:: ether_threshold_value
                            
                            	Ether Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold, self).__init__()

                                self.yang_name = "minute15-ether-threshold"
                                self.yang_parent_name = "minute15-ether-thresholds"

                                self.ether_threshold = YLeaf(YType.enumeration, "ether-threshold")

                                self.ether_threshold_value = YLeaf(YType.int32, "ether-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ether_threshold",
                                                "ether_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ether_threshold.is_set or
                                    self.ether_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ether_threshold.yfilter != YFilter.not_set or
                                    self.ether_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-ether-threshold" + "[ether-threshold='" + self.ether_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ether_threshold.is_set or self.ether_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_threshold.get_name_leafdata())
                                if (self.ether_threshold_value.is_set or self.ether_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ether-threshold" or name == "ether-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ether-threshold"):
                                    self.ether_threshold = value
                                    self.ether_threshold.value_namespace = name_space
                                    self.ether_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ether-threshold-value"):
                                    self.ether_threshold_value = value
                                    self.ether_threshold_value.value_namespace = name_space
                                    self.ether_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15_ether_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15_ether_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15-ether-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-ether-threshold"):
                                for c in self.minute15_ether_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15_ether_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-ether-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15EtherReports(Entity):
                        """
                        set ether TCA reporting status
                        
                        .. attribute:: minute15_ether_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports, self).__init__()

                            self.yang_name = "minute15-ether-reports"
                            self.yang_parent_name = "minute15-ether"

                            self.minute15_ether_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports, self).__setattr__(name, value)


                        class Minute15EtherReport(Entity):
                            """
                            none
                            
                            .. attribute:: ether_report  <key>
                            
                            	Ether Report Type
                            	**type**\:   :py:class:`EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport, self).__init__()

                                self.yang_name = "minute15-ether-report"
                                self.yang_parent_name = "minute15-ether-reports"

                                self.ether_report = YLeaf(YType.enumeration, "ether-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ether_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.ether_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ether_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-ether-report" + "[ether-report='" + self.ether_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ether_report.is_set or self.ether_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ether-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ether-report"):
                                    self.ether_report = value
                                    self.ether_report.value_namespace = name_space
                                    self.ether_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15_ether_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15_ether_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15-ether-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-ether-report"):
                                for c in self.minute15_ether_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15_ether_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-ether-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.minute15_ether_reports is not None and self.minute15_ether_reports.has_data()) or
                            (self.minute15_ether_thresholds is not None and self.minute15_ether_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.minute15_ether_reports is not None and self.minute15_ether_reports.has_operation()) or
                            (self.minute15_ether_thresholds is not None and self.minute15_ether_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15-ether" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "minute15-ether-reports"):
                            if (self.minute15_ether_reports is None):
                                self.minute15_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports()
                                self.minute15_ether_reports.parent = self
                                self._children_name_map["minute15_ether_reports"] = "minute15-ether-reports"
                            return self.minute15_ether_reports

                        if (child_yang_name == "minute15-ether-thresholds"):
                            if (self.minute15_ether_thresholds is None):
                                self.minute15_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds()
                                self.minute15_ether_thresholds.parent = self
                                self._children_name_map["minute15_ether_thresholds"] = "minute15-ether-thresholds"
                            return self.minute15_ether_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "minute15-ether-reports" or name == "minute15-ether-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.minute15_ether is not None and self.minute15_ether.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.minute15_ether is not None and self.minute15_ether.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ethernet-minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "minute15-ether"):
                        if (self.minute15_ether is None):
                            self.minute15_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether()
                            self.minute15_ether.parent = self
                            self._children_name_map["minute15_ether"] = "minute15-ether"
                        return self.minute15_ether

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "minute15-ether"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class HoVcHour24(Entity):
                """
                set HO\_VC threshold
                
                .. attribute:: ho_vc_hour24ho_vc
                
                	Configure ho\_vc performance monitoring
                	**type**\:   :py:class:`HoVcHour24HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24, self).__init__()

                    self.yang_name = "ho-vc-hour24"
                    self.yang_parent_name = "performance-management"

                    self.ho_vc_hour24ho_vc = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc()
                    self.ho_vc_hour24ho_vc.parent = self
                    self._children_name_map["ho_vc_hour24ho_vc"] = "ho-vc-hour24ho-vc"
                    self._children_yang_names.add("ho-vc-hour24ho-vc")


                class HoVcHour24HoVc(Entity):
                    """
                    Configure ho\_vc performance monitoring
                    
                    .. attribute:: ho_vc_hour24ho_vc_reports
                    
                    	set ho\_vc TCA reporting status
                    	**type**\:   :py:class:`HoVcHour24HoVcReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports>`
                    
                    .. attribute:: ho_vc_hour24ho_vc_thresholds
                    
                    	Configure threshold on ho\_vc parameters
                    	**type**\:   :py:class:`HoVcHour24HoVcThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc, self).__init__()

                        self.yang_name = "ho-vc-hour24ho-vc"
                        self.yang_parent_name = "ho-vc-hour24"

                        self.ho_vc_hour24ho_vc_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports()
                        self.ho_vc_hour24ho_vc_reports.parent = self
                        self._children_name_map["ho_vc_hour24ho_vc_reports"] = "ho-vc-hour24ho-vc-reports"
                        self._children_yang_names.add("ho-vc-hour24ho-vc-reports")

                        self.ho_vc_hour24ho_vc_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds()
                        self.ho_vc_hour24ho_vc_thresholds.parent = self
                        self._children_name_map["ho_vc_hour24ho_vc_thresholds"] = "ho-vc-hour24ho-vc-thresholds"
                        self._children_yang_names.add("ho-vc-hour24ho-vc-thresholds")


                    class HoVcHour24HoVcReports(Entity):
                        """
                        set ho\_vc TCA reporting status
                        
                        .. attribute:: ho_vc_hour24ho_vc_report
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcHour24HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports, self).__init__()

                            self.yang_name = "ho-vc-hour24ho-vc-reports"
                            self.yang_parent_name = "ho-vc-hour24ho-vc"

                            self.ho_vc_hour24ho_vc_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports, self).__setattr__(name, value)


                        class HoVcHour24HoVcReport(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_report  <key>
                            
                            	ho\_vc Report Type
                            	**type**\:   :py:class:`HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcReport>`
                            
                            .. attribute:: enable
                            
                            	ho\_vc Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport, self).__init__()

                                self.yang_name = "ho-vc-hour24ho-vc-report"
                                self.yang_parent_name = "ho-vc-hour24ho-vc-reports"

                                self.ho_vc_report = YLeaf(YType.enumeration, "ho-vc-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ho_vc_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ho_vc_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ho_vc_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-hour24ho-vc-report" + "[ho-vc-report='" + self.ho_vc_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ho_vc_report.is_set or self.ho_vc_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ho_vc_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ho-vc-report"):
                                    self.ho_vc_report = value
                                    self.ho_vc_report.value_namespace = name_space
                                    self.ho_vc_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ho_vc_hour24ho_vc_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ho_vc_hour24ho_vc_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-hour24ho-vc-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-hour24ho-vc-report"):
                                for c in self.ho_vc_hour24ho_vc_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ho_vc_hour24ho_vc_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-hour24ho-vc-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class HoVcHour24HoVcThresholds(Entity):
                        """
                        Configure threshold on ho\_vc parameters
                        
                        .. attribute:: ho_vc_hour24ho_vc_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcHour24HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds, self).__init__()

                            self.yang_name = "ho-vc-hour24ho-vc-thresholds"
                            self.yang_parent_name = "ho-vc-hour24ho-vc"

                            self.ho_vc_hour24ho_vc_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds, self).__setattr__(name, value)


                        class HoVcHour24HoVcThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_threshold  <key>
                            
                            	ho\_vc Threshold Type
                            	**type**\:   :py:class:`HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcThreshold>`
                            
                            .. attribute:: ho_vc_threshold_value
                            
                            	ho\_vc Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold, self).__init__()

                                self.yang_name = "ho-vc-hour24ho-vc-threshold"
                                self.yang_parent_name = "ho-vc-hour24ho-vc-thresholds"

                                self.ho_vc_threshold = YLeaf(YType.enumeration, "ho-vc-threshold")

                                self.ho_vc_threshold_value = YLeaf(YType.int32, "ho-vc-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ho_vc_threshold",
                                                "ho_vc_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ho_vc_threshold.is_set or
                                    self.ho_vc_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ho_vc_threshold.yfilter != YFilter.not_set or
                                    self.ho_vc_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-hour24ho-vc-threshold" + "[ho-vc-threshold='" + self.ho_vc_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ho_vc_threshold.is_set or self.ho_vc_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ho_vc_threshold.get_name_leafdata())
                                if (self.ho_vc_threshold_value.is_set or self.ho_vc_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ho_vc_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-threshold" or name == "ho-vc-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ho-vc-threshold"):
                                    self.ho_vc_threshold = value
                                    self.ho_vc_threshold.value_namespace = name_space
                                    self.ho_vc_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ho-vc-threshold-value"):
                                    self.ho_vc_threshold_value = value
                                    self.ho_vc_threshold_value.value_namespace = name_space
                                    self.ho_vc_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ho_vc_hour24ho_vc_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ho_vc_hour24ho_vc_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-hour24ho-vc-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-hour24ho-vc-threshold"):
                                for c in self.ho_vc_hour24ho_vc_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ho_vc_hour24ho_vc_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-hour24ho-vc-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.ho_vc_hour24ho_vc_reports is not None and self.ho_vc_hour24ho_vc_reports.has_data()) or
                            (self.ho_vc_hour24ho_vc_thresholds is not None and self.ho_vc_hour24ho_vc_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.ho_vc_hour24ho_vc_reports is not None and self.ho_vc_hour24ho_vc_reports.has_operation()) or
                            (self.ho_vc_hour24ho_vc_thresholds is not None and self.ho_vc_hour24ho_vc_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ho-vc-hour24ho-vc" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ho-vc-hour24ho-vc-reports"):
                            if (self.ho_vc_hour24ho_vc_reports is None):
                                self.ho_vc_hour24ho_vc_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports()
                                self.ho_vc_hour24ho_vc_reports.parent = self
                                self._children_name_map["ho_vc_hour24ho_vc_reports"] = "ho-vc-hour24ho-vc-reports"
                            return self.ho_vc_hour24ho_vc_reports

                        if (child_yang_name == "ho-vc-hour24ho-vc-thresholds"):
                            if (self.ho_vc_hour24ho_vc_thresholds is None):
                                self.ho_vc_hour24ho_vc_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds()
                                self.ho_vc_hour24ho_vc_thresholds.parent = self
                                self._children_name_map["ho_vc_hour24ho_vc_thresholds"] = "ho-vc-hour24ho-vc-thresholds"
                            return self.ho_vc_hour24ho_vc_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ho-vc-hour24ho-vc-reports" or name == "ho-vc-hour24ho-vc-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.ho_vc_hour24ho_vc is not None and self.ho_vc_hour24ho_vc.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ho_vc_hour24ho_vc is not None and self.ho_vc_hour24ho_vc.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ho-vc-hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ho-vc-hour24ho-vc"):
                        if (self.ho_vc_hour24ho_vc is None):
                            self.ho_vc_hour24ho_vc = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc()
                            self.ho_vc_hour24ho_vc.parent = self
                            self._children_name_map["ho_vc_hour24ho_vc"] = "ho-vc-hour24ho-vc"
                        return self.ho_vc_hour24ho_vc

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ho-vc-hour24ho-vc"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Second30(Entity):
                """
                Configure optics performance monitoring for 30
                sec
                
                .. attribute:: second30_optics
                
                	Configure optics performance monitoring
                	**type**\:   :py:class:`Second30Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics>`
                
                .. attribute:: second30fec
                
                	Configure fec g709 performance monitoring
                	**type**\:   :py:class:`Second30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec>`
                
                .. attribute:: second30otn
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Second30Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30, self).__init__()

                    self.yang_name = "second30"
                    self.yang_parent_name = "performance-management"

                    self.second30_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics()
                    self.second30_optics.parent = self
                    self._children_name_map["second30_optics"] = "second30-optics"
                    self._children_yang_names.add("second30-optics")

                    self.second30fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec()
                    self.second30fec.parent = self
                    self._children_name_map["second30fec"] = "second30fec"
                    self._children_yang_names.add("second30fec")

                    self.second30otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn()
                    self.second30otn.parent = self
                    self._children_name_map["second30otn"] = "second30otn"
                    self._children_yang_names.add("second30otn")


                class Second30Fec(Entity):
                    """
                    Configure fec g709 performance monitoring
                    
                    .. attribute:: second30fec_reports
                    
                    	set fec TCA reporting status
                    	**type**\:   :py:class:`Second30FecReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports>`
                    
                    .. attribute:: second30fec_thresholds
                    
                    	Configure fec threshold
                    	**type**\:   :py:class:`Second30FecThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec, self).__init__()

                        self.yang_name = "second30fec"
                        self.yang_parent_name = "second30"

                        self.second30fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports()
                        self.second30fec_reports.parent = self
                        self._children_name_map["second30fec_reports"] = "second30fec-reports"
                        self._children_yang_names.add("second30fec-reports")

                        self.second30fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds()
                        self.second30fec_thresholds.parent = self
                        self._children_name_map["second30fec_thresholds"] = "second30fec-thresholds"
                        self._children_yang_names.add("second30fec-thresholds")


                    class Second30FecThresholds(Entity):
                        """
                        Configure fec threshold
                        
                        .. attribute:: second30fec_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds, self).__init__()

                            self.yang_name = "second30fec-thresholds"
                            self.yang_parent_name = "second30fec"

                            self.second30fec_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds, self).__setattr__(name, value)


                        class Second30FecThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: fec_threshold  <key>
                            
                            	Fec Threshold Type
                            	**type**\:   :py:class:`FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecThreshold>`
                            
                            .. attribute:: fec_threshold_value
                            
                            	Fec Threshold Value
                            	**type**\:  str
                            
                            	**length:** 1..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold, self).__init__()

                                self.yang_name = "second30fec-threshold"
                                self.yang_parent_name = "second30fec-thresholds"

                                self.fec_threshold = YLeaf(YType.enumeration, "fec-threshold")

                                self.fec_threshold_value = YLeaf(YType.str, "fec-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fec_threshold",
                                                "fec_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fec_threshold.is_set or
                                    self.fec_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fec_threshold.yfilter != YFilter.not_set or
                                    self.fec_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30fec-threshold" + "[fec-threshold='" + self.fec_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fec_threshold.is_set or self.fec_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_threshold.get_name_leafdata())
                                if (self.fec_threshold_value.is_set or self.fec_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fec-threshold" or name == "fec-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fec-threshold"):
                                    self.fec_threshold = value
                                    self.fec_threshold.value_namespace = name_space
                                    self.fec_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "fec-threshold-value"):
                                    self.fec_threshold_value = value
                                    self.fec_threshold_value.value_namespace = name_space
                                    self.fec_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30fec_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30fec_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30fec-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30fec-threshold"):
                                for c in self.second30fec_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30fec_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30fec-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Second30FecReports(Entity):
                        """
                        set fec TCA reporting status
                        
                        .. attribute:: second30fec_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports, self).__init__()

                            self.yang_name = "second30fec-reports"
                            self.yang_parent_name = "second30fec"

                            self.second30fec_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports, self).__setattr__(name, value)


                        class Second30FecReport(Entity):
                            """
                            none
                            
                            .. attribute:: fec_report  <key>
                            
                            	Fec Report Type
                            	**type**\:   :py:class:`FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecReport>`
                            
                            .. attribute:: enable
                            
                            	Fec Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport, self).__init__()

                                self.yang_name = "second30fec-report"
                                self.yang_parent_name = "second30fec-reports"

                                self.fec_report = YLeaf(YType.enumeration, "fec-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fec_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fec_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fec_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30fec-report" + "[fec-report='" + self.fec_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fec_report.is_set or self.fec_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fec-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fec-report"):
                                    self.fec_report = value
                                    self.fec_report.value_namespace = name_space
                                    self.fec_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30fec_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30fec_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30fec-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30fec-report"):
                                for c in self.second30fec_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30fec_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30fec-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.second30fec_reports is not None and self.second30fec_reports.has_data()) or
                            (self.second30fec_thresholds is not None and self.second30fec_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.second30fec_reports is not None and self.second30fec_reports.has_operation()) or
                            (self.second30fec_thresholds is not None and self.second30fec_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "second30fec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "second30fec-reports"):
                            if (self.second30fec_reports is None):
                                self.second30fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports()
                                self.second30fec_reports.parent = self
                                self._children_name_map["second30fec_reports"] = "second30fec-reports"
                            return self.second30fec_reports

                        if (child_yang_name == "second30fec-thresholds"):
                            if (self.second30fec_thresholds is None):
                                self.second30fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds()
                                self.second30fec_thresholds.parent = self
                                self._children_name_map["second30fec_thresholds"] = "second30fec-thresholds"
                            return self.second30fec_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "second30fec-reports" or name == "second30fec-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Second30Optics(Entity):
                    """
                    Configure optics performance monitoring
                    
                    .. attribute:: second30_optics_reports
                    
                    	set optics TCA reporting status
                    	**type**\:   :py:class:`Second30OpticsReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports>`
                    
                    .. attribute:: second30_optics_thresholds
                    
                    	Configure threshold on optics parameters
                    	**type**\:   :py:class:`Second30OpticsThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics, self).__init__()

                        self.yang_name = "second30-optics"
                        self.yang_parent_name = "second30"

                        self.second30_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports()
                        self.second30_optics_reports.parent = self
                        self._children_name_map["second30_optics_reports"] = "second30-optics-reports"
                        self._children_yang_names.add("second30-optics-reports")

                        self.second30_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds()
                        self.second30_optics_thresholds.parent = self
                        self._children_name_map["second30_optics_thresholds"] = "second30-optics-thresholds"
                        self._children_yang_names.add("second30-optics-thresholds")


                    class Second30OpticsReports(Entity):
                        """
                        set optics TCA reporting status
                        
                        .. attribute:: second30_optics_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports, self).__init__()

                            self.yang_name = "second30-optics-reports"
                            self.yang_parent_name = "second30-optics"

                            self.second30_optics_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports, self).__setattr__(name, value)


                        class Second30OpticsReport(Entity):
                            """
                            none
                            
                            .. attribute:: optics_report  <key>
                            
                            	Optics Report Type
                            	**type**\:   :py:class:`OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport, self).__init__()

                                self.yang_name = "second30-optics-report"
                                self.yang_parent_name = "second30-optics-reports"

                                self.optics_report = YLeaf(YType.enumeration, "optics-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("optics_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.optics_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.optics_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30-optics-report" + "[optics-report='" + self.optics_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.optics_report.is_set or self.optics_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "optics-report"):
                                    self.optics_report = value
                                    self.optics_report.value_namespace = name_space
                                    self.optics_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30_optics_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30_optics_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30-optics-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30-optics-report"):
                                for c in self.second30_optics_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30_optics_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30-optics-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Second30OpticsThresholds(Entity):
                        """
                        Configure threshold on optics parameters
                        
                        .. attribute:: second30_optics_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds, self).__init__()

                            self.yang_name = "second30-optics-thresholds"
                            self.yang_parent_name = "second30-optics"

                            self.second30_optics_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds, self).__setattr__(name, value)


                        class Second30OpticsThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: optics_threshold  <key>
                            
                            	Optics Threshold Type
                            	**type**\:   :py:class:`OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsThreshold>`
                            
                            .. attribute:: optics_threshold_value
                            
                            	Optics Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold, self).__init__()

                                self.yang_name = "second30-optics-threshold"
                                self.yang_parent_name = "second30-optics-thresholds"

                                self.optics_threshold = YLeaf(YType.enumeration, "optics-threshold")

                                self.optics_threshold_value = YLeaf(YType.int32, "optics-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("optics_threshold",
                                                "optics_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.optics_threshold.is_set or
                                    self.optics_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.optics_threshold.yfilter != YFilter.not_set or
                                    self.optics_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30-optics-threshold" + "[optics-threshold='" + self.optics_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.optics_threshold.is_set or self.optics_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_threshold.get_name_leafdata())
                                if (self.optics_threshold_value.is_set or self.optics_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-threshold" or name == "optics-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "optics-threshold"):
                                    self.optics_threshold = value
                                    self.optics_threshold.value_namespace = name_space
                                    self.optics_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "optics-threshold-value"):
                                    self.optics_threshold_value = value
                                    self.optics_threshold_value.value_namespace = name_space
                                    self.optics_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30_optics_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30_optics_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30-optics-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30-optics-threshold"):
                                for c in self.second30_optics_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30_optics_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30-optics-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.second30_optics_reports is not None and self.second30_optics_reports.has_data()) or
                            (self.second30_optics_thresholds is not None and self.second30_optics_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.second30_optics_reports is not None and self.second30_optics_reports.has_operation()) or
                            (self.second30_optics_thresholds is not None and self.second30_optics_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "second30-optics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "second30-optics-reports"):
                            if (self.second30_optics_reports is None):
                                self.second30_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports()
                                self.second30_optics_reports.parent = self
                                self._children_name_map["second30_optics_reports"] = "second30-optics-reports"
                            return self.second30_optics_reports

                        if (child_yang_name == "second30-optics-thresholds"):
                            if (self.second30_optics_thresholds is None):
                                self.second30_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds()
                                self.second30_optics_thresholds.parent = self
                                self._children_name_map["second30_optics_thresholds"] = "second30-optics-thresholds"
                            return self.second30_optics_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "second30-optics-reports" or name == "second30-optics-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Second30Otn(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: second30_otn_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Second30OtnThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes>`
                    
                    .. attribute:: second30otn_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Second30OtnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn, self).__init__()

                        self.yang_name = "second30otn"
                        self.yang_parent_name = "second30"

                        self.second30_otn_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes()
                        self.second30_otn_threshes.parent = self
                        self._children_name_map["second30_otn_threshes"] = "second30-otn-threshes"
                        self._children_yang_names.add("second30-otn-threshes")

                        self.second30otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports()
                        self.second30otn_reports.parent = self
                        self._children_name_map["second30otn_reports"] = "second30otn-reports"
                        self._children_yang_names.add("second30otn-reports")


                    class Second30OtnThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: second30_otn_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OtnThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes, self).__init__()

                            self.yang_name = "second30-otn-threshes"
                            self.yang_parent_name = "second30otn"

                            self.second30_otn_thresh = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes, self).__setattr__(name, value)


                        class Second30OtnThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh, self).__init__()

                                self.yang_name = "second30-otn-thresh"
                                self.yang_parent_name = "second30-otn-threshes"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30-otn-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30_otn_thresh:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30_otn_thresh:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30-otn-threshes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30-otn-thresh"):
                                for c in self.second30_otn_thresh:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30_otn_thresh.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30-otn-thresh"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Second30OtnReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: second30otn_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports, self).__init__()

                            self.yang_name = "second30otn-reports"
                            self.yang_parent_name = "second30otn"

                            self.second30otn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports, self).__setattr__(name, value)


                        class Second30OtnReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport, self).__init__()

                                self.yang_name = "second30otn-report"
                                self.yang_parent_name = "second30otn-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30otn-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30otn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30otn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30otn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30otn-report"):
                                for c in self.second30otn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30otn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30otn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.second30_otn_threshes is not None and self.second30_otn_threshes.has_data()) or
                            (self.second30otn_reports is not None and self.second30otn_reports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.second30_otn_threshes is not None and self.second30_otn_threshes.has_operation()) or
                            (self.second30otn_reports is not None and self.second30otn_reports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "second30otn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "second30-otn-threshes"):
                            if (self.second30_otn_threshes is None):
                                self.second30_otn_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes()
                                self.second30_otn_threshes.parent = self
                                self._children_name_map["second30_otn_threshes"] = "second30-otn-threshes"
                            return self.second30_otn_threshes

                        if (child_yang_name == "second30otn-reports"):
                            if (self.second30otn_reports is None):
                                self.second30otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports()
                                self.second30otn_reports.parent = self
                                self._children_name_map["second30otn_reports"] = "second30otn-reports"
                            return self.second30otn_reports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "second30-otn-threshes" or name == "second30otn-reports"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.second30_optics is not None and self.second30_optics.has_data()) or
                        (self.second30fec is not None and self.second30fec.has_data()) or
                        (self.second30otn is not None and self.second30otn.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.second30_optics is not None and self.second30_optics.has_operation()) or
                        (self.second30fec is not None and self.second30fec.has_operation()) or
                        (self.second30otn is not None and self.second30otn.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "second30" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "second30-optics"):
                        if (self.second30_optics is None):
                            self.second30_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics()
                            self.second30_optics.parent = self
                            self._children_name_map["second30_optics"] = "second30-optics"
                        return self.second30_optics

                    if (child_yang_name == "second30fec"):
                        if (self.second30fec is None):
                            self.second30fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec()
                            self.second30fec.parent = self
                            self._children_name_map["second30fec"] = "second30fec"
                        return self.second30fec

                    if (child_yang_name == "second30otn"):
                        if (self.second30otn is None):
                            self.second30otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn()
                            self.second30otn.parent = self
                            self._children_name_map["second30otn"] = "second30otn"
                        return self.second30otn

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "second30-optics" or name == "second30fec" or name == "second30otn"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Hour24OtnTcms(Entity):
                """
                Configure pm parameters of tcm's 24 hour
                interval
                
                .. attribute:: hour24otn_tcm
                
                	configure otn g709 tcm's performance monitoring
                	**type**\: list of    :py:class:`Hour24OtnTcm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms, self).__init__()

                    self.yang_name = "hour24otn-tcms"
                    self.yang_parent_name = "performance-management"

                    self.hour24otn_tcm = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms, self).__setattr__(name, value)


                class Hour24OtnTcm(Entity):
                    """
                    configure otn g709 tcm's performance
                    monitoring
                    
                    .. attribute:: tcm_number  <key>
                    
                    	TCM number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: hour24otn_tcm_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Hour24OtnTcmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports>`
                    
                    .. attribute:: hour24otn_tcm_thresholds
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Hour24OtnTcmThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm, self).__init__()

                        self.yang_name = "hour24otn-tcm"
                        self.yang_parent_name = "hour24otn-tcms"

                        self.tcm_number = YLeaf(YType.int32, "tcm-number")

                        self.hour24otn_tcm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports()
                        self.hour24otn_tcm_reports.parent = self
                        self._children_name_map["hour24otn_tcm_reports"] = "hour24otn-tcm-reports"
                        self._children_yang_names.add("hour24otn-tcm-reports")

                        self.hour24otn_tcm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds()
                        self.hour24otn_tcm_thresholds.parent = self
                        self._children_name_map["hour24otn_tcm_thresholds"] = "hour24otn-tcm-thresholds"
                        self._children_yang_names.add("hour24otn-tcm-thresholds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tcm_number") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm, self).__setattr__(name, value)


                    class Hour24OtnTcmThresholds(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: hour24otn_tcm_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnTcmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds, self).__init__()

                            self.yang_name = "hour24otn-tcm-thresholds"
                            self.yang_parent_name = "hour24otn-tcm"

                            self.hour24otn_tcm_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds, self).__setattr__(name, value)


                        class Hour24OtnTcmThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnTcmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold, self).__init__()

                                self.yang_name = "hour24otn-tcm-threshold"
                                self.yang_parent_name = "hour24otn-tcm-thresholds"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24otn-tcm-threshold" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24otn_tcm_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24otn_tcm_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24otn-tcm-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24otn-tcm-threshold"):
                                for c in self.hour24otn_tcm_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24otn_tcm_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24otn-tcm-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24OtnTcmReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: hour24otn_tcm_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports, self).__init__()

                            self.yang_name = "hour24otn-tcm-reports"
                            self.yang_parent_name = "hour24otn-tcm"

                            self.hour24otn_tcm_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports, self).__setattr__(name, value)


                        class Hour24OtnTcmReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport, self).__init__()

                                self.yang_name = "hour24otn-tcm-report"
                                self.yang_parent_name = "hour24otn-tcm-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24otn-tcm-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24otn_tcm_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24otn_tcm_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24otn-tcm-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24otn-tcm-report"):
                                for c in self.hour24otn_tcm_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24otn_tcm_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24otn-tcm-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.tcm_number.is_set or
                            (self.hour24otn_tcm_reports is not None and self.hour24otn_tcm_reports.has_data()) or
                            (self.hour24otn_tcm_thresholds is not None and self.hour24otn_tcm_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tcm_number.yfilter != YFilter.not_set or
                            (self.hour24otn_tcm_reports is not None and self.hour24otn_tcm_reports.has_operation()) or
                            (self.hour24otn_tcm_thresholds is not None and self.hour24otn_tcm_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24otn-tcm" + "[tcm-number='" + self.tcm_number.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tcm_number.is_set or self.tcm_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tcm_number.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24otn-tcm-reports"):
                            if (self.hour24otn_tcm_reports is None):
                                self.hour24otn_tcm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports()
                                self.hour24otn_tcm_reports.parent = self
                                self._children_name_map["hour24otn_tcm_reports"] = "hour24otn-tcm-reports"
                            return self.hour24otn_tcm_reports

                        if (child_yang_name == "hour24otn-tcm-thresholds"):
                            if (self.hour24otn_tcm_thresholds is None):
                                self.hour24otn_tcm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds()
                                self.hour24otn_tcm_thresholds.parent = self
                                self._children_name_map["hour24otn_tcm_thresholds"] = "hour24otn-tcm-thresholds"
                            return self.hour24otn_tcm_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24otn-tcm-reports" or name == "hour24otn-tcm-thresholds" or name == "tcm-number"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tcm-number"):
                            self.tcm_number = value
                            self.tcm_number.value_namespace = name_space
                            self.tcm_number.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.hour24otn_tcm:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.hour24otn_tcm:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hour24otn-tcms" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "hour24otn-tcm"):
                        for c in self.hour24otn_tcm:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.hour24otn_tcm.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hour24otn-tcm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class StsMinute15(Entity):
                """
                set STS threshold
                
                .. attribute:: sts_minute15_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`StsMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15, self).__init__()

                    self.yang_name = "sts-minute15"
                    self.yang_parent_name = "performance-management"

                    self.sts_minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path()
                    self.sts_minute15_path.parent = self
                    self._children_name_map["sts_minute15_path"] = "sts-minute15-path"
                    self._children_yang_names.add("sts-minute15-path")


                class StsMinute15Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sts_minute15_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`StsMinute15PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports>`
                    
                    .. attribute:: sts_minute15_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`StsMinute15PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path, self).__init__()

                        self.yang_name = "sts-minute15-path"
                        self.yang_parent_name = "sts-minute15"

                        self.sts_minute15_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports()
                        self.sts_minute15_path_reports.parent = self
                        self._children_name_map["sts_minute15_path_reports"] = "sts-minute15-path-reports"
                        self._children_yang_names.add("sts-minute15-path-reports")

                        self.sts_minute15_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds()
                        self.sts_minute15_path_thresholds.parent = self
                        self._children_name_map["sts_minute15_path_thresholds"] = "sts-minute15-path-thresholds"
                        self._children_yang_names.add("sts-minute15-path-thresholds")


                    class StsMinute15PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sts_minute15_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`StsMinute15PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports, self).__init__()

                            self.yang_name = "sts-minute15-path-reports"
                            self.yang_parent_name = "sts-minute15-path"

                            self.sts_minute15_path_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports, self).__setattr__(name, value)


                        class StsMinute15PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`StsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsReport>`
                            
                            .. attribute:: enable
                            
                            	Path Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport, self).__init__()

                                self.yang_name = "sts-minute15-path-report"
                                self.yang_parent_name = "sts-minute15-path-reports"

                                self.path_report = YLeaf(YType.enumeration, "path-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-minute15-path-report" + "[path-report='" + self.path_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_report.is_set or self.path_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-report"):
                                    self.path_report = value
                                    self.path_report.value_namespace = name_space
                                    self.path_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sts_minute15_path_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sts_minute15_path_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-minute15-path-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-minute15-path-report"):
                                for c in self.sts_minute15_path_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sts_minute15_path_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-minute15-path-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StsMinute15PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sts_minute15_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StsMinute15PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds, self).__init__()

                            self.yang_name = "sts-minute15-path-thresholds"
                            self.yang_parent_name = "sts-minute15-path"

                            self.sts_minute15_path_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds, self).__setattr__(name, value)


                        class StsMinute15PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`StsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold, self).__init__()

                                self.yang_name = "sts-minute15-path-threshold"
                                self.yang_parent_name = "sts-minute15-path-thresholds"

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_threshold",
                                                "path_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path_threshold.is_set or
                                    self.path_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_threshold.yfilter != YFilter.not_set or
                                    self.path_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-minute15-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_threshold.is_set or self.path_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold.get_name_leafdata())
                                if (self.path_threshold_value.is_set or self.path_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-threshold" or name == "path-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-threshold"):
                                    self.path_threshold = value
                                    self.path_threshold.value_namespace = name_space
                                    self.path_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-threshold-value"):
                                    self.path_threshold_value = value
                                    self.path_threshold_value.value_namespace = name_space
                                    self.path_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sts_minute15_path_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sts_minute15_path_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-minute15-path-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-minute15-path-threshold"):
                                for c in self.sts_minute15_path_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sts_minute15_path_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-minute15-path-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sts_minute15_path_reports is not None and self.sts_minute15_path_reports.has_data()) or
                            (self.sts_minute15_path_thresholds is not None and self.sts_minute15_path_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sts_minute15_path_reports is not None and self.sts_minute15_path_reports.has_operation()) or
                            (self.sts_minute15_path_thresholds is not None and self.sts_minute15_path_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sts-minute15-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sts-minute15-path-reports"):
                            if (self.sts_minute15_path_reports is None):
                                self.sts_minute15_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports()
                                self.sts_minute15_path_reports.parent = self
                                self._children_name_map["sts_minute15_path_reports"] = "sts-minute15-path-reports"
                            return self.sts_minute15_path_reports

                        if (child_yang_name == "sts-minute15-path-thresholds"):
                            if (self.sts_minute15_path_thresholds is None):
                                self.sts_minute15_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds()
                                self.sts_minute15_path_thresholds.parent = self
                                self._children_name_map["sts_minute15_path_thresholds"] = "sts-minute15-path-thresholds"
                            return self.sts_minute15_path_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sts-minute15-path-reports" or name == "sts-minute15-path-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.sts_minute15_path is not None and self.sts_minute15_path.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.sts_minute15_path is not None and self.sts_minute15_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sts-minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sts-minute15-path"):
                        if (self.sts_minute15_path is None):
                            self.sts_minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path()
                            self.sts_minute15_path.parent = self
                            self._children_name_map["sts_minute15_path"] = "sts-minute15-path"
                        return self.sts_minute15_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sts-minute15-path"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Hour24(Entity):
                """
                Configure pm parameters of 24 hour interval
                
                .. attribute:: hour24_optics
                
                	Configure optics performance monitoring
                	**type**\:   :py:class:`Hour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics>`
                
                .. attribute:: hour24fec
                
                	Configure fec g709 performance monitoring
                	**type**\:   :py:class:`Hour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec>`
                
                .. attribute:: hour24otn
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Hour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24, self).__init__()

                    self.yang_name = "hour24"
                    self.yang_parent_name = "performance-management"

                    self.hour24_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics()
                    self.hour24_optics.parent = self
                    self._children_name_map["hour24_optics"] = "hour24-optics"
                    self._children_yang_names.add("hour24-optics")

                    self.hour24fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec()
                    self.hour24fec.parent = self
                    self._children_name_map["hour24fec"] = "hour24fec"
                    self._children_yang_names.add("hour24fec")

                    self.hour24otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn()
                    self.hour24otn.parent = self
                    self._children_name_map["hour24otn"] = "hour24otn"
                    self._children_yang_names.add("hour24otn")


                class Hour24Otn(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: hour24otn_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Hour24OtnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports>`
                    
                    .. attribute:: hour24otn_thresholds
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Hour24OtnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn, self).__init__()

                        self.yang_name = "hour24otn"
                        self.yang_parent_name = "hour24"

                        self.hour24otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports()
                        self.hour24otn_reports.parent = self
                        self._children_name_map["hour24otn_reports"] = "hour24otn-reports"
                        self._children_yang_names.add("hour24otn-reports")

                        self.hour24otn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds()
                        self.hour24otn_thresholds.parent = self
                        self._children_name_map["hour24otn_thresholds"] = "hour24otn-thresholds"
                        self._children_yang_names.add("hour24otn-thresholds")


                    class Hour24OtnThresholds(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: hour24otn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds, self).__init__()

                            self.yang_name = "hour24otn-thresholds"
                            self.yang_parent_name = "hour24otn"

                            self.hour24otn_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds, self).__setattr__(name, value)


                        class Hour24OtnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold, self).__init__()

                                self.yang_name = "hour24otn-threshold"
                                self.yang_parent_name = "hour24otn-thresholds"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24otn-threshold" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24otn_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24otn_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24otn-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24otn-threshold"):
                                for c in self.hour24otn_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24otn_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24otn-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24OtnReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: hour24otn_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports, self).__init__()

                            self.yang_name = "hour24otn-reports"
                            self.yang_parent_name = "hour24otn"

                            self.hour24otn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports, self).__setattr__(name, value)


                        class Hour24OtnReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport, self).__init__()

                                self.yang_name = "hour24otn-report"
                                self.yang_parent_name = "hour24otn-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24otn-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24otn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24otn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24otn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24otn-report"):
                                for c in self.hour24otn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24otn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24otn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.hour24otn_reports is not None and self.hour24otn_reports.has_data()) or
                            (self.hour24otn_thresholds is not None and self.hour24otn_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.hour24otn_reports is not None and self.hour24otn_reports.has_operation()) or
                            (self.hour24otn_thresholds is not None and self.hour24otn_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24otn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24otn-reports"):
                            if (self.hour24otn_reports is None):
                                self.hour24otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports()
                                self.hour24otn_reports.parent = self
                                self._children_name_map["hour24otn_reports"] = "hour24otn-reports"
                            return self.hour24otn_reports

                        if (child_yang_name == "hour24otn-thresholds"):
                            if (self.hour24otn_thresholds is None):
                                self.hour24otn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds()
                                self.hour24otn_thresholds.parent = self
                                self._children_name_map["hour24otn_thresholds"] = "hour24otn-thresholds"
                            return self.hour24otn_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24otn-reports" or name == "hour24otn-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Hour24Optics(Entity):
                    """
                    Configure optics performance monitoring
                    
                    .. attribute:: hour24_optics_reports
                    
                    	set optics TCA reporting status
                    	**type**\:   :py:class:`Hour24OpticsReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports>`
                    
                    .. attribute:: hour24_optics_thresholds
                    
                    	Configure threshold on optics parameters
                    	**type**\:   :py:class:`Hour24OpticsThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics, self).__init__()

                        self.yang_name = "hour24-optics"
                        self.yang_parent_name = "hour24"

                        self.hour24_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports()
                        self.hour24_optics_reports.parent = self
                        self._children_name_map["hour24_optics_reports"] = "hour24-optics-reports"
                        self._children_yang_names.add("hour24-optics-reports")

                        self.hour24_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds()
                        self.hour24_optics_thresholds.parent = self
                        self._children_name_map["hour24_optics_thresholds"] = "hour24-optics-thresholds"
                        self._children_yang_names.add("hour24-optics-thresholds")


                    class Hour24OpticsThresholds(Entity):
                        """
                        Configure threshold on optics parameters
                        
                        .. attribute:: hour24_optics_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds, self).__init__()

                            self.yang_name = "hour24-optics-thresholds"
                            self.yang_parent_name = "hour24-optics"

                            self.hour24_optics_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds, self).__setattr__(name, value)


                        class Hour24OpticsThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: optics_threshold  <key>
                            
                            	Optics Threshold Type
                            	**type**\:   :py:class:`OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsThreshold>`
                            
                            .. attribute:: dbm
                            
                            	Used only for Opt and Opr,To Enter Threshold in dbm use 1
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: optics_threshold_value
                            
                            	Optics Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold, self).__init__()

                                self.yang_name = "hour24-optics-threshold"
                                self.yang_parent_name = "hour24-optics-thresholds"

                                self.optics_threshold = YLeaf(YType.enumeration, "optics-threshold")

                                self.dbm = YLeaf(YType.int32, "dbm")

                                self.optics_threshold_value = YLeaf(YType.int32, "optics-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("optics_threshold",
                                                "dbm",
                                                "optics_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.optics_threshold.is_set or
                                    self.dbm.is_set or
                                    self.optics_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.optics_threshold.yfilter != YFilter.not_set or
                                    self.dbm.yfilter != YFilter.not_set or
                                    self.optics_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24-optics-threshold" + "[optics-threshold='" + self.optics_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.optics_threshold.is_set or self.optics_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_threshold.get_name_leafdata())
                                if (self.dbm.is_set or self.dbm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dbm.get_name_leafdata())
                                if (self.optics_threshold_value.is_set or self.optics_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-threshold" or name == "dbm" or name == "optics-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "optics-threshold"):
                                    self.optics_threshold = value
                                    self.optics_threshold.value_namespace = name_space
                                    self.optics_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "dbm"):
                                    self.dbm = value
                                    self.dbm.value_namespace = name_space
                                    self.dbm.value_namespace_prefix = name_space_prefix
                                if(value_path == "optics-threshold-value"):
                                    self.optics_threshold_value = value
                                    self.optics_threshold_value.value_namespace = name_space
                                    self.optics_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24_optics_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24_optics_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24-optics-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24-optics-threshold"):
                                for c in self.hour24_optics_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24_optics_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24-optics-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24OpticsReports(Entity):
                        """
                        set optics TCA reporting status
                        
                        .. attribute:: hour24_optics_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports, self).__init__()

                            self.yang_name = "hour24-optics-reports"
                            self.yang_parent_name = "hour24-optics"

                            self.hour24_optics_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports, self).__setattr__(name, value)


                        class Hour24OpticsReport(Entity):
                            """
                            none
                            
                            .. attribute:: optics_report  <key>
                            
                            	Optics Report Type
                            	**type**\:   :py:class:`OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport, self).__init__()

                                self.yang_name = "hour24-optics-report"
                                self.yang_parent_name = "hour24-optics-reports"

                                self.optics_report = YLeaf(YType.enumeration, "optics-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("optics_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.optics_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.optics_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24-optics-report" + "[optics-report='" + self.optics_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.optics_report.is_set or self.optics_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "optics-report"):
                                    self.optics_report = value
                                    self.optics_report.value_namespace = name_space
                                    self.optics_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24_optics_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24_optics_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24-optics-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24-optics-report"):
                                for c in self.hour24_optics_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24_optics_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24-optics-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.hour24_optics_reports is not None and self.hour24_optics_reports.has_data()) or
                            (self.hour24_optics_thresholds is not None and self.hour24_optics_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.hour24_optics_reports is not None and self.hour24_optics_reports.has_operation()) or
                            (self.hour24_optics_thresholds is not None and self.hour24_optics_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24-optics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24-optics-reports"):
                            if (self.hour24_optics_reports is None):
                                self.hour24_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports()
                                self.hour24_optics_reports.parent = self
                                self._children_name_map["hour24_optics_reports"] = "hour24-optics-reports"
                            return self.hour24_optics_reports

                        if (child_yang_name == "hour24-optics-thresholds"):
                            if (self.hour24_optics_thresholds is None):
                                self.hour24_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds()
                                self.hour24_optics_thresholds.parent = self
                                self._children_name_map["hour24_optics_thresholds"] = "hour24-optics-thresholds"
                            return self.hour24_optics_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24-optics-reports" or name == "hour24-optics-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Hour24Fec(Entity):
                    """
                    Configure fec g709 performance monitoring
                    
                    .. attribute:: hour24fec_reports
                    
                    	set fec TCA reporting status
                    	**type**\:   :py:class:`Hour24FecReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports>`
                    
                    .. attribute:: hour24fec_thresholds
                    
                    	Configure fec threshold
                    	**type**\:   :py:class:`Hour24FecThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec, self).__init__()

                        self.yang_name = "hour24fec"
                        self.yang_parent_name = "hour24"

                        self.hour24fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports()
                        self.hour24fec_reports.parent = self
                        self._children_name_map["hour24fec_reports"] = "hour24fec-reports"
                        self._children_yang_names.add("hour24fec-reports")

                        self.hour24fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds()
                        self.hour24fec_thresholds.parent = self
                        self._children_name_map["hour24fec_thresholds"] = "hour24fec-thresholds"
                        self._children_yang_names.add("hour24fec-thresholds")


                    class Hour24FecThresholds(Entity):
                        """
                        Configure fec threshold
                        
                        .. attribute:: hour24fec_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds, self).__init__()

                            self.yang_name = "hour24fec-thresholds"
                            self.yang_parent_name = "hour24fec"

                            self.hour24fec_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds, self).__setattr__(name, value)


                        class Hour24FecThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: fec_threshold  <key>
                            
                            	Fec Threshold Type
                            	**type**\:   :py:class:`FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecThreshold>`
                            
                            .. attribute:: fec_threshold_value
                            
                            	Fec threshold value
                            	**type**\:  str
                            
                            	**length:** 1..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold, self).__init__()

                                self.yang_name = "hour24fec-threshold"
                                self.yang_parent_name = "hour24fec-thresholds"

                                self.fec_threshold = YLeaf(YType.enumeration, "fec-threshold")

                                self.fec_threshold_value = YLeaf(YType.str, "fec-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fec_threshold",
                                                "fec_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fec_threshold.is_set or
                                    self.fec_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fec_threshold.yfilter != YFilter.not_set or
                                    self.fec_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24fec-threshold" + "[fec-threshold='" + self.fec_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fec_threshold.is_set or self.fec_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_threshold.get_name_leafdata())
                                if (self.fec_threshold_value.is_set or self.fec_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fec-threshold" or name == "fec-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fec-threshold"):
                                    self.fec_threshold = value
                                    self.fec_threshold.value_namespace = name_space
                                    self.fec_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "fec-threshold-value"):
                                    self.fec_threshold_value = value
                                    self.fec_threshold_value.value_namespace = name_space
                                    self.fec_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24fec_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24fec_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24fec-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24fec-threshold"):
                                for c in self.hour24fec_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24fec_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24fec-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24FecReports(Entity):
                        """
                        set fec TCA reporting status
                        
                        .. attribute:: hour24fec_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports, self).__init__()

                            self.yang_name = "hour24fec-reports"
                            self.yang_parent_name = "hour24fec"

                            self.hour24fec_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports, self).__setattr__(name, value)


                        class Hour24FecReport(Entity):
                            """
                            none
                            
                            .. attribute:: fec_report  <key>
                            
                            	Fec Report type
                            	**type**\:   :py:class:`FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecReport>`
                            
                            .. attribute:: enable
                            
                            	Fec Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport, self).__init__()

                                self.yang_name = "hour24fec-report"
                                self.yang_parent_name = "hour24fec-reports"

                                self.fec_report = YLeaf(YType.enumeration, "fec-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fec_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fec_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fec_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24fec-report" + "[fec-report='" + self.fec_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fec_report.is_set or self.fec_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fec-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fec-report"):
                                    self.fec_report = value
                                    self.fec_report.value_namespace = name_space
                                    self.fec_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24fec_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24fec_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24fec-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24fec-report"):
                                for c in self.hour24fec_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24fec_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24fec-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.hour24fec_reports is not None and self.hour24fec_reports.has_data()) or
                            (self.hour24fec_thresholds is not None and self.hour24fec_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.hour24fec_reports is not None and self.hour24fec_reports.has_operation()) or
                            (self.hour24fec_thresholds is not None and self.hour24fec_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24fec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24fec-reports"):
                            if (self.hour24fec_reports is None):
                                self.hour24fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports()
                                self.hour24fec_reports.parent = self
                                self._children_name_map["hour24fec_reports"] = "hour24fec-reports"
                            return self.hour24fec_reports

                        if (child_yang_name == "hour24fec-thresholds"):
                            if (self.hour24fec_thresholds is None):
                                self.hour24fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds()
                                self.hour24fec_thresholds.parent = self
                                self._children_name_map["hour24fec_thresholds"] = "hour24fec-thresholds"
                            return self.hour24fec_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24fec-reports" or name == "hour24fec-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.hour24_optics is not None and self.hour24_optics.has_data()) or
                        (self.hour24fec is not None and self.hour24fec.has_data()) or
                        (self.hour24otn is not None and self.hour24otn.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.hour24_optics is not None and self.hour24_optics.has_operation()) or
                        (self.hour24fec is not None and self.hour24fec.has_operation()) or
                        (self.hour24otn is not None and self.hour24otn.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "hour24-optics"):
                        if (self.hour24_optics is None):
                            self.hour24_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics()
                            self.hour24_optics.parent = self
                            self._children_name_map["hour24_optics"] = "hour24-optics"
                        return self.hour24_optics

                    if (child_yang_name == "hour24fec"):
                        if (self.hour24fec is None):
                            self.hour24fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec()
                            self.hour24fec.parent = self
                            self._children_name_map["hour24fec"] = "hour24fec"
                        return self.hour24fec

                    if (child_yang_name == "hour24otn"):
                        if (self.hour24otn is None):
                            self.hour24otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn()
                            self.hour24otn.parent = self
                            self._children_name_map["hour24otn"] = "hour24otn"
                        return self.hour24otn

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hour24-optics" or name == "hour24fec" or name == "hour24otn"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class HoVcMinute15(Entity):
                """
                set HO\_VC threshold
                
                .. attribute:: ho_vc_minute15ho_vc
                
                	Configure ho\_vc performance monitoring
                	**type**\:   :py:class:`HoVcMinute15HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15, self).__init__()

                    self.yang_name = "ho-vc-minute15"
                    self.yang_parent_name = "performance-management"

                    self.ho_vc_minute15ho_vc = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc()
                    self.ho_vc_minute15ho_vc.parent = self
                    self._children_name_map["ho_vc_minute15ho_vc"] = "ho-vc-minute15ho-vc"
                    self._children_yang_names.add("ho-vc-minute15ho-vc")


                class HoVcMinute15HoVc(Entity):
                    """
                    Configure ho\_vc performance monitoring
                    
                    .. attribute:: ho_vc_minute15ho_vc_reports
                    
                    	set ho\_vc TCA reporting status
                    	**type**\:   :py:class:`HoVcMinute15HoVcReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports>`
                    
                    .. attribute:: ho_vc_minute15ho_vc_thresholds
                    
                    	Configure threshold on ho\_vc parameters
                    	**type**\:   :py:class:`HoVcMinute15HoVcThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc, self).__init__()

                        self.yang_name = "ho-vc-minute15ho-vc"
                        self.yang_parent_name = "ho-vc-minute15"

                        self.ho_vc_minute15ho_vc_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports()
                        self.ho_vc_minute15ho_vc_reports.parent = self
                        self._children_name_map["ho_vc_minute15ho_vc_reports"] = "ho-vc-minute15ho-vc-reports"
                        self._children_yang_names.add("ho-vc-minute15ho-vc-reports")

                        self.ho_vc_minute15ho_vc_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds()
                        self.ho_vc_minute15ho_vc_thresholds.parent = self
                        self._children_name_map["ho_vc_minute15ho_vc_thresholds"] = "ho-vc-minute15ho-vc-thresholds"
                        self._children_yang_names.add("ho-vc-minute15ho-vc-thresholds")


                    class HoVcMinute15HoVcReports(Entity):
                        """
                        set ho\_vc TCA reporting status
                        
                        .. attribute:: ho_vc_minute15ho_vc_report
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcMinute15HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports, self).__init__()

                            self.yang_name = "ho-vc-minute15ho-vc-reports"
                            self.yang_parent_name = "ho-vc-minute15ho-vc"

                            self.ho_vc_minute15ho_vc_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports, self).__setattr__(name, value)


                        class HoVcMinute15HoVcReport(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_report  <key>
                            
                            	ho\_vc Report Type
                            	**type**\:   :py:class:`HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcReport>`
                            
                            .. attribute:: enable
                            
                            	ho\_vc Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport, self).__init__()

                                self.yang_name = "ho-vc-minute15ho-vc-report"
                                self.yang_parent_name = "ho-vc-minute15ho-vc-reports"

                                self.ho_vc_report = YLeaf(YType.enumeration, "ho-vc-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ho_vc_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ho_vc_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ho_vc_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-minute15ho-vc-report" + "[ho-vc-report='" + self.ho_vc_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ho_vc_report.is_set or self.ho_vc_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ho_vc_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ho-vc-report"):
                                    self.ho_vc_report = value
                                    self.ho_vc_report.value_namespace = name_space
                                    self.ho_vc_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ho_vc_minute15ho_vc_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ho_vc_minute15ho_vc_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-minute15ho-vc-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-minute15ho-vc-report"):
                                for c in self.ho_vc_minute15ho_vc_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ho_vc_minute15ho_vc_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-minute15ho-vc-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class HoVcMinute15HoVcThresholds(Entity):
                        """
                        Configure threshold on ho\_vc parameters
                        
                        .. attribute:: ho_vc_minute15ho_vc_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcMinute15HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds, self).__init__()

                            self.yang_name = "ho-vc-minute15ho-vc-thresholds"
                            self.yang_parent_name = "ho-vc-minute15ho-vc"

                            self.ho_vc_minute15ho_vc_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds, self).__setattr__(name, value)


                        class HoVcMinute15HoVcThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_threshold  <key>
                            
                            	ho\_vc Threshold Type
                            	**type**\:   :py:class:`HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcThreshold>`
                            
                            .. attribute:: ho_vc_threshold_value
                            
                            	ho\_vc Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold, self).__init__()

                                self.yang_name = "ho-vc-minute15ho-vc-threshold"
                                self.yang_parent_name = "ho-vc-minute15ho-vc-thresholds"

                                self.ho_vc_threshold = YLeaf(YType.enumeration, "ho-vc-threshold")

                                self.ho_vc_threshold_value = YLeaf(YType.int32, "ho-vc-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ho_vc_threshold",
                                                "ho_vc_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ho_vc_threshold.is_set or
                                    self.ho_vc_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ho_vc_threshold.yfilter != YFilter.not_set or
                                    self.ho_vc_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-minute15ho-vc-threshold" + "[ho-vc-threshold='" + self.ho_vc_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ho_vc_threshold.is_set or self.ho_vc_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ho_vc_threshold.get_name_leafdata())
                                if (self.ho_vc_threshold_value.is_set or self.ho_vc_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ho_vc_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-threshold" or name == "ho-vc-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ho-vc-threshold"):
                                    self.ho_vc_threshold = value
                                    self.ho_vc_threshold.value_namespace = name_space
                                    self.ho_vc_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ho-vc-threshold-value"):
                                    self.ho_vc_threshold_value = value
                                    self.ho_vc_threshold_value.value_namespace = name_space
                                    self.ho_vc_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ho_vc_minute15ho_vc_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ho_vc_minute15ho_vc_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-minute15ho-vc-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-minute15ho-vc-threshold"):
                                for c in self.ho_vc_minute15ho_vc_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ho_vc_minute15ho_vc_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-minute15ho-vc-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.ho_vc_minute15ho_vc_reports is not None and self.ho_vc_minute15ho_vc_reports.has_data()) or
                            (self.ho_vc_minute15ho_vc_thresholds is not None and self.ho_vc_minute15ho_vc_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.ho_vc_minute15ho_vc_reports is not None and self.ho_vc_minute15ho_vc_reports.has_operation()) or
                            (self.ho_vc_minute15ho_vc_thresholds is not None and self.ho_vc_minute15ho_vc_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ho-vc-minute15ho-vc" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ho-vc-minute15ho-vc-reports"):
                            if (self.ho_vc_minute15ho_vc_reports is None):
                                self.ho_vc_minute15ho_vc_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports()
                                self.ho_vc_minute15ho_vc_reports.parent = self
                                self._children_name_map["ho_vc_minute15ho_vc_reports"] = "ho-vc-minute15ho-vc-reports"
                            return self.ho_vc_minute15ho_vc_reports

                        if (child_yang_name == "ho-vc-minute15ho-vc-thresholds"):
                            if (self.ho_vc_minute15ho_vc_thresholds is None):
                                self.ho_vc_minute15ho_vc_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds()
                                self.ho_vc_minute15ho_vc_thresholds.parent = self
                                self._children_name_map["ho_vc_minute15ho_vc_thresholds"] = "ho-vc-minute15ho-vc-thresholds"
                            return self.ho_vc_minute15ho_vc_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ho-vc-minute15ho-vc-reports" or name == "ho-vc-minute15ho-vc-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.ho_vc_minute15ho_vc is not None and self.ho_vc_minute15ho_vc.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ho_vc_minute15ho_vc is not None and self.ho_vc_minute15ho_vc.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ho-vc-minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ho-vc-minute15ho-vc"):
                        if (self.ho_vc_minute15ho_vc is None):
                            self.ho_vc_minute15ho_vc = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc()
                            self.ho_vc_minute15ho_vc.parent = self
                            self._children_name_map["ho_vc_minute15ho_vc"] = "ho-vc-minute15ho-vc"
                        return self.ho_vc_minute15ho_vc

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ho-vc-minute15ho-vc"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class StsHour24(Entity):
                """
                set STS threshold
                
                .. attribute:: sts_hour24_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`StsHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24, self).__init__()

                    self.yang_name = "sts-hour24"
                    self.yang_parent_name = "performance-management"

                    self.sts_hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path()
                    self.sts_hour24_path.parent = self
                    self._children_name_map["sts_hour24_path"] = "sts-hour24-path"
                    self._children_yang_names.add("sts-hour24-path")


                class StsHour24Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sts_hour24_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`StsHour24PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports>`
                    
                    .. attribute:: sts_hour24_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`StsHour24PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path, self).__init__()

                        self.yang_name = "sts-hour24-path"
                        self.yang_parent_name = "sts-hour24"

                        self.sts_hour24_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports()
                        self.sts_hour24_path_reports.parent = self
                        self._children_name_map["sts_hour24_path_reports"] = "sts-hour24-path-reports"
                        self._children_yang_names.add("sts-hour24-path-reports")

                        self.sts_hour24_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds()
                        self.sts_hour24_path_thresholds.parent = self
                        self._children_name_map["sts_hour24_path_thresholds"] = "sts-hour24-path-thresholds"
                        self._children_yang_names.add("sts-hour24-path-thresholds")


                    class StsHour24PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sts_hour24_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StsHour24PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds, self).__init__()

                            self.yang_name = "sts-hour24-path-thresholds"
                            self.yang_parent_name = "sts-hour24-path"

                            self.sts_hour24_path_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds, self).__setattr__(name, value)


                        class StsHour24PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`StsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold, self).__init__()

                                self.yang_name = "sts-hour24-path-threshold"
                                self.yang_parent_name = "sts-hour24-path-thresholds"

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_threshold",
                                                "path_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path_threshold.is_set or
                                    self.path_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_threshold.yfilter != YFilter.not_set or
                                    self.path_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-hour24-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_threshold.is_set or self.path_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold.get_name_leafdata())
                                if (self.path_threshold_value.is_set or self.path_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-threshold" or name == "path-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-threshold"):
                                    self.path_threshold = value
                                    self.path_threshold.value_namespace = name_space
                                    self.path_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-threshold-value"):
                                    self.path_threshold_value = value
                                    self.path_threshold_value.value_namespace = name_space
                                    self.path_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sts_hour24_path_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sts_hour24_path_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-hour24-path-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-hour24-path-threshold"):
                                for c in self.sts_hour24_path_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sts_hour24_path_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-hour24-path-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StsHour24PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sts_hour24_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`StsHour24PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports, self).__init__()

                            self.yang_name = "sts-hour24-path-reports"
                            self.yang_parent_name = "sts-hour24-path"

                            self.sts_hour24_path_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports, self).__setattr__(name, value)


                        class StsHour24PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`StsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsReport>`
                            
                            .. attribute:: enable
                            
                            	Path Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport, self).__init__()

                                self.yang_name = "sts-hour24-path-report"
                                self.yang_parent_name = "sts-hour24-path-reports"

                                self.path_report = YLeaf(YType.enumeration, "path-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-hour24-path-report" + "[path-report='" + self.path_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_report.is_set or self.path_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-report"):
                                    self.path_report = value
                                    self.path_report.value_namespace = name_space
                                    self.path_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sts_hour24_path_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sts_hour24_path_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-hour24-path-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-hour24-path-report"):
                                for c in self.sts_hour24_path_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sts_hour24_path_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-hour24-path-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sts_hour24_path_reports is not None and self.sts_hour24_path_reports.has_data()) or
                            (self.sts_hour24_path_thresholds is not None and self.sts_hour24_path_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sts_hour24_path_reports is not None and self.sts_hour24_path_reports.has_operation()) or
                            (self.sts_hour24_path_thresholds is not None and self.sts_hour24_path_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sts-hour24-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sts-hour24-path-reports"):
                            if (self.sts_hour24_path_reports is None):
                                self.sts_hour24_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports()
                                self.sts_hour24_path_reports.parent = self
                                self._children_name_map["sts_hour24_path_reports"] = "sts-hour24-path-reports"
                            return self.sts_hour24_path_reports

                        if (child_yang_name == "sts-hour24-path-thresholds"):
                            if (self.sts_hour24_path_thresholds is None):
                                self.sts_hour24_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds()
                                self.sts_hour24_path_thresholds.parent = self
                                self._children_name_map["sts_hour24_path_thresholds"] = "sts-hour24-path-thresholds"
                            return self.sts_hour24_path_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sts-hour24-path-reports" or name == "sts-hour24-path-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.sts_hour24_path is not None and self.sts_hour24_path.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.sts_hour24_path is not None and self.sts_hour24_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sts-hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sts-hour24-path"):
                        if (self.sts_hour24_path is None):
                            self.sts_hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path()
                            self.sts_hour24_path.parent = self
                            self._children_name_map["sts_hour24_path"] = "sts-hour24-path"
                        return self.sts_hour24_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sts-hour24-path"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class StmMinute15(Entity):
                """
                set STM threshold
                
                .. attribute:: stm_minute15_stm
                
                	Configure stm performance monitoring
                	**type**\:   :py:class:`StmMinute15Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15, self).__init__()

                    self.yang_name = "stm-minute15"
                    self.yang_parent_name = "performance-management"

                    self.stm_minute15_stm = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm()
                    self.stm_minute15_stm.parent = self
                    self._children_name_map["stm_minute15_stm"] = "stm-minute15-stm"
                    self._children_yang_names.add("stm-minute15-stm")


                class StmMinute15Stm(Entity):
                    """
                    Configure stm performance monitoring
                    
                    .. attribute:: stm_minute15_stm_reports
                    
                    	set stm TCA reporting status
                    	**type**\:   :py:class:`StmMinute15StmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports>`
                    
                    .. attribute:: stm_minute15_stm_thresholds
                    
                    	Configure threshold on stm parameters
                    	**type**\:   :py:class:`StmMinute15StmThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm, self).__init__()

                        self.yang_name = "stm-minute15-stm"
                        self.yang_parent_name = "stm-minute15"

                        self.stm_minute15_stm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports()
                        self.stm_minute15_stm_reports.parent = self
                        self._children_name_map["stm_minute15_stm_reports"] = "stm-minute15-stm-reports"
                        self._children_yang_names.add("stm-minute15-stm-reports")

                        self.stm_minute15_stm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds()
                        self.stm_minute15_stm_thresholds.parent = self
                        self._children_name_map["stm_minute15_stm_thresholds"] = "stm-minute15-stm-thresholds"
                        self._children_yang_names.add("stm-minute15-stm-thresholds")


                    class StmMinute15StmReports(Entity):
                        """
                        set stm TCA reporting status
                        
                        .. attribute:: stm_minute15_stm_report
                        
                        	none
                        	**type**\: list of    :py:class:`StmMinute15StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports, self).__init__()

                            self.yang_name = "stm-minute15-stm-reports"
                            self.yang_parent_name = "stm-minute15-stm"

                            self.stm_minute15_stm_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports, self).__setattr__(name, value)


                        class StmMinute15StmReport(Entity):
                            """
                            none
                            
                            .. attribute:: stm_report  <key>
                            
                            	Stm Report Type
                            	**type**\:   :py:class:`StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmReport>`
                            
                            .. attribute:: enable
                            
                            	Stm Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport, self).__init__()

                                self.yang_name = "stm-minute15-stm-report"
                                self.yang_parent_name = "stm-minute15-stm-reports"

                                self.stm_report = YLeaf(YType.enumeration, "stm-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("stm_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.stm_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.stm_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-minute15-stm-report" + "[stm-report='" + self.stm_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.stm_report.is_set or self.stm_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stm_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "stm-report"):
                                    self.stm_report = value
                                    self.stm_report.value_namespace = name_space
                                    self.stm_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.stm_minute15_stm_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.stm_minute15_stm_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-minute15-stm-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-minute15-stm-report"):
                                for c in self.stm_minute15_stm_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.stm_minute15_stm_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-minute15-stm-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StmMinute15StmThresholds(Entity):
                        """
                        Configure threshold on stm parameters
                        
                        .. attribute:: stm_minute15_stm_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StmMinute15StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds, self).__init__()

                            self.yang_name = "stm-minute15-stm-thresholds"
                            self.yang_parent_name = "stm-minute15-stm"

                            self.stm_minute15_stm_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds, self).__setattr__(name, value)


                        class StmMinute15StmThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: stm_threshold  <key>
                            
                            	Stm Threshold Type
                            	**type**\:   :py:class:`StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmThreshold>`
                            
                            .. attribute:: stm_threshold_value
                            
                            	Stm Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold, self).__init__()

                                self.yang_name = "stm-minute15-stm-threshold"
                                self.yang_parent_name = "stm-minute15-stm-thresholds"

                                self.stm_threshold = YLeaf(YType.enumeration, "stm-threshold")

                                self.stm_threshold_value = YLeaf(YType.int32, "stm-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("stm_threshold",
                                                "stm_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.stm_threshold.is_set or
                                    self.stm_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.stm_threshold.yfilter != YFilter.not_set or
                                    self.stm_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-minute15-stm-threshold" + "[stm-threshold='" + self.stm_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.stm_threshold.is_set or self.stm_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stm_threshold.get_name_leafdata())
                                if (self.stm_threshold_value.is_set or self.stm_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stm_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-threshold" or name == "stm-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "stm-threshold"):
                                    self.stm_threshold = value
                                    self.stm_threshold.value_namespace = name_space
                                    self.stm_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "stm-threshold-value"):
                                    self.stm_threshold_value = value
                                    self.stm_threshold_value.value_namespace = name_space
                                    self.stm_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.stm_minute15_stm_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.stm_minute15_stm_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-minute15-stm-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-minute15-stm-threshold"):
                                for c in self.stm_minute15_stm_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.stm_minute15_stm_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-minute15-stm-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.stm_minute15_stm_reports is not None and self.stm_minute15_stm_reports.has_data()) or
                            (self.stm_minute15_stm_thresholds is not None and self.stm_minute15_stm_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.stm_minute15_stm_reports is not None and self.stm_minute15_stm_reports.has_operation()) or
                            (self.stm_minute15_stm_thresholds is not None and self.stm_minute15_stm_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "stm-minute15-stm" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "stm-minute15-stm-reports"):
                            if (self.stm_minute15_stm_reports is None):
                                self.stm_minute15_stm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports()
                                self.stm_minute15_stm_reports.parent = self
                                self._children_name_map["stm_minute15_stm_reports"] = "stm-minute15-stm-reports"
                            return self.stm_minute15_stm_reports

                        if (child_yang_name == "stm-minute15-stm-thresholds"):
                            if (self.stm_minute15_stm_thresholds is None):
                                self.stm_minute15_stm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds()
                                self.stm_minute15_stm_thresholds.parent = self
                                self._children_name_map["stm_minute15_stm_thresholds"] = "stm-minute15-stm-thresholds"
                            return self.stm_minute15_stm_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "stm-minute15-stm-reports" or name == "stm-minute15-stm-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.stm_minute15_stm is not None and self.stm_minute15_stm.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.stm_minute15_stm is not None and self.stm_minute15_stm.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "stm-minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "stm-minute15-stm"):
                        if (self.stm_minute15_stm is None):
                            self.stm_minute15_stm = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm()
                            self.stm_minute15_stm.parent = self
                            self._children_name_map["stm_minute15_stm"] = "stm-minute15-stm"
                        return self.stm_minute15_stm

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "stm-minute15-stm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SonetHour24(Entity):
                """
                set Sonet threshold
                
                .. attribute:: sonet_hour24_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`SonetHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn>`
                
                .. attribute:: sonet_hour24_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`SonetHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24, self).__init__()

                    self.yang_name = "sonet-hour24"
                    self.yang_parent_name = "performance-management"

                    self.sonet_hour24_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn()
                    self.sonet_hour24_ocn.parent = self
                    self._children_name_map["sonet_hour24_ocn"] = "sonet-hour24-ocn"
                    self._children_yang_names.add("sonet-hour24-ocn")

                    self.sonet_hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path()
                    self.sonet_hour24_path.parent = self
                    self._children_name_map["sonet_hour24_path"] = "sonet-hour24-path"
                    self._children_yang_names.add("sonet-hour24-path")


                class SonetHour24Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sonet_hour24_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`SonetHour24PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports>`
                    
                    .. attribute:: sonet_hour24_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`SonetHour24PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path, self).__init__()

                        self.yang_name = "sonet-hour24-path"
                        self.yang_parent_name = "sonet-hour24"

                        self.sonet_hour24_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports()
                        self.sonet_hour24_path_reports.parent = self
                        self._children_name_map["sonet_hour24_path_reports"] = "sonet-hour24-path-reports"
                        self._children_yang_names.add("sonet-hour24-path-reports")

                        self.sonet_hour24_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds()
                        self.sonet_hour24_path_thresholds.parent = self
                        self._children_name_map["sonet_hour24_path_thresholds"] = "sonet-hour24-path-thresholds"
                        self._children_yang_names.add("sonet-hour24-path-thresholds")


                    class SonetHour24PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sonet_hour24_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds, self).__init__()

                            self.yang_name = "sonet-hour24-path-thresholds"
                            self.yang_parent_name = "sonet-hour24-path"

                            self.sonet_hour24_path_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds, self).__setattr__(name, value)


                        class SonetHour24PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold, self).__init__()

                                self.yang_name = "sonet-hour24-path-threshold"
                                self.yang_parent_name = "sonet-hour24-path-thresholds"

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_threshold",
                                                "path_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path_threshold.is_set or
                                    self.path_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_threshold.yfilter != YFilter.not_set or
                                    self.path_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_threshold.is_set or self.path_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold.get_name_leafdata())
                                if (self.path_threshold_value.is_set or self.path_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-threshold" or name == "path-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-threshold"):
                                    self.path_threshold = value
                                    self.path_threshold.value_namespace = name_space
                                    self.path_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-threshold-value"):
                                    self.path_threshold_value = value
                                    self.path_threshold_value.value_namespace = name_space
                                    self.path_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_hour24_path_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_hour24_path_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-hour24-path-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-hour24-path-threshold"):
                                for c in self.sonet_hour24_path_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_hour24_path_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-hour24-path-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SonetHour24PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sonet_hour24_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports, self).__init__()

                            self.yang_name = "sonet-hour24-path-reports"
                            self.yang_parent_name = "sonet-hour24-path"

                            self.sonet_hour24_path_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports, self).__setattr__(name, value)


                        class SonetHour24PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport, self).__init__()

                                self.yang_name = "sonet-hour24-path-report"
                                self.yang_parent_name = "sonet-hour24-path-reports"

                                self.path_report = YLeaf(YType.enumeration, "path-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.path_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24-path-report" + "[path-report='" + self.path_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path_report.is_set or self.path_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path-report"):
                                    self.path_report = value
                                    self.path_report.value_namespace = name_space
                                    self.path_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_hour24_path_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_hour24_path_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-hour24-path-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-hour24-path-report"):
                                for c in self.sonet_hour24_path_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_hour24_path_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-hour24-path-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sonet_hour24_path_reports is not None and self.sonet_hour24_path_reports.has_data()) or
                            (self.sonet_hour24_path_thresholds is not None and self.sonet_hour24_path_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sonet_hour24_path_reports is not None and self.sonet_hour24_path_reports.has_operation()) or
                            (self.sonet_hour24_path_thresholds is not None and self.sonet_hour24_path_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sonet-hour24-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sonet-hour24-path-reports"):
                            if (self.sonet_hour24_path_reports is None):
                                self.sonet_hour24_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports()
                                self.sonet_hour24_path_reports.parent = self
                                self._children_name_map["sonet_hour24_path_reports"] = "sonet-hour24-path-reports"
                            return self.sonet_hour24_path_reports

                        if (child_yang_name == "sonet-hour24-path-thresholds"):
                            if (self.sonet_hour24_path_thresholds is None):
                                self.sonet_hour24_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds()
                                self.sonet_hour24_path_thresholds.parent = self
                                self._children_name_map["sonet_hour24_path_thresholds"] = "sonet-hour24-path-thresholds"
                            return self.sonet_hour24_path_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sonet-hour24-path-reports" or name == "sonet-hour24-path-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SonetHour24Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: sonet_hour24_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`SonetHour24OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports>`
                    
                    .. attribute:: sonet_hour24_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`SonetHour24OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn, self).__init__()

                        self.yang_name = "sonet-hour24-ocn"
                        self.yang_parent_name = "sonet-hour24"

                        self.sonet_hour24_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports()
                        self.sonet_hour24_ocn_reports.parent = self
                        self._children_name_map["sonet_hour24_ocn_reports"] = "sonet-hour24-ocn-reports"
                        self._children_yang_names.add("sonet-hour24-ocn-reports")

                        self.sonet_hour24_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds()
                        self.sonet_hour24_ocn_thresholds.parent = self
                        self._children_name_map["sonet_hour24_ocn_thresholds"] = "sonet-hour24-ocn-thresholds"
                        self._children_yang_names.add("sonet-hour24-ocn-thresholds")


                    class SonetHour24OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: sonet_hour24_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds, self).__init__()

                            self.yang_name = "sonet-hour24-ocn-thresholds"
                            self.yang_parent_name = "sonet-hour24-ocn"

                            self.sonet_hour24_ocn_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds, self).__setattr__(name, value)


                        class SonetHour24OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold, self).__init__()

                                self.yang_name = "sonet-hour24-ocn-threshold"
                                self.yang_parent_name = "sonet-hour24-ocn-thresholds"

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_threshold",
                                                "ocn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ocn_threshold.is_set or
                                    self.ocn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_threshold.yfilter != YFilter.not_set or
                                    self.ocn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_threshold.is_set or self.ocn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold.get_name_leafdata())
                                if (self.ocn_threshold_value.is_set or self.ocn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-threshold" or name == "ocn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-threshold"):
                                    self.ocn_threshold = value
                                    self.ocn_threshold.value_namespace = name_space
                                    self.ocn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ocn-threshold-value"):
                                    self.ocn_threshold_value = value
                                    self.ocn_threshold_value.value_namespace = name_space
                                    self.ocn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_hour24_ocn_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_hour24_ocn_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-hour24-ocn-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-hour24-ocn-threshold"):
                                for c in self.sonet_hour24_ocn_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_hour24_ocn_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-hour24-ocn-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SonetHour24OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: sonet_hour24_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports, self).__init__()

                            self.yang_name = "sonet-hour24-ocn-reports"
                            self.yang_parent_name = "sonet-hour24-ocn"

                            self.sonet_hour24_ocn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports, self).__setattr__(name, value)


                        class SonetHour24OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport, self).__init__()

                                self.yang_name = "sonet-hour24-ocn-report"
                                self.yang_parent_name = "sonet-hour24-ocn-reports"

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.ocn_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_report.is_set or self.ocn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-report"):
                                    self.ocn_report = value
                                    self.ocn_report.value_namespace = name_space
                                    self.ocn_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sonet_hour24_ocn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.sonet_hour24_ocn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-hour24-ocn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-hour24-ocn-report"):
                                for c in self.sonet_hour24_ocn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sonet_hour24_ocn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-hour24-ocn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sonet_hour24_ocn_reports is not None and self.sonet_hour24_ocn_reports.has_data()) or
                            (self.sonet_hour24_ocn_thresholds is not None and self.sonet_hour24_ocn_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sonet_hour24_ocn_reports is not None and self.sonet_hour24_ocn_reports.has_operation()) or
                            (self.sonet_hour24_ocn_thresholds is not None and self.sonet_hour24_ocn_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sonet-hour24-ocn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sonet-hour24-ocn-reports"):
                            if (self.sonet_hour24_ocn_reports is None):
                                self.sonet_hour24_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports()
                                self.sonet_hour24_ocn_reports.parent = self
                                self._children_name_map["sonet_hour24_ocn_reports"] = "sonet-hour24-ocn-reports"
                            return self.sonet_hour24_ocn_reports

                        if (child_yang_name == "sonet-hour24-ocn-thresholds"):
                            if (self.sonet_hour24_ocn_thresholds is None):
                                self.sonet_hour24_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds()
                                self.sonet_hour24_ocn_thresholds.parent = self
                                self._children_name_map["sonet_hour24_ocn_thresholds"] = "sonet-hour24-ocn-thresholds"
                            return self.sonet_hour24_ocn_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sonet-hour24-ocn-reports" or name == "sonet-hour24-ocn-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.sonet_hour24_ocn is not None and self.sonet_hour24_ocn.has_data()) or
                        (self.sonet_hour24_path is not None and self.sonet_hour24_path.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.sonet_hour24_ocn is not None and self.sonet_hour24_ocn.has_operation()) or
                        (self.sonet_hour24_path is not None and self.sonet_hour24_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sonet-hour24" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sonet-hour24-ocn"):
                        if (self.sonet_hour24_ocn is None):
                            self.sonet_hour24_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn()
                            self.sonet_hour24_ocn.parent = self
                            self._children_name_map["sonet_hour24_ocn"] = "sonet-hour24-ocn"
                        return self.sonet_hour24_ocn

                    if (child_yang_name == "sonet-hour24-path"):
                        if (self.sonet_hour24_path is None):
                            self.sonet_hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path()
                            self.sonet_hour24_path.parent = self
                            self._children_name_map["sonet_hour24_path"] = "sonet-hour24-path"
                        return self.sonet_hour24_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sonet-hour24-ocn" or name == "sonet-hour24-path"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Minute15Path(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15otn_path
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Minute15OtnPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path, self).__init__()

                    self.yang_name = "minute15-path"
                    self.yang_parent_name = "performance-management"

                    self.minute15otn_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath()
                    self.minute15otn_path.parent = self
                    self._children_name_map["minute15otn_path"] = "minute15otn-path"
                    self._children_yang_names.add("minute15otn-path")


                class Minute15OtnPath(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: min15_otn_path_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Min15OtnPathThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes>`
                    
                    .. attribute:: minute15otn_path_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Minute15OtnPathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath, self).__init__()

                        self.yang_name = "minute15otn-path"
                        self.yang_parent_name = "minute15-path"

                        self.min15_otn_path_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes()
                        self.min15_otn_path_threshes.parent = self
                        self._children_name_map["min15_otn_path_threshes"] = "min15-otn-path-threshes"
                        self._children_yang_names.add("min15-otn-path-threshes")

                        self.minute15otn_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports()
                        self.minute15otn_path_reports.parent = self
                        self._children_name_map["minute15otn_path_reports"] = "minute15otn-path-reports"
                        self._children_yang_names.add("minute15otn-path-reports")


                    class Minute15OtnPathReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: minute15otn_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OtnPathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports, self).__init__()

                            self.yang_name = "minute15otn-path-reports"
                            self.yang_parent_name = "minute15otn-path"

                            self.minute15otn_path_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports, self).__setattr__(name, value)


                        class Minute15OtnPathReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport, self).__init__()

                                self.yang_name = "minute15otn-path-report"
                                self.yang_parent_name = "minute15otn-path-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15otn-path-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15otn_path_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15otn_path_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15otn-path-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15otn-path-report"):
                                for c in self.minute15otn_path_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15otn_path_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15otn-path-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Min15OtnPathThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: min15_otn_path_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Min15OtnPathThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes, self).__init__()

                            self.yang_name = "min15-otn-path-threshes"
                            self.yang_parent_name = "minute15otn-path"

                            self.min15_otn_path_thresh = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes, self).__setattr__(name, value)


                        class Min15OtnPathThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh, self).__init__()

                                self.yang_name = "min15-otn-path-thresh"
                                self.yang_parent_name = "min15-otn-path-threshes"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "min15-otn-path-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.min15_otn_path_thresh:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.min15_otn_path_thresh:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "min15-otn-path-threshes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "min15-otn-path-thresh"):
                                for c in self.min15_otn_path_thresh:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.min15_otn_path_thresh.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "min15-otn-path-thresh"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.min15_otn_path_threshes is not None and self.min15_otn_path_threshes.has_data()) or
                            (self.minute15otn_path_reports is not None and self.minute15otn_path_reports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.min15_otn_path_threshes is not None and self.min15_otn_path_threshes.has_operation()) or
                            (self.minute15otn_path_reports is not None and self.minute15otn_path_reports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15otn-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "min15-otn-path-threshes"):
                            if (self.min15_otn_path_threshes is None):
                                self.min15_otn_path_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes()
                                self.min15_otn_path_threshes.parent = self
                                self._children_name_map["min15_otn_path_threshes"] = "min15-otn-path-threshes"
                            return self.min15_otn_path_threshes

                        if (child_yang_name == "minute15otn-path-reports"):
                            if (self.minute15otn_path_reports is None):
                                self.minute15otn_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports()
                                self.minute15otn_path_reports.parent = self
                                self._children_name_map["minute15otn_path_reports"] = "minute15otn-path-reports"
                            return self.minute15otn_path_reports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "min15-otn-path-threshes" or name == "minute15otn-path-reports"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.minute15otn_path is not None and self.minute15otn_path.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.minute15otn_path is not None and self.minute15otn_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "minute15-path" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "minute15otn-path"):
                        if (self.minute15otn_path is None):
                            self.minute15otn_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath()
                            self.minute15otn_path.parent = self
                            self._children_name_map["minute15otn_path"] = "minute15otn-path"
                        return self.minute15otn_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "minute15otn-path"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OcMinute15(Entity):
                """
                set OC threshold
                
                .. attribute:: oc_minute15_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`OcMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15, self).__init__()

                    self.yang_name = "oc-minute15"
                    self.yang_parent_name = "performance-management"

                    self.oc_minute15_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn()
                    self.oc_minute15_ocn.parent = self
                    self._children_name_map["oc_minute15_ocn"] = "oc-minute15-ocn"
                    self._children_yang_names.add("oc-minute15-ocn")


                class OcMinute15Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: oc_minute15_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`OcMinute15OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports>`
                    
                    .. attribute:: oc_minute15_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`OcMinute15OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn, self).__init__()

                        self.yang_name = "oc-minute15-ocn"
                        self.yang_parent_name = "oc-minute15"

                        self.oc_minute15_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports()
                        self.oc_minute15_ocn_reports.parent = self
                        self._children_name_map["oc_minute15_ocn_reports"] = "oc-minute15-ocn-reports"
                        self._children_yang_names.add("oc-minute15-ocn-reports")

                        self.oc_minute15_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds()
                        self.oc_minute15_ocn_thresholds.parent = self
                        self._children_name_map["oc_minute15_ocn_thresholds"] = "oc-minute15-ocn-thresholds"
                        self._children_yang_names.add("oc-minute15-ocn-thresholds")


                    class OcMinute15OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: oc_minute15_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`OcMinute15OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports, self).__init__()

                            self.yang_name = "oc-minute15-ocn-reports"
                            self.yang_parent_name = "oc-minute15-ocn"

                            self.oc_minute15_ocn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports, self).__setattr__(name, value)


                        class OcMinute15OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            .. attribute:: enable
                            
                            	Ocn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport, self).__init__()

                                self.yang_name = "oc-minute15-ocn-report"
                                self.yang_parent_name = "oc-minute15-ocn-reports"

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ocn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-minute15-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_report.is_set or self.ocn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-report"):
                                    self.ocn_report = value
                                    self.ocn_report.value_namespace = name_space
                                    self.ocn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.oc_minute15_ocn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.oc_minute15_ocn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-minute15-ocn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-minute15-ocn-report"):
                                for c in self.oc_minute15_ocn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.oc_minute15_ocn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-minute15-ocn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OcMinute15OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: oc_minute15_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OcMinute15OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds, self).__init__()

                            self.yang_name = "oc-minute15-ocn-thresholds"
                            self.yang_parent_name = "oc-minute15-ocn"

                            self.oc_minute15_ocn_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds, self).__setattr__(name, value)


                        class OcMinute15OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold, self).__init__()

                                self.yang_name = "oc-minute15-ocn-threshold"
                                self.yang_parent_name = "oc-minute15-ocn-thresholds"

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ocn_threshold",
                                                "ocn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ocn_threshold.is_set or
                                    self.ocn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ocn_threshold.yfilter != YFilter.not_set or
                                    self.ocn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-minute15-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ocn_threshold.is_set or self.ocn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold.get_name_leafdata())
                                if (self.ocn_threshold_value.is_set or self.ocn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ocn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ocn-threshold" or name == "ocn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ocn-threshold"):
                                    self.ocn_threshold = value
                                    self.ocn_threshold.value_namespace = name_space
                                    self.ocn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ocn-threshold-value"):
                                    self.ocn_threshold_value = value
                                    self.ocn_threshold_value.value_namespace = name_space
                                    self.ocn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.oc_minute15_ocn_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.oc_minute15_ocn_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-minute15-ocn-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-minute15-ocn-threshold"):
                                for c in self.oc_minute15_ocn_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.oc_minute15_ocn_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-minute15-ocn-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.oc_minute15_ocn_reports is not None and self.oc_minute15_ocn_reports.has_data()) or
                            (self.oc_minute15_ocn_thresholds is not None and self.oc_minute15_ocn_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.oc_minute15_ocn_reports is not None and self.oc_minute15_ocn_reports.has_operation()) or
                            (self.oc_minute15_ocn_thresholds is not None and self.oc_minute15_ocn_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "oc-minute15-ocn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "oc-minute15-ocn-reports"):
                            if (self.oc_minute15_ocn_reports is None):
                                self.oc_minute15_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports()
                                self.oc_minute15_ocn_reports.parent = self
                                self._children_name_map["oc_minute15_ocn_reports"] = "oc-minute15-ocn-reports"
                            return self.oc_minute15_ocn_reports

                        if (child_yang_name == "oc-minute15-ocn-thresholds"):
                            if (self.oc_minute15_ocn_thresholds is None):
                                self.oc_minute15_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds()
                                self.oc_minute15_ocn_thresholds.parent = self
                                self._children_name_map["oc_minute15_ocn_thresholds"] = "oc-minute15-ocn-thresholds"
                            return self.oc_minute15_ocn_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "oc-minute15-ocn-reports" or name == "oc-minute15-ocn-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.oc_minute15_ocn is not None and self.oc_minute15_ocn.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.oc_minute15_ocn is not None and self.oc_minute15_ocn.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "oc-minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "oc-minute15-ocn"):
                        if (self.oc_minute15_ocn is None):
                            self.oc_minute15_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn()
                            self.oc_minute15_ocn.parent = self
                            self._children_name_map["oc_minute15_ocn"] = "oc-minute15-ocn"
                        return self.oc_minute15_ocn

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "oc-minute15-ocn"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EthernetSecond30(Entity):
                """
                Configure ethernet performance monitoring for
                30 sec
                
                .. attribute:: second30_ether
                
                	Configure ether performance monitoring
                	**type**\:   :py:class:`Second30Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30, self).__init__()

                    self.yang_name = "ethernet-second30"
                    self.yang_parent_name = "performance-management"

                    self.second30_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether()
                    self.second30_ether.parent = self
                    self._children_name_map["second30_ether"] = "second30-ether"
                    self._children_yang_names.add("second30-ether")


                class Second30Ether(Entity):
                    """
                    Configure ether performance monitoring
                    
                    .. attribute:: second30_ether_reports
                    
                    	set ether TCA reporting status
                    	**type**\:   :py:class:`Second30EtherReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports>`
                    
                    .. attribute:: second30_ether_thresholds
                    
                    	Configure threshold on ether parameters
                    	**type**\:   :py:class:`Second30EtherThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether, self).__init__()

                        self.yang_name = "second30-ether"
                        self.yang_parent_name = "ethernet-second30"

                        self.second30_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports()
                        self.second30_ether_reports.parent = self
                        self._children_name_map["second30_ether_reports"] = "second30-ether-reports"
                        self._children_yang_names.add("second30-ether-reports")

                        self.second30_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds()
                        self.second30_ether_thresholds.parent = self
                        self._children_name_map["second30_ether_thresholds"] = "second30-ether-thresholds"
                        self._children_yang_names.add("second30-ether-thresholds")


                    class Second30EtherThresholds(Entity):
                        """
                        Configure threshold on ether parameters
                        
                        .. attribute:: second30_ether_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds, self).__init__()

                            self.yang_name = "second30-ether-thresholds"
                            self.yang_parent_name = "second30-ether"

                            self.second30_ether_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds, self).__setattr__(name, value)


                        class Second30EtherThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ether_threshold  <key>
                            
                            	Ether Threshold Type
                            	**type**\:   :py:class:`EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherThreshold>`
                            
                            .. attribute:: ether_threshold_value
                            
                            	Ether Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold, self).__init__()

                                self.yang_name = "second30-ether-threshold"
                                self.yang_parent_name = "second30-ether-thresholds"

                                self.ether_threshold = YLeaf(YType.enumeration, "ether-threshold")

                                self.ether_threshold_value = YLeaf(YType.int32, "ether-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ether_threshold",
                                                "ether_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ether_threshold.is_set or
                                    self.ether_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ether_threshold.yfilter != YFilter.not_set or
                                    self.ether_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30-ether-threshold" + "[ether-threshold='" + self.ether_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ether_threshold.is_set or self.ether_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_threshold.get_name_leafdata())
                                if (self.ether_threshold_value.is_set or self.ether_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ether-threshold" or name == "ether-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ether-threshold"):
                                    self.ether_threshold = value
                                    self.ether_threshold.value_namespace = name_space
                                    self.ether_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "ether-threshold-value"):
                                    self.ether_threshold_value = value
                                    self.ether_threshold_value.value_namespace = name_space
                                    self.ether_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30_ether_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30_ether_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30-ether-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30-ether-threshold"):
                                for c in self.second30_ether_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30_ether_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30-ether-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Second30EtherReports(Entity):
                        """
                        set ether TCA reporting status
                        
                        .. attribute:: second30_ether_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports, self).__init__()

                            self.yang_name = "second30-ether-reports"
                            self.yang_parent_name = "second30-ether"

                            self.second30_ether_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports, self).__setattr__(name, value)


                        class Second30EtherReport(Entity):
                            """
                            none
                            
                            .. attribute:: ether_report  <key>
                            
                            	Ether Report Type
                            	**type**\:   :py:class:`EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport, self).__init__()

                                self.yang_name = "second30-ether-report"
                                self.yang_parent_name = "second30-ether-reports"

                                self.ether_report = YLeaf(YType.enumeration, "ether-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ether_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.ether_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ether_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30-ether-report" + "[ether-report='" + self.ether_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ether_report.is_set or self.ether_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ether_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ether-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ether-report"):
                                    self.ether_report = value
                                    self.ether_report.value_namespace = name_space
                                    self.ether_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.second30_ether_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.second30_ether_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "second30-ether-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30-ether-report"):
                                for c in self.second30_ether_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.second30_ether_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30-ether-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.second30_ether_reports is not None and self.second30_ether_reports.has_data()) or
                            (self.second30_ether_thresholds is not None and self.second30_ether_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.second30_ether_reports is not None and self.second30_ether_reports.has_operation()) or
                            (self.second30_ether_thresholds is not None and self.second30_ether_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "second30-ether" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "second30-ether-reports"):
                            if (self.second30_ether_reports is None):
                                self.second30_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports()
                                self.second30_ether_reports.parent = self
                                self._children_name_map["second30_ether_reports"] = "second30-ether-reports"
                            return self.second30_ether_reports

                        if (child_yang_name == "second30-ether-thresholds"):
                            if (self.second30_ether_thresholds is None):
                                self.second30_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds()
                                self.second30_ether_thresholds.parent = self
                                self._children_name_map["second30_ether_thresholds"] = "second30-ether-thresholds"
                            return self.second30_ether_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "second30-ether-reports" or name == "second30-ether-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.second30_ether is not None and self.second30_ether.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.second30_ether is not None and self.second30_ether.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ethernet-second30" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "second30-ether"):
                        if (self.second30_ether is None):
                            self.second30_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether()
                            self.second30_ether.parent = self
                            self._children_name_map["second30_ether"] = "second30-ether"
                        return self.second30_ether

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "second30-ether"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Hour24Path(Entity):
                """
                Configure pm parameters of pathmonitor 24 hour
                interval
                
                .. attribute:: hour24otn_path
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Hour24OtnPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path, self).__init__()

                    self.yang_name = "hour24-path"
                    self.yang_parent_name = "performance-management"

                    self.hour24otn_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath()
                    self.hour24otn_path.parent = self
                    self._children_name_map["hour24otn_path"] = "hour24otn-path"
                    self._children_yang_names.add("hour24otn-path")


                class Hour24OtnPath(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: hour24otn_path_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Hour24OtnPathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports>`
                    
                    .. attribute:: hour24otn_path_thresholds
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Hour24OtnPathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath, self).__init__()

                        self.yang_name = "hour24otn-path"
                        self.yang_parent_name = "hour24-path"

                        self.hour24otn_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports()
                        self.hour24otn_path_reports.parent = self
                        self._children_name_map["hour24otn_path_reports"] = "hour24otn-path-reports"
                        self._children_yang_names.add("hour24otn-path-reports")

                        self.hour24otn_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds()
                        self.hour24otn_path_thresholds.parent = self
                        self._children_name_map["hour24otn_path_thresholds"] = "hour24otn-path-thresholds"
                        self._children_yang_names.add("hour24otn-path-thresholds")


                    class Hour24OtnPathReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: hour24otn_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnPathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports, self).__init__()

                            self.yang_name = "hour24otn-path-reports"
                            self.yang_parent_name = "hour24otn-path"

                            self.hour24otn_path_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports, self).__setattr__(name, value)


                        class Hour24OtnPathReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport, self).__init__()

                                self.yang_name = "hour24otn-path-report"
                                self.yang_parent_name = "hour24otn-path-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24otn-path-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24otn_path_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24otn_path_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24otn-path-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24otn-path-report"):
                                for c in self.hour24otn_path_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24otn_path_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24otn-path-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Hour24OtnPathThresholds(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: hour24otn_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnPathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds, self).__init__()

                            self.yang_name = "hour24otn-path-thresholds"
                            self.yang_parent_name = "hour24otn-path"

                            self.hour24otn_path_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds, self).__setattr__(name, value)


                        class Hour24OtnPathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold, self).__init__()

                                self.yang_name = "hour24otn-path-threshold"
                                self.yang_parent_name = "hour24otn-path-thresholds"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "hour24otn-path-threshold" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.hour24otn_path_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.hour24otn_path_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "hour24otn-path-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "hour24otn-path-threshold"):
                                for c in self.hour24otn_path_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.hour24otn_path_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "hour24otn-path-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.hour24otn_path_reports is not None and self.hour24otn_path_reports.has_data()) or
                            (self.hour24otn_path_thresholds is not None and self.hour24otn_path_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.hour24otn_path_reports is not None and self.hour24otn_path_reports.has_operation()) or
                            (self.hour24otn_path_thresholds is not None and self.hour24otn_path_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "hour24otn-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "hour24otn-path-reports"):
                            if (self.hour24otn_path_reports is None):
                                self.hour24otn_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports()
                                self.hour24otn_path_reports.parent = self
                                self._children_name_map["hour24otn_path_reports"] = "hour24otn-path-reports"
                            return self.hour24otn_path_reports

                        if (child_yang_name == "hour24otn-path-thresholds"):
                            if (self.hour24otn_path_thresholds is None):
                                self.hour24otn_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds()
                                self.hour24otn_path_thresholds.parent = self
                                self._children_name_map["hour24otn_path_thresholds"] = "hour24otn-path-thresholds"
                            return self.hour24otn_path_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "hour24otn-path-reports" or name == "hour24otn-path-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.hour24otn_path is not None and self.hour24otn_path.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.hour24otn_path is not None and self.hour24otn_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hour24-path" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "hour24otn-path"):
                        if (self.hour24otn_path is None):
                            self.hour24otn_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath()
                            self.hour24otn_path.parent = self
                            self._children_name_map["hour24otn_path"] = "hour24otn-path"
                        return self.hour24otn_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "hour24otn-path"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Minute15(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15_optics
                
                	Configure optics performance monitoring
                	**type**\:   :py:class:`Minute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics>`
                
                .. attribute:: minute15fec
                
                	Configure fec g709 performance monitoring
                	**type**\:   :py:class:`Minute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec>`
                
                .. attribute:: minute15otn
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Minute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15, self).__init__()

                    self.yang_name = "minute15"
                    self.yang_parent_name = "performance-management"

                    self.minute15_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics()
                    self.minute15_optics.parent = self
                    self._children_name_map["minute15_optics"] = "minute15-optics"
                    self._children_yang_names.add("minute15-optics")

                    self.minute15fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec()
                    self.minute15fec.parent = self
                    self._children_name_map["minute15fec"] = "minute15fec"
                    self._children_yang_names.add("minute15fec")

                    self.minute15otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn()
                    self.minute15otn.parent = self
                    self._children_name_map["minute15otn"] = "minute15otn"
                    self._children_yang_names.add("minute15otn")


                class Minute15Optics(Entity):
                    """
                    Configure optics performance monitoring
                    
                    .. attribute:: minute15_optics_reports
                    
                    	set optics TCA reporting status
                    	**type**\:   :py:class:`Minute15OpticsReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports>`
                    
                    .. attribute:: minute15_optics_thresholds
                    
                    	Configure threshold on optics parameters
                    	**type**\:   :py:class:`Minute15OpticsThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics, self).__init__()

                        self.yang_name = "minute15-optics"
                        self.yang_parent_name = "minute15"

                        self.minute15_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports()
                        self.minute15_optics_reports.parent = self
                        self._children_name_map["minute15_optics_reports"] = "minute15-optics-reports"
                        self._children_yang_names.add("minute15-optics-reports")

                        self.minute15_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds()
                        self.minute15_optics_thresholds.parent = self
                        self._children_name_map["minute15_optics_thresholds"] = "minute15-optics-thresholds"
                        self._children_yang_names.add("minute15-optics-thresholds")


                    class Minute15OpticsThresholds(Entity):
                        """
                        Configure threshold on optics parameters
                        
                        .. attribute:: minute15_optics_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds, self).__init__()

                            self.yang_name = "minute15-optics-thresholds"
                            self.yang_parent_name = "minute15-optics"

                            self.minute15_optics_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds, self).__setattr__(name, value)


                        class Minute15OpticsThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: optics_threshold  <key>
                            
                            	Optics Threshold Type
                            	**type**\:   :py:class:`OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsThreshold>`
                            
                            .. attribute:: dbm
                            
                            	Used only for Opt and Opr,To Enter Threshold in dbm use 1
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: optics_threshold_value
                            
                            	Optics Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold, self).__init__()

                                self.yang_name = "minute15-optics-threshold"
                                self.yang_parent_name = "minute15-optics-thresholds"

                                self.optics_threshold = YLeaf(YType.enumeration, "optics-threshold")

                                self.dbm = YLeaf(YType.int32, "dbm")

                                self.optics_threshold_value = YLeaf(YType.int32, "optics-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("optics_threshold",
                                                "dbm",
                                                "optics_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.optics_threshold.is_set or
                                    self.dbm.is_set or
                                    self.optics_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.optics_threshold.yfilter != YFilter.not_set or
                                    self.dbm.yfilter != YFilter.not_set or
                                    self.optics_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-optics-threshold" + "[optics-threshold='" + self.optics_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.optics_threshold.is_set or self.optics_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_threshold.get_name_leafdata())
                                if (self.dbm.is_set or self.dbm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dbm.get_name_leafdata())
                                if (self.optics_threshold_value.is_set or self.optics_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-threshold" or name == "dbm" or name == "optics-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "optics-threshold"):
                                    self.optics_threshold = value
                                    self.optics_threshold.value_namespace = name_space
                                    self.optics_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "dbm"):
                                    self.dbm = value
                                    self.dbm.value_namespace = name_space
                                    self.dbm.value_namespace_prefix = name_space_prefix
                                if(value_path == "optics-threshold-value"):
                                    self.optics_threshold_value = value
                                    self.optics_threshold_value.value_namespace = name_space
                                    self.optics_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15_optics_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15_optics_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15-optics-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-optics-threshold"):
                                for c in self.minute15_optics_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15_optics_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-optics-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15OpticsReports(Entity):
                        """
                        set optics TCA reporting status
                        
                        .. attribute:: minute15_optics_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports, self).__init__()

                            self.yang_name = "minute15-optics-reports"
                            self.yang_parent_name = "minute15-optics"

                            self.minute15_optics_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports, self).__setattr__(name, value)


                        class Minute15OpticsReport(Entity):
                            """
                            none
                            
                            .. attribute:: optics_report  <key>
                            
                            	Optics Report Type
                            	**type**\:   :py:class:`OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport, self).__init__()

                                self.yang_name = "minute15-optics-report"
                                self.yang_parent_name = "minute15-optics-reports"

                                self.optics_report = YLeaf(YType.enumeration, "optics-report")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("optics_report") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport, self).__setattr__(name, value)

                            def has_data(self):
                                return self.optics_report.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.optics_report.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-optics-report" + "[optics-report='" + self.optics_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.optics_report.is_set or self.optics_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.optics_report.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-report"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "optics-report"):
                                    self.optics_report = value
                                    self.optics_report.value_namespace = name_space
                                    self.optics_report.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15_optics_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15_optics_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15-optics-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-optics-report"):
                                for c in self.minute15_optics_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15_optics_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-optics-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.minute15_optics_reports is not None and self.minute15_optics_reports.has_data()) or
                            (self.minute15_optics_thresholds is not None and self.minute15_optics_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.minute15_optics_reports is not None and self.minute15_optics_reports.has_operation()) or
                            (self.minute15_optics_thresholds is not None and self.minute15_optics_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15-optics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "minute15-optics-reports"):
                            if (self.minute15_optics_reports is None):
                                self.minute15_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports()
                                self.minute15_optics_reports.parent = self
                                self._children_name_map["minute15_optics_reports"] = "minute15-optics-reports"
                            return self.minute15_optics_reports

                        if (child_yang_name == "minute15-optics-thresholds"):
                            if (self.minute15_optics_thresholds is None):
                                self.minute15_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds()
                                self.minute15_optics_thresholds.parent = self
                                self._children_name_map["minute15_optics_thresholds"] = "minute15-optics-thresholds"
                            return self.minute15_optics_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "minute15-optics-reports" or name == "minute15-optics-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Minute15Fec(Entity):
                    """
                    Configure fec g709 performance monitoring
                    
                    .. attribute:: minute15fec_reports
                    
                    	set fec TCA reporting status
                    	**type**\:   :py:class:`Minute15FecReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports>`
                    
                    .. attribute:: minute15fec_thresholds
                    
                    	Configure fec threshold
                    	**type**\:   :py:class:`Minute15FecThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec, self).__init__()

                        self.yang_name = "minute15fec"
                        self.yang_parent_name = "minute15"

                        self.minute15fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports()
                        self.minute15fec_reports.parent = self
                        self._children_name_map["minute15fec_reports"] = "minute15fec-reports"
                        self._children_yang_names.add("minute15fec-reports")

                        self.minute15fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds()
                        self.minute15fec_thresholds.parent = self
                        self._children_name_map["minute15fec_thresholds"] = "minute15fec-thresholds"
                        self._children_yang_names.add("minute15fec-thresholds")


                    class Minute15FecThresholds(Entity):
                        """
                        Configure fec threshold
                        
                        .. attribute:: minute15fec_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds, self).__init__()

                            self.yang_name = "minute15fec-thresholds"
                            self.yang_parent_name = "minute15fec"

                            self.minute15fec_threshold = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds, self).__setattr__(name, value)


                        class Minute15FecThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: fec_threshold  <key>
                            
                            	Fec Threshold Type
                            	**type**\:   :py:class:`FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecThreshold>`
                            
                            .. attribute:: fec_threshold_value
                            
                            	Fec Threshold Value
                            	**type**\:  str
                            
                            	**length:** 1..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold, self).__init__()

                                self.yang_name = "minute15fec-threshold"
                                self.yang_parent_name = "minute15fec-thresholds"

                                self.fec_threshold = YLeaf(YType.enumeration, "fec-threshold")

                                self.fec_threshold_value = YLeaf(YType.str, "fec-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fec_threshold",
                                                "fec_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fec_threshold.is_set or
                                    self.fec_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fec_threshold.yfilter != YFilter.not_set or
                                    self.fec_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15fec-threshold" + "[fec-threshold='" + self.fec_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fec_threshold.is_set or self.fec_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_threshold.get_name_leafdata())
                                if (self.fec_threshold_value.is_set or self.fec_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fec-threshold" or name == "fec-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fec-threshold"):
                                    self.fec_threshold = value
                                    self.fec_threshold.value_namespace = name_space
                                    self.fec_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "fec-threshold-value"):
                                    self.fec_threshold_value = value
                                    self.fec_threshold_value.value_namespace = name_space
                                    self.fec_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15fec_threshold:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15fec_threshold:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15fec-thresholds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15fec-threshold"):
                                for c in self.minute15fec_threshold:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15fec_threshold.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15fec-threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15FecReports(Entity):
                        """
                        set fec TCA reporting status
                        
                        .. attribute:: minute15fec_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports, self).__init__()

                            self.yang_name = "minute15fec-reports"
                            self.yang_parent_name = "minute15fec"

                            self.minute15fec_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports, self).__setattr__(name, value)


                        class Minute15FecReport(Entity):
                            """
                            none
                            
                            .. attribute:: fec_report  <key>
                            
                            	Fec Report Type
                            	**type**\:   :py:class:`FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecReport>`
                            
                            .. attribute:: enable
                            
                            	Fec Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport, self).__init__()

                                self.yang_name = "minute15fec-report"
                                self.yang_parent_name = "minute15fec-reports"

                                self.fec_report = YLeaf(YType.enumeration, "fec-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fec_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fec_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fec_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15fec-report" + "[fec-report='" + self.fec_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fec_report.is_set or self.fec_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fec_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fec-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fec-report"):
                                    self.fec_report = value
                                    self.fec_report.value_namespace = name_space
                                    self.fec_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15fec_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15fec_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15fec-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15fec-report"):
                                for c in self.minute15fec_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15fec_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15fec-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.minute15fec_reports is not None and self.minute15fec_reports.has_data()) or
                            (self.minute15fec_thresholds is not None and self.minute15fec_thresholds.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.minute15fec_reports is not None and self.minute15fec_reports.has_operation()) or
                            (self.minute15fec_thresholds is not None and self.minute15fec_thresholds.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15fec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "minute15fec-reports"):
                            if (self.minute15fec_reports is None):
                                self.minute15fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports()
                                self.minute15fec_reports.parent = self
                                self._children_name_map["minute15fec_reports"] = "minute15fec-reports"
                            return self.minute15fec_reports

                        if (child_yang_name == "minute15fec-thresholds"):
                            if (self.minute15fec_thresholds is None):
                                self.minute15fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds()
                                self.minute15fec_thresholds.parent = self
                                self._children_name_map["minute15fec_thresholds"] = "minute15fec-thresholds"
                            return self.minute15fec_thresholds

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "minute15fec-reports" or name == "minute15fec-thresholds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Minute15Otn(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: min15_otn_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Min15OtnThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes>`
                    
                    .. attribute:: minute15otn_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Minute15OtnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn, self).__init__()

                        self.yang_name = "minute15otn"
                        self.yang_parent_name = "minute15"

                        self.min15_otn_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes()
                        self.min15_otn_threshes.parent = self
                        self._children_name_map["min15_otn_threshes"] = "min15-otn-threshes"
                        self._children_yang_names.add("min15-otn-threshes")

                        self.minute15otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports()
                        self.minute15otn_reports.parent = self
                        self._children_name_map["minute15otn_reports"] = "minute15otn-reports"
                        self._children_yang_names.add("minute15otn-reports")


                    class Min15OtnThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: min15_otn_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Min15OtnThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes, self).__init__()

                            self.yang_name = "min15-otn-threshes"
                            self.yang_parent_name = "minute15otn"

                            self.min15_otn_thresh = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes, self).__setattr__(name, value)


                        class Min15OtnThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh, self).__init__()

                                self.yang_name = "min15-otn-thresh"
                                self.yang_parent_name = "min15-otn-threshes"

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_threshold",
                                                "otn_threshold_value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_threshold.is_set or
                                    self.otn_threshold_value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_threshold.yfilter != YFilter.not_set or
                                    self.otn_threshold_value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "min15-otn-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_threshold.is_set or self.otn_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold.get_name_leafdata())
                                if (self.otn_threshold_value.is_set or self.otn_threshold_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_threshold_value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-threshold" or name == "otn-threshold-value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-threshold"):
                                    self.otn_threshold = value
                                    self.otn_threshold.value_namespace = name_space
                                    self.otn_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "otn-threshold-value"):
                                    self.otn_threshold_value = value
                                    self.otn_threshold_value.value_namespace = name_space
                                    self.otn_threshold_value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.min15_otn_thresh:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.min15_otn_thresh:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "min15-otn-threshes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "min15-otn-thresh"):
                                for c in self.min15_otn_thresh:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.min15_otn_thresh.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "min15-otn-thresh"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15OtnReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: minute15otn_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports, self).__init__()

                            self.yang_name = "minute15otn-reports"
                            self.yang_parent_name = "minute15otn"

                            self.minute15otn_report = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports, self).__setattr__(name, value)


                        class Minute15OtnReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport, self).__init__()

                                self.yang_name = "minute15otn-report"
                                self.yang_parent_name = "minute15otn-reports"

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("otn_report",
                                                "enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.otn_report.is_set or
                                    self.enable.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.otn_report.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15otn-report" + "[otn-report='" + self.otn_report.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.otn_report.is_set or self.otn_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.otn_report.get_name_leafdata())
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otn-report" or name == "enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "otn-report"):
                                    self.otn_report = value
                                    self.otn_report.value_namespace = name_space
                                    self.otn_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.minute15otn_report:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.minute15otn_report:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15otn-reports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15otn-report"):
                                for c in self.minute15otn_report:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.minute15otn_report.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15otn-report"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.min15_otn_threshes is not None and self.min15_otn_threshes.has_data()) or
                            (self.minute15otn_reports is not None and self.minute15otn_reports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.min15_otn_threshes is not None and self.min15_otn_threshes.has_operation()) or
                            (self.minute15otn_reports is not None and self.minute15otn_reports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "minute15otn" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "min15-otn-threshes"):
                            if (self.min15_otn_threshes is None):
                                self.min15_otn_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes()
                                self.min15_otn_threshes.parent = self
                                self._children_name_map["min15_otn_threshes"] = "min15-otn-threshes"
                            return self.min15_otn_threshes

                        if (child_yang_name == "minute15otn-reports"):
                            if (self.minute15otn_reports is None):
                                self.minute15otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports()
                                self.minute15otn_reports.parent = self
                                self._children_name_map["minute15otn_reports"] = "minute15otn-reports"
                            return self.minute15otn_reports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "min15-otn-threshes" or name == "minute15otn-reports"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.minute15_optics is not None and self.minute15_optics.has_data()) or
                        (self.minute15fec is not None and self.minute15fec.has_data()) or
                        (self.minute15otn is not None and self.minute15otn.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.minute15_optics is not None and self.minute15_optics.has_operation()) or
                        (self.minute15fec is not None and self.minute15fec.has_operation()) or
                        (self.minute15otn is not None and self.minute15otn.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "minute15" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "minute15-optics"):
                        if (self.minute15_optics is None):
                            self.minute15_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics()
                            self.minute15_optics.parent = self
                            self._children_name_map["minute15_optics"] = "minute15-optics"
                        return self.minute15_optics

                    if (child_yang_name == "minute15fec"):
                        if (self.minute15fec is None):
                            self.minute15fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec()
                            self.minute15fec.parent = self
                            self._children_name_map["minute15fec"] = "minute15fec"
                        return self.minute15fec

                    if (child_yang_name == "minute15otn"):
                        if (self.minute15otn is None):
                            self.minute15otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn()
                            self.minute15otn.parent = self
                            self._children_name_map["minute15otn"] = "minute15otn"
                        return self.minute15otn

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "minute15-optics" or name == "minute15fec" or name == "minute15otn"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.ethernet_hour24 is not None and self.ethernet_hour24.has_data()) or
                    (self.ethernet_minute15 is not None and self.ethernet_minute15.has_data()) or
                    (self.ethernet_second30 is not None and self.ethernet_second30.has_data()) or
                    (self.ho_vc_hour24 is not None and self.ho_vc_hour24.has_data()) or
                    (self.ho_vc_minute15 is not None and self.ho_vc_minute15.has_data()) or
                    (self.hour24 is not None and self.hour24.has_data()) or
                    (self.hour24_gfp is not None and self.hour24_gfp.has_data()) or
                    (self.hour24_path is not None and self.hour24_path.has_data()) or
                    (self.hour24otn_tcms is not None and self.hour24otn_tcms.has_data()) or
                    (self.minute15 is not None and self.minute15.has_data()) or
                    (self.minute15_gfp is not None and self.minute15_gfp.has_data()) or
                    (self.minute15_path is not None and self.minute15_path.has_data()) or
                    (self.minute15otn_tcms is not None and self.minute15otn_tcms.has_data()) or
                    (self.oc_hour24 is not None and self.oc_hour24.has_data()) or
                    (self.oc_minute15 is not None and self.oc_minute15.has_data()) or
                    (self.second30 is not None and self.second30.has_data()) or
                    (self.sonet_hour24 is not None and self.sonet_hour24.has_data()) or
                    (self.sonet_minute15 is not None and self.sonet_minute15.has_data()) or
                    (self.stm_hour24 is not None and self.stm_hour24.has_data()) or
                    (self.stm_minute15 is not None and self.stm_minute15.has_data()) or
                    (self.sts_hour24 is not None and self.sts_hour24.has_data()) or
                    (self.sts_minute15 is not None and self.sts_minute15.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.ethernet_hour24 is not None and self.ethernet_hour24.has_operation()) or
                    (self.ethernet_minute15 is not None and self.ethernet_minute15.has_operation()) or
                    (self.ethernet_second30 is not None and self.ethernet_second30.has_operation()) or
                    (self.ho_vc_hour24 is not None and self.ho_vc_hour24.has_operation()) or
                    (self.ho_vc_minute15 is not None and self.ho_vc_minute15.has_operation()) or
                    (self.hour24 is not None and self.hour24.has_operation()) or
                    (self.hour24_gfp is not None and self.hour24_gfp.has_operation()) or
                    (self.hour24_path is not None and self.hour24_path.has_operation()) or
                    (self.hour24otn_tcms is not None and self.hour24otn_tcms.has_operation()) or
                    (self.minute15 is not None and self.minute15.has_operation()) or
                    (self.minute15_gfp is not None and self.minute15_gfp.has_operation()) or
                    (self.minute15_path is not None and self.minute15_path.has_operation()) or
                    (self.minute15otn_tcms is not None and self.minute15otn_tcms.has_operation()) or
                    (self.oc_hour24 is not None and self.oc_hour24.has_operation()) or
                    (self.oc_minute15 is not None and self.oc_minute15.has_operation()) or
                    (self.second30 is not None and self.second30.has_operation()) or
                    (self.sonet_hour24 is not None and self.sonet_hour24.has_operation()) or
                    (self.sonet_minute15 is not None and self.sonet_minute15.has_operation()) or
                    (self.stm_hour24 is not None and self.stm_hour24.has_operation()) or
                    (self.stm_minute15 is not None and self.stm_minute15.has_operation()) or
                    (self.sts_hour24 is not None and self.sts_hour24.has_operation()) or
                    (self.sts_minute15 is not None and self.sts_minute15.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-pmengine-cfg:performance-management" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ethernet-hour24"):
                    if (self.ethernet_hour24 is None):
                        self.ethernet_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24()
                        self.ethernet_hour24.parent = self
                        self._children_name_map["ethernet_hour24"] = "ethernet-hour24"
                    return self.ethernet_hour24

                if (child_yang_name == "ethernet-minute15"):
                    if (self.ethernet_minute15 is None):
                        self.ethernet_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15()
                        self.ethernet_minute15.parent = self
                        self._children_name_map["ethernet_minute15"] = "ethernet-minute15"
                    return self.ethernet_minute15

                if (child_yang_name == "ethernet-second30"):
                    if (self.ethernet_second30 is None):
                        self.ethernet_second30 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30()
                        self.ethernet_second30.parent = self
                        self._children_name_map["ethernet_second30"] = "ethernet-second30"
                    return self.ethernet_second30

                if (child_yang_name == "ho-vc-hour24"):
                    if (self.ho_vc_hour24 is None):
                        self.ho_vc_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24()
                        self.ho_vc_hour24.parent = self
                        self._children_name_map["ho_vc_hour24"] = "ho-vc-hour24"
                    return self.ho_vc_hour24

                if (child_yang_name == "ho-vc-minute15"):
                    if (self.ho_vc_minute15 is None):
                        self.ho_vc_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15()
                        self.ho_vc_minute15.parent = self
                        self._children_name_map["ho_vc_minute15"] = "ho-vc-minute15"
                    return self.ho_vc_minute15

                if (child_yang_name == "hour24"):
                    if (self.hour24 is None):
                        self.hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24()
                        self.hour24.parent = self
                        self._children_name_map["hour24"] = "hour24"
                    return self.hour24

                if (child_yang_name == "hour24-gfp"):
                    if (self.hour24_gfp is None):
                        self.hour24_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp()
                        self.hour24_gfp.parent = self
                        self._children_name_map["hour24_gfp"] = "hour24-gfp"
                    return self.hour24_gfp

                if (child_yang_name == "hour24-path"):
                    if (self.hour24_path is None):
                        self.hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path()
                        self.hour24_path.parent = self
                        self._children_name_map["hour24_path"] = "hour24-path"
                    return self.hour24_path

                if (child_yang_name == "hour24otn-tcms"):
                    if (self.hour24otn_tcms is None):
                        self.hour24otn_tcms = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms()
                        self.hour24otn_tcms.parent = self
                        self._children_name_map["hour24otn_tcms"] = "hour24otn-tcms"
                    return self.hour24otn_tcms

                if (child_yang_name == "minute15"):
                    if (self.minute15 is None):
                        self.minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15()
                        self.minute15.parent = self
                        self._children_name_map["minute15"] = "minute15"
                    return self.minute15

                if (child_yang_name == "minute15-gfp"):
                    if (self.minute15_gfp is None):
                        self.minute15_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp()
                        self.minute15_gfp.parent = self
                        self._children_name_map["minute15_gfp"] = "minute15-gfp"
                    return self.minute15_gfp

                if (child_yang_name == "minute15-path"):
                    if (self.minute15_path is None):
                        self.minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path()
                        self.minute15_path.parent = self
                        self._children_name_map["minute15_path"] = "minute15-path"
                    return self.minute15_path

                if (child_yang_name == "minute15otn-tcms"):
                    if (self.minute15otn_tcms is None):
                        self.minute15otn_tcms = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms()
                        self.minute15otn_tcms.parent = self
                        self._children_name_map["minute15otn_tcms"] = "minute15otn-tcms"
                    return self.minute15otn_tcms

                if (child_yang_name == "oc-hour24"):
                    if (self.oc_hour24 is None):
                        self.oc_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24()
                        self.oc_hour24.parent = self
                        self._children_name_map["oc_hour24"] = "oc-hour24"
                    return self.oc_hour24

                if (child_yang_name == "oc-minute15"):
                    if (self.oc_minute15 is None):
                        self.oc_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15()
                        self.oc_minute15.parent = self
                        self._children_name_map["oc_minute15"] = "oc-minute15"
                    return self.oc_minute15

                if (child_yang_name == "second30"):
                    if (self.second30 is None):
                        self.second30 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30()
                        self.second30.parent = self
                        self._children_name_map["second30"] = "second30"
                    return self.second30

                if (child_yang_name == "sonet-hour24"):
                    if (self.sonet_hour24 is None):
                        self.sonet_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24()
                        self.sonet_hour24.parent = self
                        self._children_name_map["sonet_hour24"] = "sonet-hour24"
                    return self.sonet_hour24

                if (child_yang_name == "sonet-minute15"):
                    if (self.sonet_minute15 is None):
                        self.sonet_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15()
                        self.sonet_minute15.parent = self
                        self._children_name_map["sonet_minute15"] = "sonet-minute15"
                    return self.sonet_minute15

                if (child_yang_name == "stm-hour24"):
                    if (self.stm_hour24 is None):
                        self.stm_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24()
                        self.stm_hour24.parent = self
                        self._children_name_map["stm_hour24"] = "stm-hour24"
                    return self.stm_hour24

                if (child_yang_name == "stm-minute15"):
                    if (self.stm_minute15 is None):
                        self.stm_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15()
                        self.stm_minute15.parent = self
                        self._children_name_map["stm_minute15"] = "stm-minute15"
                    return self.stm_minute15

                if (child_yang_name == "sts-hour24"):
                    if (self.sts_hour24 is None):
                        self.sts_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24()
                        self.sts_hour24.parent = self
                        self._children_name_map["sts_hour24"] = "sts-hour24"
                    return self.sts_hour24

                if (child_yang_name == "sts-minute15"):
                    if (self.sts_minute15 is None):
                        self.sts_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15()
                        self.sts_minute15.parent = self
                        self._children_name_map["sts_minute15"] = "sts-minute15"
                    return self.sts_minute15

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ethernet-hour24" or name == "ethernet-minute15" or name == "ethernet-second30" or name == "ho-vc-hour24" or name == "ho-vc-minute15" or name == "hour24" or name == "hour24-gfp" or name == "hour24-path" or name == "hour24otn-tcms" or name == "minute15" or name == "minute15-gfp" or name == "minute15-path" or name == "minute15otn-tcms" or name == "oc-hour24" or name == "oc-minute15" or name == "second30" or name == "sonet-hour24" or name == "sonet-minute15" or name == "stm-hour24" or name == "stm-minute15" or name == "sts-hour24" or name == "sts-minute15"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class CiscoIosXrPppMaCfg_Ppp(Entity):
            """
            Interface PPP configuration data
            
            

            """

            _prefix = 'ppp-ma-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaCfg_Ppp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-cfg_ppp"
                self.yang_parent_name = "interface-configuration"

            def has_data(self):
                return False

            def has_operation(self):
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ppp-ma-cfg:Cisco-IOS-XR-ppp-ma-cfg_ppp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class CiscoIosXrPppMaFsmCfg_Ppp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: fsm
            
            	PPP FSM configuration data
            	**type**\:   :py:class:`Fsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp.Fsm>`
            
            

            """

            _prefix = 'ppp-ma-fsm-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"
                self.yang_parent_name = "interface-configuration"

                self.fsm = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp.Fsm()
                self.fsm.parent = self
                self._children_name_map["fsm"] = "fsm"
                self._children_yang_names.add("fsm")


            class Fsm(Entity):
                """
                PPP FSM configuration data
                
                .. attribute:: max_consecutive_conf_naks
                
                	This specifies the maximum number of consecutive Conf\-Naks
                	**type**\:  int
                
                	**range:** 2..10
                
                	**default value**\: 5
                
                .. attribute:: max_unacknowledged_conf_requests
                
                	This specifies the maximum number of unacknowledged Conf\-Requests
                	**type**\:  int
                
                	**range:** 4..20
                
                	**default value**\: 10
                
                .. attribute:: max_unacknowledged_term_requests
                
                	This specifies the maximum number of Term\-Requests
                	**type**\:  int
                
                	**range:** 2..10
                
                	**default value**\: 2
                
                .. attribute:: retry_timeout
                
                	This specifies the maximum time to wait for a response during PPP negotiation
                	**type**\:  int
                
                	**range:** 1..10
                
                	**default value**\: 3
                
                

                """

                _prefix = 'ppp-ma-fsm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp.Fsm, self).__init__()

                    self.yang_name = "fsm"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"

                    self.max_consecutive_conf_naks = YLeaf(YType.uint32, "max-consecutive-conf-naks")

                    self.max_unacknowledged_conf_requests = YLeaf(YType.uint32, "max-unacknowledged-conf-requests")

                    self.max_unacknowledged_term_requests = YLeaf(YType.uint32, "max-unacknowledged-term-requests")

                    self.retry_timeout = YLeaf(YType.uint32, "retry-timeout")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("max_consecutive_conf_naks",
                                    "max_unacknowledged_conf_requests",
                                    "max_unacknowledged_term_requests",
                                    "retry_timeout") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp.Fsm, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp.Fsm, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.max_consecutive_conf_naks.is_set or
                        self.max_unacknowledged_conf_requests.is_set or
                        self.max_unacknowledged_term_requests.is_set or
                        self.retry_timeout.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.max_consecutive_conf_naks.yfilter != YFilter.not_set or
                        self.max_unacknowledged_conf_requests.yfilter != YFilter.not_set or
                        self.max_unacknowledged_term_requests.yfilter != YFilter.not_set or
                        self.retry_timeout.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "fsm" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.max_consecutive_conf_naks.is_set or self.max_consecutive_conf_naks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_consecutive_conf_naks.get_name_leafdata())
                    if (self.max_unacknowledged_conf_requests.is_set or self.max_unacknowledged_conf_requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_unacknowledged_conf_requests.get_name_leafdata())
                    if (self.max_unacknowledged_term_requests.is_set or self.max_unacknowledged_term_requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_unacknowledged_term_requests.get_name_leafdata())
                    if (self.retry_timeout.is_set or self.retry_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.retry_timeout.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "max-consecutive-conf-naks" or name == "max-unacknowledged-conf-requests" or name == "max-unacknowledged-term-requests" or name == "retry-timeout"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "max-consecutive-conf-naks"):
                        self.max_consecutive_conf_naks = value
                        self.max_consecutive_conf_naks.value_namespace = name_space
                        self.max_consecutive_conf_naks.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-unacknowledged-conf-requests"):
                        self.max_unacknowledged_conf_requests = value
                        self.max_unacknowledged_conf_requests.value_namespace = name_space
                        self.max_unacknowledged_conf_requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-unacknowledged-term-requests"):
                        self.max_unacknowledged_term_requests = value
                        self.max_unacknowledged_term_requests.value_namespace = name_space
                        self.max_unacknowledged_term_requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "retry-timeout"):
                        self.retry_timeout = value
                        self.retry_timeout.value_namespace = name_space
                        self.retry_timeout.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.fsm is not None and self.fsm.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.fsm is not None and self.fsm.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ppp-ma-fsm-cfg:Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "fsm"):
                    if (self.fsm is None):
                        self.fsm = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp.Fsm()
                        self.fsm.parent = self
                        self._children_name_map["fsm"] = "fsm"
                    return self.fsm

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "fsm"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class CiscoIosXrPppMaIpcpCfg_Ppp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: ipcp
            
            	PPP IPCP configuration data
            	**type**\:   :py:class:`Ipcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp>`
            
            

            """

            _prefix = 'ppp-ma-ipcp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"
                self.yang_parent_name = "interface-configuration"

                self.ipcp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp()
                self.ipcp.parent = self
                self._children_name_map["ipcp"] = "ipcp"
                self._children_yang_names.add("ipcp")


            class Ipcp(Entity):
                """
                PPP IPCP configuration data
                
                .. attribute:: dns
                
                	IPCP DNS parameters
                	**type**\:   :py:class:`Dns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns>`
                
                .. attribute:: neighbor_route_disable
                
                	Disable Neighbor Route installation
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: peer_address
                
                	IPCP address parameters
                	**type**\:   :py:class:`PeerAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.PeerAddress>`
                
                

                """

                _prefix = 'ppp-ma-ipcp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp, self).__init__()

                    self.yang_name = "ipcp"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"

                    self.neighbor_route_disable = YLeaf(YType.empty, "neighbor-route-disable")

                    self.dns = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns()
                    self.dns.parent = self
                    self._children_name_map["dns"] = "dns"
                    self._children_yang_names.add("dns")

                    self.peer_address = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.PeerAddress()
                    self.peer_address.parent = self
                    self._children_name_map["peer_address"] = "peer-address"
                    self._children_yang_names.add("peer-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_route_disable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp, self).__setattr__(name, value)


                class PeerAddress(Entity):
                    """
                    IPCP address parameters
                    
                    .. attribute:: default
                    
                    	Specify an IP address to assign to peers through IPCP
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ppp-ma-ipcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.PeerAddress, self).__init__()

                        self.yang_name = "peer-address"
                        self.yang_parent_name = "ipcp"

                        self.default = YLeaf(YType.str, "default")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("default") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.PeerAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.PeerAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return self.default.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.default.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "peer-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.default.is_set or self.default.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "default"):
                            self.default = value
                            self.default.value_namespace = name_space
                            self.default.value_namespace_prefix = name_space_prefix


                class Dns(Entity):
                    """
                    IPCP DNS parameters
                    
                    .. attribute:: dns_addresses
                    
                    	Specify DNS address(es) to provide
                    	**type**\:   :py:class:`DnsAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns.DnsAddresses>`
                    
                    

                    """

                    _prefix = 'ppp-ma-ipcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns, self).__init__()

                        self.yang_name = "dns"
                        self.yang_parent_name = "ipcp"

                        self.dns_addresses = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns.DnsAddresses()
                        self.dns_addresses.parent = self
                        self._children_name_map["dns_addresses"] = "dns-addresses"
                        self._children_yang_names.add("dns-addresses")


                    class DnsAddresses(Entity):
                        """
                        Specify DNS address(es) to provide
                        
                        .. attribute:: primary
                        
                        	Primary DNS IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Secondary DNS IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ppp-ma-ipcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns.DnsAddresses, self).__init__()

                            self.yang_name = "dns-addresses"
                            self.yang_parent_name = "dns"

                            self.primary = YLeaf(YType.str, "primary")

                            self.secondary = YLeaf(YType.str, "secondary")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("primary",
                                            "secondary") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns.DnsAddresses, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns.DnsAddresses, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.primary.is_set or
                                self.secondary.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.primary.yfilter != YFilter.not_set or
                                self.secondary.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dns-addresses" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.primary.is_set or self.primary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary.get_name_leafdata())
                            if (self.secondary.is_set or self.secondary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.secondary.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "primary" or name == "secondary"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "primary"):
                                self.primary = value
                                self.primary.value_namespace = name_space
                                self.primary.value_namespace_prefix = name_space_prefix
                            if(value_path == "secondary"):
                                self.secondary = value
                                self.secondary.value_namespace = name_space
                                self.secondary.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.dns_addresses is not None and self.dns_addresses.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.dns_addresses is not None and self.dns_addresses.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "dns" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dns-addresses"):
                            if (self.dns_addresses is None):
                                self.dns_addresses = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns.DnsAddresses()
                                self.dns_addresses.parent = self
                                self._children_name_map["dns_addresses"] = "dns-addresses"
                            return self.dns_addresses

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dns-addresses"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.neighbor_route_disable.is_set or
                        (self.dns is not None and self.dns.has_data()) or
                        (self.peer_address is not None and self.peer_address.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_route_disable.yfilter != YFilter.not_set or
                        (self.dns is not None and self.dns.has_operation()) or
                        (self.peer_address is not None and self.peer_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ipcp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_route_disable.is_set or self.neighbor_route_disable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_route_disable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "dns"):
                        if (self.dns is None):
                            self.dns = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.Dns()
                            self.dns.parent = self
                            self._children_name_map["dns"] = "dns"
                        return self.dns

                    if (child_yang_name == "peer-address"):
                        if (self.peer_address is None):
                            self.peer_address = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp.PeerAddress()
                            self.peer_address.parent = self
                            self._children_name_map["peer_address"] = "peer-address"
                        return self.peer_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "dns" or name == "peer-address" or name == "neighbor-route-disable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-route-disable"):
                        self.neighbor_route_disable = value
                        self.neighbor_route_disable.value_namespace = name_space
                        self.neighbor_route_disable.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.ipcp is not None and self.ipcp.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.ipcp is not None and self.ipcp.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ppp-ma-ipcp-cfg:Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ipcp"):
                    if (self.ipcp is None):
                        self.ipcp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp.Ipcp()
                        self.ipcp.parent = self
                        self._children_name_map["ipcp"] = "ipcp"
                    return self.ipcp

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ipcp"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class CiscoIosXrPppMaIpcpiwCfg_Ppp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: ipcpiw
            
            	PPP IPCPIW configuration data
            	**type**\:   :py:class:`Ipcpiw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp.Ipcpiw>`
            
            

            """

            _prefix = 'ppp-ma-ipcpiw-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"
                self.yang_parent_name = "interface-configuration"

                self.ipcpiw = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp.Ipcpiw()
                self.ipcpiw.parent = self
                self._children_name_map["ipcpiw"] = "ipcpiw"
                self._children_yang_names.add("ipcpiw")


            class Ipcpiw(Entity):
                """
                PPP IPCPIW configuration data
                
                .. attribute:: proxy_address
                
                	Specify an IP address to publish to peers through IPCPIW
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ppp-ma-ipcpiw-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp.Ipcpiw, self).__init__()

                    self.yang_name = "ipcpiw"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"

                    self.proxy_address = YLeaf(YType.str, "proxy-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("proxy_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp.Ipcpiw, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp.Ipcpiw, self).__setattr__(name, value)

                def has_data(self):
                    return self.proxy_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.proxy_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ipcpiw" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.proxy_address.is_set or self.proxy_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.proxy_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "proxy-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "proxy-address"):
                        self.proxy_address = value
                        self.proxy_address.value_namespace = name_space
                        self.proxy_address.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.ipcpiw is not None and self.ipcpiw.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.ipcpiw is not None and self.ipcpiw.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg:Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ipcpiw"):
                    if (self.ipcpiw is None):
                        self.ipcpiw = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp.Ipcpiw()
                        self.ipcpiw.parent = self
                        self._children_name_map["ipcpiw"] = "ipcpiw"
                    return self.ipcpiw

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ipcpiw"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class CiscoIosXrPppMaLcpCfg_Ppp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: lcp
            
            	PPP LCP configuration data
            	**type**\:   :py:class:`Lcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp>`
            
            .. attribute:: mcmp
            
            	PPP Multiclass Multilink parameters
            	**type**\:   :py:class:`Mcmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp>`
            
            

            """

            _prefix = 'ppp-ma-lcp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
                self.yang_parent_name = "interface-configuration"

                self.lcp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp()
                self.lcp.parent = self
                self._children_name_map["lcp"] = "lcp"
                self._children_yang_names.add("lcp")

                self.mcmp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp()
                self.mcmp.parent = self
                self._children_name_map["mcmp"] = "mcmp"
                self._children_yang_names.add("mcmp")


            class Mcmp(Entity):
                """
                PPP Multiclass Multilink parameters
                
                .. attribute:: enable
                
                	This specifies that MCMP is enabled on this interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: local
                
                	This specifies the MCMP options for the local host
                	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp.Local>`
                
                .. attribute:: remote
                
                	This specifies the MCMP options for the peer
                	**type**\:  int
                
                	**range:** 1..16
                
                	**default value**\: 2
                
                

                """

                _prefix = 'ppp-ma-lcp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp, self).__init__()

                    self.yang_name = "mcmp"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"

                    self.enable = YLeaf(YType.empty, "enable")

                    self.remote = YLeaf(YType.uint32, "remote")

                    self.local = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp.Local()
                    self.local.parent = self
                    self._children_name_map["local"] = "local"
                    self._children_yang_names.add("local")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("enable",
                                    "remote") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp, self).__setattr__(name, value)


                class Local(Entity):
                    """
                    This specifies the MCMP options for the local
                    host
                    
                    .. attribute:: initial
                    
                    	Local Initial #classes
                    	**type**\:  int
                    
                    	**range:** 1..16
                    
                    	**default value**\: 2
                    
                    .. attribute:: maximum
                    
                    	Local Maximum #classes
                    	**type**\:  int
                    
                    	**range:** 1..16
                    
                    	**default value**\: 4
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp.Local, self).__init__()

                        self.yang_name = "local"
                        self.yang_parent_name = "mcmp"

                        self.initial = YLeaf(YType.uint32, "initial")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("initial",
                                        "maximum") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp.Local, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp.Local, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.initial.is_set or
                            self.maximum.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.initial.yfilter != YFilter.not_set or
                            self.maximum.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "local" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.initial.is_set or self.initial.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.initial.get_name_leafdata())
                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "initial" or name == "maximum"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "initial"):
                            self.initial = value
                            self.initial.value_namespace = name_space
                            self.initial.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum"):
                            self.maximum = value
                            self.maximum.value_namespace = name_space
                            self.maximum.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.enable.is_set or
                        self.remote.is_set or
                        (self.local is not None and self.local.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        self.remote.yfilter != YFilter.not_set or
                        (self.local is not None and self.local.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mcmp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())
                    if (self.remote.is_set or self.remote.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "local"):
                        if (self.local is None):
                            self.local = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp.Local()
                            self.local.parent = self
                            self._children_name_map["local"] = "local"
                        return self.local

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "local" or name == "enable" or name == "remote"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote"):
                        self.remote = value
                        self.remote.value_namespace = name_space
                        self.remote.value_namespace_prefix = name_space_prefix


            class Lcp(Entity):
                """
                PPP LCP configuration data
                
                .. attribute:: authentication
                
                	PPP authentication parameters
                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication>`
                
                .. attribute:: chap
                
                	Challenge Handshake Authentication Protocol (CHAP) configuration data
                	**type**\:   :py:class:`Chap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Chap>`
                
                .. attribute:: loop_back
                
                	Loopback configuration
                	**type**\:   :py:class:`LoopBack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.LoopBack>`
                
                .. attribute:: ms_chap
                
                	Microsoft Challenge Handshake Authentication Protocol (MS\-CHAP) configuration data
                	**type**\:   :py:class:`MsChap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.MsChap>`
                
                .. attribute:: multilink
                
                	Multilink configuration
                	**type**\:   :py:class:`Multilink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink>`
                
                .. attribute:: pap
                
                	Password Authentication Protocol (PAP) configuration data
                	**type**\:   :py:class:`Pap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap>`
                
                .. attribute:: service_type
                
                	This specifies whether to allow multiple authentication failures and, if so, how many
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ppp-ma-lcp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp, self).__init__()

                    self.yang_name = "lcp"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"

                    self.service_type = YLeaf(YType.int32, "service-type")

                    self.authentication = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"
                    self._children_yang_names.add("authentication")

                    self.chap = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Chap()
                    self.chap.parent = self
                    self._children_name_map["chap"] = "chap"
                    self._children_yang_names.add("chap")

                    self.loop_back = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.LoopBack()
                    self.loop_back.parent = self
                    self._children_name_map["loop_back"] = "loop-back"
                    self._children_yang_names.add("loop-back")

                    self.ms_chap = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.MsChap()
                    self.ms_chap.parent = self
                    self._children_name_map["ms_chap"] = "ms-chap"
                    self._children_yang_names.add("ms-chap")

                    self.multilink = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink()
                    self.multilink.parent = self
                    self._children_name_map["multilink"] = "multilink"
                    self._children_yang_names.add("multilink")

                    self.pap = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap()
                    self.pap.parent = self
                    self._children_name_map["pap"] = "pap"
                    self._children_yang_names.add("pap")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("service_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp, self).__setattr__(name, value)


                class Multilink(Entity):
                    """
                    Multilink configuration
                    
                    .. attribute:: minimum_active
                    
                    	Minimum criteria for the linestate of a Multilink PPPinterface to be brought up
                    	**type**\:   :py:class:`MinimumActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink.MinimumActive>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink, self).__init__()

                        self.yang_name = "multilink"
                        self.yang_parent_name = "lcp"

                        self.minimum_active = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink.MinimumActive()
                        self.minimum_active.parent = self
                        self._children_name_map["minimum_active"] = "minimum-active"
                        self._children_yang_names.add("minimum-active")


                    class MinimumActive(Entity):
                        """
                        Minimum criteria for the linestate of a
                        Multilink PPPinterface to be brought up
                        
                        .. attribute:: links
                        
                        	Number of active links needed to bring up an MP interface
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**default value**\: 1
                        
                        

                        """

                        _prefix = 'ppp-ma-lcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink.MinimumActive, self).__init__()

                            self.yang_name = "minimum-active"
                            self.yang_parent_name = "multilink"

                            self.links = YLeaf(YType.uint32, "links")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("links") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink.MinimumActive, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink.MinimumActive, self).__setattr__(name, value)

                        def has_data(self):
                            return self.links.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.links.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minimum-active" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.links.is_set or self.links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.links.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "links"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "links"):
                                self.links = value
                                self.links.value_namespace = name_space
                                self.links.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.minimum_active is not None and self.minimum_active.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.minimum_active is not None and self.minimum_active.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multilink" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "minimum-active"):
                            if (self.minimum_active is None):
                                self.minimum_active = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink.MinimumActive()
                                self.minimum_active.parent = self
                                self._children_name_map["minimum_active"] = "minimum-active"
                            return self.minimum_active

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "minimum-active"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Pap(Entity):
                    """
                    Password Authentication Protocol (PAP)
                    configuration data
                    
                    .. attribute:: refuse
                    
                    	This specifies whether to refuse to authenticate using PAP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: send_user_info
                    
                    	This specifies the outbound PAP username and password
                    	**type**\:   :py:class:`SendUserInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap.SendUserInfo>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap, self).__init__()

                        self.yang_name = "pap"
                        self.yang_parent_name = "lcp"

                        self.refuse = YLeaf(YType.empty, "refuse")

                        self.send_user_info = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap.SendUserInfo()
                        self.send_user_info.parent = self
                        self._children_name_map["send_user_info"] = "send-user-info"
                        self._children_yang_names.add("send-user-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("refuse") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap, self).__setattr__(name, value)


                    class SendUserInfo(Entity):
                        """
                        This specifies the outbound PAP username and
                        password
                        
                        .. attribute:: password
                        
                        	Outbound PAP password
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: username
                        
                        	Outbound PAP username
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ppp-ma-lcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap.SendUserInfo, self).__init__()

                            self.yang_name = "send-user-info"
                            self.yang_parent_name = "pap"

                            self.password = YLeaf(YType.str, "password")

                            self.username = YLeaf(YType.str, "username")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("password",
                                            "username") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap.SendUserInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap.SendUserInfo, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.password.is_set or
                                self.username.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.password.yfilter != YFilter.not_set or
                                self.username.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "send-user-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.password.get_name_leafdata())
                            if (self.username.is_set or self.username.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.username.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "password" or name == "username"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "password"):
                                self.password = value
                                self.password.value_namespace = name_space
                                self.password.value_namespace_prefix = name_space_prefix
                            if(value_path == "username"):
                                self.username = value
                                self.username.value_namespace = name_space
                                self.username.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.refuse.is_set or
                            (self.send_user_info is not None and self.send_user_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.refuse.yfilter != YFilter.not_set or
                            (self.send_user_info is not None and self.send_user_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pap" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.refuse.is_set or self.refuse.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.refuse.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "send-user-info"):
                            if (self.send_user_info is None):
                                self.send_user_info = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap.SendUserInfo()
                                self.send_user_info.parent = self
                                self._children_name_map["send_user_info"] = "send-user-info"
                            return self.send_user_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "send-user-info" or name == "refuse"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "refuse"):
                            self.refuse = value
                            self.refuse.value_namespace = name_space
                            self.refuse.value_namespace_prefix = name_space_prefix


                class LoopBack(Entity):
                    """
                    Loopback configuration
                    
                    .. attribute:: ignore
                    
                    	Allow magic numbers to be equal
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.LoopBack, self).__init__()

                        self.yang_name = "loop-back"
                        self.yang_parent_name = "lcp"

                        self.ignore = YLeaf(YType.empty, "ignore")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ignore") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.LoopBack, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.LoopBack, self).__setattr__(name, value)

                    def has_data(self):
                        return self.ignore.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ignore.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "loop-back" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ignore.is_set or self.ignore.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ignore.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ignore"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ignore"):
                            self.ignore = value
                            self.ignore.value_namespace = name_space
                            self.ignore.value_namespace_prefix = name_space_prefix


                class MsChap(Entity):
                    """
                    Microsoft Challenge Handshake Authentication
                    Protocol (MS\-CHAP) configuration data
                    
                    .. attribute:: host_name
                    
                    	This specifies the MS\-CHAP hostname
                    	**type**\:  str
                    
                    .. attribute:: password
                    
                    	This specifies the default MS\-CHAP password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: refuse
                    
                    	This specifies whether to refuse to authenticate using MS\-CHAP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.MsChap, self).__init__()

                        self.yang_name = "ms-chap"
                        self.yang_parent_name = "lcp"

                        self.host_name = YLeaf(YType.str, "host-name")

                        self.password = YLeaf(YType.str, "password")

                        self.refuse = YLeaf(YType.empty, "refuse")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("host_name",
                                        "password",
                                        "refuse") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.MsChap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.MsChap, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.host_name.is_set or
                            self.password.is_set or
                            self.refuse.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.host_name.yfilter != YFilter.not_set or
                            self.password.yfilter != YFilter.not_set or
                            self.refuse.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ms-chap" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.host_name.is_set or self.host_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_name.get_name_leafdata())
                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.password.get_name_leafdata())
                        if (self.refuse.is_set or self.refuse.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.refuse.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "host-name" or name == "password" or name == "refuse"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "host-name"):
                            self.host_name = value
                            self.host_name.value_namespace = name_space
                            self.host_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "password"):
                            self.password = value
                            self.password.value_namespace = name_space
                            self.password.value_namespace_prefix = name_space_prefix
                        if(value_path == "refuse"):
                            self.refuse = value
                            self.refuse.value_namespace = name_space
                            self.refuse.value_namespace_prefix = name_space_prefix


                class Authentication(Entity):
                    """
                    PPP authentication parameters
                    
                    .. attribute:: max_authentication_failures
                    
                    	This specifies whether to allow multiple authentication failures and, if so, how many
                    	**type**\:  int
                    
                    	**range:** 0..10
                    
                    .. attribute:: method
                    
                    	This specifies the PPP link authentication method
                    	**type**\:   :py:class:`Method <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication.Method>`
                    
                    .. attribute:: timeout
                    
                    	Maximum time to wait for an authentication response
                    	**type**\:  int
                    
                    	**range:** 3..30
                    
                    	**default value**\: 10
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "lcp"

                        self.max_authentication_failures = YLeaf(YType.uint32, "max-authentication-failures")

                        self.timeout = YLeaf(YType.uint32, "timeout")

                        self.method = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication.Method()
                        self.method.parent = self
                        self._children_name_map["method"] = "method"
                        self._children_yang_names.add("method")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("max_authentication_failures",
                                        "timeout") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication, self).__setattr__(name, value)


                    class Method(Entity):
                        """
                        This specifies the PPP link authentication
                        method
                        
                        .. attribute:: method
                        
                        	Select between one and three authentication methods in order of preference
                        	**type**\:  list of   :py:class:`PppAuthenticationMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ppp_ma_lcp_cfg.PppAuthenticationMethod>`
                        
                        .. attribute:: name
                        
                        	Use an authentication list with this name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ppp-ma-lcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication.Method, self).__init__()

                            self.yang_name = "method"
                            self.yang_parent_name = "authentication"

                            self.method = YLeafList(YType.enumeration, "method")

                            self.name = YLeaf(YType.str, "name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("method",
                                            "name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication.Method, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication.Method, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.method.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return self.name.is_set

                        def has_operation(self):
                            for leaf in self.method.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.method.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "method" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            leaf_name_data.extend(self.method.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "method" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "method"):
                                self.method.append(value)
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.max_authentication_failures.is_set or
                            self.timeout.is_set or
                            (self.method is not None and self.method.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.max_authentication_failures.yfilter != YFilter.not_set or
                            self.timeout.yfilter != YFilter.not_set or
                            (self.method is not None and self.method.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "authentication" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.max_authentication_failures.is_set or self.max_authentication_failures.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_authentication_failures.get_name_leafdata())
                        if (self.timeout.is_set or self.timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.timeout.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "method"):
                            if (self.method is None):
                                self.method = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication.Method()
                                self.method.parent = self
                                self._children_name_map["method"] = "method"
                            return self.method

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "method" or name == "max-authentication-failures" or name == "timeout"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "max-authentication-failures"):
                            self.max_authentication_failures = value
                            self.max_authentication_failures.value_namespace = name_space
                            self.max_authentication_failures.value_namespace_prefix = name_space_prefix
                        if(value_path == "timeout"):
                            self.timeout = value
                            self.timeout.value_namespace = name_space
                            self.timeout.value_namespace_prefix = name_space_prefix


                class Chap(Entity):
                    """
                    Challenge Handshake Authentication Protocol
                    (CHAP) configuration data
                    
                    .. attribute:: host_name
                    
                    	This specifies the CHAP hostname
                    	**type**\:  str
                    
                    .. attribute:: password
                    
                    	This specifies the default CHAP password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: refuse
                    
                    	This specifies whether to refuse to authenticate using CHAP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Chap, self).__init__()

                        self.yang_name = "chap"
                        self.yang_parent_name = "lcp"

                        self.host_name = YLeaf(YType.str, "host-name")

                        self.password = YLeaf(YType.str, "password")

                        self.refuse = YLeaf(YType.empty, "refuse")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("host_name",
                                        "password",
                                        "refuse") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Chap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Chap, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.host_name.is_set or
                            self.password.is_set or
                            self.refuse.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.host_name.yfilter != YFilter.not_set or
                            self.password.yfilter != YFilter.not_set or
                            self.refuse.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "chap" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.host_name.is_set or self.host_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_name.get_name_leafdata())
                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.password.get_name_leafdata())
                        if (self.refuse.is_set or self.refuse.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.refuse.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "host-name" or name == "password" or name == "refuse"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "host-name"):
                            self.host_name = value
                            self.host_name.value_namespace = name_space
                            self.host_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "password"):
                            self.password = value
                            self.password.value_namespace = name_space
                            self.password.value_namespace_prefix = name_space_prefix
                        if(value_path == "refuse"):
                            self.refuse = value
                            self.refuse.value_namespace = name_space
                            self.refuse.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.service_type.is_set or
                        (self.authentication is not None and self.authentication.has_data()) or
                        (self.chap is not None and self.chap.has_data()) or
                        (self.loop_back is not None and self.loop_back.has_data()) or
                        (self.ms_chap is not None and self.ms_chap.has_data()) or
                        (self.multilink is not None and self.multilink.has_data()) or
                        (self.pap is not None and self.pap.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.service_type.yfilter != YFilter.not_set or
                        (self.authentication is not None and self.authentication.has_operation()) or
                        (self.chap is not None and self.chap.has_operation()) or
                        (self.loop_back is not None and self.loop_back.has_operation()) or
                        (self.ms_chap is not None and self.ms_chap.has_operation()) or
                        (self.multilink is not None and self.multilink.has_operation()) or
                        (self.pap is not None and self.pap.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lcp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.service_type.is_set or self.service_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.service_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "authentication"):
                        if (self.authentication is None):
                            self.authentication = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"
                        return self.authentication

                    if (child_yang_name == "chap"):
                        if (self.chap is None):
                            self.chap = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Chap()
                            self.chap.parent = self
                            self._children_name_map["chap"] = "chap"
                        return self.chap

                    if (child_yang_name == "loop-back"):
                        if (self.loop_back is None):
                            self.loop_back = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.LoopBack()
                            self.loop_back.parent = self
                            self._children_name_map["loop_back"] = "loop-back"
                        return self.loop_back

                    if (child_yang_name == "ms-chap"):
                        if (self.ms_chap is None):
                            self.ms_chap = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.MsChap()
                            self.ms_chap.parent = self
                            self._children_name_map["ms_chap"] = "ms-chap"
                        return self.ms_chap

                    if (child_yang_name == "multilink"):
                        if (self.multilink is None):
                            self.multilink = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Multilink()
                            self.multilink.parent = self
                            self._children_name_map["multilink"] = "multilink"
                        return self.multilink

                    if (child_yang_name == "pap"):
                        if (self.pap is None):
                            self.pap = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp.Pap()
                            self.pap.parent = self
                            self._children_name_map["pap"] = "pap"
                        return self.pap

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "authentication" or name == "chap" or name == "loop-back" or name == "ms-chap" or name == "multilink" or name == "pap" or name == "service-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "service-type"):
                        self.service_type = value
                        self.service_type.value_namespace = name_space
                        self.service_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.lcp is not None and self.lcp.has_data()) or
                    (self.mcmp is not None and self.mcmp.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.lcp is not None and self.lcp.has_operation()) or
                    (self.mcmp is not None and self.mcmp.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ppp-ma-lcp-cfg:Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "lcp"):
                    if (self.lcp is None):
                        self.lcp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Lcp()
                        self.lcp.parent = self
                        self._children_name_map["lcp"] = "lcp"
                    return self.lcp

                if (child_yang_name == "mcmp"):
                    if (self.mcmp is None):
                        self.mcmp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp.Mcmp()
                        self.mcmp.parent = self
                        self._children_name_map["mcmp"] = "mcmp"
                    return self.mcmp

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "lcp" or name == "mcmp"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class SsrpSession(Entity):
            """
            SSRP Config
            
            .. attribute:: group_id
            
            	This specifies the SSRP group and session\-id
            	**type**\:   :py:class:`GroupId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId>`
            
            

            """

            _prefix = 'ppp-ma-ssrp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.SsrpSession, self).__init__()

                self.yang_name = "ssrp-session"
                self.yang_parent_name = "interface-configuration"

                self.group_id = InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId()
                self.group_id.parent = self
                self._children_name_map["group_id"] = "group-id"
                self._children_yang_names.add("group-id")


            class GroupId(Entity):
                """
                This specifies the SSRP group and session\-id
                
                .. attribute:: group
                
                	SSRP Group\-ID
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: id
                
                	SSRP Session\-ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                

                """

                _prefix = 'ppp-ma-ssrp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId, self).__init__()

                    self.yang_name = "group-id"
                    self.yang_parent_name = "ssrp-session"

                    self.group = YLeaf(YType.uint32, "group")

                    self.id = YLeaf(YType.uint32, "id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group",
                                    "id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group.is_set or
                        self.id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group.yfilter != YFilter.not_set or
                        self.id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-id" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group.is_set or self.group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group.get_name_leafdata())
                    if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group" or name == "id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group"):
                        self.group = value
                        self.group.value_namespace = name_space
                        self.group.value_namespace_prefix = name_space_prefix
                    if(value_path == "id"):
                        self.id = value
                        self.id.value_namespace = name_space
                        self.id.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.group_id is not None and self.group_id.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.group_id is not None and self.group_id.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-ppp-ma-ssrp-cfg:ssrp-session" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "group-id"):
                    if (self.group_id is None):
                        self.group_id = InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId()
                        self.group_id.parent = self
                        self._children_name_map["group_id"] = "group-id"
                    return self.group_id

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "group-id"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Qos(Entity):
            """
            Interface QOS configuration
            
            .. attribute:: input
            
            	Ingress service policy
            	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input>`
            
            .. attribute:: output
            
            	Egress service policy
            	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output>`
            
            

            """

            _prefix = 'qos-ma-cfg'
            _revision = '2016-12-23'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Qos, self).__init__()

                self.yang_name = "qos"
                self.yang_parent_name = "interface-configuration"

                self.input = InterfaceConfigurations.InterfaceConfiguration.Qos.Input()
                self.input.parent = self
                self._children_name_map["input"] = "input"
                self._children_yang_names.add("input")

                self.output = InterfaceConfigurations.InterfaceConfiguration.Qos.Output()
                self.output.parent = self
                self._children_name_map["output"] = "output"
                self._children_yang_names.add("output")


            class Output(Entity):
                """
                Egress service policy
                
                .. attribute:: service_policy
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy>`
                
                .. attribute:: service_policy_qos
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2016-12-23'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output, self).__init__()

                    self.yang_name = "output"
                    self.yang_parent_name = "qos"

                    self.service_policy = YList(self)
                    self.service_policy_qos = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output, self).__setattr__(name, value)


                class ServicePolicy(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: account_type
                    
                    	Turn off L2 or L3 accounting
                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                    
                    .. attribute:: l1_user_defined
                    
                    	User specified value
                    	**type**\:  int
                    
                    	**range:** \-63..63
                    
                    .. attribute:: resource_id
                    
                    	Resource ID value
                    	**type**\:  int
                    
                    	**range:** 0..3
                    
                    .. attribute:: service_fragment_parent_policy
                    
                    	service\-fragment\-parent\-policy
                    	**type**\:  bool
                    
                    .. attribute:: spi_name
                    
                    	Name of the SPI
                    	**type**\:  str
                    
                    .. attribute:: subscriber_parent_policy
                    
                    	TRUE if service\-policy applied on svlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2016-12-23'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "output"

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.account_type = YLeaf(YType.enumeration, "account-type")

                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                        self.spi_name = YLeaf(YType.str, "spi-name")

                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("service_policy_name",
                                        "account_type",
                                        "l1_user_defined",
                                        "resource_id",
                                        "service_fragment_parent_policy",
                                        "spi_name",
                                        "subscriber_parent_policy") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.service_policy_name.is_set or
                            self.account_type.is_set or
                            self.l1_user_defined.is_set or
                            self.resource_id.is_set or
                            self.service_fragment_parent_policy.is_set or
                            self.spi_name.is_set or
                            self.subscriber_parent_policy.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.service_policy_name.yfilter != YFilter.not_set or
                            self.account_type.yfilter != YFilter.not_set or
                            self.l1_user_defined.yfilter != YFilter.not_set or
                            self.resource_id.yfilter != YFilter.not_set or
                            self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                            self.spi_name.yfilter != YFilter.not_set or
                            self.subscriber_parent_policy.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_policy_name.get_name_leafdata())
                        if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.account_type.get_name_leafdata())
                        if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                        if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resource_id.get_name_leafdata())
                        if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                        if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spi_name.get_name_leafdata())
                        if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "service-policy-name" or name == "account-type" or name == "l1-user-defined" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "service-policy-name"):
                            self.service_policy_name = value
                            self.service_policy_name.value_namespace = name_space
                            self.service_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "account-type"):
                            self.account_type = value
                            self.account_type.value_namespace = name_space
                            self.account_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "l1-user-defined"):
                            self.l1_user_defined = value
                            self.l1_user_defined.value_namespace = name_space
                            self.l1_user_defined.value_namespace_prefix = name_space_prefix
                        if(value_path == "resource-id"):
                            self.resource_id = value
                            self.resource_id.value_namespace = name_space
                            self.resource_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "service-fragment-parent-policy"):
                            self.service_fragment_parent_policy = value
                            self.service_fragment_parent_policy.value_namespace = name_space
                            self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                        if(value_path == "spi-name"):
                            self.spi_name = value
                            self.spi_name.value_namespace = name_space
                            self.spi_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-parent-policy"):
                            self.subscriber_parent_policy = value
                            self.subscriber_parent_policy.value_namespace = name_space
                            self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix


                class ServicePolicyQos(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: subscriber_group_names
                    
                    	Subscriber Group Name Details
                    	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames>`
                    
                    .. attribute:: subscriber_parent
                    
                    	Subscriber Parent Details
                    	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2016-12-23'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos, self).__init__()

                        self.yang_name = "service-policy-qos"
                        self.yang_parent_name = "output"

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                        self.subscriber_group_names.parent = self
                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                        self._children_yang_names.add("subscriber-group-names")

                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent()
                        self.subscriber_parent.parent = self
                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                        self._children_yang_names.add("subscriber-parent")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("service_policy_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos, self).__setattr__(name, value)


                    class SubscriberGroupNames(Entity):
                        """
                        Subscriber Group Name Details
                        
                        .. attribute:: subscriber_group_name
                        
                        	Subscriber Group details
                        	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                            self.yang_name = "subscriber-group-names"
                            self.yang_parent_name = "service-policy-qos"

                            self.subscriber_group_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)


                        class SubscriberGroupName(Entity):
                            """
                            Subscriber Group details
                            
                            .. attribute:: subscriber_group_string  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: policy_merge
                            
                            	Not supported (Leave unspecified)
                            	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	TRUE if service\-policy applied is a service\-fragment policy)
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                self.yang_name = "subscriber-group-name"
                                self.yang_parent_name = "subscriber-group-names"

                                self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("subscriber_group_string",
                                                "account_type",
                                                "l1_user_defined",
                                                "policy_merge",
                                                "resource_id",
                                                "service_fragment_parent_policy",
                                                "spi_name",
                                                "subscriber_parent_policy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.subscriber_group_string.is_set or
                                    self.account_type.is_set or
                                    self.l1_user_defined.is_set or
                                    self.policy_merge.is_set or
                                    self.resource_id.is_set or
                                    self.service_fragment_parent_policy.is_set or
                                    self.spi_name.is_set or
                                    self.subscriber_parent_policy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.subscriber_group_string.yfilter != YFilter.not_set or
                                    self.account_type.yfilter != YFilter.not_set or
                                    self.l1_user_defined.yfilter != YFilter.not_set or
                                    self.policy_merge.yfilter != YFilter.not_set or
                                    self.resource_id.yfilter != YFilter.not_set or
                                    self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                    self.spi_name.yfilter != YFilter.not_set or
                                    self.subscriber_parent_policy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.subscriber_group_string.is_set or self.subscriber_group_string.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_group_string.get_name_leafdata())
                                if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.account_type.get_name_leafdata())
                                if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resource_id.get_name_leafdata())
                                if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spi_name.get_name_leafdata())
                                if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "subscriber-group-string" or name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "subscriber-group-string"):
                                    self.subscriber_group_string = value
                                    self.subscriber_group_string.value_namespace = name_space
                                    self.subscriber_group_string.value_namespace_prefix = name_space_prefix
                                if(value_path == "account-type"):
                                    self.account_type = value
                                    self.account_type.value_namespace = name_space
                                    self.account_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "l1-user-defined"):
                                    self.l1_user_defined = value
                                    self.l1_user_defined.value_namespace = name_space
                                    self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                if(value_path == "policy-merge"):
                                    self.policy_merge = value
                                    self.policy_merge.value_namespace = name_space
                                    self.policy_merge.value_namespace_prefix = name_space_prefix
                                if(value_path == "resource-id"):
                                    self.resource_id = value
                                    self.resource_id.value_namespace = name_space
                                    self.resource_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-fragment-parent-policy"):
                                    self.service_fragment_parent_policy = value
                                    self.service_fragment_parent_policy.value_namespace = name_space
                                    self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spi-name"):
                                    self.spi_name = value
                                    self.spi_name.value_namespace = name_space
                                    self.spi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-parent-policy"):
                                    self.subscriber_parent_policy = value
                                    self.subscriber_parent_policy.value_namespace = name_space
                                    self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.subscriber_group_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.subscriber_group_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-group-names" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "subscriber-group-name"):
                                for c in self.subscriber_group_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.subscriber_group_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "subscriber-group-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SubscriberParent(Entity):
                        """
                        Subscriber Parent Details
                        
                        .. attribute:: account_type
                        
                        	Turn off L2 or L3 accounting
                        	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                        
                        .. attribute:: l1_user_defined
                        
                        	User specified value
                        	**type**\:  int
                        
                        	**range:** \-63..63
                        
                        .. attribute:: policy_merge
                        
                        	Not supported (Leave unspecified)
                        	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                        
                        .. attribute:: resource_id
                        
                        	Resource ID value
                        	**type**\:  int
                        
                        	**range:** 0..3
                        
                        .. attribute:: service_fragment_parent_policy
                        
                        	TRUE if service\-policy applied is a service\-fragment policy)
                        	**type**\:  bool
                        
                        .. attribute:: spi_name
                        
                        	Name of the SPI
                        	**type**\:  str
                        
                        .. attribute:: subscriber_parent_policy
                        
                        	TRUE if service\-policy applied on svlan
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent, self).__init__()

                            self.yang_name = "subscriber-parent"
                            self.yang_parent_name = "service-policy-qos"

                            self.account_type = YLeaf(YType.enumeration, "account-type")

                            self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                            self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                            self.resource_id = YLeaf(YType.uint32, "resource-id")

                            self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                            self.spi_name = YLeaf(YType.str, "spi-name")

                            self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("account_type",
                                            "l1_user_defined",
                                            "policy_merge",
                                            "resource_id",
                                            "service_fragment_parent_policy",
                                            "spi_name",
                                            "subscriber_parent_policy") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.account_type.is_set or
                                self.l1_user_defined.is_set or
                                self.policy_merge.is_set or
                                self.resource_id.is_set or
                                self.service_fragment_parent_policy.is_set or
                                self.spi_name.is_set or
                                self.subscriber_parent_policy.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.account_type.yfilter != YFilter.not_set or
                                self.l1_user_defined.yfilter != YFilter.not_set or
                                self.policy_merge.yfilter != YFilter.not_set or
                                self.resource_id.yfilter != YFilter.not_set or
                                self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                self.spi_name.yfilter != YFilter.not_set or
                                self.subscriber_parent_policy.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-parent" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.account_type.get_name_leafdata())
                            if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                            if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_merge.get_name_leafdata())
                            if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resource_id.get_name_leafdata())
                            if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                            if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spi_name.get_name_leafdata())
                            if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "account-type"):
                                self.account_type = value
                                self.account_type.value_namespace = name_space
                                self.account_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "l1-user-defined"):
                                self.l1_user_defined = value
                                self.l1_user_defined.value_namespace = name_space
                                self.l1_user_defined.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-merge"):
                                self.policy_merge = value
                                self.policy_merge.value_namespace = name_space
                                self.policy_merge.value_namespace_prefix = name_space_prefix
                            if(value_path == "resource-id"):
                                self.resource_id = value
                                self.resource_id.value_namespace = name_space
                                self.resource_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "service-fragment-parent-policy"):
                                self.service_fragment_parent_policy = value
                                self.service_fragment_parent_policy.value_namespace = name_space
                                self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "spi-name"):
                                self.spi_name = value
                                self.spi_name.value_namespace = name_space
                                self.spi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-parent-policy"):
                                self.subscriber_parent_policy = value
                                self.subscriber_parent_policy.value_namespace = name_space
                                self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.service_policy_name.is_set or
                            (self.subscriber_group_names is not None and self.subscriber_group_names.has_data()) or
                            (self.subscriber_parent is not None and self.subscriber_parent.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.service_policy_name.yfilter != YFilter.not_set or
                            (self.subscriber_group_names is not None and self.subscriber_group_names.has_operation()) or
                            (self.subscriber_parent is not None and self.subscriber_parent.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "subscriber-group-names"):
                            if (self.subscriber_group_names is None):
                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                            return self.subscriber_group_names

                        if (child_yang_name == "subscriber-parent"):
                            if (self.subscriber_parent is None):
                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                            return self.subscriber_parent

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "subscriber-group-names" or name == "subscriber-parent" or name == "service-policy-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "service-policy-name"):
                            self.service_policy_name = value
                            self.service_policy_name.value_namespace = name_space
                            self.service_policy_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.service_policy:
                        if (c.has_data()):
                            return True
                    for c in self.service_policy_qos:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.service_policy:
                        if (c.has_operation()):
                            return True
                    for c in self.service_policy_qos:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "output" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "service-policy"):
                        for c in self.service_policy:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.service_policy.append(c)
                        return c

                    if (child_yang_name == "service-policy-qos"):
                        for c in self.service_policy_qos:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.service_policy_qos.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "service-policy" or name == "service-policy-qos"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Input(Entity):
                """
                Ingress service policy
                
                .. attribute:: service_policy
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy>`
                
                .. attribute:: service_policy_qos
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2016-12-23'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input, self).__init__()

                    self.yang_name = "input"
                    self.yang_parent_name = "qos"

                    self.service_policy = YList(self)
                    self.service_policy_qos = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input, self).__setattr__(name, value)


                class ServicePolicy(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: account_type
                    
                    	Turn off L2 or L3 accounting
                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                    
                    .. attribute:: l1_user_defined
                    
                    	User specified value
                    	**type**\:  int
                    
                    	**range:** \-63..63
                    
                    .. attribute:: resource_id
                    
                    	Resource ID value
                    	**type**\:  int
                    
                    	**range:** 0..3
                    
                    .. attribute:: service_fragment_parent_policy
                    
                    	service\-fragment\-parent\-policy
                    	**type**\:  bool
                    
                    .. attribute:: spi_name
                    
                    	Name of the SPI
                    	**type**\:  str
                    
                    .. attribute:: subscriber_parent_policy
                    
                    	TRUE if service\-policy applied on svlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2016-12-23'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "input"

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.account_type = YLeaf(YType.enumeration, "account-type")

                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                        self.spi_name = YLeaf(YType.str, "spi-name")

                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("service_policy_name",
                                        "account_type",
                                        "l1_user_defined",
                                        "resource_id",
                                        "service_fragment_parent_policy",
                                        "spi_name",
                                        "subscriber_parent_policy") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.service_policy_name.is_set or
                            self.account_type.is_set or
                            self.l1_user_defined.is_set or
                            self.resource_id.is_set or
                            self.service_fragment_parent_policy.is_set or
                            self.spi_name.is_set or
                            self.subscriber_parent_policy.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.service_policy_name.yfilter != YFilter.not_set or
                            self.account_type.yfilter != YFilter.not_set or
                            self.l1_user_defined.yfilter != YFilter.not_set or
                            self.resource_id.yfilter != YFilter.not_set or
                            self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                            self.spi_name.yfilter != YFilter.not_set or
                            self.subscriber_parent_policy.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_policy_name.get_name_leafdata())
                        if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.account_type.get_name_leafdata())
                        if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                        if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resource_id.get_name_leafdata())
                        if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                        if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spi_name.get_name_leafdata())
                        if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "service-policy-name" or name == "account-type" or name == "l1-user-defined" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "service-policy-name"):
                            self.service_policy_name = value
                            self.service_policy_name.value_namespace = name_space
                            self.service_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "account-type"):
                            self.account_type = value
                            self.account_type.value_namespace = name_space
                            self.account_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "l1-user-defined"):
                            self.l1_user_defined = value
                            self.l1_user_defined.value_namespace = name_space
                            self.l1_user_defined.value_namespace_prefix = name_space_prefix
                        if(value_path == "resource-id"):
                            self.resource_id = value
                            self.resource_id.value_namespace = name_space
                            self.resource_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "service-fragment-parent-policy"):
                            self.service_fragment_parent_policy = value
                            self.service_fragment_parent_policy.value_namespace = name_space
                            self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                        if(value_path == "spi-name"):
                            self.spi_name = value
                            self.spi_name.value_namespace = name_space
                            self.spi_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-parent-policy"):
                            self.subscriber_parent_policy = value
                            self.subscriber_parent_policy.value_namespace = name_space
                            self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix


                class ServicePolicyQos(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: subscriber_group_names
                    
                    	Subscriber Group Name Details
                    	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames>`
                    
                    .. attribute:: subscriber_parent
                    
                    	Subscriber Parent Details
                    	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2016-12-23'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos, self).__init__()

                        self.yang_name = "service-policy-qos"
                        self.yang_parent_name = "input"

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                        self.subscriber_group_names.parent = self
                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                        self._children_yang_names.add("subscriber-group-names")

                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent()
                        self.subscriber_parent.parent = self
                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                        self._children_yang_names.add("subscriber-parent")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("service_policy_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos, self).__setattr__(name, value)


                    class SubscriberGroupNames(Entity):
                        """
                        Subscriber Group Name Details
                        
                        .. attribute:: subscriber_group_name
                        
                        	Subscriber Group details
                        	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                            self.yang_name = "subscriber-group-names"
                            self.yang_parent_name = "service-policy-qos"

                            self.subscriber_group_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__setattr__(name, value)


                        class SubscriberGroupName(Entity):
                            """
                            Subscriber Group details
                            
                            .. attribute:: subscriber_group_string  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: policy_merge
                            
                            	Not supported (Leave unspecified)
                            	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	TRUE if service\-policy applied is a service\-fragment policy)
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2016-12-23'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                self.yang_name = "subscriber-group-name"
                                self.yang_parent_name = "subscriber-group-names"

                                self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("subscriber_group_string",
                                                "account_type",
                                                "l1_user_defined",
                                                "policy_merge",
                                                "resource_id",
                                                "service_fragment_parent_policy",
                                                "spi_name",
                                                "subscriber_parent_policy") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.subscriber_group_string.is_set or
                                    self.account_type.is_set or
                                    self.l1_user_defined.is_set or
                                    self.policy_merge.is_set or
                                    self.resource_id.is_set or
                                    self.service_fragment_parent_policy.is_set or
                                    self.spi_name.is_set or
                                    self.subscriber_parent_policy.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.subscriber_group_string.yfilter != YFilter.not_set or
                                    self.account_type.yfilter != YFilter.not_set or
                                    self.l1_user_defined.yfilter != YFilter.not_set or
                                    self.policy_merge.yfilter != YFilter.not_set or
                                    self.resource_id.yfilter != YFilter.not_set or
                                    self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                    self.spi_name.yfilter != YFilter.not_set or
                                    self.subscriber_parent_policy.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.subscriber_group_string.is_set or self.subscriber_group_string.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_group_string.get_name_leafdata())
                                if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.account_type.get_name_leafdata())
                                if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                                if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.policy_merge.get_name_leafdata())
                                if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resource_id.get_name_leafdata())
                                if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                                if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spi_name.get_name_leafdata())
                                if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "subscriber-group-string" or name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "subscriber-group-string"):
                                    self.subscriber_group_string = value
                                    self.subscriber_group_string.value_namespace = name_space
                                    self.subscriber_group_string.value_namespace_prefix = name_space_prefix
                                if(value_path == "account-type"):
                                    self.account_type = value
                                    self.account_type.value_namespace = name_space
                                    self.account_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "l1-user-defined"):
                                    self.l1_user_defined = value
                                    self.l1_user_defined.value_namespace = name_space
                                    self.l1_user_defined.value_namespace_prefix = name_space_prefix
                                if(value_path == "policy-merge"):
                                    self.policy_merge = value
                                    self.policy_merge.value_namespace = name_space
                                    self.policy_merge.value_namespace_prefix = name_space_prefix
                                if(value_path == "resource-id"):
                                    self.resource_id = value
                                    self.resource_id.value_namespace = name_space
                                    self.resource_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-fragment-parent-policy"):
                                    self.service_fragment_parent_policy = value
                                    self.service_fragment_parent_policy.value_namespace = name_space
                                    self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "spi-name"):
                                    self.spi_name = value
                                    self.spi_name.value_namespace = name_space
                                    self.spi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-parent-policy"):
                                    self.subscriber_parent_policy = value
                                    self.subscriber_parent_policy.value_namespace = name_space
                                    self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.subscriber_group_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.subscriber_group_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-group-names" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "subscriber-group-name"):
                                for c in self.subscriber_group_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.subscriber_group_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "subscriber-group-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SubscriberParent(Entity):
                        """
                        Subscriber Parent Details
                        
                        .. attribute:: account_type
                        
                        	Turn off L2 or L3 accounting
                        	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                        
                        .. attribute:: l1_user_defined
                        
                        	User specified value
                        	**type**\:  int
                        
                        	**range:** \-63..63
                        
                        .. attribute:: policy_merge
                        
                        	Not supported (Leave unspecified)
                        	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                        
                        .. attribute:: resource_id
                        
                        	Resource ID value
                        	**type**\:  int
                        
                        	**range:** 0..3
                        
                        .. attribute:: service_fragment_parent_policy
                        
                        	TRUE if service\-policy applied is a service\-fragment policy)
                        	**type**\:  bool
                        
                        .. attribute:: spi_name
                        
                        	Name of the SPI
                        	**type**\:  str
                        
                        .. attribute:: subscriber_parent_policy
                        
                        	TRUE if service\-policy applied on svlan
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2016-12-23'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent, self).__init__()

                            self.yang_name = "subscriber-parent"
                            self.yang_parent_name = "service-policy-qos"

                            self.account_type = YLeaf(YType.enumeration, "account-type")

                            self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                            self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                            self.resource_id = YLeaf(YType.uint32, "resource-id")

                            self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                            self.spi_name = YLeaf(YType.str, "spi-name")

                            self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("account_type",
                                            "l1_user_defined",
                                            "policy_merge",
                                            "resource_id",
                                            "service_fragment_parent_policy",
                                            "spi_name",
                                            "subscriber_parent_policy") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.account_type.is_set or
                                self.l1_user_defined.is_set or
                                self.policy_merge.is_set or
                                self.resource_id.is_set or
                                self.service_fragment_parent_policy.is_set or
                                self.spi_name.is_set or
                                self.subscriber_parent_policy.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.account_type.yfilter != YFilter.not_set or
                                self.l1_user_defined.yfilter != YFilter.not_set or
                                self.policy_merge.yfilter != YFilter.not_set or
                                self.resource_id.yfilter != YFilter.not_set or
                                self.service_fragment_parent_policy.yfilter != YFilter.not_set or
                                self.spi_name.yfilter != YFilter.not_set or
                                self.subscriber_parent_policy.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-parent" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.account_type.is_set or self.account_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.account_type.get_name_leafdata())
                            if (self.l1_user_defined.is_set or self.l1_user_defined.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.l1_user_defined.get_name_leafdata())
                            if (self.policy_merge.is_set or self.policy_merge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_merge.get_name_leafdata())
                            if (self.resource_id.is_set or self.resource_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resource_id.get_name_leafdata())
                            if (self.service_fragment_parent_policy.is_set or self.service_fragment_parent_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_fragment_parent_policy.get_name_leafdata())
                            if (self.spi_name.is_set or self.spi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spi_name.get_name_leafdata())
                            if (self.subscriber_parent_policy.is_set or self.subscriber_parent_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_parent_policy.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "account-type" or name == "l1-user-defined" or name == "policy-merge" or name == "resource-id" or name == "service-fragment-parent-policy" or name == "spi-name" or name == "subscriber-parent-policy"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "account-type"):
                                self.account_type = value
                                self.account_type.value_namespace = name_space
                                self.account_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "l1-user-defined"):
                                self.l1_user_defined = value
                                self.l1_user_defined.value_namespace = name_space
                                self.l1_user_defined.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-merge"):
                                self.policy_merge = value
                                self.policy_merge.value_namespace = name_space
                                self.policy_merge.value_namespace_prefix = name_space_prefix
                            if(value_path == "resource-id"):
                                self.resource_id = value
                                self.resource_id.value_namespace = name_space
                                self.resource_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "service-fragment-parent-policy"):
                                self.service_fragment_parent_policy = value
                                self.service_fragment_parent_policy.value_namespace = name_space
                                self.service_fragment_parent_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "spi-name"):
                                self.spi_name = value
                                self.spi_name.value_namespace = name_space
                                self.spi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-parent-policy"):
                                self.subscriber_parent_policy = value
                                self.subscriber_parent_policy.value_namespace = name_space
                                self.subscriber_parent_policy.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.service_policy_name.is_set or
                            (self.subscriber_group_names is not None and self.subscriber_group_names.has_data()) or
                            (self.subscriber_parent is not None and self.subscriber_parent.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.service_policy_name.yfilter != YFilter.not_set or
                            (self.subscriber_group_names is not None and self.subscriber_group_names.has_operation()) or
                            (self.subscriber_parent is not None and self.subscriber_parent.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.service_policy_name.is_set or self.service_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_policy_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "subscriber-group-names"):
                            if (self.subscriber_group_names is None):
                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                            return self.subscriber_group_names

                        if (child_yang_name == "subscriber-parent"):
                            if (self.subscriber_parent is None):
                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                            return self.subscriber_parent

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "subscriber-group-names" or name == "subscriber-parent" or name == "service-policy-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "service-policy-name"):
                            self.service_policy_name = value
                            self.service_policy_name.value_namespace = name_space
                            self.service_policy_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.service_policy:
                        if (c.has_data()):
                            return True
                    for c in self.service_policy_qos:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.service_policy:
                        if (c.has_operation()):
                            return True
                    for c in self.service_policy_qos:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "input" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "service-policy"):
                        for c in self.service_policy:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.service_policy.append(c)
                        return c

                    if (child_yang_name == "service-policy-qos"):
                        for c in self.service_policy_qos:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.service_policy_qos.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "service-policy" or name == "service-policy-qos"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.input is not None and self.input.has_data()) or
                    (self.output is not None and self.output.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.input is not None and self.input.has_operation()) or
                    (self.output is not None and self.output.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-qos-ma-cfg:qos" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "input"):
                    if (self.input is None):
                        self.input = InterfaceConfigurations.InterfaceConfiguration.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                    return self.input

                if (child_yang_name == "output"):
                    if (self.output is None):
                        self.output = InterfaceConfigurations.InterfaceConfiguration.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                    return self.output

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "input" or name == "output"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Subscriber(Entity):
            """
            Subscribers on interface
            
            .. attribute:: ip_subscriber
            
            	IP subscribers on interface
            	**type**\:   :py:class:`IpSubscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber>`
            
            

            """

            _prefix = 'subscriber-ipsub-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber, self).__init__()

                self.yang_name = "subscriber"
                self.yang_parent_name = "interface-configuration"

                self.ip_subscriber = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber()
                self.ip_subscriber.parent = self
                self._children_name_map["ip_subscriber"] = "ip-subscriber"
                self._children_yang_names.add("ip-subscriber")


            class IpSubscriber(Entity):
                """
                IP subscribers on interface
                
                .. attribute:: interface
                
                	Enable IP Static subscriber
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipv4
                
                	IPv4 subscriber
                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 subscriber
                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6>`
                
                .. attribute:: session_limit
                
                	IP subscriber session limit
                	**type**\:   :py:class:`SessionLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit>`
                
                .. attribute:: subscriber_templates
                
                	Enable subscriber templates on this access interface
                	**type**\:  int
                
                	**range:** 1..10
                
                	**default value**\: 10
                
                

                """

                _prefix = 'subscriber-ipsub-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber, self).__init__()

                    self.yang_name = "ip-subscriber"
                    self.yang_parent_name = "subscriber"

                    self.interface = YLeaf(YType.empty, "interface")

                    self.subscriber_templates = YLeaf(YType.uint32, "subscriber-templates")

                    self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._children_yang_names.add("ipv4")

                    self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._children_yang_names.add("ipv6")

                    self.session_limit = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit()
                    self.session_limit.parent = self
                    self._children_name_map["session_limit"] = "session-limit"
                    self._children_yang_names.add("session-limit")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface",
                                    "subscriber_templates") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber, self).__setattr__(name, value)


                class Ipv4(Entity):
                    """
                    IPv4 subscriber
                    
                    .. attribute:: l2_connected
                    
                    	L2 connected IPv4 subscriber
                    	**type**\:   :py:class:`L2Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected>`
                    
                    .. attribute:: routed
                    
                    	Routed IPv4 subscriber
                    	**type**\:   :py:class:`Routed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed>`
                    
                    

                    """

                    _prefix = 'subscriber-ipsub-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "ip-subscriber"

                        self.l2_connected = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected()
                        self.l2_connected.parent = self
                        self._children_name_map["l2_connected"] = "l2-connected"
                        self._children_yang_names.add("l2-connected")

                        self.routed = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed()
                        self.routed.parent = self
                        self._children_name_map["routed"] = "routed"
                        self._children_yang_names.add("routed")


                    class L2Connected(Entity):
                        """
                        L2 connected IPv4 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IP subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected, self).__init__()

                            self.yang_name = "l2-connected"
                            self.yang_parent_name = "ipv4"

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")


                        class Initiator(Entity):
                            """
                            Configure IP subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IP subscriber DHCP initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unclassified_source_fsol
                            
                            	Configure IP subscriber unclassified source initiator
                            	**type**\:   :py:class:`UnclassifiedSourceFsol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "l2-connected"

                                self.dhcp = YLeaf(YType.empty, "dhcp")

                                self.unclassified_source_fsol = None
                                self._children_name_map["unclassified_source_fsol"] = "unclassified-source-fsol"
                                self._children_yang_names.add("unclassified-source-fsol")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dhcp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator, self).__setattr__(name, value)


                            class UnclassifiedSourceFsol(Entity):
                                """
                                Configure IP subscriber unclassified source
                                initiator
                                
                                .. attribute:: address_unique
                                
                                	Check for subscriber IP uniqueness during first sign of life
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: enable
                                
                                	Enable unclassified source
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                	**mandatory**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'subscriber-ipsub-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol, self).__init__()

                                    self.yang_name = "unclassified-source-fsol"
                                    self.yang_parent_name = "initiator"
                                    self.is_presence_container = True

                                    self.address_unique = YLeaf(YType.boolean, "address-unique")

                                    self.enable = YLeaf(YType.empty, "enable")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address_unique",
                                                    "enable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address_unique.is_set or
                                        self.enable.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address_unique.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unclassified-source-fsol" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address_unique.is_set or self.address_unique.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address_unique.get_name_leafdata())
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address-unique" or name == "enable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address-unique"):
                                        self.address_unique = value
                                        self.address_unique.value_namespace = name_space
                                        self.address_unique.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.dhcp.is_set or
                                    (self.unclassified_source_fsol is not None))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dhcp.yfilter != YFilter.not_set or
                                    (self.unclassified_source_fsol is not None and self.unclassified_source_fsol.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "initiator" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dhcp.is_set or self.dhcp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "unclassified-source-fsol"):
                                    if (self.unclassified_source_fsol is None):
                                        self.unclassified_source_fsol = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol()
                                        self.unclassified_source_fsol.parent = self
                                        self._children_name_map["unclassified_source_fsol"] = "unclassified-source-fsol"
                                    return self.unclassified_source_fsol

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "unclassified-source-fsol" or name == "dhcp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dhcp"):
                                    self.dhcp = value
                                    self.dhcp.value_namespace = name_space
                                    self.dhcp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.initiator is not None and self.initiator.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.initiator is not None and self.initiator.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2-connected" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "initiator"):
                                if (self.initiator is None):
                                    self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator()
                                    self.initiator.parent = self
                                    self._children_name_map["initiator"] = "initiator"
                                return self.initiator

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "initiator"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Routed(Entity):
                        """
                        Routed IPv4 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IP subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed, self).__init__()

                            self.yang_name = "routed"
                            self.yang_parent_name = "ipv4"

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")


                        class Initiator(Entity):
                            """
                            Configure IP subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IPv6 subscriber DHCP initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unclassified_ip
                            
                            	Configure IPv6 subscriber unclassified source initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "routed"

                                self.dhcp = YLeaf(YType.empty, "dhcp")

                                self.unclassified_ip = YLeaf(YType.empty, "unclassified-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dhcp",
                                                "unclassified_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dhcp.is_set or
                                    self.unclassified_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dhcp.yfilter != YFilter.not_set or
                                    self.unclassified_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "initiator" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dhcp.is_set or self.dhcp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp.get_name_leafdata())
                                if (self.unclassified_ip.is_set or self.unclassified_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unclassified_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dhcp" or name == "unclassified-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dhcp"):
                                    self.dhcp = value
                                    self.dhcp.value_namespace = name_space
                                    self.dhcp.value_namespace_prefix = name_space_prefix
                                if(value_path == "unclassified-ip"):
                                    self.unclassified_ip = value
                                    self.unclassified_ip.value_namespace = name_space
                                    self.unclassified_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.initiator is not None and self.initiator.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.initiator is not None and self.initiator.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "routed" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "initiator"):
                                if (self.initiator is None):
                                    self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator()
                                    self.initiator.parent = self
                                    self._children_name_map["initiator"] = "initiator"
                                return self.initiator

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "initiator"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.l2_connected is not None and self.l2_connected.has_data()) or
                            (self.routed is not None and self.routed.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.l2_connected is not None and self.l2_connected.has_operation()) or
                            (self.routed is not None and self.routed.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv4" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2-connected"):
                            if (self.l2_connected is None):
                                self.l2_connected = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected()
                                self.l2_connected.parent = self
                                self._children_name_map["l2_connected"] = "l2-connected"
                            return self.l2_connected

                        if (child_yang_name == "routed"):
                            if (self.routed is None):
                                self.routed = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed()
                                self.routed.parent = self
                                self._children_name_map["routed"] = "routed"
                            return self.routed

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2-connected" or name == "routed"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SessionLimit(Entity):
                    """
                    IP subscriber session limit
                    
                    .. attribute:: total
                    
                    	Session limit for all sources
                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total>`
                    
                    .. attribute:: unclassified_source
                    
                    	Session limit for unclassified sources
                    	**type**\:   :py:class:`UnclassifiedSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource>`
                    
                    

                    """

                    _prefix = 'subscriber-ipsub-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit, self).__init__()

                        self.yang_name = "session-limit"
                        self.yang_parent_name = "ip-subscriber"

                        self.total = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._children_yang_names.add("total")

                        self.unclassified_source = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource()
                        self.unclassified_source.parent = self
                        self._children_name_map["unclassified_source"] = "unclassified-source"
                        self._children_yang_names.add("unclassified-source")


                    class Total(Entity):
                        """
                        Session limit for all sources
                        
                        .. attribute:: per_vlan
                        
                        	Configure per\-vlan session limit for all sources
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "session-limit"

                            self.per_vlan = YLeaf(YType.int32, "per-vlan")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("per_vlan") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total, self).__setattr__(name, value)

                        def has_data(self):
                            return self.per_vlan.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.per_vlan.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "total" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.per_vlan.is_set or self.per_vlan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.per_vlan.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "per-vlan"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "per-vlan"):
                                self.per_vlan = value
                                self.per_vlan.value_namespace = name_space
                                self.per_vlan.value_namespace_prefix = name_space_prefix


                    class UnclassifiedSource(Entity):
                        """
                        Session limit for unclassified sources
                        
                        .. attribute:: per_vlan
                        
                        	Configure per\-vlan session limit for unclassified sources
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource, self).__init__()

                            self.yang_name = "unclassified-source"
                            self.yang_parent_name = "session-limit"

                            self.per_vlan = YLeaf(YType.int32, "per-vlan")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("per_vlan") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource, self).__setattr__(name, value)

                        def has_data(self):
                            return self.per_vlan.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.per_vlan.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "unclassified-source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.per_vlan.is_set or self.per_vlan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.per_vlan.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "per-vlan"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "per-vlan"):
                                self.per_vlan = value
                                self.per_vlan.value_namespace = name_space
                                self.per_vlan.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.total is not None and self.total.has_data()) or
                            (self.unclassified_source is not None and self.unclassified_source.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.total is not None and self.total.has_operation()) or
                            (self.unclassified_source is not None and self.unclassified_source.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "session-limit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "total"):
                            if (self.total is None):
                                self.total = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total()
                                self.total.parent = self
                                self._children_name_map["total"] = "total"
                            return self.total

                        if (child_yang_name == "unclassified-source"):
                            if (self.unclassified_source is None):
                                self.unclassified_source = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource()
                                self.unclassified_source.parent = self
                                self._children_name_map["unclassified_source"] = "unclassified-source"
                            return self.unclassified_source

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "total" or name == "unclassified-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Ipv6(Entity):
                    """
                    IPv6 subscriber
                    
                    .. attribute:: l2_connected
                    
                    	L2 connected IPv6 subscriber
                    	**type**\:   :py:class:`L2Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected>`
                    
                    .. attribute:: routed
                    
                    	Routed IPv6 subscriber
                    	**type**\:   :py:class:`Routed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed>`
                    
                    

                    """

                    _prefix = 'subscriber-ipsub-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "ip-subscriber"

                        self.l2_connected = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected()
                        self.l2_connected.parent = self
                        self._children_name_map["l2_connected"] = "l2-connected"
                        self._children_yang_names.add("l2-connected")

                        self.routed = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed()
                        self.routed.parent = self
                        self._children_name_map["routed"] = "routed"
                        self._children_yang_names.add("routed")


                    class L2Connected(Entity):
                        """
                        L2 connected IPv6 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IPv6 subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected, self).__init__()

                            self.yang_name = "l2-connected"
                            self.yang_parent_name = "ipv6"

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")


                        class Initiator(Entity):
                            """
                            Configure IPv6 subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IPv6 subscriber DHCP initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unclassified_source_fsol
                            
                            	Configure IP subscriber unclassified source initiator
                            	**type**\:   :py:class:`UnclassifiedSourceFsol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "l2-connected"

                                self.dhcp = YLeaf(YType.empty, "dhcp")

                                self.unclassified_source_fsol = None
                                self._children_name_map["unclassified_source_fsol"] = "unclassified-source-fsol"
                                self._children_yang_names.add("unclassified-source-fsol")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dhcp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator, self).__setattr__(name, value)


                            class UnclassifiedSourceFsol(Entity):
                                """
                                Configure IP subscriber unclassified source
                                initiator
                                
                                .. attribute:: address_unique
                                
                                	Check for subscriber IP uniqueness during first sign of life
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: enable
                                
                                	Enable unclassified source
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                	**mandatory**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'subscriber-ipsub-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol, self).__init__()

                                    self.yang_name = "unclassified-source-fsol"
                                    self.yang_parent_name = "initiator"
                                    self.is_presence_container = True

                                    self.address_unique = YLeaf(YType.boolean, "address-unique")

                                    self.enable = YLeaf(YType.empty, "enable")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address_unique",
                                                    "enable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address_unique.is_set or
                                        self.enable.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address_unique.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unclassified-source-fsol" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address_unique.is_set or self.address_unique.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address_unique.get_name_leafdata())
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address-unique" or name == "enable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address-unique"):
                                        self.address_unique = value
                                        self.address_unique.value_namespace = name_space
                                        self.address_unique.value_namespace_prefix = name_space_prefix
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.dhcp.is_set or
                                    (self.unclassified_source_fsol is not None))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dhcp.yfilter != YFilter.not_set or
                                    (self.unclassified_source_fsol is not None and self.unclassified_source_fsol.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "initiator" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dhcp.is_set or self.dhcp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "unclassified-source-fsol"):
                                    if (self.unclassified_source_fsol is None):
                                        self.unclassified_source_fsol = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol()
                                        self.unclassified_source_fsol.parent = self
                                        self._children_name_map["unclassified_source_fsol"] = "unclassified-source-fsol"
                                    return self.unclassified_source_fsol

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "unclassified-source-fsol" or name == "dhcp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dhcp"):
                                    self.dhcp = value
                                    self.dhcp.value_namespace = name_space
                                    self.dhcp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.initiator is not None and self.initiator.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.initiator is not None and self.initiator.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2-connected" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "initiator"):
                                if (self.initiator is None):
                                    self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator()
                                    self.initiator.parent = self
                                    self._children_name_map["initiator"] = "initiator"
                                return self.initiator

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "initiator"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Routed(Entity):
                        """
                        Routed IPv6 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IP subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed, self).__init__()

                            self.yang_name = "routed"
                            self.yang_parent_name = "ipv6"

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")


                        class Initiator(Entity):
                            """
                            Configure IP subscriber initiator
                            
                            .. attribute:: unclassified_ip
                            
                            	Configure unclassified packets as first\-sign\-of\-life for IPv6 subscriber
                            	**type**\:  int
                            
                            	**range:** 1..128
                            
                            	**default value**\: 128
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "routed"

                                self.unclassified_ip = YLeaf(YType.uint32, "unclassified-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("unclassified_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator, self).__setattr__(name, value)

                            def has_data(self):
                                return self.unclassified_ip.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.unclassified_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "initiator" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.unclassified_ip.is_set or self.unclassified_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unclassified_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "unclassified-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "unclassified-ip"):
                                    self.unclassified_ip = value
                                    self.unclassified_ip.value_namespace = name_space
                                    self.unclassified_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.initiator is not None and self.initiator.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.initiator is not None and self.initiator.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "routed" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "initiator"):
                                if (self.initiator is None):
                                    self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator()
                                    self.initiator.parent = self
                                    self._children_name_map["initiator"] = "initiator"
                                return self.initiator

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "initiator"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.l2_connected is not None and self.l2_connected.has_data()) or
                            (self.routed is not None and self.routed.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.l2_connected is not None and self.l2_connected.has_operation()) or
                            (self.routed is not None and self.routed.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv6" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2-connected"):
                            if (self.l2_connected is None):
                                self.l2_connected = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected()
                                self.l2_connected.parent = self
                                self._children_name_map["l2_connected"] = "l2-connected"
                            return self.l2_connected

                        if (child_yang_name == "routed"):
                            if (self.routed is None):
                                self.routed = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed()
                                self.routed.parent = self
                                self._children_name_map["routed"] = "routed"
                            return self.routed

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2-connected" or name == "routed"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.interface.is_set or
                        self.subscriber_templates.is_set or
                        (self.ipv4 is not None and self.ipv4.has_data()) or
                        (self.ipv6 is not None and self.ipv6.has_data()) or
                        (self.session_limit is not None and self.session_limit.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface.yfilter != YFilter.not_set or
                        self.subscriber_templates.yfilter != YFilter.not_set or
                        (self.ipv4 is not None and self.ipv4.has_operation()) or
                        (self.ipv6 is not None and self.ipv6.has_operation()) or
                        (self.session_limit is not None and self.session_limit.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ip-subscriber" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface.get_name_leafdata())
                    if (self.subscriber_templates.is_set or self.subscriber_templates.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.subscriber_templates.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv4"):
                        if (self.ipv4 is None):
                            self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                        return self.ipv4

                    if (child_yang_name == "ipv6"):
                        if (self.ipv6 is None):
                            self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                        return self.ipv6

                    if (child_yang_name == "session-limit"):
                        if (self.session_limit is None):
                            self.session_limit = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit()
                            self.session_limit.parent = self
                            self._children_name_map["session_limit"] = "session-limit"
                        return self.session_limit

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv4" or name == "ipv6" or name == "session-limit" or name == "interface" or name == "subscriber-templates"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface"):
                        self.interface = value
                        self.interface.value_namespace = name_space
                        self.interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "subscriber-templates"):
                        self.subscriber_templates = value
                        self.subscriber_templates.value_namespace = name_space
                        self.subscriber_templates.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.ip_subscriber is not None and self.ip_subscriber.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.ip_subscriber is not None and self.ip_subscriber.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-subscriber-ipsub-cfg:subscriber" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ip-subscriber"):
                    if (self.ip_subscriber is None):
                        self.ip_subscriber = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber()
                        self.ip_subscriber.parent = self
                        self._children_name_map["ip_subscriber"] = "ip-subscriber"
                    return self.ip_subscriber

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ip-subscriber"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Pppoe(Entity):
            """
            Interface PPPoE configuration data
            
            .. attribute:: enable_bba_group
            
            	Use this BBA\-Group to enable PPPoE on this interface
            	**type**\:   :py:class:`EnableBbaGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'subscriber-pppoe-ma-cmd-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Pppoe, self).__init__()

                self.yang_name = "pppoe"
                self.yang_parent_name = "interface-configuration"

                self.enable_bba_group = None
                self._children_name_map["enable_bba_group"] = "enable-bba-group"
                self._children_yang_names.add("enable-bba-group")


            class EnableBbaGroup(Entity):
                """
                Use this BBA\-Group to enable PPPoE on this
                interface
                
                .. attribute:: bba_group_name
                
                	Name of the BBA\-Group
                	**type**\:  str
                
                .. attribute:: enable
                
                	Enable PPPoE on this interface
                	**type**\:  bool
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'subscriber-pppoe-ma-cmd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup, self).__init__()

                    self.yang_name = "enable-bba-group"
                    self.yang_parent_name = "pppoe"
                    self.is_presence_container = True

                    self.bba_group_name = YLeaf(YType.str, "bba-group-name")

                    self.enable = YLeaf(YType.boolean, "enable")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bba_group_name",
                                    "enable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bba_group_name.is_set or
                        self.enable.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bba_group_name.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "enable-bba-group" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bba_group_name.is_set or self.bba_group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bba_group_name.get_name_leafdata())
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bba-group-name" or name == "enable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bba-group-name"):
                        self.bba_group_name = value
                        self.bba_group_name.value_namespace = name_space
                        self.bba_group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.enable_bba_group is not None)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.enable_bba_group is not None and self.enable_bba_group.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-subscriber-pppoe-ma-cmd-cfg:pppoe" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "enable-bba-group"):
                    if (self.enable_bba_group is None):
                        self.enable_bba_group = InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup()
                        self.enable_bba_group.parent = self
                        self._children_name_map["enable_bba_group"] = "enable-bba-group"
                    return self.enable_bba_group

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "enable-bba-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class NetFlow(Entity):
            """
            Interface netflow configuration
            
            .. attribute:: data_link_frame_section
            
            	Configure datalinkframesection netflow
            	**type**\:   :py:class:`DataLinkFrameSection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection>`
            
            .. attribute:: ipv4
            
            	Configure IPv4 netflow
            	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4>`
            
            .. attribute:: ipv6
            
            	Configure IPv6 netflow
            	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6>`
            
            .. attribute:: mpls
            
            	Configure MPLS netflow
            	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls>`
            
            

            """

            _prefix = 'traffmon-netflow-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow, self).__init__()

                self.yang_name = "net-flow"
                self.yang_parent_name = "interface-configuration"

                self.data_link_frame_section = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection()
                self.data_link_frame_section.parent = self
                self._children_name_map["data_link_frame_section"] = "data-link-frame-section"
                self._children_yang_names.add("data-link-frame-section")

                self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4()
                self.ipv4.parent = self
                self._children_name_map["ipv4"] = "ipv4"
                self._children_yang_names.add("ipv4")

                self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"
                self._children_yang_names.add("ipv6")

                self.mpls = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"
                self._children_yang_names.add("mpls")


            class DataLinkFrameSection(Entity):
                """
                Configure datalinkframesection netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection, self).__init__()

                    self.yang_name = "data-link-frame-section"
                    self.yang_parent_name = "net-flow"

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "data-link-frame-section"

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ingress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "egress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.egress is not None and self.egress.has_data()) or
                            (self.ingress is not None and self.ingress.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.egress is not None and self.egress.has_operation()) or
                            (self.ingress is not None and self.ingress.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flow-monitor-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "egress"):
                            if (self.egress is None):
                                self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress()
                                self.egress.parent = self
                                self._children_name_map["egress"] = "egress"
                            return self.egress

                        if (child_yang_name == "ingress"):
                            if (self.ingress is None):
                                self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress()
                                self.ingress.parent = self
                                self._children_name_map["ingress"] = "ingress"
                            return self.ingress

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "egress" or name == "ingress"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.flow_monitor_map is not None and self.flow_monitor_map.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.flow_monitor_map is not None and self.flow_monitor_map.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "data-link-frame-section" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flow-monitor-map"):
                        if (self.flow_monitor_map is None):
                            self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap()
                            self.flow_monitor_map.parent = self
                            self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                        return self.flow_monitor_map

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-monitor-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Mpls(Entity):
                """
                Configure MPLS netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "net-flow"

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "mpls"

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ingress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "egress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.egress is not None and self.egress.has_data()) or
                            (self.ingress is not None and self.ingress.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.egress is not None and self.egress.has_operation()) or
                            (self.ingress is not None and self.ingress.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flow-monitor-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "egress"):
                            if (self.egress is None):
                                self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress()
                                self.egress.parent = self
                                self._children_name_map["egress"] = "egress"
                            return self.egress

                        if (child_yang_name == "ingress"):
                            if (self.ingress is None):
                                self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress()
                                self.ingress.parent = self
                                self._children_name_map["ingress"] = "ingress"
                            return self.ingress

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "egress" or name == "ingress"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.flow_monitor_map is not None and self.flow_monitor_map.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.flow_monitor_map is not None and self.flow_monitor_map.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mpls" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flow-monitor-map"):
                        if (self.flow_monitor_map is None):
                            self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap()
                            self.flow_monitor_map.parent = self
                            self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                        return self.flow_monitor_map

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-monitor-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Ipv6(Entity):
                """
                Configure IPv6 netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "net-flow"

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "ipv6"

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ingress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "egress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.egress is not None and self.egress.has_data()) or
                            (self.ingress is not None and self.ingress.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.egress is not None and self.egress.has_operation()) or
                            (self.ingress is not None and self.ingress.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flow-monitor-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "egress"):
                            if (self.egress is None):
                                self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress()
                                self.egress.parent = self
                                self._children_name_map["egress"] = "egress"
                            return self.egress

                        if (child_yang_name == "ingress"):
                            if (self.ingress is None):
                                self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress()
                                self.ingress.parent = self
                                self._children_name_map["ingress"] = "ingress"
                            return self.ingress

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "egress" or name == "ingress"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.flow_monitor_map is not None and self.flow_monitor_map.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.flow_monitor_map is not None and self.flow_monitor_map.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ipv6" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flow-monitor-map"):
                        if (self.flow_monitor_map is None):
                            self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap()
                            self.flow_monitor_map.parent = self
                            self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                        return self.flow_monitor_map

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-monitor-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Ipv4(Entity):
                """
                Configure IPv4 netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4, self).__init__()

                    self.yang_name = "ipv4"
                    self.yang_parent_name = "net-flow"

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "ipv4"

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ingress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"

                            self.flow_monitor_name = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress, self).__setattr__(name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("monitor_map_name",
                                                "sampler_map_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.monitor_map_name.is_set or
                                    self.sampler_map_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.monitor_map_name.yfilter != YFilter.not_set or
                                    self.sampler_map_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.monitor_map_name.is_set or self.monitor_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor_map_name.get_name_leafdata())
                                if (self.sampler_map_name.is_set or self.sampler_map_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sampler_map_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "monitor-map-name" or name == "sampler-map-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "monitor-map-name"):
                                    self.monitor_map_name = value
                                    self.monitor_map_name.value_namespace = name_space
                                    self.monitor_map_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "sampler-map-name"):
                                    self.sampler_map_name = value
                                    self.sampler_map_name.value_namespace = name_space
                                    self.sampler_map_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flow_monitor_name:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flow_monitor_name:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "egress" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flow-monitor-name"):
                                for c in self.flow_monitor_name:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flow_monitor_name.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-monitor-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.egress is not None and self.egress.has_data()) or
                            (self.ingress is not None and self.ingress.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.egress is not None and self.egress.has_operation()) or
                            (self.ingress is not None and self.ingress.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flow-monitor-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "egress"):
                            if (self.egress is None):
                                self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress()
                                self.egress.parent = self
                                self._children_name_map["egress"] = "egress"
                            return self.egress

                        if (child_yang_name == "ingress"):
                            if (self.ingress is None):
                                self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress()
                                self.ingress.parent = self
                                self._children_name_map["ingress"] = "ingress"
                            return self.ingress

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "egress" or name == "ingress"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.flow_monitor_map is not None and self.flow_monitor_map.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.flow_monitor_map is not None and self.flow_monitor_map.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ipv4" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flow-monitor-map"):
                        if (self.flow_monitor_map is None):
                            self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap()
                            self.flow_monitor_map.parent = self
                            self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                        return self.flow_monitor_map

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-monitor-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.data_link_frame_section is not None and self.data_link_frame_section.has_data()) or
                    (self.ipv4 is not None and self.ipv4.has_data()) or
                    (self.ipv6 is not None and self.ipv6.has_data()) or
                    (self.mpls is not None and self.mpls.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.data_link_frame_section is not None and self.data_link_frame_section.has_operation()) or
                    (self.ipv4 is not None and self.ipv4.has_operation()) or
                    (self.ipv6 is not None and self.ipv6.has_operation()) or
                    (self.mpls is not None and self.mpls.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-traffmon-netflow-cfg:net-flow" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "data-link-frame-section"):
                    if (self.data_link_frame_section is None):
                        self.data_link_frame_section = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection()
                        self.data_link_frame_section.parent = self
                        self._children_name_map["data_link_frame_section"] = "data-link-frame-section"
                    return self.data_link_frame_section

                if (child_yang_name == "ipv4"):
                    if (self.ipv4 is None):
                        self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                    return self.ipv4

                if (child_yang_name == "ipv6"):
                    if (self.ipv6 is None):
                        self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6()
                        self.ipv6.parent = self
                        self._children_name_map["ipv6"] = "ipv6"
                    return self.ipv6

                if (child_yang_name == "mpls"):
                    if (self.mpls is None):
                        self.mpls = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"
                    return self.mpls

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "data-link-frame-section" or name == "ipv4" or name == "ipv6" or name == "mpls"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class TunnelIp(Entity):
            """
            IP over GRE encapsulation
            
            .. attribute:: allow_key
            
            	Enable flag bit to allow packets with GRE key
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: destination
            
            	Configure destination of tunnel
            	**type**\:   :py:class:`Destination <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination>`
            
            .. attribute:: disable
            
            	Disable DF bit (i.e. allow fragmentation)
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: keepalive
            
            	Enable keepalive packets on this tunnel
            	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive>`
            
            .. attribute:: key
            
            	Configure the key value for packets sent over this tunnel
            	**type**\:   :py:class:`Key <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key>`
            
            .. attribute:: mode
            
            	Tunnel encapsulation method
            	**type**\:   :py:class:`Mode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode>`
            
            .. attribute:: source
            
            	Configure source of tunnel
            	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source>`
            
            .. attribute:: tos
            
            	Configure Type of Service bits for this tunnel
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: ttl
            
            	Configure the time\-to\-live for packets sent over this tunnel
            	**type**\:  int
            
            	**range:** 1..255
            
            .. attribute:: tunnel_vrf
            
            	Tunnel vrf label name
            	**type**\:  str
            
            	**length:** 1..32
            
            

            """

            _prefix = 'tunnel-gre-cfg'
            _revision = '2016-05-25'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp, self).__init__()

                self.yang_name = "tunnel-ip"
                self.yang_parent_name = "interface-configuration"

                self.allow_key = YLeaf(YType.empty, "allow-key")

                self.disable = YLeaf(YType.int32, "disable")

                self.tos = YLeaf(YType.uint32, "tos")

                self.ttl = YLeaf(YType.uint32, "ttl")

                self.tunnel_vrf = YLeaf(YType.str, "tunnel-vrf")

                self.destination = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"
                self._children_yang_names.add("destination")

                self.keepalive = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive()
                self.keepalive.parent = self
                self._children_name_map["keepalive"] = "keepalive"
                self._children_yang_names.add("keepalive")

                self.key = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key()
                self.key.parent = self
                self._children_name_map["key"] = "key"
                self._children_yang_names.add("key")

                self.mode = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode()
                self.mode.parent = self
                self._children_name_map["mode"] = "mode"
                self._children_yang_names.add("mode")

                self.source = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"
                self._children_yang_names.add("source")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("allow_key",
                                "disable",
                                "tos",
                                "ttl",
                                "tunnel_vrf") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp, self).__setattr__(name, value)


            class Mode(Entity):
                """
                Tunnel encapsulation method
                
                .. attribute:: decap
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value
                
                	GRE IPV4 \- 1, GRE IPV6 \- 2, MGRE IPV4 \- 3, MGRE IPV6 \-4. IPV4 \- 5, IPV6 \- 6
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2016-05-25'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode, self).__init__()

                    self.yang_name = "mode"
                    self.yang_parent_name = "tunnel-ip"

                    self.decap = YLeaf(YType.empty, "decap")

                    self.value = YLeaf(YType.int32, "value")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("decap",
                                    "value") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.decap.is_set or
                        self.value.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.decap.yfilter != YFilter.not_set or
                        self.value.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mode" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.decap.is_set or self.decap.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.decap.get_name_leafdata())
                    if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.value.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "decap" or name == "value"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "decap"):
                        self.decap = value
                        self.decap.value_namespace = name_space
                        self.decap.value_namespace_prefix = name_space_prefix
                    if(value_path == "value"):
                        self.value = value
                        self.value.value_namespace = name_space
                        self.value.value_namespace_prefix = name_space_prefix


            class Source(Entity):
                """
                Configure source of tunnel
                
                .. attribute:: address
                
                	IPV4 address of the tunnel source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: interface_name
                
                	Name of tunnel source interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ipv6_address
                
                	IPV6 address of the tunnel source
                	**type**\:  str
                
                .. attribute:: type
                
                	1 for Interface Name, 2 for IPv4 Address, 3 for IPv6 Address
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2016-05-25'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "tunnel-ip"

                    self.address = YLeaf(YType.str, "address")

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    self.type = YLeaf(YType.int32, "type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("address",
                                    "interface_name",
                                    "ipv6_address",
                                    "type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.address.is_set or
                        self.interface_name.is_set or
                        self.ipv6_address.is_set or
                        self.type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.address.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.ipv6_address.yfilter != YFilter.not_set or
                        self.type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "source" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.address.get_name_leafdata())
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())
                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "address" or name == "interface-name" or name == "ipv6-address" or name == "type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "address"):
                        self.address = value
                        self.address.value_namespace = name_space
                        self.address.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "ipv6-address"):
                        self.ipv6_address = value
                        self.ipv6_address.value_namespace = name_space
                        self.ipv6_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "type"):
                        self.type = value
                        self.type.value_namespace = name_space
                        self.type.value_namespace_prefix = name_space_prefix


            class Key(Entity):
                """
                Configure the key value for packets sent over
                this tunnel
                
                .. attribute:: entropy
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value
                
                	Enter the KEY value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2016-05-25'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key, self).__init__()

                    self.yang_name = "key"
                    self.yang_parent_name = "tunnel-ip"

                    self.entropy = YLeaf(YType.empty, "entropy")

                    self.value = YLeaf(YType.uint32, "value")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("entropy",
                                    "value") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.entropy.is_set or
                        self.value.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.entropy.yfilter != YFilter.not_set or
                        self.value.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "key" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.entropy.is_set or self.entropy.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.entropy.get_name_leafdata())
                    if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.value.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "entropy" or name == "value"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "entropy"):
                        self.entropy = value
                        self.entropy.value_namespace = name_space
                        self.entropy.value_namespace_prefix = name_space_prefix
                    if(value_path == "value"):
                        self.value = value
                        self.value.value_namespace = name_space
                        self.value.value_namespace_prefix = name_space_prefix


            class Keepalive(Entity):
                """
                Enable keepalive packets on this tunnel
                
                .. attribute:: keep_alive_period
                
                	Keepalive period in seconds (default 10 seconds)
                	**type**\:  int
                
                	**range:** 1..32767
                
                .. attribute:: keep_alive_retries
                
                	Number of retries (default 3)
                	**type**\:  int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2016-05-25'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive, self).__init__()

                    self.yang_name = "keepalive"
                    self.yang_parent_name = "tunnel-ip"

                    self.keep_alive_period = YLeaf(YType.uint32, "keep-alive-period")

                    self.keep_alive_retries = YLeaf(YType.uint32, "keep-alive-retries")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("keep_alive_period",
                                    "keep_alive_retries") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.keep_alive_period.is_set or
                        self.keep_alive_retries.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.keep_alive_period.yfilter != YFilter.not_set or
                        self.keep_alive_retries.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "keepalive" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.keep_alive_period.is_set or self.keep_alive_period.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.keep_alive_period.get_name_leafdata())
                    if (self.keep_alive_retries.is_set or self.keep_alive_retries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.keep_alive_retries.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "keep-alive-period" or name == "keep-alive-retries"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "keep-alive-period"):
                        self.keep_alive_period = value
                        self.keep_alive_period.value_namespace = name_space
                        self.keep_alive_period.value_namespace_prefix = name_space_prefix
                    if(value_path == "keep-alive-retries"):
                        self.keep_alive_retries = value
                        self.keep_alive_retries.value_namespace = name_space
                        self.keep_alive_retries.value_namespace_prefix = name_space_prefix


            class Destination(Entity):
                """
                Configure destination of tunnel
                
                .. attribute:: address
                
                	IPV4 address of the tunnel destination
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: address_mask
                
                	IPv4 prefix length of the tunnel destination
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv6_address
                
                	IPV6 address of the tunnel destination
                	**type**\:  str
                
                .. attribute:: prefix_list_name
                
                	Prefix\-list to validate destination's resolving prefix
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: type
                
                	1 for IPv4 Address, 2 for IPv6 Address
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2016-05-25'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "tunnel-ip"

                    self.address = YLeaf(YType.str, "address")

                    self.address_mask = YLeaf(YType.str, "address-mask")

                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                    self.type = YLeaf(YType.int32, "type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("address",
                                    "address_mask",
                                    "ipv6_address",
                                    "prefix_list_name",
                                    "type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.address.is_set or
                        self.address_mask.is_set or
                        self.ipv6_address.is_set or
                        self.prefix_list_name.is_set or
                        self.type.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.address.yfilter != YFilter.not_set or
                        self.address_mask.yfilter != YFilter.not_set or
                        self.ipv6_address.yfilter != YFilter.not_set or
                        self.prefix_list_name.yfilter != YFilter.not_set or
                        self.type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "destination" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.address.get_name_leafdata())
                    if (self.address_mask.is_set or self.address_mask.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.address_mask.get_name_leafdata())
                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())
                    if (self.prefix_list_name.is_set or self.prefix_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.prefix_list_name.get_name_leafdata())
                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "address" or name == "address-mask" or name == "ipv6-address" or name == "prefix-list-name" or name == "type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "address"):
                        self.address = value
                        self.address.value_namespace = name_space
                        self.address.value_namespace_prefix = name_space_prefix
                    if(value_path == "address-mask"):
                        self.address_mask = value
                        self.address_mask.value_namespace = name_space
                        self.address_mask.value_namespace_prefix = name_space_prefix
                    if(value_path == "ipv6-address"):
                        self.ipv6_address = value
                        self.ipv6_address.value_namespace = name_space
                        self.ipv6_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "prefix-list-name"):
                        self.prefix_list_name = value
                        self.prefix_list_name.value_namespace = name_space
                        self.prefix_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "type"):
                        self.type = value
                        self.type.value_namespace = name_space
                        self.type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.allow_key.is_set or
                    self.disable.is_set or
                    self.tos.is_set or
                    self.ttl.is_set or
                    self.tunnel_vrf.is_set or
                    (self.destination is not None and self.destination.has_data()) or
                    (self.keepalive is not None and self.keepalive.has_data()) or
                    (self.key is not None and self.key.has_data()) or
                    (self.mode is not None and self.mode.has_data()) or
                    (self.source is not None and self.source.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.allow_key.yfilter != YFilter.not_set or
                    self.disable.yfilter != YFilter.not_set or
                    self.tos.yfilter != YFilter.not_set or
                    self.ttl.yfilter != YFilter.not_set or
                    self.tunnel_vrf.yfilter != YFilter.not_set or
                    (self.destination is not None and self.destination.has_operation()) or
                    (self.keepalive is not None and self.keepalive.has_operation()) or
                    (self.key is not None and self.key.has_operation()) or
                    (self.mode is not None and self.mode.has_operation()) or
                    (self.source is not None and self.source.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-tunnel-gre-cfg:tunnel-ip" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.allow_key.is_set or self.allow_key.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.allow_key.get_name_leafdata())
                if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.disable.get_name_leafdata())
                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tos.get_name_leafdata())
                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ttl.get_name_leafdata())
                if (self.tunnel_vrf.is_set or self.tunnel_vrf.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tunnel_vrf.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "destination"):
                    if (self.destination is None):
                        self.destination = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination()
                        self.destination.parent = self
                        self._children_name_map["destination"] = "destination"
                    return self.destination

                if (child_yang_name == "keepalive"):
                    if (self.keepalive is None):
                        self.keepalive = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive()
                        self.keepalive.parent = self
                        self._children_name_map["keepalive"] = "keepalive"
                    return self.keepalive

                if (child_yang_name == "key"):
                    if (self.key is None):
                        self.key = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key()
                        self.key.parent = self
                        self._children_name_map["key"] = "key"
                    return self.key

                if (child_yang_name == "mode"):
                    if (self.mode is None):
                        self.mode = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode()
                        self.mode.parent = self
                        self._children_name_map["mode"] = "mode"
                    return self.mode

                if (child_yang_name == "source"):
                    if (self.source is None):
                        self.source = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                    return self.source

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "destination" or name == "keepalive" or name == "key" or name == "mode" or name == "source" or name == "allow-key" or name == "disable" or name == "tos" or name == "ttl" or name == "tunnel-vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "allow-key"):
                    self.allow_key = value
                    self.allow_key.value_namespace = name_space
                    self.allow_key.value_namespace_prefix = name_space_prefix
                if(value_path == "disable"):
                    self.disable = value
                    self.disable.value_namespace = name_space
                    self.disable.value_namespace_prefix = name_space_prefix
                if(value_path == "tos"):
                    self.tos = value
                    self.tos.value_namespace = name_space
                    self.tos.value_namespace_prefix = name_space_prefix
                if(value_path == "ttl"):
                    self.ttl = value
                    self.ttl.value_namespace = name_space
                    self.ttl.value_namespace_prefix = name_space_prefix
                if(value_path == "tunnel-vrf"):
                    self.tunnel_vrf = value
                    self.tunnel_vrf.value_namespace = name_space
                    self.tunnel_vrf.value_namespace_prefix = name_space_prefix


        class Nve(Entity):
            """
            NVE operational data
            
            .. attribute:: anycast
            
            	Enable anycast mode for this NVE interface
            	**type**\:   :py:class:`Anycast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast>`
            
            .. attribute:: member_vnis
            
            	VNI configuration Table for this NVE
            	**type**\:   :py:class:`MemberVnis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis>`
            
            .. attribute:: overlay_encapsulation
            
            	The Overlay Encapsulation for this NVE
            	**type**\:   :py:class:`OverlayEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.OverlayEncapEnum>`
            
            	**default value**\: vx-lan-encapsulation
            
            .. attribute:: redundancy
            
            	Redundancy configuration for this NVE
            	**type**\:   :py:class:`Redundancy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy>`
            
            .. attribute:: source_interface
            
            	Source Interface for this NVE
            	**type**\:  str
            
            .. attribute:: vx_lan_udp_port
            
            	UDP port number in VxLAN encapsulation
            	**type**\:   :py:class:`VxlanUdpPortEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.VxlanUdpPortEnum>`
            
            	**default value**\: ietf-udp-port
            
            

            """

            _prefix = 'tunnel-nve-cfg'
            _revision = '2016-08-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Nve, self).__init__()

                self.yang_name = "nve"
                self.yang_parent_name = "interface-configuration"

                self.overlay_encapsulation = YLeaf(YType.enumeration, "overlay-encapsulation")

                self.source_interface = YLeaf(YType.str, "source-interface")

                self.vx_lan_udp_port = YLeaf(YType.enumeration, "vx-lan-udp-port")

                self.anycast = InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast()
                self.anycast.parent = self
                self._children_name_map["anycast"] = "anycast"
                self._children_yang_names.add("anycast")

                self.member_vnis = InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis()
                self.member_vnis.parent = self
                self._children_name_map["member_vnis"] = "member-vnis"
                self._children_yang_names.add("member-vnis")

                self.redundancy = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._children_yang_names.add("redundancy")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("overlay_encapsulation",
                                "source_interface",
                                "vx_lan_udp_port") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Nve, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve, self).__setattr__(name, value)


            class Anycast(Entity):
                """
                Enable anycast mode for this NVE interface
                
                .. attribute:: source_interface
                
                	Name of the Anycast mode source interface
                	**type**\:  str
                
                .. attribute:: sync_group
                
                	MCast group for syncing between Anycast gateways
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'tunnel-nve-cfg'
                _revision = '2016-08-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast, self).__init__()

                    self.yang_name = "anycast"
                    self.yang_parent_name = "nve"

                    self.source_interface = YLeaf(YType.str, "source-interface")

                    self.sync_group = YLeaf(YType.str, "sync-group")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("source_interface",
                                    "sync_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.source_interface.is_set or
                        self.sync_group.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.source_interface.yfilter != YFilter.not_set or
                        self.sync_group.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "anycast" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.source_interface.is_set or self.source_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_interface.get_name_leafdata())
                    if (self.sync_group.is_set or self.sync_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "source-interface" or name == "sync-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "source-interface"):
                        self.source_interface = value
                        self.source_interface.value_namespace = name_space
                        self.source_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-group"):
                        self.sync_group = value
                        self.sync_group.value_namespace = name_space
                        self.sync_group.value_namespace_prefix = name_space_prefix


            class Redundancy(Entity):
                """
                Redundancy configuration for this NVE
                
                .. attribute:: backbone_mpls
                
                	MPLS backbone
                	**type**\:   :py:class:`BackboneMpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls>`
                
                .. attribute:: backbone_vx_lan
                
                	VXLAN backbone
                	**type**\:   :py:class:`BackboneVxLan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan>`
                
                .. attribute:: enable
                
                	Enable Redundancy
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'tunnel-nve-cfg'
                _revision = '2016-08-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "nve"

                    self.enable = YLeaf(YType.empty, "enable")

                    self.backbone_mpls = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls()
                    self.backbone_mpls.parent = self
                    self._children_name_map["backbone_mpls"] = "backbone-mpls"
                    self._children_yang_names.add("backbone-mpls")

                    self.backbone_vx_lan = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan()
                    self.backbone_vx_lan.parent = self
                    self._children_name_map["backbone_vx_lan"] = "backbone-vx-lan"
                    self._children_yang_names.add("backbone-vx-lan")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("enable") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy, self).__setattr__(name, value)


                class BackboneVxLan(Entity):
                    """
                    VXLAN backbone
                    
                    .. attribute:: backbone_vx_laniccp
                    
                    	VxLAN backbone ICCP group
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: enable
                    
                    	Enable Backbone VxLAN
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'tunnel-nve-cfg'
                    _revision = '2016-08-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan, self).__init__()

                        self.yang_name = "backbone-vx-lan"
                        self.yang_parent_name = "redundancy"

                        self.backbone_vx_laniccp = YLeaf(YType.int32, "backbone-vx-laniccp")

                        self.enable = YLeaf(YType.empty, "enable")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("backbone_vx_laniccp",
                                        "enable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.backbone_vx_laniccp.is_set or
                            self.enable.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.backbone_vx_laniccp.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "backbone-vx-lan" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.backbone_vx_laniccp.is_set or self.backbone_vx_laniccp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backbone_vx_laniccp.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "backbone-vx-laniccp" or name == "enable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "backbone-vx-laniccp"):
                            self.backbone_vx_laniccp = value
                            self.backbone_vx_laniccp.value_namespace = name_space
                            self.backbone_vx_laniccp.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix


                class BackboneMpls(Entity):
                    """
                    MPLS backbone
                    
                    .. attribute:: backbone_mplsiccp
                    
                    	MPLS backbone ICCP group
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: enable
                    
                    	Enable Backbone MPLS
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'tunnel-nve-cfg'
                    _revision = '2016-08-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls, self).__init__()

                        self.yang_name = "backbone-mpls"
                        self.yang_parent_name = "redundancy"

                        self.backbone_mplsiccp = YLeaf(YType.int32, "backbone-mplsiccp")

                        self.enable = YLeaf(YType.empty, "enable")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("backbone_mplsiccp",
                                        "enable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.backbone_mplsiccp.is_set or
                            self.enable.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.backbone_mplsiccp.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "backbone-mpls" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.backbone_mplsiccp.is_set or self.backbone_mplsiccp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backbone_mplsiccp.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "backbone-mplsiccp" or name == "enable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "backbone-mplsiccp"):
                            self.backbone_mplsiccp = value
                            self.backbone_mplsiccp.value_namespace = name_space
                            self.backbone_mplsiccp.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.enable.is_set or
                        (self.backbone_mpls is not None and self.backbone_mpls.has_data()) or
                        (self.backbone_vx_lan is not None and self.backbone_vx_lan.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.enable.yfilter != YFilter.not_set or
                        (self.backbone_mpls is not None and self.backbone_mpls.has_operation()) or
                        (self.backbone_vx_lan is not None and self.backbone_vx_lan.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "redundancy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enable.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "backbone-mpls"):
                        if (self.backbone_mpls is None):
                            self.backbone_mpls = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls()
                            self.backbone_mpls.parent = self
                            self._children_name_map["backbone_mpls"] = "backbone-mpls"
                        return self.backbone_mpls

                    if (child_yang_name == "backbone-vx-lan"):
                        if (self.backbone_vx_lan is None):
                            self.backbone_vx_lan = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan()
                            self.backbone_vx_lan.parent = self
                            self._children_name_map["backbone_vx_lan"] = "backbone-vx-lan"
                        return self.backbone_vx_lan

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "backbone-mpls" or name == "backbone-vx-lan" or name == "enable"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "enable"):
                        self.enable = value
                        self.enable.value_namespace = name_space
                        self.enable.value_namespace_prefix = name_space_prefix


            class MemberVnis(Entity):
                """
                VNI configuration Table for this NVE
                
                .. attribute:: member_vni
                
                	VNI member attributes
                	**type**\: list of    :py:class:`MemberVni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni>`
                
                

                """

                _prefix = 'tunnel-nve-cfg'
                _revision = '2016-08-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis, self).__init__()

                    self.yang_name = "member-vnis"
                    self.yang_parent_name = "nve"

                    self.member_vni = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis, self).__setattr__(name, value)


                class MemberVni(Entity):
                    """
                    VNI member attributes
                    
                    .. attribute:: vni_start  <key>
                    
                    	Single VNI or Range Start
                    	**type**\:  int
                    
                    	**range:** 1..16777215
                    
                    .. attribute:: vni_end  <key>
                    
                    	Range End
                    	**type**\:  int
                    
                    	**range:** 1..16777215
                    
                    .. attribute:: enable
                    
                    	Enable VNI
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: host_reachability
                    
                    	Control protocol for VxLAN tunnel endpoint reachability
                    	**type**\:   :py:class:`HostReachProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.HostReachProtocol>`
                    
                    .. attribute:: load_balance_per_evi
                    
                    	Per\-evi load balance mode
                    	**type**\:   :py:class:`LoadBalanceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.LoadBalanceEnum>`
                    
                    .. attribute:: multicast
                    
                    	Mulitcast core group range associated with the VxLAN segment(s)
                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unknown_unicast_flooding
                    
                    	Suppression of unknown unicast flooding
                    	**type**\:   :py:class:`UnknownUnicastFloodingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.UnknownUnicastFloodingEnum>`
                    
                    .. attribute:: vrf
                    
                    	VRF associated with the VxLAN segment
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'tunnel-nve-cfg'
                    _revision = '2016-08-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni, self).__init__()

                        self.yang_name = "member-vni"
                        self.yang_parent_name = "member-vnis"

                        self.vni_start = YLeaf(YType.uint32, "vni-start")

                        self.vni_end = YLeaf(YType.uint32, "vni-end")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.host_reachability = YLeaf(YType.enumeration, "host-reachability")

                        self.load_balance_per_evi = YLeaf(YType.enumeration, "load-balance-per-evi")

                        self.unknown_unicast_flooding = YLeaf(YType.enumeration, "unknown-unicast-flooding")

                        self.vrf = YLeaf(YType.str, "vrf")

                        self.multicast = None
                        self._children_name_map["multicast"] = "multicast"
                        self._children_yang_names.add("multicast")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vni_start",
                                        "vni_end",
                                        "enable",
                                        "host_reachability",
                                        "load_balance_per_evi",
                                        "unknown_unicast_flooding",
                                        "vrf") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni, self).__setattr__(name, value)


                    class Multicast(Entity):
                        """
                        Mulitcast core group range associated with
                        the VxLAN segment(s)
                        
                        .. attribute:: multicast_group_max
                        
                        	IPV4 group address MAX
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_min
                        
                        	IPV4 group address of the tunnel source
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'tunnel-nve-cfg'
                        _revision = '2016-08-30'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast, self).__init__()

                            self.yang_name = "multicast"
                            self.yang_parent_name = "member-vni"
                            self.is_presence_container = True

                            self.multicast_group_max = YLeaf(YType.str, "multicast-group-max")

                            self.multicast_group_min = YLeaf(YType.str, "multicast-group-min")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("multicast_group_max",
                                            "multicast_group_min") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.multicast_group_max.is_set or
                                self.multicast_group_min.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.multicast_group_max.yfilter != YFilter.not_set or
                                self.multicast_group_min.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.multicast_group_max.is_set or self.multicast_group_max.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_group_max.get_name_leafdata())
                            if (self.multicast_group_min.is_set or self.multicast_group_min.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_group_min.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "multicast-group-max" or name == "multicast-group-min"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "multicast-group-max"):
                                self.multicast_group_max = value
                                self.multicast_group_max.value_namespace = name_space
                                self.multicast_group_max.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-group-min"):
                                self.multicast_group_min = value
                                self.multicast_group_min.value_namespace = name_space
                                self.multicast_group_min.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.vni_start.is_set or
                            self.vni_end.is_set or
                            self.enable.is_set or
                            self.host_reachability.is_set or
                            self.load_balance_per_evi.is_set or
                            self.unknown_unicast_flooding.is_set or
                            self.vrf.is_set or
                            (self.multicast is not None))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vni_start.yfilter != YFilter.not_set or
                            self.vni_end.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.host_reachability.yfilter != YFilter.not_set or
                            self.load_balance_per_evi.yfilter != YFilter.not_set or
                            self.unknown_unicast_flooding.yfilter != YFilter.not_set or
                            self.vrf.yfilter != YFilter.not_set or
                            (self.multicast is not None and self.multicast.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "member-vni" + "[vni-start='" + self.vni_start.get() + "']" + "[vni-end='" + self.vni_end.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vni_start.is_set or self.vni_start.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_start.get_name_leafdata())
                        if (self.vni_end.is_set or self.vni_end.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_end.get_name_leafdata())
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.host_reachability.is_set or self.host_reachability.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_reachability.get_name_leafdata())
                        if (self.load_balance_per_evi.is_set or self.load_balance_per_evi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance_per_evi.get_name_leafdata())
                        if (self.unknown_unicast_flooding.is_set or self.unknown_unicast_flooding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unknown_unicast_flooding.get_name_leafdata())
                        if (self.vrf.is_set or self.vrf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "multicast"):
                            if (self.multicast is None):
                                self.multicast = InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                            return self.multicast

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "multicast" or name == "vni-start" or name == "vni-end" or name == "enable" or name == "host-reachability" or name == "load-balance-per-evi" or name == "unknown-unicast-flooding" or name == "vrf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vni-start"):
                            self.vni_start = value
                            self.vni_start.value_namespace = name_space
                            self.vni_start.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-end"):
                            self.vni_end = value
                            self.vni_end.value_namespace = name_space
                            self.vni_end.value_namespace_prefix = name_space_prefix
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-reachability"):
                            self.host_reachability = value
                            self.host_reachability.value_namespace = name_space
                            self.host_reachability.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance-per-evi"):
                            self.load_balance_per_evi = value
                            self.load_balance_per_evi.value_namespace = name_space
                            self.load_balance_per_evi.value_namespace_prefix = name_space_prefix
                        if(value_path == "unknown-unicast-flooding"):
                            self.unknown_unicast_flooding = value
                            self.unknown_unicast_flooding.value_namespace = name_space
                            self.unknown_unicast_flooding.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf"):
                            self.vrf = value
                            self.vrf.value_namespace = name_space
                            self.vrf.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.member_vni:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.member_vni:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "member-vnis" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "member-vni"):
                        for c in self.member_vni:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.member_vni.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "member-vni"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.overlay_encapsulation.is_set or
                    self.source_interface.is_set or
                    self.vx_lan_udp_port.is_set or
                    (self.anycast is not None and self.anycast.has_data()) or
                    (self.member_vnis is not None and self.member_vnis.has_data()) or
                    (self.redundancy is not None and self.redundancy.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.overlay_encapsulation.yfilter != YFilter.not_set or
                    self.source_interface.yfilter != YFilter.not_set or
                    self.vx_lan_udp_port.yfilter != YFilter.not_set or
                    (self.anycast is not None and self.anycast.has_operation()) or
                    (self.member_vnis is not None and self.member_vnis.has_operation()) or
                    (self.redundancy is not None and self.redundancy.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-tunnel-nve-cfg:nve" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.overlay_encapsulation.is_set or self.overlay_encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.overlay_encapsulation.get_name_leafdata())
                if (self.source_interface.is_set or self.source_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_interface.get_name_leafdata())
                if (self.vx_lan_udp_port.is_set or self.vx_lan_udp_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vx_lan_udp_port.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "anycast"):
                    if (self.anycast is None):
                        self.anycast = InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast()
                        self.anycast.parent = self
                        self._children_name_map["anycast"] = "anycast"
                    return self.anycast

                if (child_yang_name == "member-vnis"):
                    if (self.member_vnis is None):
                        self.member_vnis = InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis()
                        self.member_vnis.parent = self
                        self._children_name_map["member_vnis"] = "member-vnis"
                    return self.member_vnis

                if (child_yang_name == "redundancy"):
                    if (self.redundancy is None):
                        self.redundancy = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy()
                        self.redundancy.parent = self
                        self._children_name_map["redundancy"] = "redundancy"
                    return self.redundancy

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "anycast" or name == "member-vnis" or name == "redundancy" or name == "overlay-encapsulation" or name == "source-interface" or name == "vx-lan-udp-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "overlay-encapsulation"):
                    self.overlay_encapsulation = value
                    self.overlay_encapsulation.value_namespace = name_space
                    self.overlay_encapsulation.value_namespace_prefix = name_space_prefix
                if(value_path == "source-interface"):
                    self.source_interface = value
                    self.source_interface.value_namespace = name_space
                    self.source_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "vx-lan-udp-port"):
                    self.vx_lan_udp_port = value
                    self.vx_lan_udp_port.value_namespace = name_space
                    self.vx_lan_udp_port.value_namespace_prefix = name_space_prefix


        class Wanphy(Entity):
            """
            WANPHY port controller configuration
            
            .. attribute:: lan_mode
            
            	Configure LAN Mode
            	**type**\:   :py:class:`WanphyLanMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_wanphy_ui_cfg.WanphyLanMode>`
            
            .. attribute:: report_line_ais
            
            	Configure Line Alarm Indication Signal reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_lof
            
            	Configure Loss Of Frame reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_lop
            
            	Configure Loss Of Pointer reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_los
            
            	Configure Loss Of Signal reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_ais
            
            	Configure Path Alarm Indication Signal reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_fe_ais
            
            	Configure Path Far End Payload Label Mismatch reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_fe_plm
            
            	Configure Path Far End Payload Label Mismatch reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_lcd
            
            	Configure Path Loss Of Code\-Group Delineation reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_plm
            
            	Configure Path Payload Label Mismatch reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_rdi
            
            	Configure Path Remote Defect Indicator reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_rdi
            
            	Configure Remote Defect Indicator reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_sd_ber
            
            	Configure B2 BER in excess of SD threshold reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_sf_ber
            
            	Configure B2 BER in excess of SF threshold reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: threshold_sd_ber
            
            	Bit error rate is 10 to the minus n, where n is threshold value
            	**type**\:  int
            
            	**range:** 3..9
            
            	**default value**\: 6
            
            .. attribute:: threshold_sf_ber
            
            	Bit error rate is 10 to the minus n, where n is threshold value
            	**type**\:  int
            
            	**range:** 3..9
            
            	**default value**\: 3
            
            .. attribute:: wan_mode
            
            	Configure WAN Mode
            	**type**\:   :py:class:`WanphyWanMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_wanphy_ui_cfg.WanphyWanMode>`
            
            

            """

            _prefix = 'wanphy-ui-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Wanphy, self).__init__()

                self.yang_name = "wanphy"
                self.yang_parent_name = "interface-configuration"

                self.lan_mode = YLeaf(YType.enumeration, "lan-mode")

                self.report_line_ais = YLeaf(YType.empty, "report-line-ais")

                self.report_lof = YLeaf(YType.empty, "report-lof")

                self.report_lop = YLeaf(YType.empty, "report-lop")

                self.report_los = YLeaf(YType.empty, "report-los")

                self.report_path_ais = YLeaf(YType.empty, "report-path-ais")

                self.report_path_fe_ais = YLeaf(YType.empty, "report-path-fe-ais")

                self.report_path_fe_plm = YLeaf(YType.empty, "report-path-fe-plm")

                self.report_path_lcd = YLeaf(YType.empty, "report-path-lcd")

                self.report_path_plm = YLeaf(YType.empty, "report-path-plm")

                self.report_path_rdi = YLeaf(YType.empty, "report-path-rdi")

                self.report_rdi = YLeaf(YType.empty, "report-rdi")

                self.report_sd_ber = YLeaf(YType.empty, "report-sd-ber")

                self.report_sf_ber = YLeaf(YType.empty, "report-sf-ber")

                self.threshold_sd_ber = YLeaf(YType.uint32, "threshold-sd-ber")

                self.threshold_sf_ber = YLeaf(YType.uint32, "threshold-sf-ber")

                self.wan_mode = YLeaf(YType.enumeration, "wan-mode")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("lan_mode",
                                "report_line_ais",
                                "report_lof",
                                "report_lop",
                                "report_los",
                                "report_path_ais",
                                "report_path_fe_ais",
                                "report_path_fe_plm",
                                "report_path_lcd",
                                "report_path_plm",
                                "report_path_rdi",
                                "report_rdi",
                                "report_sd_ber",
                                "report_sf_ber",
                                "threshold_sd_ber",
                                "threshold_sf_ber",
                                "wan_mode") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(InterfaceConfigurations.InterfaceConfiguration.Wanphy, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(InterfaceConfigurations.InterfaceConfiguration.Wanphy, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.lan_mode.is_set or
                    self.report_line_ais.is_set or
                    self.report_lof.is_set or
                    self.report_lop.is_set or
                    self.report_los.is_set or
                    self.report_path_ais.is_set or
                    self.report_path_fe_ais.is_set or
                    self.report_path_fe_plm.is_set or
                    self.report_path_lcd.is_set or
                    self.report_path_plm.is_set or
                    self.report_path_rdi.is_set or
                    self.report_rdi.is_set or
                    self.report_sd_ber.is_set or
                    self.report_sf_ber.is_set or
                    self.threshold_sd_ber.is_set or
                    self.threshold_sf_ber.is_set or
                    self.wan_mode.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.lan_mode.yfilter != YFilter.not_set or
                    self.report_line_ais.yfilter != YFilter.not_set or
                    self.report_lof.yfilter != YFilter.not_set or
                    self.report_lop.yfilter != YFilter.not_set or
                    self.report_los.yfilter != YFilter.not_set or
                    self.report_path_ais.yfilter != YFilter.not_set or
                    self.report_path_fe_ais.yfilter != YFilter.not_set or
                    self.report_path_fe_plm.yfilter != YFilter.not_set or
                    self.report_path_lcd.yfilter != YFilter.not_set or
                    self.report_path_plm.yfilter != YFilter.not_set or
                    self.report_path_rdi.yfilter != YFilter.not_set or
                    self.report_rdi.yfilter != YFilter.not_set or
                    self.report_sd_ber.yfilter != YFilter.not_set or
                    self.report_sf_ber.yfilter != YFilter.not_set or
                    self.threshold_sd_ber.yfilter != YFilter.not_set or
                    self.threshold_sf_ber.yfilter != YFilter.not_set or
                    self.wan_mode.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "Cisco-IOS-XR-wanphy-ui-cfg:wanphy" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.lan_mode.is_set or self.lan_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lan_mode.get_name_leafdata())
                if (self.report_line_ais.is_set or self.report_line_ais.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_line_ais.get_name_leafdata())
                if (self.report_lof.is_set or self.report_lof.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_lof.get_name_leafdata())
                if (self.report_lop.is_set or self.report_lop.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_lop.get_name_leafdata())
                if (self.report_los.is_set or self.report_los.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_los.get_name_leafdata())
                if (self.report_path_ais.is_set or self.report_path_ais.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_path_ais.get_name_leafdata())
                if (self.report_path_fe_ais.is_set or self.report_path_fe_ais.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_path_fe_ais.get_name_leafdata())
                if (self.report_path_fe_plm.is_set or self.report_path_fe_plm.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_path_fe_plm.get_name_leafdata())
                if (self.report_path_lcd.is_set or self.report_path_lcd.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_path_lcd.get_name_leafdata())
                if (self.report_path_plm.is_set or self.report_path_plm.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_path_plm.get_name_leafdata())
                if (self.report_path_rdi.is_set or self.report_path_rdi.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_path_rdi.get_name_leafdata())
                if (self.report_rdi.is_set or self.report_rdi.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_rdi.get_name_leafdata())
                if (self.report_sd_ber.is_set or self.report_sd_ber.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_sd_ber.get_name_leafdata())
                if (self.report_sf_ber.is_set or self.report_sf_ber.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.report_sf_ber.get_name_leafdata())
                if (self.threshold_sd_ber.is_set or self.threshold_sd_ber.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.threshold_sd_ber.get_name_leafdata())
                if (self.threshold_sf_ber.is_set or self.threshold_sf_ber.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.threshold_sf_ber.get_name_leafdata())
                if (self.wan_mode.is_set or self.wan_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.wan_mode.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "lan-mode" or name == "report-line-ais" or name == "report-lof" or name == "report-lop" or name == "report-los" or name == "report-path-ais" or name == "report-path-fe-ais" or name == "report-path-fe-plm" or name == "report-path-lcd" or name == "report-path-plm" or name == "report-path-rdi" or name == "report-rdi" or name == "report-sd-ber" or name == "report-sf-ber" or name == "threshold-sd-ber" or name == "threshold-sf-ber" or name == "wan-mode"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "lan-mode"):
                    self.lan_mode = value
                    self.lan_mode.value_namespace = name_space
                    self.lan_mode.value_namespace_prefix = name_space_prefix
                if(value_path == "report-line-ais"):
                    self.report_line_ais = value
                    self.report_line_ais.value_namespace = name_space
                    self.report_line_ais.value_namespace_prefix = name_space_prefix
                if(value_path == "report-lof"):
                    self.report_lof = value
                    self.report_lof.value_namespace = name_space
                    self.report_lof.value_namespace_prefix = name_space_prefix
                if(value_path == "report-lop"):
                    self.report_lop = value
                    self.report_lop.value_namespace = name_space
                    self.report_lop.value_namespace_prefix = name_space_prefix
                if(value_path == "report-los"):
                    self.report_los = value
                    self.report_los.value_namespace = name_space
                    self.report_los.value_namespace_prefix = name_space_prefix
                if(value_path == "report-path-ais"):
                    self.report_path_ais = value
                    self.report_path_ais.value_namespace = name_space
                    self.report_path_ais.value_namespace_prefix = name_space_prefix
                if(value_path == "report-path-fe-ais"):
                    self.report_path_fe_ais = value
                    self.report_path_fe_ais.value_namespace = name_space
                    self.report_path_fe_ais.value_namespace_prefix = name_space_prefix
                if(value_path == "report-path-fe-plm"):
                    self.report_path_fe_plm = value
                    self.report_path_fe_plm.value_namespace = name_space
                    self.report_path_fe_plm.value_namespace_prefix = name_space_prefix
                if(value_path == "report-path-lcd"):
                    self.report_path_lcd = value
                    self.report_path_lcd.value_namespace = name_space
                    self.report_path_lcd.value_namespace_prefix = name_space_prefix
                if(value_path == "report-path-plm"):
                    self.report_path_plm = value
                    self.report_path_plm.value_namespace = name_space
                    self.report_path_plm.value_namespace_prefix = name_space_prefix
                if(value_path == "report-path-rdi"):
                    self.report_path_rdi = value
                    self.report_path_rdi.value_namespace = name_space
                    self.report_path_rdi.value_namespace_prefix = name_space_prefix
                if(value_path == "report-rdi"):
                    self.report_rdi = value
                    self.report_rdi.value_namespace = name_space
                    self.report_rdi.value_namespace_prefix = name_space_prefix
                if(value_path == "report-sd-ber"):
                    self.report_sd_ber = value
                    self.report_sd_ber.value_namespace = name_space
                    self.report_sd_ber.value_namespace_prefix = name_space_prefix
                if(value_path == "report-sf-ber"):
                    self.report_sf_ber = value
                    self.report_sf_ber.value_namespace = name_space
                    self.report_sf_ber.value_namespace_prefix = name_space_prefix
                if(value_path == "threshold-sd-ber"):
                    self.threshold_sd_ber = value
                    self.threshold_sd_ber.value_namespace = name_space
                    self.threshold_sd_ber.value_namespace_prefix = name_space_prefix
                if(value_path == "threshold-sf-ber"):
                    self.threshold_sf_ber = value
                    self.threshold_sf_ber.value_namespace = name_space
                    self.threshold_sf_ber.value_namespace_prefix = name_space_prefix
                if(value_path == "wan-mode"):
                    self.wan_mode = value
                    self.wan_mode.value_namespace = name_space
                    self.wan_mode.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                self.active.is_set or
                self.interface_name.is_set or
                self.bandwidth.is_set or
                self.description.is_set or
                self.interface_mode_non_physical.is_set or
                self.interface_virtual.is_set or
                self.laser_squelch.is_set or
                self.link_status.is_set or
                self.mac_addr.is_set or
                self.maintenance_embargo.is_set or
                self.perf_mon_disable.is_set or
                self.secondary_admin_state.is_set or
                self.shutdown.is_set or
                self.track_name.is_set or
                self.vrf.is_set or
                (self.aaa_table is not None and self.aaa_table.has_data()) or
                (self.afs is not None and self.afs.has_data()) or
                (self.atm is not None and self.atm.has_data()) or
                (self.bfd is not None and self.bfd.has_data()) or
                (self.bundle is not None and self.bundle.has_data()) or
                (self.bundle_member is not None and self.bundle_member.has_data()) or
                (self.bvi is not None and self.bvi.has_data()) or
                (self.carrier_delay is not None and self.carrier_delay.has_data()) or
                (self.cdp is not None and self.cdp.has_data()) or
                (self.cisco_ios_xr_ppp_ma_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_cfg_ppp.has_data()) or
                (self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp.has_data()) or
                (self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp.has_data()) or
                (self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp.has_data()) or
                (self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp.has_data()) or
                (self.client_port is not None and self.client_port.has_data()) or
                (self.dagrs is not None and self.dagrs.has_data()) or
                (self.dampening is not None and self.dampening.has_data()) or
                (self.dwdm is not None and self.dwdm.has_data()) or
                (self.encapsulation is not None and self.encapsulation.has_data()) or
                (self.es_packet_filter is not None and self.es_packet_filter.has_data()) or
                (self.ethernet is not None and self.ethernet.has_data()) or
                (self.ethernet_bng is not None and self.ethernet_bng.has_data()) or
                (self.ethernet_control is not None and self.ethernet_control.has_data()) or
                (self.ethernet_features is not None and self.ethernet_features.has_data()) or
                (self.ethernet_service is not None and self.ethernet_service.has_data()) or
                (self.ipv4_network is not None and self.ipv4_network.has_data()) or
                (self.ipv4_network_forwarding is not None and self.ipv4_network_forwarding.has_data()) or
                (self.ipv4_packet_filter is not None and self.ipv4_packet_filter.has_data()) or
                (self.ipv4arp is not None and self.ipv4arp.has_data()) or
                (self.ipv6_neighbor is not None and self.ipv6_neighbor.has_data()) or
                (self.ipv6_network is not None and self.ipv6_network.has_data()) or
                (self.ipv6_packet_filter is not None and self.ipv6_packet_filter.has_data()) or
                (self.l2_transport is not None and self.l2_transport.has_data()) or
                (self.lacp is not None and self.lacp.has_data()) or
                (self.mac_accounting is not None and self.mac_accounting.has_data()) or
                (self.macsec is not None and self.macsec.has_data()) or
                (self.mlacp is not None and self.mlacp.has_data()) or
                (self.mte_tunnel_attributes is not None and self.mte_tunnel_attributes.has_data()) or
                (self.mtus is not None and self.mtus.has_data()) or
                (self.net_flow is not None and self.net_flow.has_data()) or
                (self.nv_satellite_access is not None and self.nv_satellite_access.has_data()) or
                (self.nv_satellite_fabric_link is not None and self.nv_satellite_fabric_link.has_data()) or
                (self.nv_satellite_fabric_network is not None and self.nv_satellite_fabric_network.has_data()) or
                (self.nve is not None and self.nve.has_data()) or
                (self.optics is not None and self.optics.has_data()) or
                (self.otu is not None and self.otu.has_data()) or
                (self.pbr is not None and self.pbr.has_data()) or
                (self.performance_management is not None and self.performance_management.has_data()) or
                (self.portmode is not None and self.portmode.has_data()) or
                (self.pppoe is not None and self.pppoe.has_data()) or
                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                (self.qos is not None and self.qos.has_data()) or
                (self.service_policies is not None and self.service_policies.has_data()) or
                (self.span_monitor_sessions is not None and self.span_monitor_sessions.has_data()) or
                (self.ssrp_session is not None and self.ssrp_session.has_data()) or
                (self.statistics is not None and self.statistics.has_data()) or
                (self.subscriber is not None and self.subscriber.has_data()) or
                (self.transport_profile_tunnel is not None and self.transport_profile_tunnel.has_data()) or
                (self.tunnel_ip is not None and self.tunnel_ip.has_data()) or
                (self.tunnel_te_attributes is not None and self.tunnel_te_attributes.has_data()) or
                (self.vlan_sub_configuration is not None and self.vlan_sub_configuration.has_data()) or
                (self.vlan_trunk_configuration is not None and self.vlan_trunk_configuration.has_data()) or
                (self.wanphy is not None and self.wanphy.has_data()) or
                (self.lldp is not None))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.active.yfilter != YFilter.not_set or
                self.interface_name.yfilter != YFilter.not_set or
                self.bandwidth.yfilter != YFilter.not_set or
                self.description.yfilter != YFilter.not_set or
                self.interface_mode_non_physical.yfilter != YFilter.not_set or
                self.interface_virtual.yfilter != YFilter.not_set or
                self.laser_squelch.yfilter != YFilter.not_set or
                self.link_status.yfilter != YFilter.not_set or
                self.mac_addr.yfilter != YFilter.not_set or
                self.maintenance_embargo.yfilter != YFilter.not_set or
                self.perf_mon_disable.yfilter != YFilter.not_set or
                self.secondary_admin_state.yfilter != YFilter.not_set or
                self.shutdown.yfilter != YFilter.not_set or
                self.track_name.yfilter != YFilter.not_set or
                self.vrf.yfilter != YFilter.not_set or
                (self.aaa_table is not None and self.aaa_table.has_operation()) or
                (self.afs is not None and self.afs.has_operation()) or
                (self.atm is not None and self.atm.has_operation()) or
                (self.bfd is not None and self.bfd.has_operation()) or
                (self.bundle is not None and self.bundle.has_operation()) or
                (self.bundle_member is not None and self.bundle_member.has_operation()) or
                (self.bvi is not None and self.bvi.has_operation()) or
                (self.carrier_delay is not None and self.carrier_delay.has_operation()) or
                (self.cdp is not None and self.cdp.has_operation()) or
                (self.cisco_ios_xr_ppp_ma_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_cfg_ppp.has_operation()) or
                (self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp.has_operation()) or
                (self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp.has_operation()) or
                (self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp.has_operation()) or
                (self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp is not None and self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp.has_operation()) or
                (self.client_port is not None and self.client_port.has_operation()) or
                (self.dagrs is not None and self.dagrs.has_operation()) or
                (self.dampening is not None and self.dampening.has_operation()) or
                (self.dwdm is not None and self.dwdm.has_operation()) or
                (self.encapsulation is not None and self.encapsulation.has_operation()) or
                (self.es_packet_filter is not None and self.es_packet_filter.has_operation()) or
                (self.ethernet is not None and self.ethernet.has_operation()) or
                (self.ethernet_bng is not None and self.ethernet_bng.has_operation()) or
                (self.ethernet_control is not None and self.ethernet_control.has_operation()) or
                (self.ethernet_features is not None and self.ethernet_features.has_operation()) or
                (self.ethernet_service is not None and self.ethernet_service.has_operation()) or
                (self.ipv4_network is not None and self.ipv4_network.has_operation()) or
                (self.ipv4_network_forwarding is not None and self.ipv4_network_forwarding.has_operation()) or
                (self.ipv4_packet_filter is not None and self.ipv4_packet_filter.has_operation()) or
                (self.ipv4arp is not None and self.ipv4arp.has_operation()) or
                (self.ipv6_neighbor is not None and self.ipv6_neighbor.has_operation()) or
                (self.ipv6_network is not None and self.ipv6_network.has_operation()) or
                (self.ipv6_packet_filter is not None and self.ipv6_packet_filter.has_operation()) or
                (self.l2_transport is not None and self.l2_transport.has_operation()) or
                (self.lacp is not None and self.lacp.has_operation()) or
                (self.lldp is not None and self.lldp.has_operation()) or
                (self.mac_accounting is not None and self.mac_accounting.has_operation()) or
                (self.macsec is not None and self.macsec.has_operation()) or
                (self.mlacp is not None and self.mlacp.has_operation()) or
                (self.mte_tunnel_attributes is not None and self.mte_tunnel_attributes.has_operation()) or
                (self.mtus is not None and self.mtus.has_operation()) or
                (self.net_flow is not None and self.net_flow.has_operation()) or
                (self.nv_satellite_access is not None and self.nv_satellite_access.has_operation()) or
                (self.nv_satellite_fabric_link is not None and self.nv_satellite_fabric_link.has_operation()) or
                (self.nv_satellite_fabric_network is not None and self.nv_satellite_fabric_network.has_operation()) or
                (self.nve is not None and self.nve.has_operation()) or
                (self.optics is not None and self.optics.has_operation()) or
                (self.otu is not None and self.otu.has_operation()) or
                (self.pbr is not None and self.pbr.has_operation()) or
                (self.performance_management is not None and self.performance_management.has_operation()) or
                (self.portmode is not None and self.portmode.has_operation()) or
                (self.pppoe is not None and self.pppoe.has_operation()) or
                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                (self.qos is not None and self.qos.has_operation()) or
                (self.service_policies is not None and self.service_policies.has_operation()) or
                (self.span_monitor_sessions is not None and self.span_monitor_sessions.has_operation()) or
                (self.ssrp_session is not None and self.ssrp_session.has_operation()) or
                (self.statistics is not None and self.statistics.has_operation()) or
                (self.subscriber is not None and self.subscriber.has_operation()) or
                (self.transport_profile_tunnel is not None and self.transport_profile_tunnel.has_operation()) or
                (self.tunnel_ip is not None and self.tunnel_ip.has_operation()) or
                (self.tunnel_te_attributes is not None and self.tunnel_te_attributes.has_operation()) or
                (self.vlan_sub_configuration is not None and self.vlan_sub_configuration.has_operation()) or
                (self.vlan_trunk_configuration is not None and self.vlan_trunk_configuration.has_operation()) or
                (self.wanphy is not None and self.wanphy.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-configuration" + "[active='" + self.active.get() + "']" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ifmgr-cfg:interface-configurations/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                leaf_name_data.append(self.active.get_name_leafdata())
            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                leaf_name_data.append(self.interface_name.get_name_leafdata())
            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bandwidth.get_name_leafdata())
            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                leaf_name_data.append(self.description.get_name_leafdata())
            if (self.interface_mode_non_physical.is_set or self.interface_mode_non_physical.yfilter != YFilter.not_set):
                leaf_name_data.append(self.interface_mode_non_physical.get_name_leafdata())
            if (self.interface_virtual.is_set or self.interface_virtual.yfilter != YFilter.not_set):
                leaf_name_data.append(self.interface_virtual.get_name_leafdata())
            if (self.laser_squelch.is_set or self.laser_squelch.yfilter != YFilter.not_set):
                leaf_name_data.append(self.laser_squelch.get_name_leafdata())
            if (self.link_status.is_set or self.link_status.yfilter != YFilter.not_set):
                leaf_name_data.append(self.link_status.get_name_leafdata())
            if (self.mac_addr.is_set or self.mac_addr.yfilter != YFilter.not_set):
                leaf_name_data.append(self.mac_addr.get_name_leafdata())
            if (self.maintenance_embargo.is_set or self.maintenance_embargo.yfilter != YFilter.not_set):
                leaf_name_data.append(self.maintenance_embargo.get_name_leafdata())
            if (self.perf_mon_disable.is_set or self.perf_mon_disable.yfilter != YFilter.not_set):
                leaf_name_data.append(self.perf_mon_disable.get_name_leafdata())
            if (self.secondary_admin_state.is_set or self.secondary_admin_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.secondary_admin_state.get_name_leafdata())
            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                leaf_name_data.append(self.shutdown.get_name_leafdata())
            if (self.track_name.is_set or self.track_name.yfilter != YFilter.not_set):
                leaf_name_data.append(self.track_name.get_name_leafdata())
            if (self.vrf.is_set or self.vrf.yfilter != YFilter.not_set):
                leaf_name_data.append(self.vrf.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "aaa-table"):
                if (self.aaa_table is None):
                    self.aaa_table = InterfaceConfigurations.InterfaceConfiguration.AaaTable()
                    self.aaa_table.parent = self
                    self._children_name_map["aaa_table"] = "aaa-table"
                return self.aaa_table

            if (child_yang_name == "afs"):
                if (self.afs is None):
                    self.afs = InterfaceConfigurations.InterfaceConfiguration.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"
                return self.afs

            if (child_yang_name == "atm"):
                if (self.atm is None):
                    self.atm = InterfaceConfigurations.InterfaceConfiguration.Atm()
                    self.atm.parent = self
                    self._children_name_map["atm"] = "atm"
                return self.atm

            if (child_yang_name == "bfd"):
                if (self.bfd is None):
                    self.bfd = InterfaceConfigurations.InterfaceConfiguration.Bfd()
                    self.bfd.parent = self
                    self._children_name_map["bfd"] = "bfd"
                return self.bfd

            if (child_yang_name == "bundle"):
                if (self.bundle is None):
                    self.bundle = InterfaceConfigurations.InterfaceConfiguration.Bundle()
                    self.bundle.parent = self
                    self._children_name_map["bundle"] = "bundle"
                return self.bundle

            if (child_yang_name == "bundle-member"):
                if (self.bundle_member is None):
                    self.bundle_member = InterfaceConfigurations.InterfaceConfiguration.BundleMember()
                    self.bundle_member.parent = self
                    self._children_name_map["bundle_member"] = "bundle-member"
                return self.bundle_member

            if (child_yang_name == "bvi"):
                if (self.bvi is None):
                    self.bvi = InterfaceConfigurations.InterfaceConfiguration.Bvi()
                    self.bvi.parent = self
                    self._children_name_map["bvi"] = "bvi"
                return self.bvi

            if (child_yang_name == "carrier-delay"):
                if (self.carrier_delay is None):
                    self.carrier_delay = InterfaceConfigurations.InterfaceConfiguration.CarrierDelay()
                    self.carrier_delay.parent = self
                    self._children_name_map["carrier_delay"] = "carrier-delay"
                return self.carrier_delay

            if (child_yang_name == "cdp"):
                if (self.cdp is None):
                    self.cdp = InterfaceConfigurations.InterfaceConfiguration.Cdp()
                    self.cdp.parent = self
                    self._children_name_map["cdp"] = "cdp"
                return self.cdp

            if (child_yang_name == "Cisco-IOS-XR-ppp-ma-cfg_ppp"):
                if (self.cisco_ios_xr_ppp_ma_cfg_ppp is None):
                    self.cisco_ios_xr_ppp_ma_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaCfg_Ppp()
                    self.cisco_ios_xr_ppp_ma_cfg_ppp.parent = self
                    self._children_name_map["cisco_ios_xr_ppp_ma_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-cfg_ppp"
                return self.cisco_ios_xr_ppp_ma_cfg_ppp

            if (child_yang_name == "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"):
                if (self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp is None):
                    self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaFsmCfg_Ppp()
                    self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp.parent = self
                    self._children_name_map["cisco_ios_xr_ppp_ma_fsm_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"
                return self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp

            if (child_yang_name == "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"):
                if (self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp is None):
                    self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpCfg_Ppp()
                    self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp.parent = self
                    self._children_name_map["cisco_ios_xr_ppp_ma_ipcp_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"
                return self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp

            if (child_yang_name == "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"):
                if (self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp is None):
                    self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaIpcpiwCfg_Ppp()
                    self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp.parent = self
                    self._children_name_map["cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"
                return self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp

            if (child_yang_name == "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"):
                if (self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp is None):
                    self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIosXrPppMaLcpCfg_Ppp()
                    self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp.parent = self
                    self._children_name_map["cisco_ios_xr_ppp_ma_lcp_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
                return self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp

            if (child_yang_name == "client-port"):
                if (self.client_port is None):
                    self.client_port = InterfaceConfigurations.InterfaceConfiguration.ClientPort()
                    self.client_port.parent = self
                    self._children_name_map["client_port"] = "client-port"
                return self.client_port

            if (child_yang_name == "dagrs"):
                if (self.dagrs is None):
                    self.dagrs = InterfaceConfigurations.InterfaceConfiguration.Dagrs()
                    self.dagrs.parent = self
                    self._children_name_map["dagrs"] = "dagrs"
                return self.dagrs

            if (child_yang_name == "dampening"):
                if (self.dampening is None):
                    self.dampening = InterfaceConfigurations.InterfaceConfiguration.Dampening()
                    self.dampening.parent = self
                    self._children_name_map["dampening"] = "dampening"
                return self.dampening

            if (child_yang_name == "dwdm"):
                if (self.dwdm is None):
                    self.dwdm = InterfaceConfigurations.InterfaceConfiguration.Dwdm()
                    self.dwdm.parent = self
                    self._children_name_map["dwdm"] = "dwdm"
                return self.dwdm

            if (child_yang_name == "encapsulation"):
                if (self.encapsulation is None):
                    self.encapsulation = InterfaceConfigurations.InterfaceConfiguration.Encapsulation()
                    self.encapsulation.parent = self
                    self._children_name_map["encapsulation"] = "encapsulation"
                return self.encapsulation

            if (child_yang_name == "es-packet-filter"):
                if (self.es_packet_filter is None):
                    self.es_packet_filter = InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter()
                    self.es_packet_filter.parent = self
                    self._children_name_map["es_packet_filter"] = "es-packet-filter"
                return self.es_packet_filter

            if (child_yang_name == "ethernet"):
                if (self.ethernet is None):
                    self.ethernet = InterfaceConfigurations.InterfaceConfiguration.Ethernet()
                    self.ethernet.parent = self
                    self._children_name_map["ethernet"] = "ethernet"
                return self.ethernet

            if (child_yang_name == "ethernet-bng"):
                if (self.ethernet_bng is None):
                    self.ethernet_bng = InterfaceConfigurations.InterfaceConfiguration.EthernetBng()
                    self.ethernet_bng.parent = self
                    self._children_name_map["ethernet_bng"] = "ethernet-bng"
                return self.ethernet_bng

            if (child_yang_name == "ethernet-control"):
                if (self.ethernet_control is None):
                    self.ethernet_control = InterfaceConfigurations.InterfaceConfiguration.EthernetControl()
                    self.ethernet_control.parent = self
                    self._children_name_map["ethernet_control"] = "ethernet-control"
                return self.ethernet_control

            if (child_yang_name == "ethernet-features"):
                if (self.ethernet_features is None):
                    self.ethernet_features = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures()
                    self.ethernet_features.parent = self
                    self._children_name_map["ethernet_features"] = "ethernet-features"
                return self.ethernet_features

            if (child_yang_name == "ethernet-service"):
                if (self.ethernet_service is None):
                    self.ethernet_service = InterfaceConfigurations.InterfaceConfiguration.EthernetService()
                    self.ethernet_service.parent = self
                    self._children_name_map["ethernet_service"] = "ethernet-service"
                return self.ethernet_service

            if (child_yang_name == "ipv4-network"):
                if (self.ipv4_network is None):
                    self.ipv4_network = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network()
                    self.ipv4_network.parent = self
                    self._children_name_map["ipv4_network"] = "ipv4-network"
                return self.ipv4_network

            if (child_yang_name == "ipv4-network-forwarding"):
                if (self.ipv4_network_forwarding is None):
                    self.ipv4_network_forwarding = InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding()
                    self.ipv4_network_forwarding.parent = self
                    self._children_name_map["ipv4_network_forwarding"] = "ipv4-network-forwarding"
                return self.ipv4_network_forwarding

            if (child_yang_name == "ipv4-packet-filter"):
                if (self.ipv4_packet_filter is None):
                    self.ipv4_packet_filter = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter()
                    self.ipv4_packet_filter.parent = self
                    self._children_name_map["ipv4_packet_filter"] = "ipv4-packet-filter"
                return self.ipv4_packet_filter

            if (child_yang_name == "ipv4arp"):
                if (self.ipv4arp is None):
                    self.ipv4arp = InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp()
                    self.ipv4arp.parent = self
                    self._children_name_map["ipv4arp"] = "ipv4arp"
                return self.ipv4arp

            if (child_yang_name == "ipv6-neighbor"):
                if (self.ipv6_neighbor is None):
                    self.ipv6_neighbor = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor()
                    self.ipv6_neighbor.parent = self
                    self._children_name_map["ipv6_neighbor"] = "ipv6-neighbor"
                return self.ipv6_neighbor

            if (child_yang_name == "ipv6-network"):
                if (self.ipv6_network is None):
                    self.ipv6_network = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network()
                    self.ipv6_network.parent = self
                    self._children_name_map["ipv6_network"] = "ipv6-network"
                return self.ipv6_network

            if (child_yang_name == "ipv6-packet-filter"):
                if (self.ipv6_packet_filter is None):
                    self.ipv6_packet_filter = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter()
                    self.ipv6_packet_filter.parent = self
                    self._children_name_map["ipv6_packet_filter"] = "ipv6-packet-filter"
                return self.ipv6_packet_filter

            if (child_yang_name == "l2-transport"):
                if (self.l2_transport is None):
                    self.l2_transport = InterfaceConfigurations.InterfaceConfiguration.L2Transport()
                    self.l2_transport.parent = self
                    self._children_name_map["l2_transport"] = "l2-transport"
                return self.l2_transport

            if (child_yang_name == "lacp"):
                if (self.lacp is None):
                    self.lacp = InterfaceConfigurations.InterfaceConfiguration.Lacp()
                    self.lacp.parent = self
                    self._children_name_map["lacp"] = "lacp"
                return self.lacp

            if (child_yang_name == "lldp"):
                if (self.lldp is None):
                    self.lldp = InterfaceConfigurations.InterfaceConfiguration.Lldp()
                    self.lldp.parent = self
                    self._children_name_map["lldp"] = "lldp"
                return self.lldp

            if (child_yang_name == "mac-accounting"):
                if (self.mac_accounting is None):
                    self.mac_accounting = InterfaceConfigurations.InterfaceConfiguration.MacAccounting()
                    self.mac_accounting.parent = self
                    self._children_name_map["mac_accounting"] = "mac-accounting"
                return self.mac_accounting

            if (child_yang_name == "macsec"):
                if (self.macsec is None):
                    self.macsec = InterfaceConfigurations.InterfaceConfiguration.Macsec()
                    self.macsec.parent = self
                    self._children_name_map["macsec"] = "macsec"
                return self.macsec

            if (child_yang_name == "mlacp"):
                if (self.mlacp is None):
                    self.mlacp = InterfaceConfigurations.InterfaceConfiguration.Mlacp()
                    self.mlacp.parent = self
                    self._children_name_map["mlacp"] = "mlacp"
                return self.mlacp

            if (child_yang_name == "mte-tunnel-attributes"):
                if (self.mte_tunnel_attributes is None):
                    self.mte_tunnel_attributes = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes()
                    self.mte_tunnel_attributes.parent = self
                    self._children_name_map["mte_tunnel_attributes"] = "mte-tunnel-attributes"
                return self.mte_tunnel_attributes

            if (child_yang_name == "mtus"):
                if (self.mtus is None):
                    self.mtus = InterfaceConfigurations.InterfaceConfiguration.Mtus()
                    self.mtus.parent = self
                    self._children_name_map["mtus"] = "mtus"
                return self.mtus

            if (child_yang_name == "net-flow"):
                if (self.net_flow is None):
                    self.net_flow = InterfaceConfigurations.InterfaceConfiguration.NetFlow()
                    self.net_flow.parent = self
                    self._children_name_map["net_flow"] = "net-flow"
                return self.net_flow

            if (child_yang_name == "nv-satellite-access"):
                if (self.nv_satellite_access is None):
                    self.nv_satellite_access = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess()
                    self.nv_satellite_access.parent = self
                    self._children_name_map["nv_satellite_access"] = "nv-satellite-access"
                return self.nv_satellite_access

            if (child_yang_name == "nv-satellite-fabric-link"):
                if (self.nv_satellite_fabric_link is None):
                    self.nv_satellite_fabric_link = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink()
                    self.nv_satellite_fabric_link.parent = self
                    self._children_name_map["nv_satellite_fabric_link"] = "nv-satellite-fabric-link"
                return self.nv_satellite_fabric_link

            if (child_yang_name == "nv-satellite-fabric-network"):
                if (self.nv_satellite_fabric_network is None):
                    self.nv_satellite_fabric_network = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork()
                    self.nv_satellite_fabric_network.parent = self
                    self._children_name_map["nv_satellite_fabric_network"] = "nv-satellite-fabric-network"
                return self.nv_satellite_fabric_network

            if (child_yang_name == "nve"):
                if (self.nve is None):
                    self.nve = InterfaceConfigurations.InterfaceConfiguration.Nve()
                    self.nve.parent = self
                    self._children_name_map["nve"] = "nve"
                return self.nve

            if (child_yang_name == "optics"):
                if (self.optics is None):
                    self.optics = InterfaceConfigurations.InterfaceConfiguration.Optics()
                    self.optics.parent = self
                    self._children_name_map["optics"] = "optics"
                return self.optics

            if (child_yang_name == "otu"):
                if (self.otu is None):
                    self.otu = InterfaceConfigurations.InterfaceConfiguration.Otu()
                    self.otu.parent = self
                    self._children_name_map["otu"] = "otu"
                return self.otu

            if (child_yang_name == "pbr"):
                if (self.pbr is None):
                    self.pbr = InterfaceConfigurations.InterfaceConfiguration.Pbr()
                    self.pbr.parent = self
                    self._children_name_map["pbr"] = "pbr"
                return self.pbr

            if (child_yang_name == "performance-management"):
                if (self.performance_management is None):
                    self.performance_management = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement()
                    self.performance_management.parent = self
                    self._children_name_map["performance_management"] = "performance-management"
                return self.performance_management

            if (child_yang_name == "portmode"):
                if (self.portmode is None):
                    self.portmode = InterfaceConfigurations.InterfaceConfiguration.Portmode()
                    self.portmode.parent = self
                    self._children_name_map["portmode"] = "portmode"
                return self.portmode

            if (child_yang_name == "pppoe"):
                if (self.pppoe is None):
                    self.pppoe = InterfaceConfigurations.InterfaceConfiguration.Pppoe()
                    self.pppoe.parent = self
                    self._children_name_map["pppoe"] = "pppoe"
                return self.pppoe

            if (child_yang_name == "pseudowire-ether"):
                if (self.pseudowire_ether is None):
                    self.pseudowire_ether = InterfaceConfigurations.InterfaceConfiguration.PseudowireEther()
                    self.pseudowire_ether.parent = self
                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                return self.pseudowire_ether

            if (child_yang_name == "pseudowire-iw"):
                if (self.pseudowire_iw is None):
                    self.pseudowire_iw = InterfaceConfigurations.InterfaceConfiguration.PseudowireIw()
                    self.pseudowire_iw.parent = self
                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                return self.pseudowire_iw

            if (child_yang_name == "qos"):
                if (self.qos is None):
                    self.qos = InterfaceConfigurations.InterfaceConfiguration.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                return self.qos

            if (child_yang_name == "service-policies"):
                if (self.service_policies is None):
                    self.service_policies = InterfaceConfigurations.InterfaceConfiguration.ServicePolicies()
                    self.service_policies.parent = self
                    self._children_name_map["service_policies"] = "service-policies"
                return self.service_policies

            if (child_yang_name == "span-monitor-sessions"):
                if (self.span_monitor_sessions is None):
                    self.span_monitor_sessions = InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions()
                    self.span_monitor_sessions.parent = self
                    self._children_name_map["span_monitor_sessions"] = "span-monitor-sessions"
                return self.span_monitor_sessions

            if (child_yang_name == "ssrp-session"):
                if (self.ssrp_session is None):
                    self.ssrp_session = InterfaceConfigurations.InterfaceConfiguration.SsrpSession()
                    self.ssrp_session.parent = self
                    self._children_name_map["ssrp_session"] = "ssrp-session"
                return self.ssrp_session

            if (child_yang_name == "statistics"):
                if (self.statistics is None):
                    self.statistics = InterfaceConfigurations.InterfaceConfiguration.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                return self.statistics

            if (child_yang_name == "subscriber"):
                if (self.subscriber is None):
                    self.subscriber = InterfaceConfigurations.InterfaceConfiguration.Subscriber()
                    self.subscriber.parent = self
                    self._children_name_map["subscriber"] = "subscriber"
                return self.subscriber

            if (child_yang_name == "transport-profile-tunnel"):
                if (self.transport_profile_tunnel is None):
                    self.transport_profile_tunnel = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel()
                    self.transport_profile_tunnel.parent = self
                    self._children_name_map["transport_profile_tunnel"] = "transport-profile-tunnel"
                return self.transport_profile_tunnel

            if (child_yang_name == "tunnel-ip"):
                if (self.tunnel_ip is None):
                    self.tunnel_ip = InterfaceConfigurations.InterfaceConfiguration.TunnelIp()
                    self.tunnel_ip.parent = self
                    self._children_name_map["tunnel_ip"] = "tunnel-ip"
                return self.tunnel_ip

            if (child_yang_name == "tunnel-te-attributes"):
                if (self.tunnel_te_attributes is None):
                    self.tunnel_te_attributes = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes()
                    self.tunnel_te_attributes.parent = self
                    self._children_name_map["tunnel_te_attributes"] = "tunnel-te-attributes"
                return self.tunnel_te_attributes

            if (child_yang_name == "vlan-sub-configuration"):
                if (self.vlan_sub_configuration is None):
                    self.vlan_sub_configuration = InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration()
                    self.vlan_sub_configuration.parent = self
                    self._children_name_map["vlan_sub_configuration"] = "vlan-sub-configuration"
                return self.vlan_sub_configuration

            if (child_yang_name == "vlan-trunk-configuration"):
                if (self.vlan_trunk_configuration is None):
                    self.vlan_trunk_configuration = InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration()
                    self.vlan_trunk_configuration.parent = self
                    self._children_name_map["vlan_trunk_configuration"] = "vlan-trunk-configuration"
                return self.vlan_trunk_configuration

            if (child_yang_name == "wanphy"):
                if (self.wanphy is None):
                    self.wanphy = InterfaceConfigurations.InterfaceConfiguration.Wanphy()
                    self.wanphy.parent = self
                    self._children_name_map["wanphy"] = "wanphy"
                return self.wanphy

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "aaa-table" or name == "afs" or name == "atm" or name == "bfd" or name == "bundle" or name == "bundle-member" or name == "bvi" or name == "carrier-delay" or name == "cdp" or name == "Cisco-IOS-XR-ppp-ma-cfg_ppp" or name == "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp" or name == "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp" or name == "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp" or name == "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp" or name == "client-port" or name == "dagrs" or name == "dampening" or name == "dwdm" or name == "encapsulation" or name == "es-packet-filter" or name == "ethernet" or name == "ethernet-bng" or name == "ethernet-control" or name == "ethernet-features" or name == "ethernet-service" or name == "ipv4-network" or name == "ipv4-network-forwarding" or name == "ipv4-packet-filter" or name == "ipv4arp" or name == "ipv6-neighbor" or name == "ipv6-network" or name == "ipv6-packet-filter" or name == "l2-transport" or name == "lacp" or name == "lldp" or name == "mac-accounting" or name == "macsec" or name == "mlacp" or name == "mte-tunnel-attributes" or name == "mtus" or name == "net-flow" or name == "nv-satellite-access" or name == "nv-satellite-fabric-link" or name == "nv-satellite-fabric-network" or name == "nve" or name == "optics" or name == "otu" or name == "pbr" or name == "performance-management" or name == "portmode" or name == "pppoe" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "qos" or name == "service-policies" or name == "span-monitor-sessions" or name == "ssrp-session" or name == "statistics" or name == "subscriber" or name == "transport-profile-tunnel" or name == "tunnel-ip" or name == "tunnel-te-attributes" or name == "vlan-sub-configuration" or name == "vlan-trunk-configuration" or name == "wanphy" or name == "active" or name == "interface-name" or name == "bandwidth" or name == "description" or name == "interface-mode-non-physical" or name == "interface-virtual" or name == "laser-squelch" or name == "link-status" or name == "mac-addr" or name == "maintenance-embargo" or name == "perf-mon-disable" or name == "secondary-admin-state" or name == "shutdown" or name == "track-name" or name == "vrf"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "active"):
                self.active = value
                self.active.value_namespace = name_space
                self.active.value_namespace_prefix = name_space_prefix
            if(value_path == "interface-name"):
                self.interface_name = value
                self.interface_name.value_namespace = name_space
                self.interface_name.value_namespace_prefix = name_space_prefix
            if(value_path == "bandwidth"):
                self.bandwidth = value
                self.bandwidth.value_namespace = name_space
                self.bandwidth.value_namespace_prefix = name_space_prefix
            if(value_path == "description"):
                self.description = value
                self.description.value_namespace = name_space
                self.description.value_namespace_prefix = name_space_prefix
            if(value_path == "interface-mode-non-physical"):
                self.interface_mode_non_physical = value
                self.interface_mode_non_physical.value_namespace = name_space
                self.interface_mode_non_physical.value_namespace_prefix = name_space_prefix
            if(value_path == "interface-virtual"):
                self.interface_virtual = value
                self.interface_virtual.value_namespace = name_space
                self.interface_virtual.value_namespace_prefix = name_space_prefix
            if(value_path == "laser-squelch"):
                self.laser_squelch = value
                self.laser_squelch.value_namespace = name_space
                self.laser_squelch.value_namespace_prefix = name_space_prefix
            if(value_path == "link-status"):
                self.link_status = value
                self.link_status.value_namespace = name_space
                self.link_status.value_namespace_prefix = name_space_prefix
            if(value_path == "mac-addr"):
                self.mac_addr = value
                self.mac_addr.value_namespace = name_space
                self.mac_addr.value_namespace_prefix = name_space_prefix
            if(value_path == "maintenance-embargo"):
                self.maintenance_embargo = value
                self.maintenance_embargo.value_namespace = name_space
                self.maintenance_embargo.value_namespace_prefix = name_space_prefix
            if(value_path == "perf-mon-disable"):
                self.perf_mon_disable = value
                self.perf_mon_disable.value_namespace = name_space
                self.perf_mon_disable.value_namespace_prefix = name_space_prefix
            if(value_path == "secondary-admin-state"):
                self.secondary_admin_state = value
                self.secondary_admin_state.value_namespace = name_space
                self.secondary_admin_state.value_namespace_prefix = name_space_prefix
            if(value_path == "shutdown"):
                self.shutdown = value
                self.shutdown.value_namespace = name_space
                self.shutdown.value_namespace_prefix = name_space_prefix
            if(value_path == "track-name"):
                self.track_name = value
                self.track_name.value_namespace = name_space
                self.track_name.value_namespace_prefix = name_space_prefix
            if(value_path == "vrf"):
                self.vrf = value
                self.vrf.value_namespace = name_space
                self.vrf.value_namespace_prefix = name_space_prefix

    def has_data(self):
        for c in self.interface_configuration:
            if (c.has_data()):
                return True
        return False

    def has_operation(self):
        for c in self.interface_configuration:
            if (c.has_operation()):
                return True
        return self.yfilter != YFilter.not_set

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ifmgr-cfg:interface-configurations" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "interface-configuration"):
            for c in self.interface_configuration:
                segment = c.get_segment_path()
                if (segment_path == segment):
                    return c
            c = InterfaceConfigurations.InterfaceConfiguration()
            c.parent = self
            local_reference_key = "ydk::seg::%s" % segment_path
            self._local_refs[local_reference_key] = c
            self.interface_configuration.append(c)
            return c

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "interface-configuration"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = InterfaceConfigurations()
        return self._top_entity

